select 'rhnsat/start.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/start.sql
whenever sqlerror exit failure;

select 'rhnsat/packages/rhn_bel.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_bel.pks
create or replace
package rhn_bel
is
   function is_org_paid (
      org_id_in in number
   ) return number;
        function lookup_email_state (
                state_in in varchar2
        ) return number;
end;
/
show errors;

select 'rhnsat/packages/rhn_cache.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_cache.pks
create or replace package
rhn_cache
is
	version varchar2(100) := '';
	procedure update_perms_for_server(
		server_id_in in number
	);
	procedure update_perms_for_user(
		user_id_in in number
	);
	procedure update_perms_for_server_group(
		server_group_id_in in number
	);
end rhn_cache;
/
show errors

select 'rhnsat/tables/web_customer.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/web_customer.sql
create table
web_customer
(
	id		number
			constraint web_customer_id_nn not null
			constraint web_customer_id_pk primary key
				using index tablespace [[web_index_tablespace_2]]
				,
	name		varchar2(128)
			constraint web_customer_name_nn not null,
	oracle_customer_id number
			constraint web_customer_ocid_unq unique
				using index tablespace [[web_index_tablespace_2]]
				,
	oracle_customer_number number
			constraint web_customer_ocn_unq unique
				using index tablespace [[web_index_tablespace_2]]
				,
	customer_type	char(1) default ('P')
			constraint web_customer_type_nn not null
			constraint web_customer_type_list
				check (customer_type in ('B', 'P')),
        credit_application_completed varchar2(1),
	created		date default(sysdate)
			constraint web_customer_created_nn not null,
	modified	date default(sysdate)
			constraint web_customer_modified_nn not null
)
tablespace [[web_tablespace_2]]
	enable row movement
	;
create sequence web_customer_id_seq start with 2;
create unique index web_customer_name_uq_idx
    on web_customer(name)
    tablespace [[web_tablespace_2]]
  ;

select 'rhnsat/tables/rhnArchType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnArchType.sql
create sequence rhn_archtype_id_seq;
create table
rhnArchType
(
	id		number
			constraint rhn_archtype_id_nn not null
			constraint rhn_archtype_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(64)
			constraint rhn_archtype_label_nn not null,
	name		varchar2(128)
			constraint rhn_archtype_name_nn not null,
	created		date default(sysdate)
			constraint rhn_archtype_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_archtype_mod_nn not null
)
	enable row movement
  ;
create index rhn_archtype_label_id_idx
	on rhnArchType( label, id )
	tablespace [[64k_tbs]]
  ;
alter table rhnArchType add constraint rhn_archtype_label_uq unique ( label );
create or replace trigger
rhn_archtype_mod_trig
before insert or update on rhnArchType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnChannelArch.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelArch.sql
create table
rhnChannelArch
(
	id		number
			constraint rhn_carch_id_nn not null,
	label		varchar2(64)
			constraint rhn_carch_label_nn not null,
	arch_type_id	number
			constraint rhn_carch_atid_nn not null
			constraint rhn_carch_atid_fk
				references rhnArchType(id),
	name		varchar2(64)
			constraint rhn_carch_name_nn not null,
	created		date default(sysdate)
			constraint rhn_carch_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_carch_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_channel_arch_id_seq start with 500;
create index rhn_carch_id_l_n_idx
	on rhnChannelArch(id,label,name)
	tablespace [[2m_tbs]]
  ;
alter table rhnChannelArch add constraint rhn_carch_id_pk primary key (id);
create index rhn_carch_l_id_n_idx
	on rhnChannelArch(label,id,name)
	tablespace [[2m_tbs]]
  ;
alter table rhnChannelArch add constraint rhn_carch_label_uq unique ( label );
create or replace trigger
rhn_carch_mod_trig
before insert or update on rhnChannelArch
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnChannelProduct.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelProduct.sql
create table
rhnChannelProduct
(
	id		number
			constraint rhn_channelprod_id_nn not null
			constraint rhn_channelprod_id_pk primary key
				using index tablespace [[64k_tbs]],
    	product         varchar2(256)
	    	    	constraint rhn_channelprod_product_nn not null,
	version         varchar2(64)
	    	    	constraint rhn_channelprod_version_nn not null,
	beta            char(1) default 'N'
                        constraint rhn_channelprod_beta_nn not null
                        constraint rhn_channelprod_beta_ck
                                check (beta in ('Y', 'N')),
	created		date default (sysdate)
			constraint rhn_channelprod_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_channelprod_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_channelprod_id_seq;
create unique index rhn_channelprod_p_v_b_uq
	on rhnChannelProduct(product, version, beta)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnProductName.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnProductName.sql
create table rhnProductName
(
    id       number
             constraint rhn_productname_id_nn not null
             constraint rhn_productname_id_pk primary key,
    label    varchar2(128)
             constraint rhn_productname_lbl_nn not null,
    name     varchar2(128)
             constraint rhn_productname_name_nn not null,
    created  date default(sysdate)
             constraint product_name_created_nn not null,
    modified date default(sysdate)
             constraint product_name_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_productname_id_seq start with 101;
create unique index rhn_productname_label_uq
on rhnProductName(label)
  ;
create unique index rhn_productname_name_uq
on rhnProductName(name)
  ;
create or replace trigger product_name_mod_trig
before insert or update on rhnProductName
for each row
begin
    :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnChannel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannel.sql
create table
rhnChannel
(
	id		number
			constraint rhn_channel_id_nn not null
			constraint rhn_channel_id_pk primary key
				using index tablespace [[64k_tbs]],
	parent_channel	number
			constraint rhn_channel_parent_ch_fk
				references rhnChannel(id),
	org_id		number
			constraint rhn_channel_org_fk
				references web_customer(id),
        channel_arch_id number
			constraint rhn_channel_caid_nn not null
			constraint rhn_channel_caid_fk
				references rhnChannelArch(id),
	label		varchar2(128)
			constraint rhn_channel_label_nn not null,
	basedir		varchar2(256)
			constraint rhn_channel_basedir_nn not null,
	name		varchar2(64)
			constraint rhn_channel_name_nn not null,
	summary		varchar2(500)
			constraint rhn_channel_summary_nn not null,
	description	varchar2(4000),
    product_name_id number constraint rhn_channel_product_name_ch_fk
				references rhnProductName(id),
    	gpg_key_url     varchar2(256),
	gpg_key_id	varchar2(14),
	gpg_key_fp	varchar2(50),
	end_of_life     date,
    receiving_updates  char(1)
                       default 'Y'
                       constraint rhn_channel_ru_nn not null
                       constraint rhn_channel_ru_ck
                         check (receiving_updates in ('Y', 'N')),
	last_modified	date default (sysdate)
			constraint rhn_channel_lm_nn not null,
     channel_product_id number
			constraint rhn_channel_cpid_fk
				references rhnChannelProduct(id),
	channel_access	varchar2(10) default 'private',
	maint_name	varchar2(128),
	maint_email	varchar2(128),
	maint_phone	varchar2(128),
	support_policy	varchar2(256),
	created		date default (sysdate)
			constraint rhn_channel_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_channel_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_channel_id_seq start with 101;
create unique index rhn_channel_label_uq
	on rhnChannel(label)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_channel_name_uq
	on rhnChannel(name)
	tablespace [[64k_tbs]]
  ;
create index rhn_channel_org_idx
	on rhnChannel(org_id, id)
	tablespace [[64k_tbs]]
	nologging;
create index rhn_channel_url_id_idx
	on rhnChannel(label, id)
	tablespace [[64k_tbs]]
	nologging;
create index rhn_channel_parent_id_idx
	on rhnChannel(parent_channel, id)
	tablespace [[64k_tbs]]
	nologging;
create index rhn_channel_access_idx
	on rhnChannel(channel_access)
	tablespace [[64k_tbs]]
	nologging;
show errors

select 'rhnsat/tables/rhnChannelFamily.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelFamily.sql
create table
rhnChannelFamily
(
	id		number
			constraint rhn_channel_family_id_nn not null
			constraint rhn_channel_family_id_pk primary key
				using index tablespace [[64k_tbs]],
	org_id		number
			constraint rhn_channel_family_org_fk
				references web_customer(id)
				on delete cascade,
	name		varchar2(128)
			constraint rhn_channel_family_name_nn not null,
	label		varchar2(128)
			constraint rhn_channel_family_label_nn not null,
	product_url     varchar2(128) default 'http://www.redhat.com/products/'
			constraint rhn_channel_family_url_nn not null,
	created		date default (sysdate)
			constraint rhn_channel_family_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_channel_family_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_channel_family_id_seq start with 1000;
create unique index rhn_channel_family_label_uq
	on rhnChannelFamily(label)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_channel_family_name_uq
	on rhnChannelFamily(name)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_channel_family_mod_trig
before insert or update on rhnChannelFamily
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPublicChannelFamily.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPublicChannelFamily.sql
create table
rhnPublicChannelFamily
(
	channel_family_id	number
				constraint rhn_pubcf_cfid_nn not null
				constraint rhn_pubcf_cfid_fk
					references rhnChannelFamily(id),
	created			date default(sysdate)
				constraint rhn_pubcf_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_pubcf_mod_nn not null
)
	enable row movement
;
create unique index rhn_pubcf_co_uq on
	rhnPublicChannelFamily(channel_family_id)
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/web_contact.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/web_contact.sql
create table
web_contact
(
	id		number
			constraint web_contact_pk primary key
				using index tablespace [[web_index_tablespace_2]]
				,
	org_id		number
			constraint web_contact_org_nn not null
			constraint web_contact_org_fk
				references web_customer(id),
	login	   	varchar2(64)
			constraint web_contact_login_nn not null,
	login_uc	varchar2(64)
			constraint web_contact_login_uc_nn not null
			constraint web_contact_login_uc_unq unique
				using index tablespace [[web_index_tablespace_2]]
				,
	password	varchar2(38)
			constraint web_contact_password_nn not null,
	old_password	varchar2(38),
	created		date default(sysdate)
			constraint web_contact_created_nn not null,
	modified	date default(sysdate)
			constraint web_contact_modified_nn not null,
	oracle_contact_id number
			constraint web_contact_ocid_unq unique
				using index tablespace [[web_index_tablespace_2]]
				,
	ignore_flag	char(1) default('N')
			constraint web_contact_ignore_nn not null
			constraint web_contact_ignore_ck
				check (ignore_flag in ('N','Y'))
)
tablespace [[web_tablespace_2]]
enable row movement
;
create sequence web_contact_id_seq;

select 'rhnsat/tables/rhnPrivateChannelFamily.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPrivateChannelFamily.sql
create table
rhnPrivateChannelFamily
(
	channel_family_id	number
				constraint rhn_privcf_cfid_nn not null 
				constraint rhn_privcf_cfid_fk
					references rhnChannelFamily(id),
	org_id			number
				constraint rhn_privcf_oid_nn not null
				constraint rhn_privcf_oid_fk
					references web_customer(id)
					on delete cascade,
	max_members		number,
	current_members		number default (0)
				constraint rhn_privcf_curmembers_nn not null,
	created			date default (sysdate)
				constraint rhn_privcf_created_nn not null,
	modified		date default (sysdate)
				constraint rhn_privcf_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_privcf_oid_cfid_uq
	on rhnPrivateChannelFamily( org_id, channel_family_id )
	tablespace [[2m_tbs]]
  ;
create index rhn_cfperm_cfid_oid_idx on
	rhnPrivateChannelFamily( channel_family_id, org_id )
	tablespace [[2m_tbs]]
	nologging;

select 'rhnsat/views/rhnOrgChannelFamilyPermissions.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnOrgChannelFamilyPermissions.sql
create or replace view rhnOrgChannelFamilyPermissions as
	select	pcf.channel_family_id,
		u.org_id org_id,
		to_number(null) max_members,
		0 current_members,
		pcf.created,
		pcf.modified
	from	rhnPublicChannelFamily pcf,
		web_contact u
	union
	select	channel_family_id,
		org_id,
		max_members,
		current_members,
		created,
		modified
	from	rhnPrivateChannelFamily;

select 'rhnsat/tables/rhnServerArch.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerArch.sql
create table
rhnServerArch
(
	id		number
			constraint rhn_sarch_id_nn not null,
	label		varchar2(64)
			constraint rhn_sarch_label_nn not null,
	name		varchar2(64)
			constraint rhn_sarch_name_nn not null,
	arch_type_id	number
			constraint rhn_sarch_atid_nn not null
			constraint rhn_sarch_atid_fk
				references rhnArchType(id),
	created		date default(sysdate)
			constraint rhn_sarch_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_sarch_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_server_arch_id_seq start with 1000;
create index rhn_sarch_id_l_n_idx
	on rhnServerArch(id,label,name)
	tablespace [[2m_tbs]]
  ;
alter table rhnServerArch add constraint rhn_sarch_id_pk primary key (id);
create index rhn_sarch_l_id_n_idx
	on rhnServerArch(label,id,name)
	tablespace [[2m_tbs]]
  ;
alter table rhnServerArch add constraint rhn_sarch_label_uq unique ( label );
create or replace trigger
rhn_sarch_mod_trig
before insert or update on rhnServerArch
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnProvisionState.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnProvisionState.sql
create sequence rhn_provstate_id_seq;
create table
rhnProvisionState
(
	id		number
			constraint rhn_provstate_id_nn not null
			constraint rhn_provstate_id_pk primary key,
	label		varchar2(32)
			constraint rhn_provstate_label_nn not null,
	description	varchar2(256)
			constraint rhn_provstate_desc_nn not null,
	created		date default(sysdate)
			constraint rhn_provstate_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_provstate_mod_nn not null
)
	enable row movement
  ;
create index rhn_provstate_l_id_idx
	on rhnProvisionState(label, id)
	tablespace [[64k_tbs]]
  ;
alter table rhnProvisionState add constraint rhn_provstate_l_uq
	unique ( label );
create or replace trigger
rhn_provstate_mod_trig
before insert or update on rhnProvisionState
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServer.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServer.sql
create table
rhnServer
(
        id              number
			constraint rhn_server_id_nn not null
                        constraint rhn_server_id_pk primary key
	                        using index tablespace [[4m_tbs]]
				,
        org_id          number
                        constraint rhn_server_oid_nn not null
                        constraint rhn_server_oid_fk
                                references web_customer(id)
				on delete cascade,
        digital_server_id varchar2(64)
			constraint rhn_server_dsi_nn not null,
	server_arch_id	number
			constraint rhn_server_said_nn not null
			constraint rhn_server_said_fk
				references rhnServerArch(id),
        os              varchar2(64)
			constraint rhn_server_os_nn not null,
        release         varchar2(64)
			constraint rhn_server_release_nn not null,
        name            varchar2(128),
        description     varchar2(256),
        info            varchar2(128),
        secret          varchar2(32)
			constraint rhn_server_secret_nn not null,
	creator_id	number
			constraint rhn_server_creator_fk
				references web_contact(id)
				on delete set null,
	auto_deliver	char(1) default 'N'
	    	    	constraint rhn_server_auto_deliver_nn not null
			constraint rhn_server_deliver_ck
				check (auto_deliver in ('Y', 'N')),
	auto_update     char(1) default 'N'
	    	    	constraint rhn_server_auto_update_nn not null
			constraint rhn_server_update_ck
				check (auto_update in ('Y', 'N')),
	running_kernel  varchar2(64),
        last_boot       number default 0
			constraint rhn_server_lb_nn not null,
	provision_state_id number
			constraint rhn_server_psid_fk
				references rhnProvisionState(id),
	channels_changed date,
	cobbler_id              varchar2(64),
        created         date default (sysdate)
			constraint rhn_server_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_server_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_server_id_seq start with 1000010000 order;
create unique index rhn_server_dsid_uq
	on rhnServer(digital_server_id)
	tablespace [[8m_tbs]]
  ;
create index rhn_server_oid_id_idx
	on rhnServer(org_id,id)
        tablespace [[4m_tbs]]
	nologging;
create index rhn_server_created_id_idx
	on rhnServer(created,id)
        tablespace [[4m_tbs]]
	nologging;
create index rhn_server_creator_idx
	on rhnServer(creator_id)
	tablespace [[2m_tbs]]
	nologging;
create or replace trigger
rhn_server_mod_trig
before insert or update on rhnServer
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerChannel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerChannel.sql
create table rhnServerChannel
(
	server_id	number
			constraint rhn_sc_sid_nn not null 
			constraint rhn_sc_sid_fk
				references rhnServer(id),
	channel_id	number
			constraint rhn_sc_cid_nn not null 
			constraint rhn_sc_cid_fk
				references rhnChannel(id),
	created		date default(sysdate)
			constraint rhn_sc_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_sc_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_sc_sid_cid_uq
	on rhnServerChannel(server_id, channel_id)
	tablespace [[8m_tbs]]
  ;
create index rhn_sc_cid_sid_idx
	on rhnServerChannel(channel_id, server_id)
	tablespace [[8m_tbs]]
	nologging;

select 'rhnsat/packages/rhn_channel.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_channel.pks
CREATE OR REPLACE
PACKAGE rhn_channel
IS
	version varchar2(100) := '';
    CURSOR server_base_subscriptions(server_id_in NUMBER) IS
    	   SELECT C.id
	     FROM rhnChannel C, rhnServerChannel SC
	    WHERE C.id = SC.channel_id
	      AND SC.server_id = server_id_in
	      AND C.parent_channel IS NULL;
    CURSOR check_server_subscription(server_id_in NUMBER, channel_id_in NUMBER) IS 
           SELECT channel_id 
	     FROM rhnServerChannel 
	    WHERE server_id = server_id_in 
	      AND channel_id = channel_id_in;
    CURSOR check_server_parent_membership(server_id_in NUMBER, channel_id_in NUMBER) IS
    	   SELECT C.id
	     FROM rhnChannel C, rhnServerChannel SC
	    WHERE C.parent_channel = channel_id_in
	      AND C.id = SC.channel_id
	      AND SC.server_id = server_id_in;
    CURSOR channel_family_perm_cursor(channel_family_id_in NUMBER, org_id_in NUMBER) IS
           SELECT *
	     FROM rhnOrgChannelFamilyPermissions
	    WHERE channel_family_id = channel_family_id_in
	      AND org_id = org_id_in;
    PROCEDURE license_consent(channel_id_in IN NUMBER, user_id_in IN NUMBER, server_id_in IN NUMBER);
    FUNCTION get_license_path(channel_id_in IN NUMBER) RETURN VARCHAR2;
    PROCEDURE unsubscribe_server(server_id_in IN NUMBER, channel_id_in NUMBER, immediate_in NUMBER := 1, unsubscribe_children_in number := 0,
                                 deleting_server in number := 0 );
    PROCEDURE subscribe_server(server_id_in IN NUMBER, channel_id_in NUMBER, immediate_in NUMBER := 1, user_id_in number := null);
    function can_server_consume_virt_channl(
        server_id_in IN NUMBER,
        family_id_in in number)
    return number;
    FUNCTION guess_server_base(server_id_in IN NUMBER) RETURN NUMBER;
    FUNCTION base_channel_for_release_arch(release_in in varchar2, 
	server_arch_in in varchar2, org_id_in in number := -1, 
	user_id_in in number := null) RETURN number;
    FUNCTION base_channel_rel_archid(release_in in varchar2, 
	server_arch_id_in in number, org_id_in in number := -1, 
	user_id_in in number := null) RETURN number;
    FUNCTION channel_priority(channel_id_in in number) RETURN number;
    PROCEDURE bulk_subscribe_server(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER);
    PROCEDURE bulk_unsubscribe_server(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER);
    PROCEDURE bulk_server_base_change(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER);
    procedure bulk_server_basechange_from(
	set_label_in in varchar2,
	set_uid_in in number,
	old_channel_id_in in number,
	new_channel_id_in in number);
    procedure bulk_guess_server_base(
	set_label_in in varchar2,
	set_uid_in in number);
    procedure bulk_guess_server_base_from(
	set_label_in in varchar2,
	set_uid_in in number,
	channel_id_in in number);
    PROCEDURE clear_subscriptions(server_id_in IN NUMBER, deleting_server in number := 0 );
    FUNCTION available_family_subscriptions(channel_family_id_in IN NUMBER, org_id_in IN NUMBER) RETURN NUMBER;
    function channel_family_current_members(channel_family_id_in IN NUMBER,
                                            org_id_in IN NUMBER)
    return number;
    PROCEDURE update_family_counts(channel_family_id_in IN NUMBER, org_id_in IN NUMBER);
    FUNCTION family_for_channel(channel_id_in IN NUMBER) RETURN NUMBER;
    FUNCTION available_chan_subscriptions(channel_id_in IN NUMBER, org_id_in IN NUMBER) RETURN NUMBER;
    procedure entitle_customer(customer_id_in in number, channel_family_id_in in number, quantity_in in number);
    procedure set_family_maxmembers(customer_id_in in number, channel_family_id_in in number, quantity_in in number);
    procedure unsubscribe_server_from_family(server_id_in in number, channel_family_id_in in number);
    procedure delete_server_channels(server_id_in in number);
    procedure refresh_newest_package(channel_id_in in number, caller_in in varchar2 := '(unknown)');
    function get_org_id(channel_id_in in number) return number;
    PRAGMA RESTRICT_REFERENCES(get_org_id, WNDS, RNPS, WNPS);
    function get_org_access(channel_id_in in number, org_id_in in number) return number;
    PRAGMA RESTRICT_REFERENCES(get_org_access, WNDS, RNPS, WNPS);
    function get_cfam_org_access(cfam_id_in in number, org_id_in in number) return number;
    function user_role_check_debug(channel_id_in in number, user_id_in in number, role_in in varchar2, reason_out out varchar2)
    	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(user_role_check_debug, WNDS, RNPS, WNPS);
    function user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(user_role_check, WNDS, RNPS, WNPS);
    function loose_user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(loose_user_role_check, WNDS, RNPS, WNPS);
    function direct_user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(direct_user_role_check, WNDS, RNPS, WNPS);
    function shared_user_role_check(channel_id in number, user_id in number, role in varchar2)
    	RETURN NUMBER;
    PRAGMA RESTRICT_REFERENCES(shared_user_role_check, WNDS, RNPS, WNPS);
    function org_channel_setting(channel_id_in in number, org_id_in in number, setting_in in varchar2)
    	RETURN NUMBER;
    PROCEDURE update_channel ( channel_id_in in number, invalidate_ss in number := 0, 
                               date_to_use in date := sysdate );
    PROCEDURE  update_channels_by_package ( package_id_in in number, date_to_use in date := sysdate );
     PROCEDURE update_channels_by_errata ( errata_id_in number, date_to_use in date := sysdate );
    PRAGMA RESTRICT_REFERENCES(org_channel_setting, WNDS, RNPS, WNPS);
END rhn_channel;
/
SHOW ERRORS

select 'rhnsat/packages/rhn_config.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_config.pks
create or replace package
rhn_config
is
	procedure prune_org_configs (
		org_id_in in number,
		total_in in number
	);
	function insert_revision (
		revision_in in number,
		config_file_id_in in number,
		config_content_id_in in number,
		config_info_id_in in number,
		delim_start_in in varchar2 := '{@',
		delim_end_in in varchar2 := '@}',
      config_file_type_id_in number := 1
	) return number;
	procedure delete_revision (
		config_revision_id_in in number,
		org_id_in in number := -1
	);
	function get_latest_revision (
		config_file_id_in in number
	) return number;
	function insert_file (
		config_channel_id_in in number,
		name_in in varchar2
	) return number;
	procedure delete_file (
		config_file_id_in in number
	);
	function insert_channel (
		org_id_in in number,
		type_in in varchar2,
		name_in in varchar2,
		label_in in varchar2,
		description_in in varchar2
	) return number;
	procedure delete_channel (
		config_channel_id_in in number
	);
end rhn_config;
/
show errors

select 'rhnsat/packages/rhn_config_channel.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_config_channel.pks
CREATE OR REPLACE
PACKAGE rhn_config_channel
IS
    FUNCTION get_user_chan_access(config_channel_id_in IN NUMBER, user_id_in IN NUMBER) RETURN NUMBER;
    FUNCTION get_user_revision_access(config_revision_id_in IN NUMBER, user_id_in IN NUMBER) RETURN NUMBER;
    FUNCTION get_user_file_access(config_file_id_in IN NUMBER, user_id_in IN NUMBER) RETURN NUMBER;
    FUNCTION action_diff_revision_status(action_config_revision_id_in IN NUMBER) RETURN VARCHAR2;
END rhn_config_channel;
/
SHOW ERRORS

select 'rhnsat/packages/rhn_date_manip.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_date_manip.pks
create or replace
package rhn_date_manip
is
	periods_ago number;
	function get_reporting_period_start return date;
	function get_reporting_period_end return date;
end rhn_date_manip;
/
show errors

select 'rhnsat/tables/rhnServerGroupType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerGroupType.sql
create table
rhnServerGroupType
(
        id              number
			constraint rhn_servergrouptype_id_nn not null
                        constraint rhn_servergrouptype_id_pk primary key
                                using index tablespace [[64k_tbs]],
        label           varchar2(32)
                        constraint rhn_servergrouptype_label_nn not null,
        name            varchar2(64)
                        constraint rhn_servergrouptype_name_nn not null,
        created         date default(sysdate)
                        constraint rhn_servergrouptype_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_servergrouptype_mod_nn not null,
        permanent       char default('Y')
                        constraint rhn_servergrouptype_perm_ck 
                           check (permanent in ('Y','N'))
                        constraint rhn_servergrouptype_perm_nn not null,
        is_base         char default('Y')
                        constraint rhn_servergrouptype_isbase_ck
                           check (is_base in ('Y','N'))
                        constraint rhn_servergrouptype_isbase_nn not null
)
	enable row movement
  ;
create sequence rhn_servergroup_type_seq;
create unique index rhn_servergrouptype_label_uq 
	on rhnServerGroupType(label)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/packages/rhn_entitlements.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_entitlements.pks
create or replace
package rhn_entitlements
is
	body_version varchar2(100) := '';
   type ents_array is varray(10) of rhnServerGroupType.label%TYPE;
    procedure remove_org_entitlements (
        org_id_in number
    );
    function entitlement_grants_service (
	    entitlement_in in varchar2,
		service_level_in in varchar2
	) return number;
	function lookup_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number;
	function create_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number;
   function can_entitle_server ( 
      server_id_in   in number, 
      type_label_in  in varchar2
   )
   return number;
   function can_switch_base ( 
      server_id_in   in    integer, 
      type_label_in  in    varchar2
   )
   return number;
   function find_compatible_sg (
      server_id_in in number,
      type_label_in in varchar2,
      sgid_out out number
   )
   return boolean;
	procedure entitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	);
	procedure remove_server_entitlement (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled',
        repoll_virt_guests in number := 1
	);
	procedure unentitle_server (
		server_id_in in number
	);
    procedure repoll_virt_guest_entitlements(
        server_id_in in number
    );
	function get_server_entitlement (
		server_id_in in number
	) return ents_array;
	procedure modify_org_service (
		org_id_in in number,
		service_label_in in varchar2,
		enable_in in char
	);
    procedure set_customer_enterprise (
		customer_id_in in number
	);
	procedure set_customer_provisioning (
		customer_id_in in number
	);
	procedure set_customer_nonlinux (
		customer_id_in in number
	);
    procedure unset_customer_enterprise (
		customer_id_in in number
	);
	procedure unset_customer_provisioning (
		customer_id_in in number
	);
	procedure unset_customer_nonlinux (
		customer_id_in in number
	);
    procedure assign_system_entitlement(
        group_label_in in varchar2,
        from_org_id_in in number,
        to_org_id_in in number,
        quantity_in in number
    );
    procedure assign_channel_entitlement(
        channel_family_label_in in varchar2,
        from_org_id_in in number,
        to_org_id_in in number,
        quantity_in in number
    );
    procedure activate_system_entitlement(
        org_id_in in number,
        group_label_in in varchar2,
        quantity_in in number
    );
    procedure activate_channel_entitlement(
        org_id_in in number,
        channel_family_label_in in varchar2,
        quantity_in in number
    );
    procedure set_group_count (
		customer_id_in in number,	-- customer_id
		type_in in char,			-- 'U' or 'S'
		group_type_in in number,	-- rhn[User|Server]GroupType.id
		quantity_in in number		-- quantity
    );
    procedure set_family_count (
		customer_id_in in number,		-- customer_id
		channel_family_id_in in number,	-- 246
		quantity_in in number			-- 3
    );
    procedure entitle_last_modified_servers (
		customer_id_in in number,	-- customer_id
		type_label_in in varchar2,	-- 'enterprise_entitled'
		quantity_in in number		-- 3
    );
	procedure prune_everything (
		customer_id_in in number
	);
	procedure subscribe_newest_servers (
		customer_id_in in number
	);
end rhn_entitlements;
/
show errors

select 'rhnsat/tables/rhnException.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnException.sql
create table rhnException
(
    id	        number
    	    	constraint rhn_exc_id_nn not null
		constraint rhn_exc_id_pk primary key
		    using index tablespace [[64k_tbs]],
    label       varchar2(128)
    	    	constraint rhn_exc_label_nn not null,
    message     varchar2(2000)
                constraint rhn_exc_msg_nn not null
)
	enable row movement
  ;
create unique index rhn_exc_label_uq
	on rhnException(label)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/packages/rhn_exception.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_exception.pks
CREATE OR REPLACE
PACKAGE rhn_exception
IS
    CURSOR exception_details(exception_label_in VARCHAR2) IS
        SELECT id, label, message
          FROM rhnException
         WHERE label = exception_label_in;
    PROCEDURE raise_exception(exception_label_in IN VARCHAR2);
    procedure raise_exception_val(
	exception_label_in in varchar2,
        val_in in number
    );
    PROCEDURE lookup_exception(exception_label_in IN VARCHAR2, exception_id_out OUT NUMBER, exception_message_out OUT VARCHAR2);
END rhn_exception;
/
SHOW ERRORS

select 'rhnsat/packages/rhn_exception.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_exception.pkb
CREATE OR REPLACE
PACKAGE BODY rhn_exception
IS
    PROCEDURE lookup_exception(exception_label_in IN VARCHAR2, exception_id_out OUT NUMBER, exception_message_out OUT VARCHAR2)
    IS
        return_string     VARCHAR2(2000);
    BEGIN
        FOR exc IN exception_details(exception_label_in)
        LOOP
            exception_id_out := exc.id;
            exception_message_out := '(' || exc.label || ')' || ' - ' || exc.message;
        END LOOP exception_details;
        IF exception_message_out IS NULL
        THEN
            RAISE NO_DATA_FOUND;
        END IF;
    END lookup_exception;
    PROCEDURE raise_exception(exception_label_in IN VARCHAR2)
    IS
        exception_id        NUMBER;
        exception_message   VARCHAR2(2000);
    BEGIN
        lookup_exception(exception_label_in, exception_id, exception_message);
        RAISE_APPLICATION_ERROR(exception_id, exception_message);    
    EXCEPTION
        WHEN NO_DATA_FOUND
        THEN
        RAISE_APPLICATION_ERROR(-20001, 'Unable to lookup exception with label (' || exception_label_in || ')');    
    END raise_exception;
    procedure raise_exception_val(
	exception_label_in in varchar2,
	val_in in number
    ) is
	exception_id        NUMBER;
	exception_message   VARCHAR2(2000);
    begin
	lookup_exception(exception_label_in, exception_id, exception_message);
	RAISE_APPLICATION_ERROR(exception_id, exception_message || ' (' || val_in || ')');
    exception
	when no_data_found then
	RAISE_APPLICATION_ERROR(-20001, 'Unable to lookup exception with label (' || exception_label_in || ')');
    end raise_exception_val;
END rhn_exception;
/
SHOW ERRORS

select 'rhnsat/tables/rhnServerGroup.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerGroup.sql
create table
rhnServerGroup
(
        id              number
                        constraint rhn_servergroup_id_nn not null
                        constraint rhn_servergroup_id_pk primary key
                                using index tablespace [[4m_tbs]]
				,
        name            varchar2(64)
                        constraint rhn_servergroup_name_nn not null,
        description     varchar2(1024)
                        constraint rhn_servergroup_desc_nn not null,
        max_members     number,
	current_members number default 0
                        constraint rhn_servergroup_curmembers_nn not null,
        group_type      number
                        constraint rhn_servergroup_type_fk
                                references rhnServerGroupType(id),
        org_id          number
                        constraint rhn_servergroup_oid_nn not null
                        constraint rhn_servergroup_oid_fk
                                references web_customer(id)
				on delete cascade,
        created         date default(sysdate)
                        constraint rhn_servergroup_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_servergroup_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_server_group_id_seq;
create unique index rhn_servergroup_oid_name_uq
	on rhnServerGroup(org_id, name)
	tablespace [[4m_tbs]]
  ;

select 'rhnsat/packages/rhn_org.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_org.pks
CREATE OR REPLACE
PACKAGE rhn_org
IS
	version varchar2(100) := '';
    CURSOR server_group_by_label(org_id_in NUMBER, group_label_in VARCHAR2) IS
    	   SELECT SG.*
	     FROM rhnServerGroupType SGT,
	     	  rhnServerGroup SG
	    WHERE SG.group_type = SGT.id
	      AND SGT.label = group_label_in
	      AND SG.org_id = org_id_in;
    FUNCTION find_server_group_by_type(org_id_in NUMBER, 
                                       group_label_in VARCHAR2) 
    RETURN NUMBER;
    procedure delete_org(org_id_in in number);
    procedure delete_user(user_id_in in number, deleting_org in number := 0);
END rhn_org;
/
SHOW ERRORS

select 'rhnsat/tables/rhnPackageName.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageName.sql
CREATE TABLE
rhnPackageName
(
        id              number
			constraint rhn_pn_id_nn not null
                        constraint rhn_pn_id_pk primary key
			using index tablespace [[2m_tbs]],
        name            varchar2(128)
			constraint rhn_pn_name_nn not null
)
	enable row movement
  ;
create unique index rhn_pn_name_uq
	on rhnPackageName(name)
	tablespace [[2m_tbs]]
  ;
create sequence rhn_pkg_name_seq;

select 'rhnsat/packages/rpm.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rpm.pks
CREATE OR REPLACE PACKAGE rpm AS
    FUNCTION vercmp(
        e1 VARCHAR2, v1 VARCHAR2, r1 VARCHAR2, 
        e2 VARCHAR2, v2 VARCHAR2, r2 VARCHAR2)
    RETURN NUMBER
        DETERMINISTIC
        PARALLEL_ENABLE;
    PRAGMA RESTRICT_REFERENCES(vercmp, WNDS, RNDS);
    FUNCTION vercmpCounter
    return NUMBER
        PARALLEL_ENABLE;
    PRAGMA RESTRICT_REFERENCES(vercmpCounter, WNDS, RNDS);
    FUNCTION vercmpResetCounter
    return NUMBER
        PARALLEL_ENABLE;
    PRAGMA RESTRICT_REFERENCES(vercmpResetCounter, WNDS, RNDS);
END rpm;
/
SHOW ERRORS;

select 'rhnsat/packages/rpm.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rpm.pkb
CREATE OR REPLACE PACKAGE BODY rpm AS
    vercmp_counter NUMBER := 0;
    FUNCTION isdigit(ch CHAR)
    RETURN BOOLEAN
    deterministic
    IS
    BEGIN
        if ascii(ch) between ascii('0') and ascii('9')
        then
            return TRUE;
        end if;
        return FALSE;
    END isdigit;
    FUNCTION isalpha(ch CHAR)
    RETURN BOOLEAN
    deterministic
    IS
    BEGIN
        if ascii(ch) between ascii('a') and ascii('z') or 
            ascii(ch) between ascii('A') and ascii('Z')
        then
            return TRUE;
        end if;
        return FALSE;
    END isalpha;
    FUNCTION isalphanum(ch CHAR)
    RETURN BOOLEAN
    deterministic
    IS
    BEGIN
        if ascii(ch) between ascii('a') and ascii('z') or 
            ascii(ch) between ascii('A') and ascii('Z') or
            ascii(ch) between ascii('0') and ascii('9')
        then
            return TRUE;
        end if;
        return FALSE;
    END isalphanum;
    FUNCTION rpmstrcmp (string1 IN VARCHAR2, string2 IN VARCHAR2)
    RETURN NUMBER
    deterministic
    IS
        digits CHAR(10) := '0123456789';
        lc_alpha CHAR(27) := 'abcdefghijklmnopqrstuvwxyz';
        uc_alpha CHAR(27) := 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
        alpha CHAR(54) := lc_alpha || uc_alpha;
        str1 VARCHAR2(32767) := string1;
        str2 VARCHAR2(32767) := string2;
        one VARCHAR2(32767);
        two VARCHAR2(32767);
        isnum BOOLEAN;
    BEGIN
        if str1 is NULL or str2 is NULL
        then
            raise VALUE_ERROR;
        end if;
        if str1 = str2
        then
            return 0;
        end if;
        one := str1;
        two := str2;
        <<segment_loop>>
        while one is not null and two is not null
        loop
            declare
                segm1 VARCHAR2(32767);
                segm2 VARCHAR2(32767);
            begin
                while one is not null and not isalphanum(one)
                loop
                    one := substr(one, 2);
                end loop;
                while two is not null and not isalphanum(two)
                loop
                    two := substr(two, 2);
                end loop;
                str1 := one;
                str2 := two;
                /* grab first completely alpha or completely numeric segment */
                /* leave one and two pointing to the start of the alpha or numeric */
                /* segment and walk str1 and str2 to end of segment */
                if str1 is not null and isdigit(str1)
                then
                    str1 := ltrim(str1, digits);
                    str2 := ltrim(str2, digits);
                    isnum := true;
                else
                    str1 := ltrim(str1, alpha);
                    str2 := ltrim(str2, alpha);
                    isnum := false;
                end if;
                if str1 is not null
                then segm1 := substr(one, 1, length(one) - length(str1));
                else segm1 := one;
                end if;
                if str2 is not null
                then segm2 := substr(two, 1, length(two) - length(str2));
                else segm2 := two;
                end if;
                /* take care of the case where the two version segments are */
                /* different types: one numeric and one alpha */
                if segm1 is null then return -1; end if; /* arbitrary */
                if segm2 is null then
					if isnum then
						return 1;
					else
						return -1;
					end if;
				end if;
                if isnum
                then
                    /* this used to be done by converting the digit segments */
                    /* to ints using atoi() - it's changed because long */
                    /* digit segments can overflow an int - this should fix that. */
                    /* throw away any leading zeros - it's a number, right? */
                    segm1 := ltrim(segm1, '0');
                    segm2 := ltrim(segm2, '0');
                    /* whichever number has more digits wins */
                    if segm1 is null and segm2 is not null
                    then
                        return -1;
                    end if;
                    if segm1 is not null and segm2 is null
                    then
                        return 1;
                    end if;
                    if length(segm1) > length(segm2) then return 1; end if;
                    if length(segm2) > length(segm1) then return -1; end if;
                end if;
                /* strcmp will return which one is greater - even if the two */
                /* segments are alpha or if they are numeric.  don't return  */
                /* if they are equal because there might be more segments to */
                /* compare */
                if segm1 < segm2 then return -1; end if;
                if segm1 > segm2 then return 1; end if;
                one := str1;
                two := str2;
            end;
        end loop segment_loop;
        /* this catches the case where all numeric and alpha segments have */
        /* compared identically but the segment sepparating characters were */
        /* different */
        if one is null and two is null then return 0; end if;
        /* whichever version still has characters left over wins */
        if one is null then return -1; end if;
        return 1;
    END rpmstrcmp;
    FUNCTION vercmp(
        e1 VARCHAR2, v1 VARCHAR2, r1 VARCHAR2, 
        e2 VARCHAR2, v2 VARCHAR2, r2 VARCHAR2)
    RETURN NUMBER
    IS
        rc NUMBER;
    BEGIN
        DECLARE
          ep1 NUMBER;
          ep2 NUMBER;
          BEGIN
            vercmp_counter := vercmp_counter + 1;
            if e1 is null then
              ep1 := 0;
            else
              ep1 := TO_NUMBER(e1);
            end if;
            if e2 is null then
              ep2 := 0;
            else
              ep2 := TO_NUMBER(e2);
            end if;
            if ep1 < ep2 then return -1; end if;
            if ep1 > ep2 then return 1; end if;
            rc := rpmstrcmp(v1, v2);
            if rc != 0 then return rc; end if;
           return rpmstrcmp(r1, r2);
         END;
    END vercmp;
    FUNCTION vercmpCounter
    RETURN NUMBER
    IS
    BEGIN
        return vercmp_counter;
    END vercmpCounter;
    FUNCTION vercmpResetCounter
    RETURN NUMBER
    IS
        result NUMBER;
    BEGIN
        result := vercmp_counter;
        vercmp_counter := 0;
        return result;
    END vercmpResetCounter;
END rpm;
/
SHOW ERRORS;

select 'rhnsat/class/evr_t.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/class/evr_t.sql
create or replace type evr_t AS OBJECT (
        epoch           varchar2(16),
        version         varchar2(512),
        release         varchar2(512),
        ORDER MEMBER FUNCTION compare (other_in IN evr_t)
          RETURN INTEGER,
        MEMBER FUNCTION as_vre RETURN VARCHAR2,
        MEMBER FUNCTION as_vre_simple RETURN VARCHAR2
);
/
show errors
create or replace type body evr_t
as
order member function compare (other_in IN evr_t)
  return integer
is
begin
        return rpm.vercmp(SELF.epoch, SELF.version, SELF.release,
                          other_in.epoch, other_in.version, other_in.release);
end;
member function as_vre
  return varchar2
is
begin
        return self.version || '-' || SELF.release || ':' || SELF.epoch;
end;
member function as_vre_simple
  return VARCHAR2
is
    vre_out VARCHAR2(256);
begin
    vre_out := self.version || '-' || self.release;
    if self.epoch is not null
    then
        vre_out := vre_out || ':' || self.epoch;
    end if;
    return vre_out;
end;
end;
/
show errors

select 'rhnsat/tables/rhnPackageEVR.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageEVR.sql
create table
rhnPackageEVR
(
        id              number
			constraint rhn_pe_id_nn not null
                        constraint rhn_pe_id_pk primary key,
        epoch           varchar2(16),
        version         varchar2(512)
			constraint rhn_pe_version_nn not null,
        release         varchar2(512)
			constraint rhn_pe_release_nn not null,
        evr             evr_t
			constraint rhn_pe_evr_nn not null
)
	enable row movement
  ;
create sequence rhn_pkg_evr_seq;
create unique index rhn_pe_v_r_e_uq
	on rhnPackageEVR(version, release, epoch)
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnPackageArch.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageArch.sql
create table
rhnPackageArch
(
	id		number
			constraint rhn_parch_id_nn not null,
	label		varchar2(64)
			constraint rhn_parch_label_nn not null,
	name		varchar2(64)
			constraint rhn_parch_name_nn not null,
	arch_type_id	number
			constraint rhn_parch_atid_nn not null
			constraint rhn_parch_atid_fk
				references rhnArchType(id),
	created		date default(sysdate)
			constraint rhn_parch_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_parch_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_package_arch_id_seq start with 100;
create index rhn_parch_id_l_n_idx
	on rhnPackageArch(id,label,name)
	tablespace [[2m_tbs]]
  ;
alter table rhnPackageArch add constraint rhn_parch_id_pk primary key (id);
create index rhn_parch_l_id_n_idx
	on rhnPackageArch(label,id,name)
	tablespace [[2m_tbs]]
  ;
alter table rhnPackageArch add constraint rhn_parch_label_uq unique ( label );
create or replace trigger
rhn_parch_mod_trig
before insert or update on rhnPackageArch
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPackageGroup.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageGroup.sql
create table
rhnPackageGroup
(
        id              number
			constraint rhn_package_group_id_nn not null
                        constraint rhn_package_group_id_pk primary key
                        using index tablespace [[2m_tbs]],
        name            varchar2(100)
			constraint rhn_package_group_name_nn not null,
        created         date default(sysdate)
			constraint rhn_package_group_created_nn not null,
        modified        date default(sysdate)
			constraint rhn_package_group_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_package_group_id_seq;
create unique index rhn_package_group_name_uq
	on rhnPackageGroup(name)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_package_group_mod_trig
before insert or update on rhnPackageGroup
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnSourceRPM.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSourceRPM.sql
create table
rhnSourceRPM
(
	id		number
			constraint rhn_sourceRPM_id_nn not null
			constraint rhn_sourceRPM_id_pk primary key
			using index tablespace [[64k_tbs]],
	name		varchar2(128)
			constraint rhn_sourcerpm_name_nn not null
)
	enable row movement
  ;
create unique index rhn_srpm_name_uq
	on rhnSourceRPM(name)
	tablespace [[64k_tbs]]
  ;
create sequence rhn_sourcerpm_id_seq;

select 'rhnsat/tables/rhnPackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackage.sql
create table
rhnPackage
(
        id              number
			constraint rhn_package_id_nn not null
                        constraint rhn_package_id_pk primary key
				using index tablespace [[4m_tbs]]
				,
        org_id          number
                        constraint rhn_package_oid_fk
				references web_customer(id)
				on delete cascade,
        name_id         number
			constraint rhn_package_nid_nn not null
                        constraint rhn_package_nid_fk
				references rhnPackageName(id),
        evr_id          number
			constraint rhn_package_eid_nn not null
                        constraint rhn_package_eid_fk
				references rhnPackageEvr(id),
	package_arch_id	number
			constraint rhn_package_paid_nn not null
			constraint rhn_package_paid_fk
				references rhnPackageArch(id),
        package_group   number
                        constraint rhn_package_group_fk
				references rhnPackageGroup(id),
        rpm_version     varchar2(16),
        description     varchar2(4000),
        summary         varchar2(4000),
        package_size    number
			constraint rhn_package_pkg_size_nn not null,
        payload_size    number,
        build_host      varchar2(256),
        build_time      date,
	source_rpm_id	number
			constraint rhn_package_srcrpmid_fk
				references rhnSourceRPM(id),
        md5sum          varchar2(64)
			constraint rhn_package_md5_nn not null,
        vendor          varchar2(64)
			constraint rhn_package_vendor_nn not null,
        payload_format  varchar2(32),
        compat          number(1) default 0
                        constraint rhn_package_compat_check
                                check (compat in (1,0)),
        path            varchar2(1000),
	header_sig	varchar2(64),
	copyright	varchar2(64),
	cookie		varchar2(128),
	last_modified	date default (sysdate)
			constraint rhn_package_lm_nn not null,
        created         date default (sysdate)
			constraint rhn_package_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_package_modified_nn not null,
        header_start    number default -1
                        constraint rhn_package_hs_nn not null,
        header_end      number default -1
                        constraint rhn_package_he_nn not null
)
	enable row movement
  ;
create sequence rhn_package_id_seq;
create unique index rhn_package_md5_oid_uq
	on rhnPackage(md5sum, org_id)
        tablespace [[2m_tbs]]
  ;
create index rhn_package_oid_id_idx
	on rhnPackage(org_id, id)
	tablespace [[64k_tbs]]
	nologging;
create index rhn_package_id_nid_paid_idx
	on rhnPackage(id,name_id, package_arch_id)
	tablespace [[2m_tbs]]
	nologging;
create index rhn_package_nid_id_idx
	on rhnPackage(name_id,id)
	tablespace [[2m_tbs]]
	nologging;
create or replace trigger
rhn_package_mod_trig
before insert or update on rhnPackage
for each row
begin
	if :new.last_modified = :old.last_modified then
		:new.last_modified := sysdate;
	end if;       
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnChannelPackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelPackage.sql
create table
rhnChannelPackage
(
	channel_id	number
			constraint rhn_cp_cid_nn not null 
			constraint rhn_cp_cid_fk
				references rhnChannel(id) on delete cascade,
	package_id	number
			constraint rhn_cp_pid_nn not null
			constraint rhn_cp_pid_fk
				references rhnPackage(id),
	created		date default (sysdate)
			constraint rhn_cp_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cp_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_cp_cp_uq
	on rhnChannelPackage(channel_id,package_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_cp_pc_idx 
       on rhnChannelPackage(package_id, channel_id)
       tablespace [[64k_tbs]]
       nologging;

select 'rhnsat/packages/rhn_package.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_package.pks
CREATE OR REPLACE
PACKAGE rhn_package
IS
    CURSOR channel_occupancy_cursor(package_id_in IN NUMBER) IS
    SELECT C.id channel_id, C.name channel_name
      FROM rhnChannel C,
      	   rhnChannelPackage CP
     WHERE C.id = CP.channel_id
       AND CP.package_id = package_id_in
     ORDER BY C.name DESC;
    FUNCTION canonical_name(name_in IN VARCHAR2, evr_in IN EVR_T, 
    	                    arch_in IN VARCHAR2 := NULL)
      RETURN VARCHAR2
      DETERMINISTIC;
    FUNCTION channel_occupancy_string(package_id_in IN NUMBER, separator_in VARCHAR2 := ', ') 
      RETURN VARCHAR2;
END rhn_package;
/
SHOW ERRORS

select 'rhnsat/packages/rhn_quota.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_quota.pks
create or replace package
rhn_quota
is
	function recompute_org_quota_used (
		org_id_in in number
	) return number;
	function get_org_for_config_content (
		config_content_id_in in number
	) return number;
	procedure set_org_quota_total (
		org_id_in in number,
		total_in in number
	);
	procedure update_org_quota (
		org_id_in in number
	);
end rhn_quota;
/
show errors

select 'rhnsat/packages/rhn_server.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_server.pks
create or replace
package rhn_server
is
    function system_service_level(
    	server_id_in in number,
	service_level_in in varchar2
    ) return number;	    
    function can_change_base_channel(
    	server_id_in in number
    ) return number;
    procedure set_custom_value(
    	server_id_in in number,
	user_id_in in number,
	key_label_in varchar2,
     	value_in in varchar2
    );
    function bulk_set_custom_value(
    	key_label_in in varchar2,
	value_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    ) return integer;
    procedure snapshot_server(
    	server_id_in in number,
	reason_in in varchar2
    );
    procedure bulk_snapshot(
    	reason_in in varchar2,
    	set_label_in in varchar2,
	set_uid_in in number
    );
    procedure tag_delete(
    	server_id_in in number,
	tag_id_in in number
    );
    procedure tag_snapshot(
    	snapshot_id_in in number,
	org_id_in in number,
    	tagname_in in varchar2
    );
    procedure bulk_snapshot_tag(
    	org_id_in in number,
    	tagname_in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    );
    procedure remove_action(
	server_id_in in number,
	action_id_in in number
    );
    function check_user_access(server_id_in in number, user_id_in in number) return number;
    function can_server_consume_virt_slot(server_id_in in number,
                                              group_type_in in
                                              rhnServerGroupType.label%TYPE)
    return number;                                              
    procedure insert_into_servergroup (
	server_id_in in number,
	server_group_id_in in number
    );
    function insert_into_servergroup_maybe (
	server_id_in in number,
	server_group_id_in in number
    ) return number;
	procedure insert_set_into_servergroup (
	server_group_id_in in number,
	user_id_in in number,
	set_label_in in varchar2
	);
    procedure delete_from_servergroup (
	server_id_in in number,
	server_group_id_in in number
    );
	procedure delete_set_from_servergroup (
	server_group_id_in in number,
	user_id_in in number,
	set_label_in in varchar2
	);
	procedure clear_servergroup (
	server_group_id_in in number
	);
	procedure delete_from_org_servergroups (
	server_id_in in number
	);
	function get_ip_address (
		server_id_in in number
	) return varchar2;
end rhn_server;
/
SHOW ERRORS

select 'rhnsat/tables/rhnSet.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSet.sql
create table
rhnSet
(
	user_id		number
			constraint rhn_set_user_nn not null
			constraint rhn_set_user_fk
				   references web_contact(id)
				   on delete cascade,
	label		varchar2(32)
			constraint rhn_set_label_nn not null,
	element		number
			constraint rhn_set_elem_nn not null,
	element_two	number,
	element_three	number,
	constraint	rhn_set_user_label_elem_unq
		UNIQUE(user_id, label, element, element_two, element_three)
		using index tablespace [[8m_tbs]]
)
	enable row movement
  ;
alter table rhnSet nologging;

select 'rhnsat/packages/rhn_set.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_set.pks
CREATE OR REPLACE
PACKAGE rhn_set
IS
    CURSOR set_iterator(set_label_in IN VARCHAR2, set_user_id_in IN NUMBER) IS
    	   SELECT user_id, label, element, element_two
	     FROM rhnSet
	    WHERE label = set_label_in
	      AND user_id = set_user_id_in;
END rhn_set;
/
SHOW ERRORS

select 'rhnsat/packages/rhn_user.pks' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_user.pks
create or replace
package rhn_user
is
	version varchar2(100) := '';
    function check_role(user_id_in in number, role_in in varchar2) return number;
    PRAGMA RESTRICT_REFERENCES(check_role, WNDS, RNPS, WNPS);
    function check_role_implied(user_id_in in number, role_in in varchar2) return number;
    PRAGMA RESTRICT_REFERENCES(check_role_implied, WNDS, RNPS, WNPS);
    function get_org_id(user_id_in in number) return number;
    PRAGMA RESTRICT_REFERENCES(get_org_id, WNDS, RNPS, WNPS);
	function find_mailable_address(user_id_in in number) return varchar2;
	procedure add_servergroup_perm(
		user_id_in in number,
		server_group_id_in in number
	);
	procedure remove_servergroup_perm(
		user_id_in in number,
		server_group_id_in in number
	);
	procedure add_to_usergroup(
		user_id_in in number,
		user_group_id_in in number
	);
	procedure add_users_to_usergroups(
		user_id_in in number
	);
	procedure remove_from_usergroup(
		user_id_in in number,
		user_group_id_in in number
	);
	procedure remove_users_from_servergroups(
		user_id_in in number
	);
end rhn_user;
/
SHOW ERRORS

select 'rhnsat/tables/rhn_command_groups.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_groups.sql
create table 
rhn_command_groups
(
    group_name  varchar2 (10)
        constraint rhn_cmdgr_group_name_nn not null
        constraint rhn_cmdgr_group_name_pk primary key
                using index tablespace [[64k_tbs]],
    description varchar2 (80)
)
    enable row movement
  ;
comment on table rhn_command_groups 
    is 'CMDGR  Command group definitions';

select 'rhnsat/tables/rhn_command_class.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_class.sql
create table 
rhn_command_class
(
    class_name  varchar2 (40)
        constraint rhn_comcl_class_name_nn not null
        constraint rhn_comcl_class_name_pk primary key
            using index tablespace [[2m_tbs]]
)
    enable row movement
  ;
COMMENT ON TABLE rhn_command_class IS 'COMCL Command classes';

select 'rhnsat/tables/rhn_command_requirements.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_requirements.sql
create table 
rhn_command_requirements
(
    name        varchar2 (40)
        constraint rhn_creqs_name_nn not null
        constraint rhn_creqs_name_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    description varchar2 (4000)
        constraint rhn_creqs_description_nn not null
)
    enable row movement
  ;
comment on table rhn_command_requirements 
    is 'creqs storage for system requirements for commands';

select 'rhnsat/tables/rhn_command.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command.sql
create table 
rhn_command 
(
    recid               number   (12)                   
        constraint rhn_cmmnd_recid_nn not null
        constraint rhn_cmmnd_recid_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    name                varchar2 (40)                   
        constraint rhn_cmmnd_name_nn not null,
    description         varchar2 (80)                   
        constraint rhn_cmmnd_desc_nn not null,
    group_name          varchar2 (40),       
    allowed_in_suite    char     (1) default '1' 
        constraint rhn_cmmnd_allowed_nn not null,
    command_class       varchar2 (255) default '/var/lib/nocpulse/libexec/plugin'
        constraint rhn_cmmnd_class_nn not null,
    enabled             char     (1) default '1' 
        constraint rhn_cmmnd_enabled_nn not null,
    for_host_probe      char     (1) default '0' 
        constraint rhn_cmmnd_host_probe_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date,
    system_requirements varchar2 (40),
    version_support     varchar2 (1024),
    help_url            varchar2 (1024)
)
    enable row movement
  ;
comment on table rhn_command 
    is 'CMMND A command that probes can run';
comment on column rhn_command.command_class 
    is 'Program to run ';
comment on column rhn_command.enabled 
    is 'Whether command should be usable';
comment on column rhn_command.for_host_probe 
    is 'Whether this is one of the host-alive checks';
create unique index rhn_cmmnd_name_uq
    on rhn_command ( name )
    tablespace [[2m_tbs]]
  ;
create unique index rhn_cmmnd_recid_comm_cl_uq
    on rhn_command ( recid, command_class )
    tablespace [[2m_tbs]]
  ;
alter table rhn_command
    add constraint rhn_cmmnd_name_uq
    unique ( recid, command_class );
alter table rhn_command
    add constraint rhn_cmmnd_cmdgr_group_name_fk
    foreign key ( group_name )
    references rhn_command_groups( group_name );
alter table rhn_command
    add constraint rhn_cmmnd_comcl_class_name_fk
    foreign key ( command_class )
    references rhn_command_class( class_name );
alter table rhn_command
    add constraint rhn_cmmnd_sys_reqs_fk
    foreign key ( system_requirements )
    references rhn_command_requirements( name )
    on delete cascade;
create sequence rhn_commands_recid_seq
    start with 305;

select 'rhnsat/tables/rhn_probe_types.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_probe_types.sql
create table 
rhn_probe_types
(
    probe_type          varchar2 (20)
        constraint rhn_prbtp_probe_type_nn not null
        constraint rhn_prbtp_probe_type_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    type_description    varchar2 (200)
        constraint rhn_prbtp_type_desc_nn not null
)
    enable row movement
  ;
comment on table rhn_probe_types 
    is 'prbtp  probe types';

select 'rhnsat/tables/rhn_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_probe.sql
create table 
rhn_probe
(
    recid                            number   (12)
        constraint rhn_probe_recid_nn not null
        constraint rhn_probe_recid_pk primary key
            using index tablespace [[8m_tbs]]
            ,
    probe_type                       varchar2 (15)
        constraint rhn_probe_probe_type_nn not null,
    description                      varchar2 (255)
	constraint rhn_probe_description_nn not null,
    customer_id                      number   (12)
        constraint rhn_probe_cust_id_nn not null,
    command_id                       number   (16)
        constraint rhn_probe_command_id_nn not null,
    contact_group_id                 number   (12),
    notify_critical                  char     (1),
    notify_warning                   char     (1),
    notify_unknown                   char     (1),
    notify_recovery                  char     (1),
    notification_interval_minutes    number   (16)
        constraint rhn_probe_notif_int_nn not null,
    check_interval_minutes           number   (16)
        constraint rhn_probe_chk_int_nn not null,
    retry_interval_minutes           number   (16)
        constraint rhn_probe_retry_int_nn not null,
    max_attempts                     number   (16),
    last_update_user                 varchar2 (40),
    last_update_date                 date
)
    enable row movement
  ;
comment on table rhn_probe 
    is 'probe  probe definitions';
create unique index rhn_probe_recid_probe_type_uq 
    on rhn_probe ( recid, probe_type )
    tablespace [[8m_tbs]]
  ;
create index rhn_probe_check_command_id_idx 
    on rhn_probe ( command_id )
    tablespace [[8m_tbs]]
  ;
create index rhn_probe_customer_id_idx 
    on rhn_probe ( customer_id )
    tablespace [[8m_tbs]]
  ;
create index rhn_probe_probe_type_idx 
    on rhn_probe ( probe_type )
    tablespace [[8m_tbs]]
  ;
create index rhn_probe_contact_grp_idx 
    on rhn_probe ( contact_group_id )
    tablespace [[8m_tbs]]
  ;
alter table rhn_probe 
    add constraint rhn_probe_recid_probe_type_uq 
    unique ( recid, probe_type );
alter table rhn_probe
    add constraint rhn_probe_cmmnd_command_id_fk
    foreign key ( command_id )
    references rhn_command( recid );
alter table rhn_probe
    add constraint rhn_probe_cstmr_customer_id_fk
    foreign key ( customer_id )
    references web_customer( id );
alter table rhn_probe
    add constraint rhn_probe_prbtp_probe_type_fk
    foreign key ( probe_type )
    references rhn_probe_types( probe_type );
create sequence rhn_probes_recid_seq;

select 'rhnsat/tables/rhn_command_target.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_target.sql
create table 
    rhn_command_target
(
    recid       number   (12)
        constraint rhn_cmdtg_recid_nn not null,
    target_type varchar2 (10)
        constraint rhn_cmdtg_target_ty_nn not null
        constraint cmdtg_target_type_ck check
            (target_type in ('cluster','node')),
    customer_id number   (12)
        constraint rhn_cmdtg_cust_id_nn not null
)
    enable row movement
  ;
comment on table rhn_command_target 
    is 'cmdtg  command target (cluster or node)';
create unique index rhn_cmdtg_recid_pk 
    on rhn_command_target ( recid, target_type )
    tablespace [[2m_tbs]]
  ;
alter table rhn_command_target 
    add constraint rhn_cmdtg_recid_target_type_pk 
    primary key (recid, target_type);
create index rhn_cmdtg_cid_idx
	on rhn_command_target( customer_id )
	tablespace [[4m_tbs]]
  ;
alter table rhn_command_target
    add constraint rhn_cmdtg_cstmr_customer_id_fk
    foreign key ( customer_id )
    references web_customer( id );
create sequence rhn_command_target_recid_seq;

select 'rhnsat/tables/rhn_physical_location.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_physical_location.sql
create table 
rhn_physical_location
(
    recid               number   (12)
        constraint rhn_phslc_recid_nn not null
        constraint rhn_phslc_recid_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    location_name       varchar2 (40),
    address1            varchar2 (255),
    address2            varchar2 (255),
    city                varchar2 (128),
    state               varchar2 (128),
    country             varchar2 (2),
    zipcode             varchar2 (10),
    phone               varchar2 (40),
    deleted             char     (1),
    last_update_user    varchar2 (40),
    last_update_date    date,
    customer_id         number   (12)  default 999
        constraint rhn_phslc_cust_id_nn not null
)
    enable row movement
  ;
comment on table rhn_physical_location 
    is 'phslc  physical location records';
create sequence rhn_physical_loc_recid_seq;

select 'rhnsat/tables/rhn_sat_cluster.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_sat_cluster.sql
create table 
rhn_sat_cluster
(
    recid                   number   (12)
        constraint rhn_satcl_recid_nn not null
        constraint rhn_satcl_recid_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    target_type             varchar2 (10) default 'cluster'
        constraint rhn_satcl_target_type_nn not null
        constraint rhn_satcl_target_type_ck check (target_type in ('cluster')),
    customer_id             number   (12)
        constraint rhn_satcl_cust_id_nn not null,
    description             varchar2 (255)
        constraint rhn_satcl_desc_nn not null,
    last_update_user        varchar2 (40),
    last_update_date        date,
    physical_location_id    number   (12)
        constraint rhn_satcl_location_id_nn not null,
    public_key              varchar2 (2000),
    vip                     varchar2 (15),
    deployed                char     (1)  default '0'
        constraint rhn_satcl_deployed_nn not null
        constraint rhn_satcl_deployed_ck check (deployed in ('0','1')),
    pem_public_key          varchar2 (2000),
    pem_public_key_hash     varchar2 (20)
)
    enable row movement
  ;
comment on table rhn_sat_cluster 
    is 'satcl  satellite cluster';
alter table rhn_sat_cluster
    add constraint rhn_satcl_cmdtg_recid_tar_fk
    foreign key ( recid, target_type )
    references rhn_command_target( recid, target_type )
    on delete cascade;
create index rhn_satcl_cid_idx
	on rhn_sat_cluster( customer_id )
	tablespace [[4m_tbs]]
  ;
alter table rhn_sat_cluster
    add constraint rhn_satcl_cstmr_customer_id_fk
    foreign key ( customer_id )
    references web_customer( id );
alter table rhn_sat_cluster
    add constraint rhn_satcl_phslc_phys_loc_fk
    foreign key ( physical_location_id )
    references rhn_physical_location( recid );

select 'rhnsat/tables/rhn_check_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_check_probe.sql
create table 
rhn_check_probe
(
    probe_id        number   (12)
        constraint rhn_chkpb_probe_id_nn not null
        constraint rhn_chkpb_probe_id_pk primary key
            using index tablespace [[4m_tbs]]
            ,
    probe_type      varchar2 (12) default 'check' 
        constraint rhn_chk_probe_type_nn not null
        constraint chkpb_probe_type_ck 
            check (probe_type='check'),
    host_id         number   (12)
        constraint rhn_chk_host_id_nn not null,
    sat_cluster_id  number   (12)
        constraint rhn_chk_sat_cluster_id_nn not null
)
    enable row movement
  ;
comment on table rhn_check_probe 
    is 'CHKPB  Service check probe definitions (monitoring)';
create index rhn_chkpb_host_id_idx 
    on rhn_check_probe ( host_id )
    tablespace [[4m_tbs]]
  ;
create index rhn_chkpb_sat_cluster_id_idx
    on rhn_check_probe ( sat_cluster_id )
    tablespace [[4m_tbs]]
  ;
create unique index rhn_chkpb_pid_ptype_uq_idx
    on rhn_check_probe ( probe_id, probe_type )
    tablespace [[4m_tbs]]
  ;
alter table rhn_check_probe
    add constraint rhn_chkpb_host_id_fk
    foreign key ( host_id )
    references rhnServer( id );
alter table rhn_check_probe
    add constraint rhn_chkpb_recid_probe_typ_fk
    foreign key ( probe_id, probe_type )
    references rhn_probe( recid, probe_type )
    on delete cascade;
alter table rhn_check_probe
    add constraint rhn_chkpb_satcl_sat_cl_id_fk
    foreign key ( sat_cluster_id )
    references rhn_sat_cluster( recid )
    on delete cascade;

select 'rhnsat/synonyms/check_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/check_probe.sql
create or replace synonym check_probe for rhn_check_probe;

select 'rhnsat/tables/rhn_check_suites.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_check_suites.sql
create table 
rhn_check_suites
(
    recid               number   (12)
        constraint rhn_cksut_recid_nn not null
        constraint rhn_cksut_recid_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    customer_id         number   (12)
        constraint rhn_cksut_custid_nn not null,
    suite_name          varchar2 (40)
        constraint rhn_cksut_suite_name_nn not null,
    description         varchar2 (255),
    last_update_user    varchar2 (40)
        constraint rhn_cksut_last_user_nn not null,
    last_update_date    date
        constraint rhn_cksut_last_date_nn not null
) 
    enable row movement
  ;
comment on table rhn_check_suites 
    is 'CKSUT  check suites';
create index rhn_cksut_cid_idx
	on rhn_check_suites( customer_id )
	tablespace [[2m_tbs]]
  ;
alter table rhn_check_suites
    add constraint rhn_cksut_cstmr_customer_id_fk
    foreign key ( customer_id )
    references web_customer( id );
create sequence rhn_check_suites_recid_seq;

select 'rhnsat/tables/rhn_check_suite_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_check_suite_probe.sql
create table 
rhn_check_suite_probe
(
    probe_id        number   (12)
        constraint rhn_ckspb_probe_id_nn not null
        constraint rhn_ckspb_probe_id_pk primary key
            using index tablespace [[4m_tbs]]
            ,
    probe_type      varchar2 (12) default 'suite' 
        constraint rhn_ckspb_probe_type_nn not null
        constraint rhn_ckspb_probe_type_ck check ( probe_type = 'suite' ),
    check_suite_id  number   (12)
        constraint rhn_ckspb_check_suite_id_nn not null
) 
    enable row movement
  ;
comment on table rhn_check_suite_probe 
    is 'CKSPB  Check suite probe definitions (monitoring)';
create index rhn_ckspb_check_suite_id_idx 
    on rhn_check_suite_probe ( check_suite_id )
    tablespace [[4m_tbs]]
  ;
alter table rhn_check_suite_probe
    add constraint rhn_ckspb_cksut_ck_suite_id_fk
    foreign key ( check_suite_id )
    references rhn_check_suites( recid )
    on delete cascade;

select 'rhnsat/synonyms/check_suite_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/check_suite_probe.sql
create or replace synonym check_suite_probe for rhn_check_suite_probe;

select 'rhnsat/synonyms/check_suites.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/check_suites.sql
create or replace synonym check_suites for rhn_check_suites;
create or replace synonym check_suites_recid_seq for rhn_check_suites_recid_seq;

select 'rhnsat/synonyms/command.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command.sql
create or replace synonym command  for rhn_command;
create or replace synonym commands_recid_seq for rhn_commands_recid_seq;

select 'rhnsat/tables/rhn_command_center_state.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_center_state.sql
create table 
rhn_command_center_state
(
    cust_admin_access_allowed char     (1)
        constraint rhn_cmdcs_allowed_nn not null,
    reason                    varchar2 (2000)
        constraint rhn_cmdcs_reason_nn not null,
    last_update_user          varchar2 (40)
        constraint rhn_cmdcs_last_user_nn not null,
    last_update_date          date
        constraint rhn_cmdcs_last_date_nn not null
) 
    enable row movement
  ;
comment on table rhn_command_center_state 
    is 'CMDCS  State of the command center (monitoring)';

select 'rhnsat/synonyms/command_center_state.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_center_state.sql
create or replace synonym command_center_state for rhn_command_center_state;

select 'rhnsat/synonyms/command_class.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_class.sql
create or replace synonym command_class for rhn_command_class;

select 'rhnsat/synonyms/command_groups.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_groups.sql
create or replace synonym command_groups for rhn_command_groups;

select 'rhnsat/synonyms/command_param_threshold.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_param_threshold.sql
create or replace synonym command_parameter_threshold for rhn_command_param_threshold;

select 'rhnsat/tables/rhn_widget.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_widget.sql
create table 
rhn_widget
( 
    name                varchar2 (20)
        constraint rhn_wdget_name_nn not null
        constraint rhn_wdget_name_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    description         varchar2 (80)
        constraint rhn_wdget_desc_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date         
) 
    enable row movement
  ;
comment on table rhn_widget 
    is 'wdget  text,password,menu,radio,checkbox';

select 'rhnsat/tables/rhn_semantic_data_type.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_semantic_data_type.sql
create table 
rhn_semantic_data_type
(
    name                varchar2 (10)
        constraint rhn_sdtyp_name_nn not null
        constraint rhn_sdtyp_name_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    description         varchar2 (80)
        constraint rhn_sdtyp_desc_nn not null,
    label_name          varchar2 (80),
    converter_name      varchar2 (128),
    help_file           varchar2 (128),
    last_update_user    varchar2 (40),
    last_update_date    date
)
    enable row movement
  ;
comment on table rhn_semantic_data_type 
    is 'sdtyp  data type int, float, string, ipaddress, hostname';

select 'rhnsat/tables/rhn_command_parameter.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_parameter.sql
create table 
rhn_command_parameter
(
    command_id              number   (12)
        constraint rhn_cparm_command_id_nn  not null,
    param_name              varchar2 (40)
        constraint rhn_cparm_param_name_nn not null,
    param_type              varchar2 (10) default 'config'
        constraint rhn_cparm_param_type_nn  not null,
    data_type_name          varchar2 (10)
        constraint rhn_cparm_data_type_name_nn  not null,
    description             varchar2 (80)
        constraint rhn_cparm_description_nn not null,
    mandatory               char     (1) default '0'
        constraint rhn_cparm_mandatory_nn  not null,
    default_value           varchar2 (1024),
    min_value               number,
    max_value               number,
    field_order             number
        constraint rhn_cparm_field_order_nn not null,
    field_widget_name       varchar2 (20)
        constraint rhn_cparm_field_widget_name_nn not null,
    field_visible_length    number,
    field_maximum_length    number,
    field_visible           char     (1) default '1'
        constraint rhn_cparm_field_visible_nn not null,
    default_value_visible   char     (1) default '1'
        constraint rhn_cparm_def_value_vis_nn not null,
    last_update_user        varchar2 (40),
    last_update_date        date
)
    enable row movement
  ;
comment on table rhn_command_parameter 
    is 'CPARM  A parameter for a particular command';
comment on column rhn_command_parameter.field_visible 
    is 'if default is $HOSTADDRESS$, param is marked as default not visible ';
create unique index rhn_cparm_cmd_id_param_name_uq 
    ON rhn_command_parameter ( command_id, param_name )
    tablespace [[2m_tbs]]
  ;
create unique index rhn_cparm_id_p_name_p_type_uq 
    on rhn_command_parameter ( command_id, param_name, param_type )
    tablespace [[2m_tbs]]
  ;
create unique index rhn_cparm_cmd_id_field_orde_uq 
    on rhn_command_parameter (command_id, field_order)
    tablespace [[2m_tbs]]
  ;
alter table rhn_command_parameter 
    add constraint rhn_cparm_id_parm_name_pk
    primary key ( command_id, param_name );
alter table rhn_command_parameter 
    add constraint rhn_cparm_id_p_name_p_type_uq 
    unique ( command_id, param_name, param_type );
alter table rhn_command_parameter
    add constraint rhn_cparm_id_field_orde_uq
    unique ( command_id, field_order );
alter table rhn_command_parameter
    add constraint rhn_cparm_cmd_command_id_fk
    foreign key ( command_id )
    references rhn_command( recid )
    on delete cascade;
alter table rhn_command_parameter
    add constraint rhn_cparm_sdtyp_name_fk
    foreign key ( data_type_name )
    references rhn_semantic_data_type( name );
alter table rhn_command_parameter
    add constraint rhn_cparm_wdgt_fld_wdgt_n_fk
    foreign key ( field_widget_name )
    references rhn_widget( name );

select 'rhnsat/synonyms/command_parameter.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_parameter.sql
create or replace synonym command_parameter for rhn_command_parameter;

select 'rhnsat/tables/rhn_command_queue_commands.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_queue_commands.sql
create table 
rhn_command_queue_commands
(
    recid               number   (12)
        constraint rhn_cqcmd_recid_nn not null
        constraint rhn_cqcmd_recid_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    description         varchar2 (40)
        constraint rhn_cqcmd_description_nn not null,
    notes               varchar2 (2000),
    command_line        varchar2 (2000)
        constraint rhn_cqcmd_command_line_nn not null,
    permanent           char     (1)
        constraint rhn_cqcmd_permanent_nn not null,
    restartable         char     (1)
        constraint rhn_cqcmd_restartable_nn not null,
    effective_user      varchar2 (40)
        constraint rhn_cqcmd_effective_usr_nn not null,
    effective_group     varchar2 (40)
        constraint rhn_cqcmd_effective_grp_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date
)
    enable row movement
  ;
comment on table rhn_command_queue_commands 
    is 'cqcmd  command queue command definitions';
create sequence rhn_command_q_comm_recid_seq
    start with 100;

select 'rhnsat/synonyms/command_queue_commands.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_queue_commands.sql
create or replace synonym command_queue_commands for rhn_command_queue_commands;
create or replace synonym command_q_command_recid_seq for rhn_command_q_comm_recid_seq;

select 'rhnsat/tables/rhn_command_queue_instances.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_queue_instances.sql
create table 
rhn_command_queue_instances
(
    recid               number   (12)
        constraint rhn_cqins_recid_nn not null
        constraint rhn_cqins_recid_pk primary key
            using index tablespace [[4m_tbs]]
            ,
    command_id          number   (12)
        constraint rhn_cqins_command_id_nn not null,
    notes               varchar2 (2000),
    date_submitted      date
        constraint rhn_cqins_date_submitted_nn not null,
    expiration_date     date
        constraint rhn_cqins_expiration_date_nn not null,
    notify_email        varchar2 (50),
    timeout             number   (5),
    last_update_user    varchar2 (40),
    last_update_date    date
)
    enable row movement
  ;
comment on table rhn_command_queue_instances 
    is 'cqins  command queue instance definitions';
create index rhn_cqins_command_id_idx 
    on rhn_command_queue_instances ( command_id )
    tablespace [[4m_tbs]]
    logging;
alter table rhn_command_queue_instances
    add constraint rhn_cqins_cqcmd_command_id_fk
    foreign key ( command_id )
    references rhn_command_queue_commands( recid );
create sequence rhn_command_q_inst_recid_seq;

select 'rhnsat/tables/rhn_command_queue_execs.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_queue_execs.sql
create table 
rhn_command_queue_execs
(
    instance_id         number   (12)
        constraint rhn_cqexe_instance_id_nn not null,
    netsaint_id         number   (12)
        constraint rhn_cqexe_netsaint_id_nn not null,
    date_accepted       date,
    date_executed       date,	
    exit_status         number   (5),
    execution_time      number   (10,6),
    stdout              varchar2 (4000),
    stderr              varchar2 (4000),
    last_update_date    date,
    target_type         varchar2 (10)
        constraint rhn_cqexe_target_type_nn not null
)
    enable row movement
  ;
comment on table rhn_command_queue_execs 
    is 'cqexe  command queue execution records';
create unique index rhn_cqexe_inst_id_nsaint_pk 
    on rhn_command_queue_execs ( instance_id, netsaint_id );
create index rhn_command_queue_netsaint_idx 
    on rhn_command_queue_execs ( netsaint_id )
    tablespace [[8m_tbs]]
  ;
create index rhn_cqexe_instance_id_idx 
    on rhn_command_queue_execs ( instance_id )
    tablespace [[8m_tbs]]
  ;
create index rhn_cqexe_date_executed_idx 
    on rhn_command_queue_execs ( date_executed )
    tablespace [[8m_tbs]]
  ;
alter table rhn_command_queue_execs 
    add constraint rhn_cqexe_inst_id_nsaint_pk 
    primary key ( instance_id, netsaint_id );
alter table rhn_command_queue_execs
    add constraint rhn_cqexe_cqins_inst_id_fk
    foreign key ( instance_id )
    references rhn_command_queue_instances( recid )
    on delete cascade;
alter table rhn_command_queue_execs
    add constraint rhn_cqexe_satcl_nsaint_id_fk
    foreign key ( netsaint_id, target_type )
    references rhn_command_target( recid, target_type )
    on delete cascade;

select 'rhnsat/synonyms/command_queue_execs.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_queue_execs.sql
create or replace synonym command_queue_execs for rhn_command_queue_execs;

select 'rhnsat/tables/rhn_command_queue_execs_bk.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_queue_execs_bk.sql
create table 
rhn_command_queue_execs_bk
(
    instance_id         number   (12)
        constraint rhn_cqcmdbk_instance_id_nn not null,
    netsaint_id         number   (12)
        constraint rhn_cqcmdbk_netsaint_id_nn not null,
    date_accepted       date,
    date_executed       date,
    exit_status         number   (5),
    execution_time      number   (10),
    stdout              varchar2 (4000),
    stderr              varchar2 (4000),
    last_update_date    date,
    target_type         varchar2 (10)
        constraint rhn_cqcmdbk_target_type_nn not null
)
    enable row movement
  ;

select 'rhnsat/synonyms/command_queue_execs_bk.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_queue_execs_bk.sql
create or replace synonym command_queue_execs_bk for rhn_command_queue_execs_bk;

select 'rhnsat/synonyms/command_queue_instances.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_queue_instances.sql
create or replace synonym command_queue_instances for rhn_command_queue_instances;
create or replace synonym command_q_instance_recid_seq for rhn_command_q_inst_recid_seq;

select 'rhnsat/tables/rhn_command_queue_instances_bk.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_queue_instances_bk.sql
create table 
rhn_command_queue_instances_bk
(
    recid               number   (12)
        constraint rhn_cqinsbk_recid_nn not null,
    command_id          number   (12)
        constraint rhn_cqinsbk_command_id_nn not null,
    notes               varchar2 (2000),
    date_submitted      date
        constraint rhn_cqinsbk_date_sub_nn not null,
    expiration_date     date
        constraint rhn_cqinsbk_exp_date_nn not null,
    notify_email        varchar2 (50),
    timeout             number   (5),
    last_update_user    varchar2 (40),
    last_update_date    date
)
    enable row movement
  ;

select 'rhnsat/synonyms/command_queue_instances_bk.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_queue_instances_bk.sql
create or replace synonym command_queue_instances_bk for rhn_command_queue_instances_bk;

select 'rhnsat/tables/rhn_command_queue_params.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_queue_params.sql
create table
rhn_command_queue_params
(
    instance_id     number   (12)
        constraint rhn_cqprm_instance_id_nn not null,
    ord             number   (3)
        constraint rhn_cqprm_ord_nn not null,
    value           varchar2 (1024)
)
    enable row movement
  ;
comment on table rhn_command_queue_params 
    is 'cqprm   command queue parameter definitions';
create unique index rhn_cqprm_instance_id_ord_pk 
    on rhn_command_queue_params ( instance_id, ord )
    tablespace [[4m_tbs]]
  ;
alter table rhn_command_queue_params 
    add constraint rhn_cqprm_instance_id_ord_pk 
    primary key ( instance_id, ord );
alter table rhn_command_queue_params
    add constraint rhn_cqprm_cqins_instance_id_fk
    foreign key ( instance_id )
    references rhn_command_queue_instances( recid )
    on delete cascade;

select 'rhnsat/synonyms/command_queue_params.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_queue_params.sql
create or replace synonym command_queue_params for rhn_command_queue_params;

select 'rhnsat/tables/rhn_command_queue_sessions.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_queue_sessions.sql
create table 
rhn_command_queue_sessions
(
    contact_id          number   (12)
        constraint rhn_cqses_contact_id_nn not null,
    session_id          varchar2 (255),
    expiration_date     date,
    last_update_user    varchar2 (40),        
    last_update_date    date
)  
    enable row movement
  ;
comment on table rhn_command_queue_sessions 
    is 'cqses  command queue sessions';
create unique index rhn_cqses_cid_uq
	on rhn_command_queue_sessions( contact_id )
	tablespace [[4m_tbs]]
  ;
alter table rhn_command_queue_sessions
    add constraint rhn_cqses_cntct_contact_idfk
    foreign key ( contact_id )
    references web_contact( id );

select 'rhnsat/synonyms/command_queue_sessions.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_queue_sessions.sql
create or replace synonym command_queue_sessions for rhn_command_queue_sessions;

select 'rhnsat/synonyms/command_requirements.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_requirements.sql
create or replace synonym command_requirements for rhn_command_requirements;

select 'rhnsat/synonyms/command_target.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/command_target.sql
create or replace synonym command_target for rhn_command_target;
create or replace synonym command_target_recid_seq for rhn_command_target_recid_seq;

select 'rhnsat/tables/rhn_config_group.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_config_group.sql
create table 
rhn_config_group
(
    name        varchar2 (255)
        constraint rhn_confg_name_nn not null
        constraint rhn_confg_name_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    description varchar2 (255)
)
    enable row movement
  ;
comment on table rhn_config_group 
    is 'confg  configuration group definition:general,mail,cf_db';

select 'rhnsat/synonyms/config_group.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/config_group.sql
create or replace synonym config_group for rhn_config_group;

select 'rhnsat/tables/rhn_environment.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_environment.sql
create table 
rhn_environment
(
    name            varchar2 (255)
        constraint rhn_envir_name_nn not null
        constraint rhn_envir_name_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    description     varchar2 (255)
)
    enable row movement
  ;
comment on table rhn_environment 
    is 'envir environments:dev,qa,stage,prod,license';

select 'rhnsat/tables/rhn_config_macro.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_config_macro.sql
create table 
rhn_config_macro
(
    environment         varchar2 (255)
        constraint rhn_confm_env_nn not null,
    name                varchar2 (255)
        constraint rhn_confm_name_nn not null,
    definition          varchar2 (255),
    description         varchar2 (255),
    editable            char     (1) default 0
        constraint rhn_confm_editable_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date
)
    enable row movement
  ;
comment on table rhn_config_macro 
    is 'confm configuration macro def';
create unique index rhn_confm_environment_name_pk 
    on rhn_config_macro ( environment, name )
    tablespace [[2m_tbs]]
  ;
alter table rhn_config_macro 
    add constraint rhn_confm_environment_name_pk 
    primary key ( environment, name );
alter table rhn_config_macro
    add constraint rhn_confm_envir_environment_fk
    foreign key ( environment )
    references rhn_environment( name );

select 'rhnsat/synonyms/config_macro.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/config_macro.sql
create or replace synonym config_macro for rhn_config_macro;

select 'rhnsat/tables/rhn_config_security_type.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_config_security_type.sql
create table 
rhn_config_security_type
(
    name        varchar2 (255)
        constraint rhn_conct_name_nn not null
        constraint rhn_conct_name_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    description varchar2 (255)
)
    enable row movement
  ;
comment on table rhn_config_security_type 
    is 'conct security levels internal,external,all';

select 'rhnsat/tables/rhn_config_parameter.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_config_parameter.sql
create table 
rhn_config_parameter
(
    group_name          varchar2 (255)
        constraint rhn_confp_group_name_nn not null,
    name                varchar2 (255)
        constraint rhn_confp_name_nn not null,
    value               varchar2 (255),
    security_type       varchar2 (255)
        constraint rhn_confp_security_type_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date
)  
    enable row movement
  ;
comment on table rhn_config_parameter 
    is 'confp  configuration parameter definition';
create unique index rhn_confp_group_name_name_pk 
    on rhn_config_parameter ( group_name,  name ) 
    tablespace [[2m_tbs]]
  ;
alter table rhn_config_parameter 
    add constraint rhn_confp_group_name_name_pk primary key ( group_name, name);
alter table rhn_config_parameter
    add constraint rhn_confp_grpnm_group_name_fk
    foreign key ( group_name )
    references rhn_config_group( name );
alter table rhn_config_parameter
    add constraint rhn_confp_scrty_sec_type_fk
    foreign key ( security_type )
    references rhn_config_security_type( name );

select 'rhnsat/synonyms/config_parameter.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/config_parameter.sql
create or replace synonym config_parameter for rhn_config_parameter;

select 'rhnsat/synonyms/config_security_type.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/config_security_type.sql
create or replace synonym config_security_type for rhn_config_security_type;

select 'rhnsat/tables/web_user_prefix.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/web_user_prefix.sql
create table
web_user_prefix
(
	text			varchar2(12)
				constraint wup_text_nn not null
				constraint wup_text_pk primary key
)
	enable row movement
	;
insert into WEB_USER_PREFIX values (' ');
insert into WEB_USER_PREFIX values ('.');
insert into WEB_USER_PREFIX values ('Mr.');
insert into WEB_USER_PREFIX values ('Mrs.');
insert into WEB_USER_PREFIX values ('Miss');
insert into WEB_USER_PREFIX values ('Ms.');
insert into WEB_USER_PREFIX values ('Dr.');
insert into WEB_USER_PREFIX values ('Hr.');
insert into WEB_USER_PREFIX values ('Sr.');

select 'rhnsat/tables/web_user_personal_info.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/web_user_personal_info.sql
create table
web_user_personal_info
(
	web_user_id		number
				constraint wupi_wuid_nn not null
				constraint personal_info_web_user_id_fk
					references web_contact(id)
					on delete cascade,
	prefix			varchar2(12) default ' '
				constraint wupi_prefix_nn not null
				constraint wupi_prefix_fk
					references web_user_prefix(text),
	first_names		varchar2(128)
				constraint wupi_fn_nn not null,
	last_name		varchar2(128)
				constraint wupi_ln_nn not null,
	genqual			varchar2(12),
	parent_company		varchar2(128),
	company			varchar2(128),
	title			varchar2(128),
	phone			varchar2(128),
	fax			varchar2(128),
	email			varchar2(128),
	email_uc		varchar2(128),
	pin			number,
	created			date default(sysdate)
				constraint wupi_created_nn not null,
	modified		date default(sysdate)
				constraint wupi_modified_nn not null,
	first_names_ol		varchar2(128),
	last_name_ol		varchar2(128),
	genqual_ol		varchar2(12),
	parent_company_ol	varchar2(128),
	company_ol		varchar2(128),
	title_ol		varchar2(128)
)
	enable row movement
	;
create or replace trigger
web_user_pi_timestamp
before insert or update on web_user_personal_info
for each row
begin
  :new.email_uc := upper(:new.email);
  :new.modified := sysdate;
end;
/
show errors
create index wupi_email_uc_idx
	on web_user_personal_info ( email_uc );

select 'rhnsat/views/rhn_contact_monitoring.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhn_contact_monitoring.sql
create or replace view rhn_contact_monitoring as
select	u.id			recid,
	u.org_id		customer_id,
	wupi.last_name		contact_last_name,
	wupi.first_names	contact_first_name,
	rhn_user.find_mailable_address(u.id)
				email_address,
	u.login			username,
	u.password		password,
	1			schedule_id,
	'GMT'			preferred_time_zone
from 
	web_user_personal_info wupi,
	web_contact u
where	1=1
	and u.id = wupi.web_user_id
/

select 'rhnsat/synonyms/contact.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/contact.sql
create or replace synonym contact for rhn_contact_monitoring;

select 'rhnsat/tables/rhn_method_types.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_method_types.sql
create table 
rhn_method_types
(
    recid                   number   (12)
        constraint rhn_mthtp_recid_nn not null
        constraint rhn_mthtp_recid_ck check (recid > 0)
        constraint rhn_mthtp_recid_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    method_type_name        varchar2 (20),
    notification_format_id  number   (12) default 4
        constraint rhn_mthtp_notif_fmt_nn not null
)  
    enable row movement
  ;
comment on table rhn_method_types 
    is 'mthtp  method types';

select 'rhnsat/tables/rhn_pager_types.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_pager_types.sql
create table 
rhn_pager_types
(
    recid           number   (12)
        constraint rhn_pgrtp_recid_nn not null
        constraint rhn_pgrtp_recid_ck check (recid > 0)
        constraint rhn_pgrtp_recid_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    pager_type_name varchar2 (50)
)
    enable row movement
  ;
comment on table rhn_pager_types 
    is 'pgrtp  pager types';
create sequence rhn_pager_types_recid_seq;

select 'rhnsat/tables/rhn_schedule_types.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_schedule_types.sql
create table 
rhn_schedule_types
(
    recid           number   (12)
        constraint rhn_schtp_recid_nn not null
        constraint rhn_schtp_recid_ck check (recid > 0)
        constraint rhn_schtp_recid_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    description     varchar2 (40)
)
    enable row movement
  ;
comment on table rhn_schedule_types 
    is 'schtp  schedule types';
create sequence rhn_schedule_types_recid_seq;

select 'rhnsat/tables/rhn_schedules.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_schedules.sql
create table 
rhn_schedules
(
    recid               number   (12)
        constraint rhn_sched_recid_nn not null
        constraint rhn_sched_recid_ck check (recid > 0)
        constraint rhn_sched_recid_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    schedule_type_id    number   (12)
        constraint rhn_sched_type_id_nn not null,
    description         varchar2 (40) default 'unknown'
        constraint rhn_sched_desc_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date,
    customer_id         number   (12)
)
    enable row movement
  ;
comment on table rhn_schedules 
    is 'sched  schedule definitions';
create index rhn_sched_schedule_type_id_idx 
    on rhn_schedules ( schedule_type_id )
    tablespace [[2m_tbs]]
  ;
create unique index rhn_cust_cust_id_desc_uq 
    on rhn_schedules ( customer_id, description )
    tablespace [[2m_tbs]]
  ;
alter table rhn_schedules
    add constraint rhn_sched_cstmr_cust_id_fk
    foreign key ( customer_id )
    references web_customer( id );
alter table rhn_schedules
    add constraint rhn_sched_schtp_sched_ty_fk
    foreign key ( schedule_type_id )
    references rhn_schedule_types( recid );
create sequence rhn_schedules_recid_seq;

select 'rhnsat/tables/rhn_time_zone_names.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_time_zone_names.sql
create table 
rhn_time_zone_names
(
    recid                            number   (12)
        constraint rhn_tznms_recid_nn not null,
    java_id                          varchar2 (40)
        constraint rhn_tznms_java_id_nn not null
        constraint rhn_tznms_java_id_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    display_name                     varchar2 (60)
        constraint rhn_tznms_display_name_nn not null,
    gmt_offset_minutes               number   (4)
        constraint rhn_tznms_gmt_offset_nn not null,
    use_daylight_time                char     (1)
        constraint rhn_tznms_use_dst_nn not null,
    last_update_user                 varchar2 (40),
    last_update_date                 date
)
    enable row movement
  ;
comment on table rhn_time_zone_names 
    is 'tznms  time zone names';
create unique index rhn_time_zone_names_uq 
    on rhn_time_zone_names ( display_name )
    tablespace [[64k_tbs]]
  ;
alter table rhn_time_zone_names 
    add constraint rhn_time_zone_names_uq unique ( display_name );

select 'rhnsat/tables/rhn_notification_formats.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_notification_formats.sql
create table 
rhn_notification_formats
(
    recid               number   (12)
        constraint rhn_ntfmt_recid_nn not null
        constraint rhn_ntfmt_recid_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    customer_id         number   (12),
    description         varchar2 (255)
        constraint rhn_ntfmt_desc_nn not null,
    subject_format      varchar2 (4000),
    body_format         varchar2 (4000)
        constraint rhn_ntfmt_body_fmt_nn not null,
    max_subject_length  number   (12),
    max_body_length     number   (12) default 1920
        constraint rhn_ntfmt_max_body_nn not null,
    reply_format        varchar2 (4000)
)
    enable row movement
  ;
comment on table rhn_notification_formats 
    is 'ntfmt  notification message formats';
create index rhn_ntfmt_customer_idx 
    on rhn_notification_formats ( customer_id )
    tablespace [[64k_tbs]]
  ;
alter table rhn_notification_formats
    add constraint rhn_ntfmt_customer_fk
    foreign key ( customer_id )
    references web_customer( id );
create sequence rhn_ntfmt_recid_seq;

select 'rhnsat/tables/rhnTimezone.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTimezone.sql
create sequence rhn_timezone_id_seq start with 7000 order;
create table 
rhnTimezone
(
        id              number
			constraint rhn_timezone_id_nn not null,
        olson_name      varchar2(128)
	    	    	constraint rhn_timezone_olson_nn not null,
	display_name    varchar2(128)
	    	    	constraint rhn_timezone_display_nn not null
)
	enable row movement
  ;
create index rhn_timezone_id_idx
	on rhnTimezone( id )
	tablespace [[64k_tbs]]
  ;
alter table rhnTimezone add constraint rhn_timezone_id_pk
	primary key ( id );
create unique index rhn_timezone_olson_uq
	on rhnTimezone(olson_name);
create unique index rhn_timezone_display_uq
	on rhnTimezone(display_name);

select 'rhnsat/tables/rhnUserInfo.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserInfo.sql
create table 
rhnUserInfo
(
        user_id		number
                        constraint rhn_user_info_user_nn not null
                        constraint rhn_user_info_user_fk
                                references web_contact(id) on delete cascade,
	no_clear_sets	number default(0)
			constraint rhn_user_info_clearsets_nn not null,
	page_size	number default(20)
			constraint rhn_user_info_pagesize_nn not null,
	email_notify	number default(1)
			constraint rhn_user_info_notify_nn not null,
	bad_email	number default(0)
			constraint rhn_user_info_bademail_nn not null,
	tz_offset       number default(-5)
	    	    	constraint rhn_user_info_tzoffset_nn not null
			constraint rhn_user_info_tzoffset_ck
				check (tz_offset >= -11 and tz_offset <= 13),
	timezone_id     number
			constraint rhn_user_info_tzid_fk
				references rhnTimezone(id) on delete cascade,
	show_applied_errata
			char(1) default('N')
			constraint rhn_user_info_sea_nn not null
			constraint rhn_user_info_sea_ck check
				(show_applied_errata in ('Y','N')),
	show_system_group_list
			char(1) default('N')
			constraint rhn_user_info_ssgl_nn not null
			constraint rhn_user_info_ssgl_ck check
				(show_system_group_list in ('Y','N')),
	agreed_to_terms
			char(1) default('N')
			constraint rhn_user_info_agreed_nn not null
			constraint rhn_user_info_agreed_ck check
				(agreed_to_terms in ('Y','N')),
	use_pam_authentication
			char(1) default('N')
			constraint rhn_user_info_pam_nn not null
			constraint rhn_user_info_pam_ck check
				(use_pam_authentication in ('Y','N')),
	last_logged_in 	date,
    	agreed_to_ws_terms
	                char(1)
                        constraint rhn_user_info_ws_ck check
			    (agreed_to_ws_terms is null or agreed_to_ws_terms in ('Y','N')),
    	agreed_to_es_terms
	    	    	char(1)
                        constraint rhn_user_info_es_ck check
			    (agreed_to_es_terms is null or agreed_to_es_terms in ('Y','N')),
      	created		date default(sysdate)
			constraint rhn_user_info_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_user_info_modified_nn not null,
        preferred_locale varchar2(8)
)
	enable row movement
  ;
create index rhn_user_info_uid_email_idx
	on rhnUserInfo ( user_id, email_notify )
	tablespace [[4m_tbs]]
  ;
alter table rhnUserInfo add
	constraint rhn_user_info_uid_uq unique ( user_id );

select 'rhnsat/tables/rhn_contact_methods.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_contact_methods.sql
create table 
rhn_contact_methods
(
    recid                            number   (12)
        constraint rhn_cmeth_recid_nn not null
        constraint rhn_cmeth_recid_notzero check (recid > 0) 
        constraint rhn_cmeth_recid_pk primary key
            using index tablespace [[2m_tbs]]
                ,
    method_name                      varchar2 (20),
    contact_id                       number   (12)
        constraint rhn_cmeth_contact_id_nn not null,
    schedule_id                      number   (12),
    method_type_id                   number   (12)
        constraint rhn_cmeth_meth_type_nn not null,
    pager_type_id                    number   (12),
    pager_pin                        varchar2 (20),
    pager_email                      varchar2 (50),
    pager_max_message_length         number   (6)
        constraint rhn_cmeth_pgr_length_limit 
        check (pager_max_message_length between 10 and 1920),
    pager_split_long_messages        char     (1),
    email_address                    varchar2 (50),
    email_reply_to                   varchar2 (50),
    last_update_user                 varchar2 (40),
    last_update_date                 date,
    snmp_host                        varchar2 (255),
    snmp_port                        number   (5),
    notification_format_id           number   (12) default 4
        constraint rhn_cmeth_notif_fmt_nn not null,
    sender_sat_cluster_id            number   (12)
)
    enable row movement
  ;
comment on table rhn_contact_methods 
    is 'cmeth  contact method definitions';
create index rhn_cmeth_sndr_scid_idx
    on rhn_contact_methods ( sender_sat_cluster_id )
    tablespace [[2m_tbs]]
  ;
create index rhn_cmeth_contact_id_idx
    on rhn_contact_methods ( contact_id )
    tablespace [[2m_tbs]]
  ;
create unique index rhn_cmeth_id_name_uq
    on rhn_contact_methods ( contact_id, method_name )
    tablespace [[2m_tbs]]
  ;
create index rhn_cmeth_method_type_id_idx
    on rhn_contact_methods ( method_type_id )
    tablespace [[2m_tbs]]
  ;
create index rhn_cmeth_schedule_id_idx
    on rhn_contact_methods ( schedule_id )
    tablespace [[2m_tbs]]
  ;
alter table rhn_contact_methods
    add constraint rhn_cmeth_contact_id_fk
    foreign key ( contact_id )
    references web_contact( id );
alter table rhn_contact_methods
    add constraint rhn_cmeth_method_type_id_fk
    foreign key ( method_type_id )
    references rhn_method_types( recid );
alter table rhn_contact_methods
    add constraint rhn_cmeth_pager_type_id_fk
    foreign key ( pager_type_id )
    references rhn_pager_types( recid );
alter table rhn_contact_methods
    add constraint rhn_cmeth_sender_sat_clus_fk
    foreign key ( sender_sat_cluster_id )
    references rhn_sat_cluster( recid );
alter table rhn_contact_methods
    add constraint rhn_cmeth_schedule_id_fk
    foreign key ( schedule_id )
    references rhn_schedules( recid );
alter table rhn_contact_methods
    add constraint rhn_cmeth_ntfmt_id_fk
    foreign key ( notification_format_id )
    references rhn_notification_formats( recid );
create sequence rhn_contact_methods_recid_seq;
create or replace trigger 
rhn_cmeth_val_trig
before insert or update on rhn_contact_methods
referencing new as new old as old
for each row
declare
    msg  varchar2(200);
    missing_data exception;
begin
    msg :='missing or invalid data for contact_methods table';
    if :new.method_type_id = 1
    then
        if (
            :new.pager_email   is null     or
            :new.pager_split_long_messages  is null )
        then
            raise missing_data;
        end if;
    end if;
    if :new.method_type_id = 2
    then
        if :new.email_address is null
        then
            raise missing_data;
        end if;
    end if;
    if :new.method_type_id = 5
    then
        if (:new.snmp_host is null   or
           :new.snmp_port is null)
        then
            raise missing_data;
        end if;
    end if;
    exception
    when missing_data then
    raise_application_error (-20012,msg);
    when others then
    raise;
end;
/
show errors

select 'rhnsat/tables/rhn_strategies.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_strategies.sql
create table 
rhn_strategies
(
    recid               number   (12)
        constraint rhn_strat_recid_nn not null
        constraint rhn_strat_recid_ck check (recid > 0)
        constraint rhn_strat_recid_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    name                varchar2 (80),
    comp_crit           varchar2 (80),
    esc_crit            varchar2 (80),
    contact_strategy    varchar2 (32)
        constraint rhn_strat_cont_strat_ck 
            check (contact_strategy in ('Broadcast','Escalate')),
    ack_completed       varchar2 (32)
        constraint rhn_strat_ack_comp_ck 
            check (ack_completed in ( 'All', 'One','No' ))
)
    enable row movement
  ;
comment on table rhn_strategies 
    is 'strat  strategy definitions';
create sequence rhn_strategies_recid_seq;

select 'rhnsat/tables/rhn_contact_groups.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_contact_groups.sql
create table 
rhn_contact_groups
(  
    recid                   number   (12)
        constraint rhn_cntgp_recid_nn not null
        constraint rhn_cntgp_recid_notzero check (recid > 0)
        constraint rhn_cntgp_recid_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    contact_group_name      varchar2 (30)
        constraint rhn_cntgp_group_name_nn not null,
    customer_id             number   (12)
        constraint rhn_cntgp_cust_id_nn not null,
    strategy_id             number   (12)
        constraint rhn_cntgp_strat_id_nn not null,
    ack_wait                number   (4)
        constraint rhn_cntgp_ack_wait_nn not null
        constraint rhn_cntgp_ack_wait_ck check ( ack_wait < 20160 ),
    rotate_first            char     (1)
        constraint rhn_cntgp_rotate_f_nn not null
        constraint rhn_cntgp_rotate_f_ck check (rotate_first in (0,1)),
    last_update_user        varchar2 (40)
        constraint rhn_cntgp_last_user_nn not null,
    last_update_date        date
        constraint rhn_cntgp_last_date_nn not null,
    notification_format_id  number   (12) default 4
        constraint rhn_cntgp_notif_fmt_nn not null
)
    enable row movement
  ;
comment on table rhn_contact_groups 
    is 'cntgp  contact group definitions';
create index rhn_cntgp_strategy_id_idx
    on rhn_contact_groups ( strategy_id )
    tablespace [[2m_tbs]]
  ;
create index rhn_cntgp_customer_id_idx
    on rhn_contact_groups ( customer_id )
    tablespace [[2m_tbs]]
  ;
alter table rhn_contact_groups
    add constraint rhn_cntgp_cstmr_customer_id_fk
    foreign key ( customer_id )
    references web_customer( id );
alter table rhn_contact_groups
    add constraint rhn_cntgp_strat_strategy_id_fk
    foreign key ( strategy_id )
    references rhn_strategies( recid );
alter table rhn_contact_groups
    add constraint rhn_ntfmt_cntgp_id_fk
    foreign key ( notification_format_id )
    references rhn_notification_formats( recid );
create sequence rhn_contact_groups_recid_seq;

select 'rhnsat/tables/rhn_contact_group_members.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_contact_group_members.sql
create table 
rhn_contact_group_members
(
	contact_group_id	number
				constraint rhn_cntgm_cgid_nn not null
				constraint rhn_cntgm_cgid_fk
					references rhn_contact_groups(recid)
					on delete cascade,
	order_number		number
				constraint rhn_cntgm_on_nn not null,
	member_contact_method_id number
				constraint rhn_cntgm_mcmid_fk
					references rhn_contact_methods(recid)
					on delete cascade,
	member_contact_group_id	number
				constraint rhn_cntgm_mcgid_fk
					references rhn_contact_groups(recid)
					on delete cascade,
	last_update_user	varchar2 (40)
				constraint rhn_cntgm_last_user_nn not null,
	last_update_date	date
				constraint rhn_cntgm_last_date_nn not null
)  
	enable row movement
  ;
comment on table rhn_contact_group_members 
	is 'cntgm  contact group membership records';
create index rhn_cntgm_cgid_order_idx 
	on rhn_contact_group_members( contact_group_id, order_number )
	tablespace [[2m_tbs]]
  ;
alter table rhn_contact_group_members add constraint rhn_cntgm_cgid_order_pk 
	primary key ( contact_group_id, order_number );
create index rhn_cntgm_mcmid_idx
	on rhn_contact_group_members( member_contact_method_id )
	tablespace [[2m_tbs]]
  ;
create index rhn_cntgm_mcgid_idx
	on rhn_contact_group_members( member_contact_group_id )
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/synonyms/contact_group_members.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/contact_group_members.sql
create or replace synonym contact_group_members for rhn_contact_group_members;

select 'rhnsat/synonyms/contact_groups.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/contact_groups.sql
create or replace synonym contact_groups for rhn_contact_groups;
create or replace synonym contact_groups_recid_seq for rhn_contact_groups_recid_seq;

select 'rhnsat/synonyms/contact_methods.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/contact_methods.sql
create or replace synonym contact_methods for rhn_contact_methods;
create or replace synonym contact_methods_recid_seq for rhn_contact_methods_recid_seq;

select 'rhnsat/tables/rhn_current_alerts.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_current_alerts.sql
create table 
rhn_current_alerts
(
    recid               number   (12)
        constraint rhn_alrts_recid_nn not null
        constraint rhn_alrts_recid_pk primary key
            using index tablespace [[128m_tbs]]
            ,
    date_submitted      date,
    last_server_change  date,
    date_completed      date    default to_date('31-12-9999', 'dd-mm-yyyy'),
    original_server     number   (12),
    current_server      number   (12),
    tel_args            varchar2 (2200),
    message             varchar2 (2000),
    ticket_id           varchar2 (80),
    destination_name    varchar2 (50),
    escalation_level    number   (2)    default 0,
    host_probe_id       number   (12),
    host_state          varchar2 (255),
    service_probe_id    number   (12),
    service_state       varchar2 (255),
    customer_id         number   (12)
        constraint rhn_alrts_cust_id_nn not null,
    netsaint_id         number   (12),
    probe_type          varchar2 (20)   default 'none',
    in_progress         char     (1)    default 1
        constraint rhn_alrts_in_prog_nn not null,
    last_update_date    date,
    event_timestamp     date
)
    enable row movement
  ;
comment on table rhn_current_alerts 
    is 'alrts  current alert records';
create index rhn_alrts_service_probe_id_idx
    on rhn_current_alerts ( service_probe_id )
    tablespace [[128m_tbs]]
  ;
create index rhn_alrts_current_server_idx
    on rhn_current_alerts ( current_server )  
    tablespace [[128m_tbs]]
  ;
create index rhn_alrts_in_progress_idx
    on rhn_current_alerts ( in_progress ) 
    tablespace [[128m_tbs]]
  ;
create index rhn_alrts_ticket_id_idx
    on rhn_current_alerts ( ticket_id )
    tablespace [[128m_tbs]]
  ;
create index rhn_alrts_customer_id_idx
    on rhn_current_alerts ( customer_id )
    tablespace [[128m_tbs]]
  ;
create index rhn_alrts_netsaint_id_idx
    on rhn_current_alerts ( netsaint_id )
    tablespace [[128m_tbs]]
  ;
create index rhn_alrts_probe_type_idx
    on rhn_current_alerts ( probe_type )
    tablespace [[128m_tbs]]
  ;
create index rhn_alrts_original_server_idx
    on rhn_current_alerts ( original_server )
    tablespace [[128m_tbs]]
  ;
create index rhn_alrts_host_probe_id_idx
    on rhn_current_alerts ( host_probe_id )
    tablespace [[128m_tbs]]
  ;
create sequence rhn_current_alerts_recid_seq;
create or replace trigger 
rhn_current_alerts_mod_trig
before insert or update on rhn_current_alerts
referencing new as new old as old
for each row
declare
msg varchar2(200);
date_completed_is_null exception;
date_completed_is_not_null exception;
begin
    if :new.in_progress=0 and :new.date_completed is null
    then
        if ( updating( 'in_progress' ) and updating( 'date_completed') ) 
             or inserting
        then
            raise date_completed_is_null;
        elsif  updating( 'in_progress' )
        then
            :new.date_completed:=sysdate;
        else
            :new.in_progress:=1;
        end if;
    elsif :new.in_progress=1 and :new.date_completed is not null
    then
        if ( updating( 'in_progress' ) and updating( 'date_completed') ) 
            or inserting
        then
            raise date_completed_is_not_null;
        elsif  updating( 'in_progress' )
        then
            :new.date_completed:=null;
        else
            :new.in_progress:=0;
        end if;
    end if;
    exception
    when date_completed_is_null then
    msg:='date_completed is null while in_progress=0';
    raise_application_error (-20012,msg);
    when date_completed_is_not_null then
    msg:='date_completed is not null while in_progress=1';
    raise_application_error (-20012,msg);
    when others then
    raise;
end;
/
show errors

select 'rhnsat/synonyms/current_alerts.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/current_alerts.sql
create or replace synonym current_alerts for rhn_current_alerts;
create or replace synonym current_alerts_recid_seq for rhn_current_alerts_recid_seq;

select 'rhnsat/tables/rhn_current_state_summaries.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_current_state_summaries.sql
create table 
rhn_current_state_summaries
(
    customer_id                      number   (12)
        constraint rhn_cursu_cust_id_nn not null,
    template_id                      varchar2 (10)
        constraint rhn_cursu_template_id_nn not null,
    state                            varchar2 (20)
        constraint rhn_cursu_state_nn not null,
    state_count                      number   (9),
    last_check                       date
)  
    enable row movement
  ;
comment on table rhn_current_state_summaries
    is 'cursu  current state summaries (monitoring)';
create unique index rhn_current_state_summaries_pk 
on rhn_current_state_summaries ( customer_id, template_id, state )
    tablespace [[2m_tbs]]
  ;
alter table rhn_current_state_summaries 
    add constraint rhn_current_state_summaries_pk 
    primary key ( customer_id, template_id, state );

select 'rhnsat/synonyms/current_state_summaries.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/current_state_summaries.sql
create or replace synonym current_state_summaries for rhn_current_state_summaries;

select 'rhnsat/views/rhn_customer_monitoring.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhn_customer_monitoring.sql
create or replace view rhn_customer_monitoring as
select	org.id			recid,
	org.name		description,
	1			schedule_id,	--24 x 7
	0			def_ack_wait,
	1			def_strategy,	--Broadcast, No Ack
	'GMT'			preferred_time_zone,
	0			auto_update	--Windows only
from
	web_customer org
where	1=1
/

select 'rhnsat/synonyms/customer.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/customer.sql
create or replace synonym customer for rhn_customer_monitoring;

select 'rhnsat/tables/rhn_db_environment.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_db_environment.sql
create table 
rhn_db_environment
(
    db_name     varchar2 (20)
        constraint rhn_dbenv_db_name_nn not null
        constraint rhn_dbenv_db_name_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    environment varchar2 (255)
)
    enable row movement
  ;
comment on table rhn_db_environment 
    is 'dbenv environments - database_names xref';
alter table rhn_db_environment
    add constraint rhn_dbenv_envir_environment_fk
    foreign key ( environment )
    references rhn_environment( name );

select 'rhnsat/synonyms/db_environment.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/db_environment.sql
create or replace synonym db_environment for rhn_db_environment;

select 'rhnsat/tables/rhn_deployed_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_deployed_probe.sql
create table 
rhn_deployed_probe
(
    recid                            number   (12)
        constraint rhn_dprob_recid_nn not null
        constraint rhn_dprob_recid_pk primary key
            using index tablespace [[8m_tbs]]
            ,
    probe_type                       varchar2 (15)
        constraint rhn_dprob_probe_type_nn not null,
    description                      varchar2 (255),
    customer_id                      number   (12)
        constraint rhn_dprob_cust_id_nn not null,
    command_id                       number   (16)
        constraint rhn_dprob_command_id_nn not null,
    contact_group_id                 number   (12),
    os_id                            number   (12),
    notify_critical                  char     (1),
    notify_warning                   char     (1),
    notify_recovery                  char     (1),
    notify_unknown                   char     (1),
    notification_interval_minutes    number   (16)
        constraint rhn_dprob_notif_int_nn not null,
    check_interval_minutes           number   (16)
        constraint rhn_dprob_check_int_nn not null,
    retry_interval_minutes           number   (16)
        constraint rhn_dprob_retry_int_nn not null,
    max_attempts                     number   (16),
    sat_cluster_id                   number   (12),
    parent_probe_id                  number   (12),
    last_update_user                 varchar2 (40),
    last_update_date                 date
)
    enable row movement
  ;
comment on table rhn_deployed_probe is 'dprob  deployed_probe definitions';
create unique index rhn_dprob_recid_probe_type_uq 
    on rhn_deployed_probe ( recid, probe_type )
    tablespace [[8m_tbs]]
  ;
create index rhn_dprob_check_command_id_idx 
    on rhn_deployed_probe ( command_id )
    tablespace [[8m_tbs]]
  ;
create index rhn_dprob_customer_id_idx 
    on rhn_deployed_probe ( customer_id )
    tablespace [[8m_tbs]]
  ;
create index rhn_dprob_sat_cluster_id_idx 
    on rhn_deployed_probe ( sat_cluster_id )
    tablespace [[8m_tbs]]
  ;
alter table rhn_deployed_probe 
    add constraint dprob_recid_probe_type_uq unique ( recid, probe_type );

select 'rhnsat/synonyms/deployed_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/deployed_probe.sql
create or replace synonym deployed_probe for rhn_deployed_probe;

select 'rhnsat/synonyms/environment.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/environment.sql
create or replace synonym environment for rhn_environment;

select 'rhnsat/tables/rhn_os.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_os.sql
create table 
rhn_os
(
    recid       number   (12)
        constraint rhn_os000_recid_nn not null
        constraint rhn_os000_recid_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    os_name     varchar2 (128)
)
    enable row movement
  ;
comment on table rhn_os 
    is 'os000  operating systems';

select 'rhnsat/tables/rhn_server_monitoring_info.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_server_monitoring_info.sql
create table 
rhn_server_monitoring_info
(
    recid               number (12)
        constraint rhn_host_recid_nn not null
        constraint rhn_host_recid_pk primary key
            using index tablespace [[4m_tbs]]
            ,
    os_id               number (12)
)
    enable row movement
  ;
comment on table rhn_server_monitoring_info 
    is 'host   additional fields to rhn_server for monitoring servers';
alter table rhn_server_monitoring_info
    add constraint rhn_host_server_id_fk
    foreign key ( recid )
    references rhnServer ( id );
alter table rhn_server_monitoring_info
    add constraint rhn_host_server_name_fk
    foreign key ( os_id )
    references rhn_os ( recid );

select 'rhnsat/tables/rhnServerNetInterface.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerNetInterface.sql
create table
rhnServerNetInterface
(
	server_id	number
			constraint rhn_srv_net_iface_sid_nn not null
			constraint rhn_srv_net_iface_sid_fk 
				references rhnServer(id),
	name		varchar2(32)
			constraint rhn_srv_net_iface_name_nn not null,
	ip_addr		varchar2(64),
	netmask		varchar2(64),
	broadcast	varchar2(64),
	hw_addr		varchar2(18),
	module		varchar2(128),
	created		date default sysdate
			constraint rhn_srv_net_iface_created_nn not null,
	modified	date default sysdate
			constraint rhn_srv_net_iface_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_srv_net_iface_mod_trig
before insert or update on rhnServerNetInterface
for each row
begin
        :new.modified := sysdate;
end;
/
show errors
create index rhn_srv_net_iface_sid_name_idx
	on rhnServerNetInterface ( server_id, name )
	tablespace [[8m_tbs]]
  ;
alter table rhnServerNetInterface add constraint rhn_srv_net_iface_sid_name_uq
	unique ( server_id, name );

select 'rhnsat/tables/rhn_interface_monitoring.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_interface_monitoring.sql
create table 
rhn_interface_monitoring
(
    server_id       number
        constraint rhn_monif_server_id_nn not null
        constraint rhn_monif_server_pk primary key
            using index tablespace [[8m_tbs]]
            ,
    server_name     varchar2 (32)
        constraint rhn_monif_server_name_nn not null
)
    enable row movement
  ;
comment on table rhn_interface_monitoring
   is 'monif  Monitoring interface.  The one entry from rhnservernetinterface to be used for monitoring on a host.';
alter table rhn_interface_monitoring
    add constraint rhn_monif_server_name_fk
    foreign key ( server_id, server_name )
    references rhnServerNetInterface ( server_id, name );
create unique index rhn_int_mont_sid_sname_idx
on rhn_interface_monitoring ( server_id, server_name )
   tablespace [[8m_tbs]]
   nologging
  ;

select 'rhnsat/views/rhn_host_monitoring.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhn_host_monitoring.sql
create or replace view rhn_host_monitoring
(
	recid,
	ip,
	name,
	description,
	customer_id,
	os_id,
	asset_id,
	last_update_user,
	last_update_date
) as
select  s.id            recid,
	rhn_server.get_ip_address(s.id)	ip,
        s.name          name,
        s.description   description,
        s.org_id        customer_id,
        '4'             os_id,
        null            asset_id,
        null            last_update_user,
        null            last_update_date
from	rhnServer	s
/

select 'rhnsat/synonyms/host.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/host.sql
create or replace synonym host for rhn_host_monitoring;

select 'rhnsat/tables/rhn_host_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_host_probe.sql
create table 
rhn_host_probe
(
    probe_id        number   (12)
        constraint rhn_hstpb_probe_id_nn not null
        constraint rhn_hstpb_probe_id_pk primary key
            using index tablespace [[4m_tbs]]
            ,
    probe_type      varchar2 (12) default 'host'
        constraint rhn_hstpb_probe_type_nn not null
        constraint rhn_hstpb_probe_type_ck check ( probe_type='host' ),
    host_id         number   (12)
        constraint rhn_hstpb_host_id_nn not null,
    sat_cluster_id  number   (12)
        constraint rhn_hstpb_sat_cl_id_nn not null
)  
    enable row movement
  ;
comment on table rhn_host_probe 
    is 'hstpb  host probe definitions';
create index rhn_hstpb_host_id_idx 
    on rhn_host_probe ( host_id )
    tablespace [[4m_tbs]]
  ;
create index rhn_hstpb_sat_cluster_id_idx 
    on rhn_host_probe ( sat_cluster_id )
    tablespace [[4m_tbs]]
  ;
create unique index rhn_hstpb_pbid_ptype_idx
    on rhn_host_probe ( probe_id, probe_type )
    tablespace [[4m_tbs]]
  ;
alter table rhn_host_probe
    add constraint rhn_hstpb_host_id_fk
    foreign key ( host_id )
    references rhnServer( id );
alter table rhn_host_probe
    add constraint rhn_hstpb_probe_probe_id_fk
    foreign key ( probe_id, probe_type )
    references rhn_probe( recid, probe_type )
    on delete cascade;
alter table rhn_host_probe
    add constraint rhn_hstpb_satcl_id_fk
    foreign key ( sat_cluster_id )
    references rhn_sat_cluster( recid )
    on delete cascade;
create sequence rhn_host_probes_recid_seq;

select 'rhnsat/tables/rhn_host_check_suites.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_host_check_suites.sql
create table 
rhn_host_check_suites
(
    host_probe_id   number   (12)
        constraint rhn_hstck_host_probe_nn not null,
    suite_id        number   (12)
        constraint rhn_hstck_suite_id_nn not null
)
    enable row movement
  ;
comment on table rhn_host_check_suites 
    is 'hstck  check suites used by hosts. the host_probe_id must reference a probe oftype hostprobe.';
create unique index rhn_hstck_suite_id_probe_id_pk 
    on rhn_host_check_suites ( host_probe_id , suite_id )
    tablespace [[2m_tbs]]
  ;
alter table rhn_host_check_suites 
    add constraint rhn_hstck_suite_id_probe_id_pk 
    primary key ( host_probe_id, suite_id );
alter table rhn_host_check_suites
    add constraint rhn_hstck_cksut_suite_id_fk
    foreign key ( suite_id )
    references rhn_check_suites( recid )
    on delete cascade;
alter table rhn_host_check_suites
    add constraint rhn_hstck_hstpb_probe_id_fk
    foreign key ( host_probe_id )
    references rhn_host_probe( probe_id )
    on delete cascade;

select 'rhnsat/synonyms/host_check_suites.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/host_check_suites.sql
create or replace synonym host_check_suites for rhn_host_check_suites;

select 'rhnsat/synonyms/host_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/host_probe.sql
create or replace synonym host_probe for rhn_host_probe;
create or replace synonym host_probes_recid_seq for rhn_host_probes_recid_seq;

select 'rhnsat/tables/rhn_ll_netsaint.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_ll_netsaint.sql
create table 
rhn_ll_netsaint
(
    netsaint_id number
        constraint rhn_llnet_netsaint_id_nn not null,
    city        varchar2 (255)
)
    enable row movement
  ;
comment on table rhn_ll_netsaint 
    is 'llnet  scout records';
alter table rhn_ll_netsaint
    add constraint rhn_llnts_sat_cluster_idfk
    foreign key ( netsaint_id )
    references rhn_sat_cluster( recid );
create index rhn_ll_ntsnts_nsid_idx
on rhn_ll_netsaint ( netsaint_id )
   tablespace [[64k_tbs]]
   nologging
  ;

select 'rhnsat/synonyms/ll_netsaint.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/ll_netsaint.sql
create or replace synonym ll_netsaint for rhn_ll_netsaint;

select 'rhnsat/synonyms/method_types.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/method_types.sql
create or replace synonym method_types for rhn_method_types;

select 'rhnsat/tables/rhn_quanta.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_quanta.sql
create table 
rhn_quanta
(
    quantum_id          varchar2 (10)
        constraint rhn_qnta0_quantum_id_nn not null
        constraint rhn_qnta0_quantum_id_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    basic_unit_id       varchar2 (20),
    description         varchar2 (200),
    last_update_user    varchar2 (40),
    last_update_date    date
) 
    enable row movement
  ;
comment on table rhn_quanta 
    is 'qnta0  quanta definitions';

select 'rhnsat/tables/rhn_units.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_units.sql
create table 
rhn_units
(
    unit_id             varchar2 (10)
        constraint rhn_units_unit_id_nn not null
        constraint rhn_units_unit_id_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    quantum_id          varchar2 (10)
        constraint rhn_units_quantum_id_nn not null,
    unit_label          varchar2 (20),
    description         varchar2 (200),
    to_base_unit_fn     varchar2 (2000),
    from_base_unit_fn   varchar2 (2000),
    validate_fn         varchar2 (2000),
    last_update_user    varchar2 (40),
    last_update_date    date
)
    enable row movement
  ;
comment on table rhn_units 
    is 'units  unit definitions';
create index rhn_units_quantum_id_idx 
    on rhn_units ( quantum_id )
    tablespace [[64k_tbs]]
  ;
alter table rhn_units
    add constraint rhn_units_qnta0_quantum_id_fk
    foreign key ( quantum_id )
    references rhn_quanta( quantum_id );

select 'rhnsat/tables/rhn_metrics.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_metrics.sql
create table 
rhn_metrics 
(
    metric_id           varchar2 (40)
        constraint rhn_metric_metric_id_nn not null,
    storage_unit_id     varchar2 (10)
        constraint rhn_metric_storage_id_nn not null,
    description         varchar2 (200),
    last_update_user    varchar2 (40),
    last_update_date    date,
    label               varchar2 (40),
    command_class       varchar2 (255) default 'nothing'
        constraint rhn_metric_cmd_class_nn not null
)
    enable row movement
  ;
comment on table rhn_metrics 
    is 'metrc  metric definitions';
create unique index rhn_metrc_cmd_cl_met_id_pk 
    on rhn_metrics ( command_class, metric_id )
    tablespace [[2m_tbs]]
  ;
create index rhn_metrc_storage_unit_id_idx 
    on rhn_metrics ( storage_unit_id )
    tablespace [[2m_tbs]]
  ;
alter table rhn_metrics 
    add constraint rhn_metrc_cmd_cl_metric_id_pk 
    primary key ( command_class, metric_id );
alter table rhn_metrics
    add constraint rhn_metrc_comcl_cmd_class_fk
    foreign key ( command_class )
    references rhn_command_class( class_name );
alter table rhn_metrics
    add constraint rhn_metrc_uts_stor_ut_id_fk
    foreign key ( storage_unit_id )
    references rhn_units( unit_id );

select 'rhnsat/synonyms/metrics.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/metrics.sql
create or replace synonym metrics for rhn_metrics ;

select 'rhnsat/tables/rhn_multi_scout_threshold.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_multi_scout_threshold.sql
create table 
rhn_multi_scout_threshold
(
    probe_id                         number   (12)
        constraint rhn_msthr_probe_id_nn not null
        constraint rhn_msthr_probe_id_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    scout_warning_threshold_is_all   char     (1)  default '1'
        constraint rhn_msthr_warn_thres_nn not null,
    scout_crit_threshold_is_all      char     (1)  default '1'
        constraint rhn_msthr_crit_thres_nn not null,
    scout_warning_threshold          number   (12),
    scout_critical_threshold         number   (12)
)
    enable row movement
  ;
comment on table rhn_multi_scout_threshold 
    is 'msthr  multi_scout_threshold definitions';

select 'rhnsat/synonyms/multi_scout_threshold.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/multi_scout_threshold.sql
create or replace synonym multi_scout_threshold for rhn_multi_scout_threshold;

select 'rhnsat/synonyms/notification_formats.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/notification_formats.sql
create or replace synonym notification_formats for rhn_notification_formats;
create or replace synonym ntfmt_recid_seq for rhn_ntfmt_recid_seq;

select 'rhnsat/tables/rhn_notifservers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_notifservers.sql
create table 
rhn_notifservers
(
    recid   number   (12)
        constraint rhn_notsv_recid_nn not null
        constraint rhn_notsv_recid_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    name    varchar2 (255)
)
    enable row movement
  ;
comment on table rhn_notifservers 
    is 'notsv  notification host table';

select 'rhnsat/synonyms/notifservers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/notifservers.sql
create or replace synonym notifservers for rhn_notifservers;

select 'rhnsat/synonyms/os.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/os.sql
create or replace synonym os for rhn_os;

select 'rhnsat/tables/rhn_os_commands_xref.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_os_commands_xref.sql
create table 
rhn_os_commands_xref
(
    os_id           number   (12)
        constraint rhn_oscxr_os_id_nn not null,
    commands_id     number   (12)
        constraint rhn_oscxr_commands_id_nn not null
)
    enable row movement
  ;
comment on table rhn_os_commands_xref 
    is 'oscxr  operating systems - commands cross ref';
create unique index rhn_oscxr_os_id_commands_id_pk 
    on rhn_os_commands_xref ( os_id, commands_id )
    tablespace [[2m_tbs]]
  ;
alter table rhn_os_commands_xref 
    add constraint rhn_oscxr_os_id_commands_id_pk 
    primary key ( os_id, commands_id );
alter table rhn_os_commands_xref
    add constraint rhn_oscxr_cmmnd_commands_id_fk
    foreign key ( commands_id )
    references rhn_command( recid );
alter table rhn_os_commands_xref
    add constraint rhn_oscxr_os000_os_id_fk
    foreign key ( os_id )
    references rhn_os( recid );

select 'rhnsat/synonyms/os_commands_xref.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/os_commands_xref.sql
create or replace synonym os_commands_xref for rhn_os_commands_xref;

select 'rhnsat/synonyms/pager_types.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/pager_types.sql
create or replace synonym pager_types for rhn_pager_types;
create or replace synonym pager_types_recid_seq for rhn_pager_types_recid_seq;

select 'rhnsat/synonyms/physical_location.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/physical_location.sql
create or replace synonym physical_location for rhn_physical_location;
create or replace synonym physical_location_recid_seq for rhn_physical_loc_recid_seq;

select 'rhnsat/synonyms/probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/probe.sql
create or replace synonym probe for rhn_probe;
create or replace synonym probes_recid_seq for rhn_probes_recid_seq;

select 'rhnsat/tables/rhn_probe_param_value.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_probe_param_value.sql
create table 
rhn_probe_param_value
(
    probe_id            number
        constraint rhn_ppval_probe_id_nn not null,
    command_id          number
        constraint rhn_ppval_command_id_nn not null,
    param_name          varchar2 (40)
        constraint rhn_ppval_param_name_nn not null,
    value               varchar2 (1024),
    last_update_user    varchar2 (40),
    last_update_date    date
)
    enable row movement
  ;
comment on table rhn_probe_param_value 
    is 'ppval  param value for a probe running a command';
create unique index rhn_ppval_p_id_cmd_id_parm_pk 
    on rhn_probe_param_value ( probe_id, command_id, param_name )
    tablespace [[2m_tbs]]
  ;
alter table rhn_probe_param_value 
    add constraint rhn_ppval_p_id_cmd_id_parm_pk 
    primary key ( probe_id, command_id, param_name );
alter table rhn_probe_param_value
    add constraint rhn_ppval_chkpb_probe_id_fk
    foreign key ( probe_id )
    references rhn_probe( recid )
    on delete cascade;
alter table rhn_probe_param_value
    add constraint rhn_ppval_cmd_id_parm_nm_fk
    foreign key ( command_id, param_name )
    references rhn_command_parameter( command_id, param_name )
    on delete cascade;

select 'rhnsat/synonyms/probe_param_value.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/probe_param_value.sql
create or replace synonym probe_param_value for rhn_probe_param_value;

select 'rhnsat/tables/rhn_probe_state.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_probe_state.sql
create table rhn_probe_state
(
    probe_id                         number   (12)
        constraint rhn_prbst_probe_id_nn not null,
    scout_id                         number   (12)
        constraint rhn_prbst_scout_id_nn not null,
    state                            varchar2 (20),
    output                           varchar2 (4000),
    last_check                       date
) 
    enable row movement
  ;
comment on table rhn_probe_state is 'prbst  probe state';
create unique index rhn_prbst_probe_id_scout_id_pk 
    on rhn_probe_state ( probe_id, scout_id )
    tablespace [[8m_tbs]]
  ;
alter table rhn_probe_state 
    add constraint prbst_probe_id_scout_id_pk 
    primary key ( probe_id, scout_id );

select 'rhnsat/synonyms/probe_state.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/probe_state.sql
create or replace synonym probe_state for rhn_probe_state;

select 'rhnsat/synonyms/probe_types.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/probe_types.sql
create or replace synonym probe_types for rhn_probe_types;

select 'rhnsat/synonyms/quanta.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/quanta.sql
create or replace synonym quanta for rhn_quanta;

select 'rhnsat/tables/rhn_redirect_types.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_redirect_types.sql
create table 
rhn_redirect_types
(
    name            varchar2 (20)
        constraint rhn_rdrtp_name_nn not null
        constraint rhn_rdrtp_name_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    description     varchar2 (255),
    long_name       varchar2 (80)
)
    enable row movement
  ;
comment on table rhn_redirect_types 
    is 'rdrtp  redirect types';
create sequence rhn_redirect_types_recid_seq;

select 'rhnsat/tables/rhn_redirects.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_redirects.sql
create table 
rhn_redirects
(
    recid                            number   (12)
        constraint rhn_rdrct_recid_nn not null 
        constraint rhn_rdrct_recid_pk primary key
            using index tablespace [[8m_tbs]]
            ,
    customer_id                      number   (12),
    contact_id                       number   (12),
    redirect_type                    varchar2 (20)
        constraint rhn_rdrct_redirect_type_nn not null,
    description                      varchar2 (25),
    reason                           varchar2 (2000),
    expiration                       date
        constraint rhn_rdrct_expiration_nn not null,
    last_update_user                 varchar2 (40),
    last_update_date                 date,
    start_date                       date
        constraint rhn_rdrct_start_date_nn not null,
    recurring                        number (12,0) default 0
        constraint rhn_rdrct_recurring_nn not null
        constraint RHN_RDRCT_RECUR_VALID check (recurring in (0, 1)),
    recurring_frequency             number (12,0) default 2
         constraint RHN_RDRCT_RECUR_FREQ_VALID check (recurring_frequency in (2,3,6)),
    recurring_duration              number(12,0)  default 0,
    recurring_dur_type              number(12,0) default 12
           constraint rhn_rdrct_rec_dtype_valid check ( recurring_dur_type in (12,11,5,3,1) )
)
    enable row movement
  ;
comment on table rhn_redirects 
    is 'rdrct  redirect definitions';
create index rhn_rdrct_customer_id_idx 
    on rhn_redirects ( customer_id )
    tablespace [[8m_tbs]]
  ;
create index rhn_rdrct_redirect_type_idx 
    on rhn_redirects ( redirect_type )
    tablespace [[8m_tbs]]
  ;
alter table rhn_redirects 
    add constraint rhn_rdrct_start_lte_expir check (start_date <= expiration );
create index rhn_rdrct_cid_idx
	on rhn_redirects( contact_id )
	tablespace [[4m_tbs]]
  ;
alter table rhn_redirects
    add constraint rhn_rdrct_cntct_contact_id_fk
    foreign key ( contact_id )
    references web_contact( id );
alter table rhn_redirects
    add constraint rhn_rdrct_cstmr_customer_id_fk
    foreign key ( customer_id )
    references web_customer( id );
alter table rhn_redirects
    add constraint rhn_rdrct_rdrtp_redir_type_fk
    foreign key ( redirect_type )
    references rhn_redirect_types( name );
create sequence rhn_redirects_recid_seq;

select 'rhnsat/tables/rhn_redirect_match_types.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_redirect_match_types.sql
create table 
rhn_redirect_match_types
(
    name                             varchar2 (255)
        constraint rhn_rdrmt_name_nn not null
        constraint rhn_rdrmt_name_pk primary key
            using index tablespace [[64k_tbs]]
)
    enable row movement
  ;
comment on table rhn_redirect_match_types 
    is 'rdrmt  redirect match types';

select 'rhnsat/tables/rhn_redirect_criteria.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_redirect_criteria.sql
create table 
rhn_redirect_criteria
(
    recid           number   (12)
        constraint rhn_rdrcr_recid_nn not null
        constraint rhn_rdrcr_recid_pk primary key
            using index tablespace [[4m_tbs]]
            ,
    redirect_id     number   (12)
        constraint rhn_rdrcr_redirect_id_nn not null,
    match_param     varchar2 (255)
        constraint rhn_rdrcr_match_param_nn not null,
    match_value     varchar2 (255),
    inverted        char     (1) default 0
        constraint rhn_rdrcr_inverted_nn not null
) 
    enable row movement
  ;
comment on table rhn_redirect_criteria 
    is 'rdrcr  redirect criteria';
create index rhn_rdrcr_redirect_id_idx 
    on rhn_redirect_criteria ( redirect_id )
    tablespace [[4m_tbs]]
  ;
alter table rhn_redirect_criteria
    add constraint rhn_rdrcr_rdrct_redirect_id_fk
    foreign key ( redirect_id )
    references rhn_redirects( recid )
    on delete cascade;
alter table rhn_redirect_criteria
    add constraint rhn_rdrcr_rdrmt_match_nm_fk
    foreign key ( match_param )
    references rhn_redirect_match_types( name );
create sequence rhn_redirect_crit_recid_seq;

select 'rhnsat/synonyms/redirect_criteria.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/redirect_criteria.sql
create or replace synonym redirect_criteria for rhn_redirect_criteria;
create or replace synonym redirect_criteria_recid_seq for rhn_redirect_crit_recid_seq;

select 'rhnsat/tables/rhn_redirect_email_targets.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_redirect_email_targets.sql
create table 
rhn_redirect_email_targets
(
    redirect_id     number   (12)
        constraint rhn_rdret_redirect_id_nn not null,
    email_address   varchar2 (255)
        constraint rhn_rdret_email_addr_nn not null
)
    enable row movement
  ;
comment on table rhn_redirect_email_targets 
    is 'rdret  redirect email targets';
create unique index rhn_rdret_pk 
    on rhn_redirect_email_targets ( redirect_id, email_address )
    tablespace [[2m_tbs]]
  ;
create index rhn_rdret_redirect_id_idx 
    on rhn_redirect_email_targets ( redirect_id )
    tablespace [[2m_tbs]]
  ;
alter table rhn_redirect_email_targets 
    add constraint rhn_rdret_pk primary key ( redirect_id, email_address );
alter table rhn_redirect_email_targets
    add constraint rhn_rdret_rdrct_redirect_id_fk
    foreign key ( redirect_id )
    references rhn_redirects( recid )
    on delete cascade;

select 'rhnsat/synonyms/redirect_email_targets.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/redirect_email_targets.sql
create or replace synonym redirect_email_targets for rhn_redirect_email_targets;

select 'rhnsat/tables/rhn_redirect_group_targets.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_redirect_group_targets.sql
create table 
rhn_redirect_group_targets
(
    redirect_id         number   (12)
        constraint rhn_rdrgt_redirect_id_nn not null,
    contact_group_id    number   (12)
        constraint rhn_rdrgt_group_id_nn not null
)
    enable row movement
  ;
comment on table rhn_redirect_group_targets 
    is 'rdrgt  redirect group targets';
create unique index rhn_rdrgt_pk 
    on rhn_redirect_group_targets ( redirect_id , contact_group_id )
    tablespace [[2m_tbs]]
  ;
create index rhn_rdrgt_redirect_id_idx 
    on rhn_redirect_group_targets ( redirect_id )
    tablespace [[2m_tbs]]
  ;
alter table rhn_redirect_group_targets 
    add constraint rhn_rdrgt_pk primary key ( redirect_id, contact_group_id );
alter table rhn_redirect_group_targets
    add constraint rhn_rdrgt_rdrct_redirect_id_fk
    foreign key ( redirect_id )
    references rhn_redirects( recid )
    on delete cascade;

select 'rhnsat/synonyms/redirect_group_targets.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/redirect_group_targets.sql
create or replace synonym redirect_group_targets for rhn_redirect_group_targets;

select 'rhnsat/synonyms/redirect_match_types.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/redirect_match_types.sql
create or replace synonym redirect_match_types for rhn_redirect_match_types;

select 'rhnsat/tables/rhn_redirect_method_targets.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_redirect_method_targets.sql
create table 
rhn_redirect_method_targets
(
    redirect_id         number   (12)
        constraint rhn_rdrme_redirect_id not null,
    contact_method_id   number   (12)
        constraint rhn_rdrme_method_id not null
)
    enable row movement
  ;
comment on table rhn_redirect_method_targets 
    is 'rdrme  redirect method targets';
create unique index rhn_rdrme_pk 
    on rhn_redirect_method_targets ( redirect_id , contact_method_id )
    tablespace [[2m_tbs]]
  ;
create index rhn_rdrme_redirect_id_idx 
    on rhn_redirect_method_targets ( redirect_id )
    tablespace [[2m_tbs]]
  ;
create index rhn_rdrme_cmid_idx
    on rhn_redirect_method_targets ( contact_method_id )
    tablespace [[2m_tbs]]
  ;
alter table rhn_redirect_method_targets 
    add constraint rhn_rdrme_pk primary key ( redirect_id, contact_method_id );
alter table rhn_redirect_method_targets
    add constraint rhn_rdrmt_cmeth_redirect_id_fk
    foreign key ( contact_method_id )
    references rhn_contact_methods( recid )
    on delete cascade;
alter table rhn_redirect_method_targets
    add constraint rhn_rdrmt_rdrct_redirect_id_fk
    foreign key ( redirect_id )
    references rhn_redirects( recid )
    on delete cascade;

select 'rhnsat/synonyms/redirect_method_targets.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/redirect_method_targets.sql
create or replace synonym redirect_method_targets for rhn_redirect_method_targets;

select 'rhnsat/synonyms/redirect_types.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/redirect_types.sql
create or replace synonym redirect_types for rhn_redirect_types;
create or replace synonym redirect_types_recid_seq for rhn_redirect_types_recid_seq;

select 'rhnsat/synonyms/redirects.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/redirects.sql
create or replace synonym redirects for rhn_redirects;
create or replace synonym redirects_recid_seq for rhn_redirects_recid_seq;

select 'rhnsat/synonyms/rhnUser.satellite.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/rhnUser.satellite.sql
create synonym rhnUser for web_contact;

select 'rhnsat/synonyms/sat_cluster.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/sat_cluster.sql
create or replace synonym sat_cluster for rhn_sat_cluster;

select 'rhnsat/tables/rhn_sat_cluster_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_sat_cluster_probe.sql
create table 
rhn_sat_cluster_probe
(
    probe_id        number   (12)
        constraint rhn_sclpb_probe_id_nn not null
        constraint rhn_sclpb_probe_id_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    probe_type      varchar2 (12) default 'satcluster'
        constraint rhn_sclpb_probe_type_nn not null
        constraint rhn_sclpb_probe_type_ck check (probe_type='satcluster'),
    sat_cluster_id  number   (12)
        constraint rhn_sclpb_sat_cluster_id_nn not null
)
    enable row movement
  ;
comment on table rhn_sat_cluster_probe 
    is 'sclpb  satellite cluster probe definitions';
create index rhn_sclpb_sat_cluster_id_idx 
    on rhn_sat_cluster_probe ( sat_cluster_id ) 
    tablespace [[2m_tbs]]
  ;
create index rhn_sclpb_pid_ptype_idx
    on rhn_sat_cluster_probe ( probe_id, probe_type )
    tablespace [[2m_tbs]]
  ;
alter table rhn_sat_cluster_probe
    add constraint rhn_sclpb_prb_recid_prb_typ_fk
    foreign key ( probe_id, probe_type )
    references rhn_probe( recid, probe_type )
    on delete cascade;
alter table rhn_sat_cluster_probe
    add constraint rhn_sclpb_satcl_sat_cl_id_fk
    foreign key ( sat_cluster_id )
    references rhn_sat_cluster( recid )
    on delete cascade;

select 'rhnsat/synonyms/sat_cluster_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/sat_cluster_probe.sql
create or replace synonym sat_cluster_probe for rhn_sat_cluster_probe;

select 'rhnsat/tables/rhn_sat_node.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_sat_node.sql
create table 
rhn_sat_node
(
	recid			number(12)
				constraint rhn_satnd_recid_nn not null
				constraint rhn_satnd_recid_pk primary key
					using index tablespace [[2m_tbs]]
					,
        server_id               number
                                constraint rhn_satnd_sid_fk
	   			        references rhnServer(id),
	target_type		varchar2(10) default 'node'
				constraint rhn_satnd_target_type_nn not null
				constraint rhn_satnd_target_type_ck
					check (target_type in ('node')),
	last_update_user	varchar2(40),
	last_update_date	date,
	mac_address		varchar2(17)
				constraint rhn_satnd_mac_address_nn not null,
	max_concurrent_checks	number(4),
	sat_cluster_id		number(12)
				constraint rhn_satnd_sat_cluster_id_nn not null,
	ip			varchar2 (15),
	sched_log_level		number(4) default (0)
				constraint rhn_satnd_sched_log_level_nn not null,
	sput_log_level		number(4) default (0)
				constraint rhn_satnd_sput_log_level_nn not null,
	dq_log_level		number(4) default (0)
				constraint rhn_satnd_dq_log_level_nn not null,
	scout_shared_key	varchar2(64)
				constraint rhn_satnd_ssk_nn not null
)
	enable row movement
  ;
comment on table rhn_sat_node is 'satnd  satellite node';
create index rhn_sat_node_scid_idx
on rhn_sat_node ( sat_cluster_id )
   tablespace [[64k_tbs]]
   nologging
  ;
create index rhn_sat_node_sid_idx
on rhn_sat_node ( server_id )
   tablespace [[64k_tbs]]
   nologging
  ;
alter table rhn_sat_node add constraint rhn_satnd_cmdtg_rid_tar_ty_fk
    foreign key ( recid, target_type )
    references rhn_command_target( recid, target_type )
    on delete cascade;
alter table rhn_sat_node add constraint rhn_satnd_satcl_sat_cl_id_fk
    foreign key ( sat_cluster_id )
    references rhn_sat_cluster( recid )
    on delete cascade;

select 'rhnsat/synonyms/sat_node.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/sat_node.sql
create or replace synonym sat_node for rhn_sat_node;

select 'rhnsat/tables/rhn_sat_node_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_sat_node_probe.sql
create table 
rhn_sat_node_probe
(
    probe_id        number   (12)
        constraint rhn_sndpb_probe_id_nn not null
        constraint rhn_sndpb_probe_id_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    probe_type      varchar2 (12)  default 'satnode'
        constraint rhn_sndpb_probe_type_nn not null
        constraint rhn_sndpb_probe_type_ck check (probe_type='satnode'), 
    sat_node_id     number   (12)
        constraint rhn_sndpb_sat_node_id_nn not null
) 
    enable row movement
  ;
comment on table rhn_sat_node_probe 
    is 'sndpb  satellite node probe definitions';
create index rhn_sndpb_sat_node_id_idx 
    on rhn_sat_node_probe ( sat_node_id )
    tablespace [[2m_tbs]]
  ;
create index rhn_sndpb_pid_ptype_idx
    on rhn_sat_node_probe ( probe_id, probe_type )
    tablespace [[2m_tbs]]
  ;
alter table rhn_sat_node_probe
    add constraint rhn_sndpb_pr_recid_pr_typ_fk
    foreign key ( probe_id, probe_type )
    references rhn_probe( recid, probe_type )
    on delete cascade;
alter table rhn_sat_node_probe
    add constraint rhn_sndpb_satnd_sat_nd_id_fk
    foreign key ( sat_node_id )
    references rhn_sat_node( recid )
    on delete cascade;

select 'rhnsat/synonyms/sat_node_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/sat_node_probe.sql
create or replace synonym sat_node_probe for rhn_sat_node_probe;

select 'rhnsat/tables/rhn_satellite_state.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_satellite_state.sql
create table 
rhn_satellite_state
(
    satellite_id                     number   (12)
        constraint rhn_satst_sat_id_nn not null
        constraint rhn_satst_sat_id_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    last_check                       date,
    probe_count                      number   (10),
    pct_ok                           number   (10,2),
    pct_warning                      number   (10,2),
    pct_critical                     number   (10,2),
    pct_unknown                      number   (10,2),
    pct_pending                      number   (10,2),
    recent_state_changes             number   (10),
    imminent_probes                  number   (10),
    max_exec_time                    number   (10,2),
    min_exec_time                    number   (10,2),
    avg_exec_time                    number   (10,2),
    max_latency                      number   (10,2),
    min_latency                      number   (10,2),
    avg_latency                      number   (10,2)
)
    enable row movement
  ;
comment on table rhn_satellite_state 
    is 'satst  satellite state (monitoring)';

select 'rhnsat/synonyms/satellite_state.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/satellite_state.sql
create or replace synonym satellite_state for rhn_satellite_state;

select 'rhnsat/tables/rhn_schedule_days.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_schedule_days.sql
create table 
rhn_schedule_days
(
    recid               number   (12)
        constraint rhn_schdy_recid_nn not null
        constraint rhn_schdy_recid_ck check (recid > 0)
        constraint rhn_schdy_recid_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    schedule_id         number   (12),
    ord                 number   (3),
    start_1             date,
    end_1               date,
    start_2             date,
    end_2               date,
    start_3             date,
    end_3               date,
    start_4             date,
    end_4               date,
    last_update_user    varchar2 (40),
    last_update_date    varchar2 (40)
)
    enable row movement
  ;
comment on table rhn_schedule_days 
    is 'schdy  individual day records for schedules';
create index rhn_schdy_schedule_id_idx 
    on rhn_schedule_days ( schedule_id )
    tablespace [[2m_tbs]]
  ;
alter table rhn_schedule_days
    add constraint rhn_schdy_sched_schedule_id_fk
    foreign key ( schedule_id )
    references rhn_schedules( recid )
    on delete cascade;
create sequence rhn_schedule_days_recid_seq;

select 'rhnsat/synonyms/schedule_days.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/schedule_days.sql
create or replace synonym schedule_days for rhn_schedule_days;
create or replace synonym schedule_days_recid_seq for rhn_schedule_days_recid_seq;

select 'rhnsat/tables/rhn_schedule_days_norm.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_schedule_days_norm.sql
create table 
rhn_schedule_days_norm
(
    schedule_id     number   (12),
    ord             number   (3),
    start_int       number   (12),
    end_int         number   (12)        
)
	enable row movement
	;

select 'rhnsat/synonyms/schedule_days_norm.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/schedule_days_norm.sql
create or replace synonym schedule_days_norm for rhn_schedule_days_norm;

select 'rhnsat/synonyms/schedule_types.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/schedule_types.sql
create or replace synonym schedule_types for rhn_schedule_types;
create or replace synonym schedule_types_recid_seq for rhn_schedule_types_recid_seq;

select 'rhnsat/tables/rhn_schedule_weeks.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_schedule_weeks.sql
create table 
rhn_schedule_weeks
(
    recid                   number   (12)
        constraint rhn_schwk_recid_nn not null
        constraint rhn_schwk_recid_ck check (recid > 0)
        constraint rhn_schwk_recid_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    schedule_id             number   (12)
        constraint rhn_schwk_sched_id_nn not null,
    component_schedule_id   number   (12),
    ord                     number   (3),
    last_update_user        varchar2 (40),
    last_update_date        date
) 
    enable row movement
  ;
comment on table rhn_schedule_weeks 
    is 'schwk  individual week records for schedules';
create index rhn_schwk_schedule_id_idx 
    on rhn_schedule_weeks ( schedule_id )
    tablespace [[2m_tbs]]
  ;
create index rhn_schwk_comp_sched_id_idx 
    on rhn_schedule_weeks ( component_schedule_id )
    tablespace [[2m_tbs]]
  ;
alter table rhn_schedule_weeks
    add constraint rhn_schwk_sched_comp_sched_fk
    foreign key ( component_schedule_id )
    references rhn_schedules( recid );
alter table rhn_schedule_weeks
    add constraint rhn_schwk_sched_sched_id_fk
    foreign key ( schedule_id )
    references rhn_schedules( recid )
    on delete cascade;
create sequence rhn_schedule_weeks_recid_seq;

select 'rhnsat/synonyms/schedule_weeks.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/schedule_weeks.sql
create or replace synonym schedule_weeks for rhn_schedule_weeks;
create or replace synonym schedule_weeks_recid_seq for rhn_schedule_weeks_recid_seq;

select 'rhnsat/synonyms/schedules.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/schedules.sql
create or replace synonym schedules for rhn_schedules;
create or replace synonym schedules_recid_seq for rhn_schedules_recid_seq;

select 'rhnsat/synonyms/semantic_data_type.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/semantic_data_type.sql
create or replace synonym semantic_data_type for rhn_semantic_data_type;

select 'rhnsat/tables/rhn_service_probe_origins.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_service_probe_origins.sql
create table 
rhn_service_probe_origins
(
    service_probe_id    number   (12)
        constraint rhn_srvpo_serv_p_id_nn not null,
    origin_probe_id     number   (12),
    decoupled           char     (1) default '0'
        constraint rhn_srvpo_decoupled_nn not null
)
    enable row movement
  ;
comment on table rhn_service_probe_origins 
    is 'srvpo  mapping from a replicated service probe to the check suite probe it was copied from.  uq instead of pk because need to set origin_probe_id to null!!!';
create unique index rhn_srvpo_serv_pr_id_orig_uq 
    on rhn_service_probe_origins ( service_probe_id, origin_probe_id )
    tablespace [[8m_tbs]]
  ;
 create unique index rhn_srvpo_serv_orig_pr_id_uq
    on rhn_service_probe_origins ( origin_probe_id, service_probe_id )
    tablespace [[8m_tbs]]
  ;
alter table rhn_service_probe_origins 
    add constraint rhn_srvpo_serv_pr_id_orig_uq 
    unique ( service_probe_id, origin_probe_id );
alter table rhn_service_probe_origins
    add constraint rhn_srvpo_chkpb_orig_pr_id_fk
    foreign key ( origin_probe_id )
    references rhn_check_suite_probe( probe_id )
    on delete cascade;
alter table rhn_service_probe_origins
    add constraint rhn_srvpo_pr_serv_pr_fk
    foreign key ( service_probe_id )
    references rhn_probe( recid )
    on delete cascade;

select 'rhnsat/synonyms/service_probe_origins.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/service_probe_origins.sql
create or replace synonym service_probe_origins for rhn_service_probe_origins;

select 'rhnsat/tables/rhn_snmp_alert.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_snmp_alert.sql
create table 
rhn_snmp_alert
(
   recid                number   (12)
        constraint rhn_snmpa_recid_nn not null
        constraint rhn_snmpa_recid_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    sender_cluster_id   number   (12)
        constraint rhn_snmpa_send_clust_id_nn not null,
    dest_ip             varchar2 (255)
        constraint rhn_snmpa_dest_ip_nn not null,
    dest_port           number   (5)
        constraint rhn_snmpa_dest_port_nn not null,
    date_generated      date,
    date_submitted      date,
    command_name        varchar2 (255),
    notif_type          number   (5),
    op_center           varchar2 (255),
    notif_url           varchar2 (255),
    os_name             varchar2 (128),
    message             varchar2 (2000),
    probe_id            number   (12),
    host_ip             varchar2 (255),
    severity            number   (5),
    command_id          number   (12),
    probe_class         number   (5),
    host_name           varchar2 (255),
    support_center      varchar2 (255)
)
    enable row movement
  ;
comment on table rhn_snmp_alert 
    is 'snmpa  snmp alerts';
alter table rhn_snmp_alert
    add constraint rhn_snmp_alert_sat_cluster_fk
    foreign key ( sender_cluster_id )
    references rhn_sat_cluster( recid );
create index rhn_snmp_alrt_scid_idx
on rhn_snmp_alert ( sender_cluster_id )
   tablespace [[64k_tbs]]
   nologging
  ;
create sequence rhn_snmp_alert_recid_seq;

select 'rhnsat/synonyms/snmp_alert.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/snmp_alert.sql
create or replace synonym snmp_alert for rhn_snmp_alert;
create or replace synonym snmp_alert_recid_seq for rhn_snmp_alert_recid_seq;

select 'rhnsat/synonyms/strategies.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/strategies.sql
create or replace synonym strategies for rhn_strategies;
create or replace synonym strategies_recid_seq for rhn_strategies_recid_seq;

select 'rhnsat/tables/rhn_threshold_type.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_threshold_type.sql
create table 
rhn_threshold_type
(
    name                varchar2 (10)
        constraint rhn_trtyp_name_nn not null
        constraint rhn_trtyp_name_pk primary key
            using index tablespace [[64k_tbs]]
            ,
    description         varchar2 (80)
        constraint rhn_trtyp_desc_nn not null,
    ordinal             number   (3)
        constraint rhn_trtyp_ord_nn not null,
    last_update_user    varchar2 (40),
    last_update_date    date
)
    enable row movement
  ;
comment on table rhn_threshold_type 
    is 'trtyp threshold type:warn_min, warn_max, crit_min, crit_max';

select 'rhnsat/synonyms/threshold_type.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/threshold_type.sql
create or replace synonym threshold_type for rhn_threshold_type;

select 'rhnsat/synonyms/time_zone_names.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/time_zone_names.sql
create or replace synonym time_zone_names for rhn_time_zone_names;

select 'rhnsat/synonyms/units.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/units.sql
create or replace synonym units for rhn_units;

select 'rhnsat/tables/rhn_url_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_url_probe.sql
create table 
rhn_url_probe
(
    username                         varchar2 (40),
    password                         varchar2 (255),
    cookie_enabled                   char     (1)   default 0
        constraint rhn_urlpb_cookie_en_nn not null,
    multi_step                       char     (1)   default 0
        constraint rhn_urlpb_multi_step_nn not null
        constraint rhn_urlpb_multi_step_ck check (multi_step in ('0','1')),
    run_on_scouts                    char     (1)   default ('1')
        constraint rhn_urlpb_run_on_scouts_nn not null
        constraint rhn_urlpb_run_on_scouts_ck 
            check (run_on_scouts in ('0','1')),
    probe_id                         number   (12)
        constraint rhn_urlpb_probe_id_nn not null
        constraint rhn_urlpb_probe_id_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    probe_type                       varchar2 (12)  default 'url'
        constraint rhn_urlpb_probe_type_nn not null
        constraint rhn_urlpb_probe_type_ck check (probe_type='url'),
    sat_cluster_id                   number   (12),
    scout_warning_threshold_is_all   char     (1)   default '1'
        constraint rhn_urlpb_scout_warn_isall_nn not null,
    scout_crit_threshold_is_all      char     (1)   default '1'
        constraint rhn_urlpb_scout_crit_isall_nn not null,
    scout_warning_threshold          number   (12)  default -1,
    scout_critical_threshold         number   (12)  default -1
)
    enable row movement
  ;
comment on table rhn_url_probe 
    is 'urlpb  url probe';
alter table rhn_url_probe
    add constraint rhn_urlpb_probe_pr_id_pr_fk
    foreign key ( probe_id, probe_type )
    references rhn_probe( recid, probe_type )
    on delete cascade;
create index rhn_url_probe_pid_ptype_idx
    on rhn_url_probe ( probe_id, probe_type )
  ;

select 'rhnsat/synonyms/url_probe.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/url_probe.sql
create or replace synonym url_probe for rhn_url_probe;

select 'rhnsat/tables/rhn_url_probe_step.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_url_probe_step.sql
create table 
rhn_url_probe_step
(
    recid               number   (12)
        constraint rhn_urlps_recid_nn not null
        constraint rhn_urlps_recid_pk primary key
            using index tablespace [[2m_tbs]]
            ,
    url_probe_id        number   (12)
        constraint rhn_urlps_url_prob_id_nn not null,
    step_number         number   (3)
        constraint rhn_urlps_url_step_no_nn not null,
    description         varchar2 (255),
    url                 varchar2 (2000)
        constraint rhn_urlps_url_nn not null,
    protocol_method     varchar2 (12)
        constraint rhn_urlps_protocol_nn not null,
    verify_links        char     (1)     default 0
        constraint rhn_urlps_ver_links_nn not null
        constraint rhn_urlps_ver_links_ck check (verify_links in ('0','1')),
    load_subsidiary     char     (1)     default 0
        constraint rhn_urlps_load_sub_nn not null
        constraint rhn_urlps_load_sub_ck check (load_subsidiary in ('0','1')),
    pattern             varchar2 (255),
    vpattern            varchar2 (255),
    post_content        varchar2 (4000),
    post_content_type   varchar2 (255),
    connect_warn        number   (10,3)  default 0
        constraint rhn_urlps_conn_warn_nn not null,
    connect_crit        number   (10,3)  default 0
        constraint rhn_urlps_conn_crit_nn not null,
    latency_warn        number   (10,3)  default 0
        constraint rhn_urlps_late_warn_nn not null,
    latency_crit        number   (10,3)  default 0
        constraint rhn_urlps_late_crit_nn not null,
    dns_warn            number   (10,3)  default 0
        constraint rhn_urlps_dns_warn_nn not null,
    dns_crit            number   (10,3)  default 0
        constraint rhn_urlps_dns_crit_nn not null,
    total_warn          number   (10,3)  default 0
        constraint rhn_urlps_total_warn_nn not null,
    total_crit          number   (10,3)  default 0
        constraint rhn_urlps_total_crit_nn not null,
    trans_warn          number   (12)    default 0
        constraint rhn_urlps_trans_warn_nn not null,
    trans_crit          number   (12)    default 0
        constraint rhn_urlps_trans_crit_nn not null,
    through_warn        number   (12)    default 0
        constraint rhn_urlps_thru_warn_nn not null,
    through_crit        number   (12)    default 0
        constraint rhn_urlps_thru_crit_nn not null,
    cookie_key          varchar2 (255),
    cookie_value        varchar2 (255),
    cookie_path         varchar2 (255),
    cookie_domain       varchar2 (255),
    cookie_port         number   (5),
    cookie_secure       char     (1)     default 0
        constraint rhn_urlps_cookie_sec_nn not null
        constraint rhn_urlps_cookie_sec_ck check (cookie_secure in ('0','1')),
    cookie_maxage       number   (9)
)
    enable row movement
  ;
comment on table rhn_url_probe_step 
    is 'urlps  url probe step';
create unique index rhn_urlps_url_pr_id_stp_n_uq 
    on rhn_url_probe_step ( url_probe_id, step_number )
    tablespace [[2m_tbs]]
  ;
alter table rhn_url_probe_step
    add constraint rhn_urlps_urlpb_url_pr_id_fk
    foreign key ( url_probe_id )
    references rhn_url_probe( probe_id )
    on delete cascade;
create sequence rhn_url_probe_step_recid_seq;

select 'rhnsat/synonyms/url_probe_step.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/url_probe_step.sql
create or replace synonym url_probe_step for rhn_url_probe_step;
create or replace synonym url_probe_step_recid_seq for rhn_url_probe_step_recid_seq;

select 'rhnsat/synonyms/widget.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/synonyms/widget.sql
create or replace synonym widget for rhn_widget;

select 'rhnsat/types/channel_name_t.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/types/channel_name_t.sql
create or replace type channel_name_t as table of varchar(64)
/

select 'rhnsat/types/user_group_id_t.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/types/user_group_id_t.sql
create or replace type user_group_id_t as table of NUMBER
/

select 'rhnsat/types/user_group_label_t.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/types/user_group_label_t.sql
create or replace type user_group_label_t as table of varchar(64)
/

select 'rhnsat/types/user_group_name_t.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/types/user_group_name_t.sql
create or replace type user_group_name_t as table of varchar(64)
/

select 'rhnsat/tables/PXTSessions.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/PXTSessions.sql
create table PXTSessions (
        id              number,
        web_user_id     number
                        constraint pxtsessions_user
	                        references web_contact(id) on delete cascade,
        expires         number default 0
                        constraint pxtsessions_expires_nn not null,
        value           varchar2(4000)
                        constraint pxtsessions_value_nn not null
)
	enable row movement
	  nologging;
create unique index pxt_sessions_pk
	on PXTSessions(id)
	tablespace [[8m_tbs]]
	nologging;
alter table PXTSessions add constraint pxt_sessions_pk
	primary key (id);
create sequence pxt_id_seq;
create index PXTSessions_user
	on PXTSessions(web_user_id) 
	tablespace [[4m_tbs]]
	nologging;
create index PXTSessions_expires
	on PXTSessions(expires)
	tablespace [[8m_tbs]]
	nologging;

select 'rhnsat/tables/demo_log.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/demo_log.sql
create table demo_log (
    org_id      number,
    server_id   number
)
	enable row movement
;
create index dl_oid_sid_idx
    on demo_log (org_id, server_id)
    tablespace [[8m_tbs]]
    nologging;

select 'rhnsat/tables/rhnActionType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionType.sql
create table
rhnActionType
(
	id			number
				constraint rhn_action_type_id_nn not null
				constraint rhn_action_type_pk primary key
					using index tablespace [[64k_tbs]],
	label			varchar2(48)
				constraint rhn_action_type_label_nn not null,
	name			varchar2(100)
				constraint rhn_action_type_name_nn not null,
	trigger_snapshot	char(1) default('N')
				constraint rhn_action_type_trigsnap_nn not null
				constraint rhn_action_type_trigsnap_ck
					check (trigger_snapshot in ('Y','N')),
	unlocked_only   	char(1) default('N')
				constraint rhn_action_type_unlck_nn not null
				constraint rhn_action_type_unlck_ck
					check (unlocked_only in ('Y','N'))
)
	enable row movement
  ;
create unique index rhn_action_type_label_uq
	on rhnActionType(label)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_action_type_name_uq
	on rhnActionType(name)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnAction.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnAction.sql
create table
rhnAction
(
	id		number
			constraint rhn_action_id_nn not null
			constraint rhn_action_pk primary key
			using index tablespace [[4m_tbs]],
	org_id		number
			constraint rhn_action_oid_nn not null
			constraint rhn_action_oid_fk
				references web_customer(id)
				on delete cascade,
	action_type	number
			constraint rhn_action_at_nn not null
			constraint rhn_action_at_fk
				references rhnActionType(id),
	name            varchar2(128),
	scheduler	number
			constraint rhn_action_scheduler_fk
				references web_contact(id)
				on delete set null,
	earliest_action	date 
			constraint rhn_action_ea_nn not null,
	version		number default 0
			constraint rhn_action_version_nn not null,
	archived        number default 0
	    	    	constraint rhn_action_archived_nn not null
			constraint rhn_action_archived_ck
				check (archived in (0, 1)),
        prerequisite    number
                        constraint rhn_action_prereq_fk
                                references rhnAction(id) on delete cascade,
	created		date default (sysdate) 
			constraint rhn_action_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_action_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_event_id_seq;
create index rhn_action_oid_idx
	on rhnAction(org_id)
	tablespace [[8m_tbs]]
	nologging;
create index rhn_action_scheduler_idx
	on rhnAction(scheduler)
	tablespace [[8m_tbs]]
	nologging;
create index rhn_action_prereq_id_idx
        on rhnAction(prerequisite, id)
	tablespace [[8m_tbs]]
	nologging;
create or replace trigger
rhn_action_mod_trig
before insert or update on rhnAction
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionStatus.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionStatus.sql
create table
rhnActionStatus
(
	id		number
			constraint rhn_action_status_id_nn not null
			constraint rhn_action_status_pk primary key
				using index tablespace [[64k_tbs]],
	name		varchar2(16),
	created		date default (sysdate)
			constraint rhn_action_status_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_action_status_modified_nn not null
)
	enable row movement
  ;

select 'rhnsat/tables/rhnServerAction.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerAction.sql
create table
rhnServerAction
(
        server_id       number
			constraint rhn_server_action_sid_nn not null
                        constraint rhn_server_action_sid_fk
                        references rhnServer(id),
        action_id       number
			constraint rhn_server_action_aid_nn not null
                        constraint rhn_server_action_aid_fk
                        references rhnAction(id) on delete cascade,
        status          number
			constraint rhn_server_action_status_nn not null
                        constraint rhn_server_action_status_fk
                        references rhnActionStatus(id),
        result_code     number,
        result_msg      varchar2(1024),
        pickup_time     date,
	remaining_tries	number default(5)
			constraint rhn_server_action_remaining_nn not null,
        completion_time	date,
        created         date default (sysdate)
			constraint rhn_server_action_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_server_action_modified_nn not null
)
	enable row movement
  ;
create index rhn_ser_act_sid_aid_s_idx
        on rhnServerAction(server_id, action_id, status)
        tablespace [[8m_tbs]]
  ;
alter table rhnServerAction
	add constraint rhn_server_action_sid_aid_uq
	unique ( server_id, action_id );
create index rhn_ser_act_aid_sid_s_idx
	on rhnServerAction(action_id, server_id, status)
	tablespace [[8m_tbs]]
	nologging;
create or replace trigger
rhn_server_action_mod_trig
before insert or update on rhnServerAction
for each row
declare
	handle_status	number;
begin
	:new.modified := sysdate;
	handle_status := 0;
	if updating then
		if :new.status != :old.status then
			handle_status := 1;
		end if;
	else
		handle_status := 1;
	end if;
	if handle_status = 1 then
		if :new.status = 1 then
			:new.pickup_time := sysdate;
		elsif :new.status = 2 then
			:new.completion_time := sysdate;
		end if;
	end if;
end;
/
show errors

select 'rhnsat/tables/rhnConfigChannelType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigChannelType.sql
create sequence rhn_confchantype_id_seq;
create table
rhnConfigChannelType
(
	id		number
			constraint rhn_confchantype_id_nn not null
			constraint rhn_confchantype_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(64)
			constraint rhn_confchantype_label_nn not null,
	name		varchar2(64)
			constraint rhn_confchantype_name_nn not null,
        priority        number default(0)
	                constraint rhn_confchantype_pri_nn not null,
	created		date default(sysdate)
			constraint rhn_confchantype_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_confchantype_mod_nn not null
)
	enable row movement
  ;
create index rhn_confchantype_label_id_idx
	on rhnConfigChannelType( label, id )
	tablespace [[64k_tbs]]
  ;
alter table rhnConfigChannelType add constraint rhn_confchantype_label_uq
	unique ( label );
create or replace trigger
rhn_confchantype_mod_trig
before insert or update on rhnConfigChannelType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnConfigChannel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigChannel.sql
create sequence rhn_confchan_id_seq;
create table
rhnConfigChannel
(
	id			number
				constraint rhn_confchan_id_nn not null
				constraint rhn_confchan_id_pk primary key
					using index tablespace [[2m_tbs]],
	org_id			number
				constraint rhn_confchan_oid_nn not null
				constraint rhn_confchan_oid_fk
					references web_customer(id),
	confchan_type_id	number
				constraint rhn_confchan_ctid_nn not null
				constraint rhn_confchan_ctid_fk
					references rhnConfigChannelType(id),
	name			varchar2(128)
				constraint rhn_confchan_name_nn not null,
	label			varchar2(64)
				constraint rhn_confchan_label_nn not null,
	description		varchar2(1024)
				constraint rhn_confchan_desc_nn not null,
	created			date default(sysdate)
				constraint rhn_confchan_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_confchan_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_confchan_oid_label_type_uq
	on rhnConfigChannel( org_id, label, confchan_type_id )
	tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnActionConfigChannel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionConfigChannel.sql
create table
rhnActionConfigChannel
(
	action_id		number
				constraint rhn_actioncc_aid_nn not null
				constraint rhn_actioncc_aid_fk
					references rhnAction(id)
					on delete cascade,
	server_id		number
				constraint rhn_actioncc_sid_nn not null
				constraint rhn_actioncc_sid_fk
					references rhnServer(id),
        config_channel_id       number
				constraint rhn_actioncc_ccid_nn not null
				constraint rhn_actioncc_ccid_fk
					references rhnConfigChannel(id)
						on delete cascade,
	created			date default(sysdate)
				constraint rhn_actioncc_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actioncc_mod_nn not null
)
	enable row movement
  ;
alter table rhnActionConfigChannel 
	add constraint rhn_actioncc_sid_aid_fk
	foreign key (server_id, action_id) references
	    rhnServerAction(server_id, action_id) on delete cascade;
create unique index rhn_actioncc_aid_sid_uq
	on rhnActionConfigChannel ( action_id, server_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_actioncc_sid_aid_ccid_idx
	on rhnActionConfigChannel ( server_id, action_id, config_channel_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_act_cc_ccid_aid_sid_idx
on rhnActionConfigChannel (config_channel_id, action_id, server_id)
        tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_actioncc_mod_trig
before insert or update on rhnActionConfigChannel
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionConfigDate.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionConfigDate.sql
create table
rhnActionConfigDate
(
	action_id		number
				constraint rhn_actioncd_aid_nn not null
				constraint rhn_actioncd_aid_fk
					references rhnAction(id)
					on delete cascade,
	start_date		date
				constraint rhn_actioncd_start_nn not null,
	end_date		date,
	import_contents		char(1)
				constraint rhn_actioncd_file_ic_nn not null
				constraint rhn_actioncd_file_ic_ck
					check (import_contents in ('Y','N')),
	created			date default(sysdate)
				constraint rhn_actioncd_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actioncd_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_actioncd_aid_uq
	on rhnActionConfigDate( action_id )
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_actioncd_mod_trig
before insert or update on rhnActionConfigDate
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionConfigDateFile.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionConfigDateFile.sql
create table
rhnActionConfigDateFile
(
	action_id		number
				constraint rhn_actioncd_file_aid_nn not null
				constraint rhn_actioncd_file_aid_fk
					references rhnAction(id)
					on delete cascade,
	file_name		varchar2(512)
				constraint rhn_actioncd_file_fn_nn not null,
	file_type		char(1)
				constraint rhn_actioncd_file_ft_nn not null
				constraint rhn_actioncd_file_ft_ck
					check (file_type in ('W','B')),
	created			date default(sysdate)
				constraint rhn_actioncd_file_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actioncd_file_mod_nn not null
)
	enable row movement
  ;
create index rhn_actioncd_file_aid_fn_idx
	on rhnActionConfigDateFile(action_id, file_name)
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_actioncd_file_mod_trig
before insert or update on rhnActionConfigDateFile
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnConfigFileName.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigFileName.sql
create sequence rhn_cfname_id_seq;
create table
rhnConfigFileName
(
	id		number
			constraint rhn_cfname_id_nn not null,
	path		varchar2(1024)
			constraint rhn_cfname_path_nn not null,
	created		date default(sysdate)
			constraint rhn_cfname_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_cfname_modified_nn not null
)
	enable row movement
  ;
create index rhn_cfname_id_pk
	on rhnConfigFileName ( id )
	tablespace [[2m_tbs]]
  ;
alter table rhnConfigFileName add constraint
	rhn_cfname_id_pk primary key ( id );
create unique index rhn_cfname_path_uq
	on rhnConfigFileName ( path )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_cfname_mod_trig
before insert or update on rhnConfigFileName
for each row
begin
	:new.modified := sysdate;
end;
/

select 'rhnsat/tables/rhnConfigFileFailure.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigFileFailure.sql
create sequence rhn_conffile_failure_id_seq;
create table
rhnConfigFileFailure
(
	id			number
				constraint rhn_conffile_fail_id_nn not null
				constraint rhn_conffile_fail_id_pk 
					primary key 
					using index tablespace [[64k_tbs]],
	label			varchar2(64)
				constraint rhn_conffile_fail_label_nn not null
				constraint rhn_conffile_fail_label_uq unique
					using index tablespace [[64k_tbs]],
	name			varchar2(256)
				constraint rhn_conffile_fail_name_nn not null
				constraint rhn_conffile_fail_name_uq unique
					using index tablespace [[64k_tbs]],
	created			date default(sysdate)
				constraint rhn_conffile_fail_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_conffile_fail_mod_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_conffile_fail_mod_trig
before insert or update on rhnConfigFileFailure
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnConfigFileState.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigFileState.sql
create sequence rhn_cfstate_id_seq;
create table
rhnConfigFileState
(
	id		number
			constraint rhn_cfstate_id_nn not null
			constraint rhn_cfstate_id_pk primary key
				using index tablespace [[2m_tbs]],
	label		varchar2(32)
			constraint rhn_cfstate_label_nn not null,
	name		varchar2(256)
			constraint rhn_cfstate_name_nn not null,
	created		date default(sysdate)
			constraint rhn_cfstate_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_cfstate_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_cfstate_label_id_uq
	on rhnConfigFileState( label, id )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_cfstate_mod_trig
before insert or update on rhnConfigFileState
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnConfigFile.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigFile.sql
create sequence rhn_conffile_id_seq;
create table rhnConfigFile
(
	id			number
				constraint rhn_conffile_id_nn not null
				constraint rhn_conffile_id_pk primary key
					using index tablespace [[2m_tbs]],
	config_channel_id	number
				constraint rhn_conffile_ccid_nn not null
				constraint rhn_conffile_ccid_fk
					references rhnConfigChannel(id),
	config_file_name_id	number
				constraint rhn_conffile_cfnid_nn not null
				constraint rhn_conffile_cfnid_fk
					references rhnConfigFileName(id),
	latest_config_revision_id number
				,
	state_id		number
				constraint rhn_conffile_sid_nn not null
				constraint rhn_conffile_sid_fk
					references rhnConfigFileState(id),
	created			date default(sysdate)
				constraint rhn_conffile_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_conffile_mod_nn not null
)
	enable row movement
  ;
create index rhn_conffile_cc_cfn_s_idx
	on rhnConfigFile( config_channel_id, config_file_name_id, state_id )
	tablespace [[8m_tbs]]
  ;
alter table rhnConfigFile add constraint rhn_conffile_ccid_cfnid_uq
	unique ( config_channel_id, config_file_name_id );
create index rhn_cnf_fl_lcrid_idx
on rhnConfigFile ( latest_config_revision_id )
        tablespace [[8m_tbs]]
  ;
create or replace trigger
rhn_conffile_mod_trig
before insert or update on rhnConfigFile
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnConfigInfo.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigInfo.sql
create sequence rhn_confinfo_id_seq;
create table
rhnConfigInfo
(
	id			number
				constraint rhn_confinfo_id_nn not null
				constraint rhn_confinfo_id_pk primary key
					using index tablespace [[2m_tbs]],
	username		varchar2(32)
				constraint rhn_confinfo_username_nn not null,
	groupname		varchar2(32)
				constraint rhn_confinfo_groupname_nn not null,
	filemode		number
				constraint rhn_confinfo_filemode_nn not null,
	created			date default(sysdate)
				constraint rhn_confinfo_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_confinfo_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_confinfo_ugf_uq
	on rhnConfigInfo( username, groupname, filemode )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_confinfo_mod_trig
before insert or update on rhnConfigInfo
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnConfigContent.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigContent.sql
create sequence rhn_confcontent_id_seq;
create table
rhnConfigContent
(
	id			number
				constraint rhn_confcontent_id_nn not null
				constraint rhn_confcontent_id_pk primary key
					using index tablespace [[2m_tbs]],
	contents		blob,
	file_size		number,
	md5sum			varchar2(64)
				constraint rhn_confcontent_md5_nn not null,
	is_binary	        char(1) default('N')
				constraint rhn_confcontent_isbin_nn not null
				constraint rhn_confcontent_isbin_ck
					check (is_binary in ('Y','N')),
	created			date default(sysdate)
				constraint rhn_confcontent_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_confcontent_mod_nn not null
)
	tablespace [[blob]]
	enable row movement
  ;
create index rhn_confcontent_md5_uq
	on rhnConfigContent( md5sum )
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_confcontent_mod_trig
before insert or update on rhnConfigContent
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnConfigFileType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigFileType.sql
create table rhnConfigFileType
(
	id			number
				constraint rhn_conffiletype_id_nn not null
				constraint rhn_conffiletype_id_pk primary key
					using index tablespace [[2m_tbs]],
   label    varchar2(64)
            constraint rhn_conffiletype_label_nn not null,
   name     varchar2(256)
            constraint rhn_conffiletype_name_nn not null,
	created			date default(sysdate)
				constraint rhn_conffiletype_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_conffiletype_mod_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_conffiletype_mod_trig
before insert or update on rhnConfigFile
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnConfigRevision.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigRevision.sql
create sequence rhn_confrevision_id_seq;
create table
rhnConfigRevision
(
	id			number
				constraint rhn_confrevision_id_nn not null
				constraint rhn_confrevision_id_pk primary key
					using index tablespace [[4m_tbs]],
	revision		number
				constraint rhn_confrevision_rev_nn not null,
	config_file_id		number
				constraint rhn_confrevision_cfid_nn not null
				constraint rhn_confrevision_cfid_fk
					references rhnConfigFile(id),
	config_content_id	number
				constraint rhn_confrevision_ccid_nn not null
				constraint rhn_confrevision_ccid_fk
					references rhnConfigContent(id),
	config_info_id		number
				constraint rhn_confrevision_ciid_nn not null
				constraint rhn_confrevision_ciid_fk
					references rhnConfigInfo(id),
	delim_start		varchar2(16)
				constraint rhn_confrevision_dstart_nn not null,
	delim_end		varchar2(16)
				constraint rhn_confrevision_dend_nn not null,
	created			date default(sysdate)
				constraint rhn_confrevision_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_confrevision_mod_nn not null,
   config_file_type_id number default 1
                  constraint rhn_conf_rev_cfti_fk references rhnConfigFileType (id)
                  constraint rhn_conf_rev_cfti_nn not null,
        changed_by_id number
        default null
        constraint rhn_confrevision_cid_fk references web_contact(id) 
)
	enable row movement
  ;
create unique index rhn_confrevision_cfid_rev_uq
	on rhnConfigRevision( config_file_id, revision )
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnActionConfigFileName.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionConfigFileName.sql
create table
rhnActionConfigFileName
(
	action_id		number
				constraint rhn_actioncf_name_aid_nn not null,
	server_id		number
				constraint rhn_actioncf_name_sid_nn not null,
	config_file_name_id	number
				constraint rhn_actioncf_name_cfnid_nn not null
				constraint rhn_actioncf_name_cfnid_fk
					references rhnConfigFileName(id),
	config_revision_id	number
				constraint rhn_actioncf_name_crid_fk
					references rhnConfigRevision(id)
					on delete set null,
	failure_id		number
				constraint rhn_actioncf_failure_id_fk
					references rhnConfigFileFailure(id),
	created			date default(sysdate)
				constraint rhn_actioncf_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actioncf_mod_nn not null
)
	enable row movement
  ;
alter table rhnActionConfigFileName
	add constraint rhn_actioncf_name_aid_sid_fk
	foreign key ( server_id, action_id )
	references rhnServerAction( server_id, action_id )
	on delete cascade;
create unique index rhn_actioncf_name_asc_uq
	on rhnActionConfigFileName ( action_id, server_id, config_file_name_id )
	tablespace [[2m_tbs]]
  ;
create unique index rhn_actioncf_name_sac_uq
        on rhnActionConfigFileName ( server_id, action_id, config_file_name_id )
        tablespace [[2m_tbs]]
  ;
create index rhn_act_cnfg_fn_crid_idx
on rhnActionConfigFileName ( config_revision_id )
        tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_actioncf_name_mod_trig
before insert or update on rhnActionConfigFileName
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionConfigRevision.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionConfigRevision.sql
create sequence rhn_actioncr_id_seq;
create table
rhnActionConfigRevision
(
	id			number
				constraint rhn_actioncr_id_nn not null
				constraint rhn_actioncr_id_pk primary key
					using index tablespace [[2m_tbs]],
	action_id		number
				constraint rhn_actioncr_aid_nn not null
				constraint rhn_actioncr_aid_fk
					references rhnAction(id)
					on delete cascade,
	server_id		number
				constraint rhn_actioncr_sid_nn not null
				constraint rhn_actioncr_sid_fk
					references rhnServer(id),
	config_revision_id	number
				constraint rhn_actioncr_crid_nn not null
				constraint rhn_actioncr_crid_fk
					references rhnConfigRevision(id)
					on delete cascade,
        failure_id              number
				constraint rhn_actioncr_failid_fk
					references rhnConfigFileFailure(id),
	created			date default(sysdate)
				constraint rhn_actioncr_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actioncr_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_actioncr_aid_sid_crid_uq
	on rhnActionConfigRevision( action_id, server_id, config_revision_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_actioncr_sid_aid_idx
	on rhnActionConfigRevision( server_id, action_id )
	tablespace [[2m_tbs]]
  ;
create index rhn_act_cr_crid_idx
on rhnActionConfigRevision ( config_revision_id )
        tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_actioncr_mod_trig
before insert or update on rhnActionConfigRevision
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionConfigRevisionResult.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionConfigRevisionResult.sql
create table rhnActionConfigRevisionResult
(
	action_config_revision_id number
				constraint rhn_actioncfr_acrid_nn not null
				constraint rhn_actioncfr_acrid_fk
					references rhnActionConfigRevision(id)
					on delete cascade,
	result			blob,
	created			date default(sysdate)
				constraint rhn_actioncfr_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actioncfr_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_actioncfr_acrid_uq
	on rhnActionConfigRevisionResult( action_config_revision_id )
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_actioncfr_mod_trig
before insert or update on rhnActionConfigRevisionResult
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionDaemonConfig.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionDaemonConfig.sql
create table
rhnActionDaemonConfig
(
	action_id		number
				constraint rhn_actiondc_aid_nn not null
				constraint rhn_actiondc_aid_fk
					references rhnAction(id)
					on delete cascade,
        interval                number
                                constraint rhn_actiondc_int_nn not null,
        restart                 char(1) default 'Y'
                                constraint rhn_actiondc_rest_nn not null
                                constraint rhn_actiondc_rest_ck check 
                                    (restart in ('Y','N')),
	created			date default(sysdate)
				constraint rhn_actiondc_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actiondc_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_actiondc_aid_uq
	on rhnActionDaemonConfig ( action_id )
	tablespace [[8m_tbs]]
  ;
create or replace trigger
rhn_actiondc_mod_trig
before insert or update on rhnActionDaemonConfig
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnErrataSeverity.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataSeverity.sql
create table rhnErrataSeverity (
    id number
        constraint rhn_errata_sev_id_nn not null 
        constraint rhn_errata_sev_id_pk primary key,
    rank number 
        constraint rhn_errata_sev_rank_nn not null,
    label varchar2(40)
        constraint rhn_errata_sev_label_nn not null
)
	enable row movement
;

select 'rhnsat/tables/rhnErrata.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrata.sql
create table
rhnErrata
(
        id              number
			constraint rhn_errata_id_nn not null
                        constraint rhn_errata_id_pk primary key
                        using index tablespace [[64k_tbs]],
        advisory        varchar2(37) -- advisory code
			constraint rhn_errata_advisory_nn not null,
        advisory_type   varchar2(32) -- plain text type of advisory
			constraint rhn_errata_adv_type_nn not null
			constraint rhn_errata_adv_type_ck
			           check (advisory_type in ('Bug Fix Advisory',
				                            'Product Enhancement Advisory',
							    'Security Advisory')),
      	advisory_name	varchar2(32)  -- advisory name and version
			constraint rhn_errata_advisory_name_nn not null,
	advisory_rel	number
			constraint rhn_errata_advisory_rel_nn not null,
        product         varchar2(64)
                        constraint rhn_errata_product_nn not null,
        description     varchar2(4000), -- description
        synopsis        varchar2(4000) -- Short description
                        constraint rhn_errata_synopsis_nn not null,
        topic           varchar2(4000), -- Problem description
        solution        varchar2(4000) -- how to resolve it
                        constraint rhn_errata_solution_nn not null,
        issue_date      date default (sysdate)
			constraint rhn_errata_issue_nn not null,
        update_date     date default (sysdate)
			constraint rhn_errata_update_nn not null,
        refers_to	varchar2(4000),
        notes           varchar2(4000),
        org_id          number
                        constraint rhn_errata_oid_fk
                                references web_customer(id)
				on delete cascade,
       locally_modified char(1)
			constraint rhn_errata_lm_ck check
				(locally_modified in ('Y','N')),
        created         date default (sysdate)
			constraint rhn_errata_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_errata_modified_nn not null,
	last_modified	date default (sysdate)
                  constraint rhn_errata_last_mod_nn not null,
        severity_id     number
                        constraint rhn_errata_sevid_fk
                                references rhnErrataSeverity(id)
)
	enable row movement
  ;
create sequence rhn_errata_id_seq;
create unique index rhn_errata_advisory_uq
	on rhnErrata(advisory)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_errata_advisory_name_uq
	on rhnErrata(advisory_name)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnActionErrataUpdate.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionErrataUpdate.sql
create table
rhnActionErrataUpdate
(
	action_id       number
			constraint rhn_act_eu_act_nn not null
			constraint rhn_act_eu_act_fk 
				references rhnAction(id)
				on delete cascade,
	errata_id       number
			constraint rhn_act_eu_err_nn not null
			constraint rhn_act_eu_err_fk 
				references rhnErrata(id)
				on delete cascade
)
	enable row movement
  ;
create index rhn_act_eu_aid_eid_idx
	on rhnActionErrataUpdate(action_id, errata_id)
	tablespace [[8m_tbs]]
  ;
create index rhn_act_eu_eid_aid_idx
	on rhnActionErrataUpdate(errata_id, action_id)
	tablespace [[8m_tbs]]
  ;

select 'rhnsat/tables/rhnKSTreeType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKSTreeType.sql
create table
rhnKSTreeType
(
        id              number
			constraint rhn_kstreetype_id_nn not null
                        constraint rhn_kstreetype_id_pk primary key
                                using index tablespace [[64k_tbs]],
        label           varchar2(32)
                        constraint rhn_kstreetype_label_nn not null,
        name            varchar2(64)
                        constraint rhn_kstreetype_name_nn not null,
        created         date default(sysdate)
                        constraint rhn_kstreetype_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_kstreetype_mod_nn not null
)
	enable row movement
  ;
create sequence rhn_kstree_type_seq;
create unique index rhn_kstreetype_label_uq 
	on rhnKSTreeType(label)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnKSInstallType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKSInstallType.sql
create sequence rhn_ksinstalltype_id_seq;
create table
rhnKSInstallType
(
        id              number
			constraint rhn_ksinstalltype_id_nn not null
                        constraint rhn_ksinstalltype_id_pk primary key
                                using index tablespace [[64k_tbs]],
        label           varchar2(32)
                        constraint rhn_ksinstalltype_label_nn not null,
        name            varchar2(64)
                        constraint rhn_ksinstalltype_name_nn not null,
        created         date default(sysdate)
                        constraint rhn_ksinstalltype_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_ksinstalltype_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_ksinstalltype_label_uq 
	on rhnKSInstallType( label )
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_ksinstalltype_mod_trig
before insert or update on rhnKSInstallType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnKickstartableTree.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartableTree.sql
create sequence rhn_kstree_id_seq;
create table
rhnKickstartableTree
(
	id		number
			constraint rhn_kstree_id_nn not null,
        org_id          number
                        constraint rhn_kstree_oid_fk
                                references web_customer(id)
				on delete cascade,
	label		varchar2(64)
			constraint rhn_kstree_label_nn not null,
	base_path	varchar2(256)
			constraint rhn_kstree_bp_nn not null,
	channel_id	number
			constraint rhn_kstree_cid_nn not null
			constraint rhn_kstree_cid_fk
				references rhnChannel(id),
        cobbler_id      varchar2(64),
        cobbler_xen_id  varchar2(64),
	boot_image	varchar2(128) default('spacewalk-koan'),
        kstree_type     number
                        constraint rhn_kstree_kstreetype_nn not null
                        constraint rhn_kstree_kstreetype_fk
                                references rhnKSTreeType(id),
        install_type    number
                        constraint rhn_kstree_it_nn not null
                        constraint rhn_kstree_it_fk
                                references rhnKSInstallType(id),
	last_modified	date default(sysdate)
			constraint rhn_kstree_lastmod_nn not null,
	created		date default(sysdate)
			constraint rhn_kstree_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_kstree_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_kstree_mod_trig
before insert or update on rhnKickstartableTree
for each row
begin
     if (:new.last_modified = :old.last_modified) or 
        (:new.last_modified is null ) then
             :new.last_modified := sysdate;
     end if;
	:new.modified := sysdate;
end rhn_kstree_mod_trig;
/
show errors
create index rhn_kstree_id_pk
	on rhnKickstartableTree( id )
	tablespace [[4m_tbs]]
  ;
alter table rhnKickstartableTree add constraint rhn_kstree_id_pk
	primary key ( id );
create unique index rhn_kstree_oid_label_uq
	on rhnKickstartableTree( org_id, label )
	tablespace [[8m_tbs]]
  ;

select 'rhnsat/tables/rhnActionKickstart.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionKickstart.sql
create sequence rhn_actionks_id_seq;
create table
rhnActionKickstart
(
	id			number
				constraint rhn_actionks_id_nn not null,
	action_id		number
				constraint rhn_actionks_aid_nn not null
				constraint rhn_actionks_aid_fk
					references rhnAction(id)
					on delete cascade,
	append_string		varchar2(1024),
	kickstart_host		varchar2(256),
    static_device           varchar2(32),
	created			date default(sysdate)
				constraint rhn_actionks_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actionks_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_actionks_aid_uq
	on rhnActionKickstart( action_id )
	tablespace [[8m_tbs]]
  ;
create index rhn_actionks_id_idx
	on rhnActionKickstart( id )
	tablespace [[4m_tbs]]
  ;
alter table rhnActionKickstart add constraint rhn_actionks_id_pk
	primary key ( id );
create or replace trigger
rhn_actionks_mod_trig
before insert or update on rhnActionKickstart
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnFileList.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnFileList.sql
create sequence rhn_filelist_id_seq;
create table
rhnFileList
(
	id		number
			constraint rhn_filelist_id_nn not null
			constraint rhn_filelist_id_pk primary key
				using index tablespace [[4m_tbs]],
	label		varchar2(128)
			constraint rhn_filelist_l_nn not null,
	org_id		number
			constraint rhn_filelist_oid_nn not null
			constraint rhn_filelist_oid_fk
				references web_customer(id),
	created		date default (sysdate)
			constraint rhn_filelist_creat_nn not null,
	modified	date default (sysdate)
			constraint rhn_filelist_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_filelist_oid_l_uq
	on rhnFileList( org_id, label )
	tablespace [[8m_tbs]]
  ;
create or replace trigger
rhn_filelist_mod_trig
before insert or update on rhnFileList
for each row
begin
	:new.modified := sysdate;
end rhn_filelist_mod_trig;
/
show errors

select 'rhnsat/tables/rhnActionKickstartFileList.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionKickstartFileList.sql
create table
rhnActionKickstartFileList
(
	action_ks_id		number
				constraint rhn_actionksfl_aksid_nn not null
				constraint rhn_actionksfl_askid_fk
					references rhnActionKickstart(id)
					on delete cascade,
	file_list_id		number
				constraint rhn_actionksfl_flid_nn not null
				constraint rhn_actionksfl_flid_fk
					references rhnFileList(id)
					on delete cascade,
	created			date default (sysdate)
				constraint rhn_actionksfl_creat_nn not null,
	modified		date default (sysdate)
				constraint rhn_actionksfl_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_actionksfl_aksid_flid_uq
	on rhnActionKickstartFileList( action_ks_id, file_list_id )
	tablespace [[8m_tbs]]
  ;
create index rhn_actionksfl_flid_idx
	on rhnActionKickstartFileList( file_list_id )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_actionksfl_mod_trig
before insert or update on rhnActionKickstartFileList 
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnKSData.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKSData.sql
create sequence rhn_ks_id_seq;
create table
rhnKSData
(
	id			number
				constraint rhn_ks_id_nn not null
				constraint rhn_ks_id_pk primary key
					using index tablespace [[8m_tbs]],
	ks_type			varchar2(8) 
				constraint rhn_ks_type_nn not null,
				constraint rhn_ks_type_ck
					check (ks_type in ('wizard','raw')),
	org_id			number
				constraint rhn_ks_oid_nn not null
				constraint rhn_ks_oid_fk
					references web_customer(id)
					on delete cascade,
	is_org_default          char(1) default('N')
				constraint rhn_ks_default_nn not null
				constraint rhn_ks_default_ck
					check (is_org_default in ('Y','N')),
	label			varchar2(64)
				constraint rhn_ks_label_nn not null,
	comments		varchar2(4000),
	active			char(1) default('Y')
				constraint rhn_ks_active_nn not null
				constraint rhn_ks_active_ck
					check (active in ('Y','N')),
    postLog     char(1) default('N')
                constraint rhn_ks_post_log_nn not null
                constraint rhn_ks_post_log_ck
                    check (postLog in ('Y','N')),
    preLog     char(1) default('N')
                constraint rhn_ks_pre_log_nn not null
                constraint rhn_ks_pre_log_ck
                    check (preLog in ('Y','N')),
    kscfg      char(1) default('N')
                constraint rhn_ks_cfg_save_nn not null
                constraint rhn_ks_cfg_save_ck
                    check (kscfg in ('Y','N')),
        cobbler_id              varchar2(64),
	pre			blob,
	post			blob,
        nochroot_post           blob,
	static_device           varchar2(32),
        kernel_params           varchar2(128),
        verboseup2date char(1) default('N')
                constraint rhn_ks_verbose_up2date_nn not null
                constraint rhn_ks_verbose_up2date_ck
                check (verboseup2date in ('Y','N')),
        nonchrootpost char(1) default('N')
                constraint rhn_ks_nonchroot_post_nn not null
                constraint rhn_ks_nonchroot_post_ck
                check (nonchrootpost in ('Y','N')),
	created			date default(sysdate)
				constraint rhn_ks_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_ks_modified_nn not null
)
	enable row movement
  ;
create index rhn_ks_oid_label_id_idx
	on rhnKSData( org_id, label, id )
	tablespace [[8m_tbs]]
  ;
alter table rhnKSData add constraint rhn_ks_oid_label_uq
	unique ( org_id, label );
create or replace trigger
rhn_ks_mod_trig
before insert or update on rhnKSData
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnKickstartSessionState.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartSessionState.sql
create sequence rhn_ks_session_state_id_seq;
create table
rhnKickstartSessionState
(
	id			number
				constraint rhn_ks_session_state_id_nn not null
				constraint rhn_ks_session_state_id_pk primary key
					using index tablespace [[64k_tbs]],
	label			varchar2(64)
				constraint rhn_ks_session_state_label_nn not null,
	name			varchar2(128)
				constraint rhn_ks_session_state_name_nn not null,
	description		varchar2(1024)
				constraint rhn_ks_session_state_desc_nn not null,
	created			date default(sysdate)
				constraint rhn_ks_session_state_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_ks_session_state_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_ks_session_state_label_uq
	on rhnKickstartSessionState(label)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_ks_session_state_mod_trig
before insert or update on rhnKickstartSessionState
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerProfileType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerProfileType.sql
create sequence rhn_sproftype_id_seq;
create table
rhnServerProfileType
(
	id		number
			constraint rhn_sproftype_id_nn not null
			constraint rhn_sproftype_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(64)
			constraint rhn_sproftype_label_nn not null,
	name		varchar2(64)
			constraint rhn_sproftype_name_nn not null,
	created		date default(sysdate)
			constraint rhn_sproftype_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_sproftype_mod_nn not null
)
	enable row movement
  ;
create index rhn_sproftype_label_id_idx
	on rhnServerProfileType( label, id )
	tablespace [[64k_tbs]]
  ;
alter table rhnServerProfileType add constraint rhn_sproftype_label_uq
	unique ( label );
create or replace trigger
rhn_sproftype_mod_trig
before insert or update on rhnServerProfileType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerProfile.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerProfile.sql
create table
rhnServerProfile
(
        id              number
			constraint rhn_server_profile_id_nn not null,
        org_id          number
                        constraint rhn_server_profile_oid_nn not null
                        constraint rhn_server_profile_oid_fk
                                references web_customer(id)
				on delete cascade,
	base_channel    number
	    	    	constraint rhn_server_profile_bcid_nn not null
	    	    	constraint rhn_server_profile_bcid_fk
			    	references rhnChannel(id),
        name            varchar2(128),
        description     varchar2(256),
        info            varchar2(128),
	profile_type_id number
	    	    	constraint rhn_server_profile_ptype_nn not null
	    	    	constraint rhn_server_profile_ptype_fk
			    	references rhnServerProfileType(id),
        created         date default (sysdate)
			constraint rhn_server_profile_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_server_profile_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_server_profile_id_seq;
create unique index rhn_server_profile_noid_uq
    	on rhnServerProfile(org_id,name)
	tablespace [[64k_tbs]]
  ;
create index rhn_sprofile_id_oid_bc_idx
	on rhnServerProfile(id,org_id,base_channel)
	tablespace [[64k_tbs]]
  ;
alter table rhnServerProfile add
	constraint rhn_server_profile_id_pk primary key (id);
create index rhn_server_profile_o_id_bc_idx
	on rhnServerProfile(org_id,id,base_channel)
	tablespace [[64k_tbs]]
	nologging;
create index rhn_server_profile_bc_idx
	on rhnServerProfile(base_channel)
	tablespace [[64k_tbs]]
	nologging;

select 'rhnsat/tables/rhnKickstartVirtualizationType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartVirtualizationType.sql
create table
rhnKickstartVirtualizationType
(
	id			number
				constraint rhn_kvt_id_nn not null
				constraint rhn_kvt_id_pk primary key
					using index tablespace [[8m_tbs]],
	name			varchar2(128)
				constraint rhn_kvt_name_nn not null,
	label			varchar2(128)
				constraint rhn_kvt_label_nn not null
				constraint rhn_kvt_label_unq unique,
	created			date default (sysdate)
				constraint rhn_kvt_created_nn not null,
	modified		date default (sysdate)
				constraint rhn_kvt_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_kvt_id_seq;

select 'rhnsat/tables/rhnKickstartSession.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartSession.sql
create sequence rhn_ks_session_id_seq;
create table
rhnKickstartSession
(
	id			number
				constraint rhn_ks_session_id_nn not null
				constraint rhn_ks_session_id_pk primary key
					using index tablespace [[8m_tbs]],
	kickstart_id		number
				constraint rhn_ks_session_ksid_fk
					references rhnKSData(id)
					on delete cascade,
        kickstart_mode          varchar2(32),
	kstree_id               number
				constraint rhn_ks_session_kstid_fk
				        references rhnKickstartableTree(id)
					on delete set null,
	org_id			number
				constraint rhn_ks_session_oid_nn not null
				constraint rhn_ks_session_oid_fk
					references web_customer(id)
					on delete cascade,
    	scheduler               number
	    	    	    	constraint rhn_ks_session_sched_fk
				    	references web_contact(id)
					on delete set null,
	old_server_id		number
				constraint rhn_ks_session_osid_fk
					references rhnServer(id),
	new_server_id		number
				constraint rhn_ks_session_nsid_fk
					references rhnServer(id),
	host_server_id		number
				constraint rhn_ks_session_hsid_fk
					references rhnServer(id)
                                        on delete cascade,
	action_id		number
				constraint rhn_ks_session_aid_fk
					references rhnAction(id)
					on delete set null,
	state_id		number
				constraint rhn_ks_session_ksssid_nn not null
				constraint rhn_ks_session_ksssid_fk
					references rhnKickstartSessionState(id),
	server_profile_id	number
				constraint rhn_ks_session_spid_fk
					references rhnServerProfile(id)
					on delete set null,
	last_action		date default(sysdate)
				constraint rhn_ks_session_last_action_nn not null,
        package_fetch_count     number default 0
				constraint rhn_ks_session_pfc_nn not null,
        last_file_request       varchar2(2048),
    	system_rhn_host         varchar2(256),
	kickstart_from_host	varchar2(256),
	deploy_configs		char(1) default('N')
				constraint rhn_ks_session_dc_nn not null,
        virtualization_type     number
                                constraint rhn_kss_kvt_nn not null
	                        constraint rhn_kss_kvt_fk
				        references rhnKickstartVirtualizationType(id)
					on delete set null,
    client_ip        varchar2(15),
	created			date default(sysdate)
				constraint rhn_ks_session_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_ks_session_modified_nn not null
)
	enable row movement
  ;
create index rhn_ks_session_oid_idx
	on rhnKickstartSession( org_id )
	tablespace [[8m_tbs]]
  ;
create index rhn_ks_session_osid_aid_idx
	on rhnKickstartSession( old_server_id, action_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_ks_session_nsid_idx
	on rhnKickstartSession( new_server_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_ks_session_hsid_idx
	on rhnKickstartSession( host_server_id )
	tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnActionKickstartGuest.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionKickstartGuest.sql
create sequence rhn_actionks_xenguest_id_seq;
create table
rhnActionKickstartGuest
(
	id			number
				constraint rhn_actionks_xenguest_id_nn not null,
	action_id		number
				constraint rhn_actionks_xenguest_aid_nn not null
				constraint rhn_actionks_xenguest_aid_fk
					references rhnAction(id)
					on delete cascade,
	append_string		varchar2(1024),
        ks_session_id           number
                                constraint rhn_actionks_xenguest_ksid_fk
                                        references rhnKickstartSession(id)
                                        on delete cascade,
	guest_name		varchar2(256),
	mem_kb			number, 
	vcpus			number,
	disk_gb			number,
        cobbler_system_name		varchar2(256),
        disk_path		varchar2(256),
        virt_bridge		varchar2(256),
        kickstart_host          varchar2(256),
	created			date default(sysdate)
				constraint rhn_actionks_xenguest_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_actionks_xenguest_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_actionks_xenguest_aid_uq
	on rhnActionKickstartGuest( action_id )
	tablespace [[8m_tbs]]
  ;
create index rhn_actionks_xenguest_id_idx
	on rhnActionKickstartGuest( id )
	tablespace [[4m_tbs]]
  ;
alter table rhnActionKickstartGuest add constraint rhn_actionks_xenguest_id_pk
	primary key ( id );
create or replace trigger
rhn_actionks_xenguest_mod_trig
before insert or update on rhnActionKickstartGuest
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionPackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionPackage.sql
create sequence rhn_act_p_id_seq;
create table
rhnActionPackage
(
	id		number
			constraint rhn_act_p_id_nn not null
			constraint rhn_act_p_id_pk primary key
				using index tablespace [[8m_tbs]],
	action_id	number
			constraint rhn_act_p_act_nn not null
			constraint rhn_act_p_act_fk
				references rhnAction(id) on delete cascade,
	parameter       varchar2(128) default 'upgrade'
			constraint rhn_act_p_param_nn not null
			constraint rhn_act_p_param_ck
			    CHECK(parameter IN ('upgrade', 'install', 'remove', 'downgrade')),
	name_id		number
			constraint rhn_act_p_name_nn not null
			constraint rhn_act_p_name_fk
				references rhnPackageName(id),
	evr_id		number
			constraint rhn_act_p_evr_fk
				references rhnPackageEvr(id),
	package_arch_id	number
			constraint rhn_act_p_paid_fk
				references rhnPackageArch(id)
)
	enable row movement
  ;
create index rhn_act_p_aid_idx
	on rhnActionPackage(action_id)
	tablespace [[4m_tbs]]
	nologging;

select 'rhnsat/tables/rhnActionPackageAnswerfile.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionPackageAnswerfile.sql
create table
rhnActionPackageAnswerfile
(
	action_package_id number
			constraint rhn_act_p_af_apid_nn not null
			constraint rhn_act_p_af_apid_fk
				references rhnActionPackage(id)
				on delete cascade,
	answerfile	blob,
	created		date default(sysdate)
			constraint rhn_act_p_af_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_act_p_af_mod_nn not null
)
	tablespace [[blob]]
	enable row movement
  ;
create index rhn_act_p_af_aid_idx
	on rhnActionPackageAnswerfile( action_package_id )
	tablespace [[2m_tbs]]
	nologging;
create or replace trigger
rhn_act_p_af_mod_trig
before insert or update on rhnActionPackageAnswerfile
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPackageDelta.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageDelta.sql
create sequence rhn_packagedelta_id_seq;
create table
rhnPackageDelta
(
	id		number
			constraint	rhn_packagedelta_id_nn not null,
	label		varchar2(32)
			constraint	rhn_packagedelta_label_nn not null,
	created		date default(sysdate)
			constraint	rhn_packagedelta_created_nn not null,
	modified	date default(sysdate)
			constraint	rhn_packagedelta_modified_nn not null
)
	enable row movement
  ;
create index rhn_packagedelta_label_id_idx
	on rhnPackageDelta(label, id)
	tablespace [[8m_tbs]]
  ;
alter table rhnPackageDelta add
	constraint rhn_packagedelta_id_pk primary key (id)
	using index tablespace [[4m_tbs]];
create or replace trigger
rhn_packagedelta_mod_trig
before insert or update on rhnPackageDelta
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionPackageDelta.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionPackageDelta.sql
create table
rhnActionPackageDelta
(
	action_id		number
				constraint rhn_act_pd_aid_nn not null
				constraint rhn_act_pd_aid_fk
					references rhnAction(id)
					on delete cascade,
	package_delta_id	number
				constraint rhn_act_pd_pdid_nn not null
				constraint rhn_act_pd_pdid_fk
					references rhnPackageDelta(id)
					on delete cascade
)
	enable row movement
  ;
create unique index rhn_act_pd_aid_pdid_idx
	on rhnActionPackageDelta(action_id, package_delta_id)
	tablespace [[8m_tbs]]
	nologging;

select 'rhnsat/tables/rhnActionPackageOrder.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionPackageOrder.sql
create table rhnActionPackageOrder (
   action_package_id       number
                           constraint rhn_act_pkg_apid_nn not null
                           constraint rhn_act_pkg_apid_fk references rhnActionPackage(id)
                           on delete cascade,
   package_order           number
                           constraint rhn_act_pkg_order_nn not null
)
tablespace [[8m_data_tbs]]
	enable row movement
  ;
create index rhn_act_pkg_apid_idx
on rhnActionPackageOrder (action_package_id)
tablespace [[32m_tbs]]
  ;

select 'rhnsat/tables/rhnPackageCapability.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageCapability.sql
create table
rhnPackageCapability
(
	id		number
			constraint rhn_pkg_capability_id_nn not null
			constraint rhn_pkg_capability_id_pk primary key
				using index tablespace [[4m_tbs]],
	name		varchar2(4000)
                        constraint rhn_pkg_capability_name_nn not null,
	version		varchar2(64), -- I really hate this.
	created		date default (sysdate)
			constraint rhn_pkg_capability_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_pkg_capability_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_pkg_capability_id_seq;
create unique index rhn_pkg_cap_name_version_uq
	on rhnPackageCapability(name, version)
	tablespace [[32m_tbs]]
  ;
create or replace trigger
rhn_pkg_capability_mod_trig
before insert or update on rhnPackageCapability
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionPackageRemovalFailure.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionPackageRemovalFailure.sql
create table
rhnActionPackageRemovalFailure
(
	server_id		number
				constraint rhn_apr_failure_sid_nn not null
				constraint rhn_apr_failure_sid_fk
					references rhnServer(id),
	action_id		number
				constraint rhn_apr_failure_aid_nn not null
				constraint rhn_apr_failure_aid_fk
					references rhnAction(id)
					on delete cascade,
	name_id			number
				constraint rhn_apr_failure_nid_nn not null
				constraint rhn_apr_failure_nid_fk
					references rhnPackageName(id),
	evr_id			number
				constraint rhn_apr_failure_eid_nn not null
				constraint rhn_apr_failure_eid_fk
					references rhnPackageEVR(id),
	capability_id		number
				constraint rhn_apr_failure_capid_nn not null
				constraint rhn_apr_failure_capid_fk
					references rhnPackageCapability(id),
	flags			number
				constraint rhn_apr_failure_flags_nn not null,
	suggested		number
				constraint rhn_apr_failure_suggested_fk
					references rhnPackageName(id),
	sense			number
				constraint rhn_apr_failure_sense_nn not null
)
	enable row movement
  ;
create index rhn_apr_failure_aid_sid_idx
	on rhnActionPackageRemovalFailure( action_id, server_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_apr_failure_sid_idx
	on rhnActionPackageRemovalFailure( server_id )
	tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnActionScript.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionScript.sql
create sequence rhn_actscript_id_seq;
create table
rhnActionScript
(
	id		number
			constraint rhn_actscript_id_nn not null
			constraint rhn_actscript_id_pk primary key
				using index tablespace [[4m_tbs]],
	action_id	number
			constraint rhn_actscript_aid_nn not null
			constraint rhn_actscript_aid_fk
				references rhnAction(id)
				on delete cascade,
	username	varchar2(32)
			constraint rhn_actscript_user_nn not null,
	groupname	varchar2(32)
			constraint rhn_actscript_group_nn not null,
	script		blob,
	timeout		number,
	created		date default(sysdate)
			constraint rhn_actscript_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_actscript_mod_nn not null
)
	tablespace [[blob]]
	enable row movement
  ;
create unique index rhn_actscript_aid_uq_idx on
	rhnActionScript( action_id )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_actscript_mod_trig
before insert or update on rhnActionScript
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionStatus_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionStatus_data.sql
insert into rhnActionStatus values (0, 'Queued', sysdate, sysdate);
insert into rhnActionStatus values (1, 'Picked Up', sysdate, sysdate);
insert into rhnActionStatus values (2, 'Completed', sysdate, sysdate);
insert into rhnActionStatus values (3, 'Failed', sysdate, sysdate);
commit;

select 'rhnsat/tables/rhnActionStatus_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionStatus_triggers.sql
create or replace trigger
rhn_action_statusmod_trig
before insert or update on rhnActionStatus
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnTransaction.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTransaction.sql
create table
rhnTransaction
(
	id		number
			constraint rhn_trans_id_nn not null,
	server_id	number
			constraint rhn_trans_sid_nn not null
			constraint rhn_trans_sid_fk
				references rhnServer(id),
	timestamp	date
			constraint rhn_trans_ts_nn not null,
	rpm_trans_id	number
			constraint rhn_trans_rti_nn not null,
	label		varchar2(32),
	created		date default(sysdate)
			constraint rhn_trans_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_trans_modified_nn not null,
	constraint	rhn_trans_sid_rti_unq
			unique(server_id, rpm_trans_id)
			using index tablespace [[8m_tbs]]
)
	enable row movement
  ;
create sequence rhn_transaction_id_seq;
create index rhn_trans_id_sid_ts_rtid_idx
	on rhnTransaction(id,server_id,timestamp, rpm_trans_id)
  ;
alter table rhnTransaction add constraint rhn_trans_id_pk primary key (id)
	using index tablespace [[8m_tbs]];

select 'rhnsat/tables/rhnActionTransactions.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionTransactions.sql
create table
rhnActionTransactions
(
	action_id	number
			constraint rhn_at_aid_nn not null
			constraint rhn_at_aid_fk
				references rhnAction(id)
				on delete cascade,
	from_trans_id	number
			constraint rhn_at_ftid_nn not null
			constraint rhn_at_ftid_fk
				references rhnTransaction(id)
				on delete cascade,
	to_trans_id	number
			constraint rhn_at_ttid_nn not null
			constraint rhn_at_ttid_fk
				references rhnTransaction(id)
				on delete cascade
)
	enable row movement
  ;
create unique index rhn_at_aid_ftid_ttid_uq
	on rhnActionTransactions(action_id, from_trans_id, to_trans_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_act_trans_from_to_idx
on rhnActionTransactions ( from_trans_id, to_trans_id, action_id )
   tablespace [[64k_tbs]]
  ;
create index rhn_act_trans_to_from_idx
on rhnActionTransactions ( to_trans_id, from_trans_id, action_id )
   tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnActionType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionType_data.sql
insert into rhnActionType values (1, 'packages.refresh_list', 'Package List Refresh', 'Y', 'N');
insert into rhnActionType values (2, 'hardware.refresh_list', 'Hardware List Refresh', 'N', 'N');
insert into rhnActionType values (3, 'packages.update', 'Package Install', 'Y', 'Y');
insert into rhnActionType values (4, 'packages.remove', 'Package Removal', 'Y', 'Y');
insert into rhnActionType values (5, 'errata.update', 'Errata Update', 'Y', 'Y');
insert into rhnActionType values (6, 'up2date_config.get', 'Get server up2date config', 'Y', 'Y');
insert into rhnActionType values (7, 'up2date_config.update', 'Update server up2date config', 'Y', 'Y');
insert into rhnActionType values (8, 'packages.delta', 'Package installation and removal in one RPM transaction', 'Y', 'Y');
insert into rhnActionType values (9, 'reboot.reboot', 'System reboot', 'N', 'Y');
insert into rhnActionType values (10, 'rollback.config', 'Enable or Disable RPM Transaction Rollback', 'N', 'Y');
insert into rhnActionType values (11, 'rollback.listTransactions', 'Refresh server-side transaction list', 'N', 'N');
insert into rhnActionType values (12, 'rollback.rollback', 'RPM Transaction Rollback', 'Y', 'Y');
insert into rhnActionType values (13, 'packages.autoupdate', 'Automatic package installation', 'Y', 'Y');
insert into rhnActionType values (14, 'packages.runTransaction', 'Package Synchronization', 'Y', 'Y');
insert into rhnActionType values (15, 'configfiles.upload', 'Upload config file data to server', 'N', 'N');
insert into rhnActionType values (16, 'configfiles.deploy', 'Deploy config files to system', 'Y', 'Y');
insert into rhnActionType values (17, 'configfiles.verify', 'Verify deployed config files', 'N', 'N');
insert into rhnActionType values (18, 'configfiles.diff', 'Show differences between profiled config files and deployed config files', 'N', 'N');
insert into rhnActionType values (19, 'kickstart.initiate', 'Initiate a kickstart', 'N', 'Y');
insert into rhnActionType values (20, 'kickstart.schedule_sync', 'Schedule a package sync for kickstarts', 'N', 'N');
insert into rhnActionType values (21, 'activation.schedule_pkg_install', 'Schedule a package install for activation key', 'N', 'N');
insert into rhnActionType values (22, 'activation.schedule_deploy', 'Schedule a config deploy for activation key', 'N', 'N');
insert into rhnActionType values (23, 'configfiles.mtime_upload', 'Upload config file data based upon mtime to server', 'N', 'N');
insert into rhnActionType values (24, 'solarispkgs.install', 'Solaris Package Install', 'Y', 'Y');
insert into rhnActionType values (25, 'solarispkgs.remove', 'Solaris Package Removal', 'Y', 'Y');
insert into rhnActionType values (26, 'solarispkgs.patchInstall', 'Solaris Patch Install', 'Y', 'Y');
insert into rhnActionType values (27, 'solarispkgs.patchRemove', 'Solaris Patch Removal', 'Y', 'Y');
insert into rhnActionType values (28, 'solarispkgs.patchClusterInstall', 'Solaris Patch Cluster Install', 'Y', 'Y');
insert into rhnActionType values (29, 'solarispkgs.patchClusterRemove', 'Solaris Patch Cluster Removal', 'Y', 'Y');
insert into rhnActionType values (30, 'script.run', 'Run an arbitrary script', 'N', 'N');
insert into rhnActionType values (31, 'solarispkgs.refresh_list', 'Solaris Package List Refresh','Y','Y');
insert into rhnActionType values (32, 'rhnsd.configure', 'Spacewalk Daemon Configuration','N','N');
insert into rhnActionType values (33, 'packages.verify', 'Verify deployed packages','N','N');
insert into rhnActionType values (34, 'rhn_applet.use_satellite', 'Allows for rhn-applet use with an Spacewalk','N','N');
insert into rhnActionType values (35, 'kickstart_guest.initiate', 'Initiate a kickstart for a Xen guest.','N','Y');
insert into rhnActionType values (36, 'virt.shutdown', 'Shuts down a Xen domain.', 'N', 'N');
insert into rhnActionType values (37, 'virt.start', 'Starts up a Xen domain.', 'N', 'N');
insert into rhnActionType values (38, 'virt.suspend', 'Suspends a Xen domain.', 'N', 'N');
insert into rhnActionType values (39, 'virt.resume', 'Resumes a Xen domain.', 'N', 'N');
insert into rhnActionType values (40, 'virt.reboot', 'Reboots a Xen domain.', 'N', 'N');
insert into rhnActionType values (41, 'virt.destroy', 'Destroys a Xen Domain.', 'N', 'N');
insert into rhnActionType values (42, 'virt.setMemory', 'Sets the maximum memory usage for a Xen domain.', 'N', 'N');
insert into rhnActionType values (43, 'virt.schedulePoller', 'Sets when the poller should run.', 'N', 'N');
insert into rhnActionType values (44, 'kickstart_host.schedule_virt_host_pkg_install', 'Schedule a package install of host specific functionality.', 'N', 'N');
insert into rhnActionType values (45, 'kickstart_guest.schedule_virt_guest_pkg_install', 'Schedule a package install of guest specific functionality.', 'N', 'N');
insert into rhnActionType values (46, 'kickstart_host.add_tools_channel', 'Subscribes a server to the Spacewalk Tools channel associated with its base channel.', 'N', 'N');
insert into rhnActionType values (47, 'kickstart_guest.add_tools_channel', 'Subscribes a virtualization guest to the Spacewalk Tools channel associated with its base channel.', 'N', 'N');
insert into rhnActionType values (48, 'virt.setVCPUs', 'Sets the Vcpu  usage for a Xen domain.', 'N', 'N');
commit;
insert into rhnActionType values (49, 'proxy.deactivate', 'Deactivate Proxy', 'N', 'N');

select 'rhnsat/tables/rhnActionVirtDestroy.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionVirtDestroy.sql
create table
rhnActionVirtDestroy
(
    action_id   number  
                constraint rhn_avd_aid_nn not null
                constraint rhn_avd_aid_fk
                    references rhnAction(id)
                    on delete cascade,
    uuid        varchar2(128)
                constraint rhn_avd_uuid_nn not null,
    created     date default(sysdate)
                constraint rhn_avd_creat_nn not null,
    modified    date default(sysdate)
                constraint rhn_avd_mod_nn not null
)
    enable row movement
  ;
create unique index rhn_avd_aid_uq
    on rhnActionVirtDestroy( action_id )
    tablespace [[8m_tbs]]
  ;
alter table rhnActionVirtDestroy add constraint rhn_avd_aid_pk
    primary key ( action_id );
create or replace trigger
rhn_avd_mod_trig
before insert or update on rhnActionVirtDestroy
for each row
begin
    :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionVirtReboot.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionVirtReboot.sql
create table
rhnActionVirtReboot
(
    action_id   number  
                constraint rhn_avreboot_aid_nn not null 
                constraint rhn_avreboot_aid_fk
                    references rhnAction(id)
                    on delete cascade,
    uuid        varchar2(128)
                constraint rhn_avreboot_uuid_nn not null,
    created     date default(sysdate)
                constraint rhn_avreboot_creat_nn not null,
    modified    date default(sysdate)
                constraint rhn_avreboot_mod_nn not null
)
    enable row movement
  ;
create unique index rhn_avreboot_aid_uq
    on rhnActionVirtReboot( action_id )
    tablespace [[8m_tbs]]
  ;
alter table rhnActionVirtReboot add constraint rhn_avreboot_aid_pk
    primary key ( action_id );
create or replace trigger
rhn_avreboot_mod_trig
before insert or update on rhnActionVirtReboot
for each row
begin
    :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionVirtRefresh.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionVirtRefresh.sql
create table
rhnActionVirtRefresh
(
    action_id   number  
                constraint rhn_avrefresh_aid_nn not null
                constraint rhn_avrefresh_aid_fk
                    references rhnAction(id)
                    on delete cascade,
    created     date default(sysdate)
                constraint rhn_avrefresh_creat_nn not null,
    modified    date default(sysdate)
                constraint rhn_avrefresh_mod_nn not null
)
    enable row movement
  ;
create unique index rhn_avrefresh_aid_uq
    on rhnActionVirtRefresh( action_id )
    tablespace [[8m_tbs]]
  ;
alter table rhnActionVirtRefresh add constraint rhn_avrefresh_aid_pk
    primary key ( action_id );
create or replace trigger
rhn_avrefresh_mod_trig
before insert or update on rhnActionVirtRefresh
for each row
begin
    :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionVirtResume.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionVirtResume.sql
create table
rhnActionVirtResume
(
    action_id   number  
                constraint rhn_avresume_aid_nn not null
                constraint rhn_avresume_aid_fk
                    references rhnAction( id )
                    on delete cascade,
    uuid        varchar2(128)
                constraint rhn_avresume_uuid_nn not null,
    created     date default(sysdate)
                constraint rhn_avresume_creat_nn not null,
    modified    date default(sysdate)
                constraint rhn_avresume_mod_nn not null
)
    enable row movement
  ;
create unique index rhn_avresume_aid_uq
    on rhnActionVirtResume( action_id )
    tablespace [[8m_tbs]]
  ;
alter table rhnActionVirtResume add constraint rhn_avresume_aid_pk
    primary key ( action_id );
create or replace trigger
rhn_avresume_mod_trig
before insert or update on rhnActionVirtResume
for each row
begin
    :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionVirtSchedulePoller.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionVirtSchedulePoller.sql
create table
rhnActionVirtSchedulePoller
(
    action_id   number  
                constraint rhn_avsp_aid_nn not null
                constraint rhn_avsp_aid_fk
                    references rhnAction(id)
                    on delete cascade,
    minute      number,
    hour        number,
    dom         number,
    month       number,
    dow         number,
    created     date default(sysdate)
                constraint rhn_avsp_creat_nn not null,
    modified    date default(sysdate)
                constraint rhn_avsp_mod_nn not null
)
    enable row movement
  ;
create unique index rhn_avsp_aid_uq
    on rhnActionVirtSchedulePoller( action_id )
    tablespace [[8m_tbs]]
  ;
alter table rhnActionVirtSchedulePoller add constraint rhn_avsp_aid_pk
    primary key ( action_id );
create or replace trigger
rhn_avsp_mod_trig
before insert or update on rhnActionVirtSchedulePoller
for each row
begin
    :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionVirtSetMemory.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionVirtSetMemory.sql
create table
rhnActionVirtSetMemory
(
    action_id   number  
                constraint rhn_avsm_aid_nn not null
                constraint rhn_avsm_aid_fk
                    references rhnAction(id)
                    on delete cascade,
    uuid        varchar2(128)
                constraint rhn_avsm_uuid_nn not null,
    memory      number
                constraint rhn_avsm_mem_nn not null,
    created     date default(sysdate)
                constraint rhn_avsm_creat_nn not null,
    modified    date default(sysdate)
                constraint rhn_avsm_mod_nn not null
)
    enable row movement
  ;
create unique index rhn_avsm_aid_uq
    on rhnActionVirtSetMemory( action_id )
    tablespace [[8m_tbs]]
  ;
alter table rhnActionVirtSetMemory add constraint rhn_avsm_aid_pk
    primary key ( action_id );
create or replace trigger
rhn_avsm_mod_trig
before insert or update on rhnActionVirtSetMemory
for each row
begin
    :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionVirtShutdown.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionVirtShutdown.sql
create table
rhnActionVirtShutdown
(
    action_id   number  
                constraint rhn_avshutdown_aid_nn not null
                constraint rhn_avshutdown_aid_fk 
                    references rhnAction(id)
                    on delete cascade,
    uuid        varchar2(128)
                constraint rhn_avshutdown_uuid_nn not null,
    created     date default(sysdate)
                constraint rhn_avshutdown_creat_nn not null,
    modified    date default(sysdate)
                constraint rhn_avshutdown_mod_nn not null
)
    enable row movement
  ;
create unique index rhn_avshutdown_aid_uq
    on rhnActionVirtShutdown( action_id )
    tablespace [[8m_tbs]]
  ;
alter table rhnActionVirtShutdown add constraint rhn_avshutdown_aid_pk
    primary key ( action_id );
create or replace trigger
rhn_avshutdown_mod_trig
before insert or update on rhnActionVirtShutdown
for each row
begin
    :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionVirtStart.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionVirtStart.sql
create table
rhnActionVirtStart
(
    action_id   number  
                constraint rhn_avstart_aid_nn not null,
    uuid        varchar2(128)
                constraint rhn_avstart_uuid_nn not null,
    created     date default(sysdate)
                constraint rhn_avstart_creat_nn not null,
    modified    date default(sysdate)
                constraint rhn_avstart_mod_nn not null
)
    enable row movement
  ;
create unique index rhn_avstart_aid_uq
    on rhnActionVirtStart( action_id )
    tablespace [[8m_tbs]]
  ;
alter table rhnActionVirtStart add constraint rhn_avstart_aid_pk
    primary key ( action_id );
create or replace trigger
rhn_avstart_mod_trig
before insert or update on rhnActionVirtStart
for each row
begin
    :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionVirtSuspend.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionVirtSuspend.sql
create table
rhnActionVirtSuspend
(
    action_id   number  
                constraint rhn_avsuspend_aid_nn not null
                constraint rhn_avsuspend_aid_fk
                    references rhnAction(id)
                    on delete cascade,
    uuid        varchar2(128)
                constraint rhn_avsuspend_uuid_nn not null,
    created     date default(sysdate)
                constraint rhn_avsuspend_creat_nn not null,
    modified    date default(sysdate)
                constraint rhn_avsuspend_mod_nn not null
)
    enable row movement
  ;
create unique index rhn_avsuspend_aid_uq
    on rhnActionVirtSuspend( action_id )
    tablespace [[8m_tbs]]
  ;
alter table rhnActionVirtSuspend add constraint rhn_avsuspend_aid_pk
    primary key ( action_id );
create or replace trigger
rhn_avsuspend_mod_trig
before insert or update on rhnActionVirtSuspend
for each row
begin
    :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnActionVirtVcpu.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActionVirtVcpu.sql
create table
rhnActionVirtVcpu
(
    action_id   number  
                constraint rhn_avcpu_aid_nn not null
                constraint rhn_avcpu_aid_fk
                    references rhnAction(id)
                    on delete cascade,
    uuid        varchar2(128)
                constraint rhn_avcpu_uuid_nn not null,
    vcpu      number
                constraint rhn_avcpu_vcpus_nn not null,
    created     date default(sysdate)
                constraint rhn_avcpu_creat_nn not null,
    modified    date default(sysdate)
                constraint rhn_avcpu_mod_nn not null
)
    enable row movement
  ;
create unique index rhn_avcpu_aid_uq
    on rhnActionVirtVcpu( action_id )
    tablespace [[8m_tbs]]
  ;
alter table rhnActionVirtVcpu add constraint rhn_avcpu_aid_pk
    primary key ( action_id );
create or replace trigger
rhn_avcpu_mod_trig
before insert or update on rhnActionVirtVcpu
for each row
begin
    :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnRegToken.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnRegToken.sql
create table
rhnRegToken
(
	id		number
			constraint rhn_reg_token_id_nn not null
			constraint rhn_reg_token_pk primary key,
	org_id		number
			constraint rhn_reg_token_oid_nn not null
			constraint rhn_reg_token_oid_fk
				references web_customer(id)
				on delete cascade,
	user_id		number
			constraint rhn_reg_token_uid_fk
				references web_contact(id)
				on delete set null,
	server_id	number
			constraint rhn_reg_token_sid_fk
				references rhnServer(id),
	note		varchar2(2048)
			constraint rhn_reg_token_note_nn not null,
	usage_limit     number default 0,
        disabled        number default 0
	    	    	constraint rhn_reg_token_def_nn not null,
	deploy_configs	char(1) default('Y')
			constraint rhn_reg_token_deployconfs_nn not null
			constraint rhn_reg_token_deployconfs_ck
				check (deploy_configs in ('Y','N'))
)
	enable row movement
  ;
create index rhn_reg_token_org_id_idx
	on rhnRegToken(org_id, id)
	tablespace [[64k_tbs]]
	nologging;
create index rhn_reg_token_uid_idx
	on rhnRegToken ( user_id )
	tablespace [[64k_tbs]]
	nologging;
create index rhn_reg_token_sid_idx
	on rhnRegToken( server_id )
	tablespace [[8m_tbs]]
	nologging;
create sequence rhn_reg_token_seq;

select 'rhnsat/tables/rhnActivationKey.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnActivationKey.sql
create table
rhnActivationKey
(
	token		varchar2(48)
			constraint rhn_act_key_token_nn not null
			constraint rhn_act_key_token_uq unique,
	reg_token_id	number
			constraint rhn_act_key_reg_tid_nn not null
			constraint rhn_act_key_reg_tid_fk
				references rhnRegToken(id)
				on delete cascade,
	ks_session_id	number
			constraint rhn_act_key_ks_sid_fk
				references rhnKickstartSession(id)
				on delete cascade,
	created		date default sysdate
			constraint rhn_act_key_created_nn not null,
	modified	date default sysdate
			constraint rhn_act_key_modified_nn not null
)
	enable row movement
  ;
create index rhn_act_key_kssid_rtid_idx
on rhnActivationKey (ks_session_id, reg_token_id)
        tablespace [[64k_tbs]]
        nologging;
create index rhn_act_key_rtid_idx 
    on rhnActivationKey (reg_token_id)
    tablespace [[64k_tbs]]
    nologging;
create or replace trigger
rhn_act_key_mod_trig
before insert or update on rhnActivationKey
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnAllowTrust.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnAllowTrust.sql
create table
rhnAllowTrust
(
	org_id		number
			constraint rhn_allow_trust_oid_nn not null
			constraint rhn_allow_trust_oid_fk
				references web_customer(id)
                                on delete cascade,
        channel_flag    char(1) default('N')
                        constraint rhn_allow_trust_channelflg_nn not null
                        constraint rhn_allow_trust_channelflg_ck
                                check (channel_flag in ('N','Y')),
        migration_flag  char(1) default('N')
                        constraint rhn_allow_trust_migrflg_nn not null
                        constraint rhn_allow_trust_migrflg_ck
                                check (migration_flag in ('N','Y')),
        created         date default (sysdate)
                        constraint rhn_allow_trust_created_nn not null,
        modified        date default (sysdate)
                        constraint rhn_allow_trust_modified_nn not null
)
	enable row movement
  ;

select 'rhnsat/tables/rhnAppInstallInstance.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnAppInstallInstance.sql
create sequence rhn_appinst_instance_id_seq;
create table
rhnAppInstallInstance
(
	id		number
			constraint rhn_appinst_instance_id_nn not null,
	name		varchar2(128)
			constraint rhn_appinst_instance_name_nn not null,
	label		varchar2(128)
			constraint rhn_appinst_instance_label_nn not null,
	version		varchar2(32)
			constraint rhn_appinst_instance_vers_nn not null,
	created		date default (sysdate)
			constraint rhn_appinst_instance_creat_nn not null,
	modified	date default (sysdate)
			constraint rhn_appinst_instance_mod_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_appinst_istance_mod_trig
before insert or update on rhnAppInstallInstance
for each row
begin
	:new.modified := sysdate;
end rhn_appinst_istance_mod_trig;
/
show errors
create index rhn_appinst_instance_id_idx
	on rhnAppInstallInstance( id )
	tablespace [[4m_tbs]]
  ;
alter table rhnAppInstallInstance add constraint rhn_appinst_instance_id_pk
	primary key ( id );
create index rhn_appinst_instance_lv_id_idx
	on rhnAppInstallInstance( label, version, id )
	tablespace [[2m_tbs]]
  ;
alter table rhnAppInstallInstance add constraint rhn_appinst_instance_lv_uq
	unique ( label, version );

select 'rhnsat/tables/rhnAppInstallSession.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnAppInstallSession.sql
create sequence rhn_appinst_session_id_seq;
create table
rhnAppInstallSession
(
	id		number
			constraint rhn_appinst_session_id_nn not null,
	instance_id	number
			constraint rhn_appinst_session_iid_nn not null
			constraint rhn_appinst_session_iid_fk
				references rhnAppInstallInstance(id)
				on delete cascade,
	md5sum		varchar2(64),
	process_name	varchar2(32),
	step_number	number,
	user_id		number
			constraint rhn_appinst_session_uid_nn not null
			constraint rhn_appinst_session_uid_fk
				references web_contact(id),
	server_id	number
			constraint rhn_appinst_session_sid_nn not null
			constraint rhn_appinst_session_sid_fk
				references rhnServer(id),
	created		date default (sysdate)
			constraint rhn_appinst_session_creat_nn not null,
	modified	date default (sysdate)
			constraint rhn_appinst_session_mod_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_appinst_session_mod_trig
before insert or update on rhnAppInstallSession
for each row
begin
	:new.modified := sysdate;
end rhn_appinst_session_mod_trig;
/
show errors
create index rhn_appinst_session_id_iid_idx
	on rhnAppInstallSession( id, instance_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_appinst_session_iid_id_idx
    on rhnAppInstallSession( instance_id, id )
    tablespace [[4m_tbs]]
  ;
create index rhn_appinst_sessn_uid_iid_idx
    on rhnAppInstallSession( user_id, instance_id )
    tablespace [[4m_tbs]]
  ;
create index rhn_appinst_sessn_sid_iid_idx
    on rhnAppInstallSession( server_id, instance_id )
    tablespace [[4m_tbs]]
  ;
alter table rhnAppInstallSession add constraint rhn_appinst_sessiond_id_pk
	primary key ( id );

select 'rhnsat/tables/rhnAppInstallSessionData.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnAppInstallSessionData.sql
create sequence rhn_appinst_sdata_id_seq;
create table
rhnAppInstallSessionData
(
	id		number
			constraint rhn_appinst_sdata_id_nn not null,
	session_id	number
			constraint rhn_appinst_sdata_sid_nn not null
			constraint rhn_appinst_sdata_sid_fk
				references rhnAppInstallSession(id)
				on delete cascade,
	key		varchar2(64)
			constraint rhn_appinst_sdata_k_nn not null,
	value		varchar2(2048),
	extra_data	blob,
	created		date default (sysdate)
			constraint rhn_appinst_sdata_creat_nn not null,
	modified	date default (sysdate)
			constraint rhn_appinst_sdata_mod_nn not null
)
	tablespace [[blob]]
	enable row movement
  ;
create or replace trigger
rhn_appinst_sdata_mod_trig
before insert or update on rhnAppInstallSessionData
for each row
begin
	:new.modified := sysdate;
end rhn_appinst_sdata_mod_trig;
/
show errors
create index rhn_appinst_sdata_id_idx
	on rhnAppInstallSessionData( id )
	tablespace [[2m_tbs]]
  ;
alter table rhnAppInstallSessionData add constraint rhn_appinst_sdata_id_pk
	primary key ( id );
create index rhn_appinst_sdata_sid_k_id_idx
	on rhnAppInstallSessionData( session_id, key, id )
	tablespace [[8m_tbs]]
  ;
alter table rhnAppInstallSessionData add constraint rhn_appinst_sdata_sid_k_uq
	unique ( session_id, key );

select 'rhnsat/tables/rhnArchTypeActions.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnArchTypeActions.sql
create table
rhnArchTypeActions
(
	arch_type_id	number
			constraint rhn_archtypeacts_atid_nn not null
			constraint rhn_archtypeacts_atid_fk
				references rhnArchType(id),
	action_style	varchar2(64)
			constraint rhn_archtypeacts_as_nn not null,
	action_type_id	number
			constraint rhn_archtypeacts_actid_nn not null
			constraint rhn_archtypeacts_actid_fk
				references rhnActionType(id),
	created		date default(sysdate)
			constraint rhn_archtypeacts_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_archtypeacts_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_archtypeacts_atid_as_uq
	on rhnArchTypeActions( arch_type_id, action_style )
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_archtypeacts_mod_trig
before insert or update on rhnArchTypeActions
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnArchType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnArchType_data.sql
insert into rhnArchType (id, label, name) values
	(rhn_archtype_id_seq.nextval, 'rpm', 'RPM');
insert into rhnArchType (id, label, name) values
	(rhn_archtype_id_seq.nextval, 'sysv-solaris', 'SysV-Solaris');
insert into rhnArchType (id, label, name) values
	(rhn_archtype_id_seq.nextval, 'tar', 'tar');
insert into rhnArchType (id, label, name) values
	(rhn_archtype_id_seq.nextval, 'solaris-patch', 'Solaris Patch');
insert into rhnArchType (id, label, name) values
	(rhn_archtype_id_Seq.nextval, 'solaris-patch-cluster',
		'Solaris Patch Cluster');
commit;

select 'rhnsat/tables/rhnArchTypeActions_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnArchTypeActions_data.sql
INSERT
  INTO rhnArchTypeActions (arch_type_id, action_style, action_type_id)
       (SELECT ArchT.id, 'install', ActionT.id
          FROM rhnArchType ArchT, rhnActionType ActionT
	 WHERE ArchT.label = 'rpm'
	   AND ActionT.label = 'packages.update');
INSERT
  INTO rhnArchTypeActions (arch_type_id, action_style, action_type_id)
       (SELECT ArchT.id, 'remove', ActionT.id
          FROM rhnArchType ArchT, rhnActionType ActionT
	 WHERE ArchT.label = 'rpm'
	   AND ActionT.label = 'packages.remove');
INSERT
  INTO rhnArchTypeActions (arch_type_id, action_style, action_type_id)
       (SELECT ArchT.id, 'install', ActionT.id
          FROM rhnArchType ArchT, rhnActionType ActionT
	 WHERE ArchT.label = 'sysv-solaris'
	   AND ActionT.label = 'solarispkgs.install');
INSERT
  INTO rhnArchTypeActions (arch_type_id, action_style, action_type_id)
       (SELECT ArchT.id, 'remove', ActionT.id
          FROM rhnArchType ArchT, rhnActionType ActionT
	 WHERE ArchT.label = 'sysv-solaris'
	   AND ActionT.label = 'solarispkgs.remove');
INSERT
  INTO rhnArchTypeActions (arch_type_id, action_style, action_type_id)
       (SELECT ArchT.id, 'install', ActionT.id
          FROM rhnArchType ArchT, rhnActionType ActionT
	 WHERE ArchT.label = 'solaris-patch'
	   AND ActionT.label = 'solarispkgs.patchInstall');
INSERT
  INTO rhnArchTypeActions (arch_type_id, action_style, action_type_id)
       (SELECT ArchT.id, 'remove', ActionT.id
          FROM rhnArchType ArchT, rhnActionType ActionT
	 WHERE ArchT.label = 'solaris-patch'
	   AND ActionT.label = 'solarispkgs.patchRemove');
INSERT
  INTO rhnArchTypeActions (arch_type_id, action_style, action_type_id)
       (SELECT ArchT.id, 'install', ActionT.id
          FROM rhnArchType ArchT, rhnActionType ActionT
	 WHERE ArchT.label = 'solaris-patch-cluster'
	   AND ActionT.label = 'solarispkgs.patchClusterInstall');
INSERT
  INTO rhnArchTypeActions (arch_type_id, action_style, action_type_id)
       (SELECT ArchT.id, 'remove', ActionT.id
          FROM rhnArchType ArchT, rhnActionType ActionT
	 WHERE ArchT.label = 'solaris-patch-cluster'
	   AND ActionT.label = 'solarispkgs.patchClusterRemove');
INSERT
  INTO rhnArchTypeActions (arch_type_id, action_style, action_type_id)
       (SELECT ArchT.id, 'refresh_list', ActionT.id
          FROM rhnArchType ArchT, rhnActionType ActionT
         WHERE ArchT.label = 'sysv-solaris'
           AND ActionT.label = 'solarispkgs.refresh_list');
INSERT
  INTO rhnArchTypeActions (arch_type_id, action_style, action_type_id)
       (SELECT ArchT.id, 'refresh_list', ActionT.id
          FROM rhnArchType ArchT, rhnActionType ActionT
         WHERE ArchT.label = 'rpm'
           AND ActionT.label = 'packages.refresh_list');
INSERT
  INTO rhnArchTypeActions (arch_type_id, action_style, action_type_id)
       (SELECT ArchT.id, 'verify', ActionT.id
          FROM rhnArchType ArchT, rhnActionType ActionT
         WHERE ArchT.label = 'rpm'
           AND ActionT.label = 'packages.verify');
commit;

select 'rhnsat/tables/rhnBeehivePathMap.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnBeehivePathMap.sql
create table rhnBeehivePathMap
(
    path            varchar2(128)
                    constraint rhn_beehive_path_map_p_nn not null
                    constraint rhn_beehive_path_map_p_pk primary key
                        using index tablespace [[64k_tbs]],
    beehive_path    varchar2(128)
                    constraint rhn_beehive_path_map_bp_nn not null,
    ftp_path        varchar2(128)
                    constraint rhn_beehive_path_map_fp_nn not null,
    created         date default SYSDATE,
    modified        date default SYSDATE
)
	enable row movement
  ;
create or replace trigger
rhn_beehive_path_map_mod_trig
before insert or update on rhnBeehivePathMap
for each row
begin
    :new.modified := SYSDATE;
end rhn_beehive_mod_trig;
/
show errors

select 'rhnsat/tables/rhnBeehivePathMap_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnBeehivePathMap_data.sql
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/noarch',
    'beehive/updates/dist/6.2/noarch',
    'redhat/linux/updates/6.2/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/i386',
    'beehive/updates/dist/6.2/i386',
    'redhat/linux/updates/6.2/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/i586',
    'beehive/updates/dist/6.2/i586',
    'redhat/linux/updates/6.2/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/i686',
    'beehive/updates/dist/6.2/i686',
    'redhat/linux/updates/6.2/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/alpha',
    'beehive/updates/dist/6.2/alpha',
    'redhat/linux/updates/6.2/en/os/alpha');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/sparc',
    'beehive/updates/dist/6.2/sparc',
    'redhat/linux/updates/6.2/en/os/sparc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/sparcv9',
    'beehive/updates/dist/6.2/sparcv9',
    'redhat/linux/updates/6.2/en/os/sparcv9');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/sparc64',
    'beehive/updates/dist/6.2/sparc64',
    'redhat/linux/updates/6.2/en/os/sparc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/os/SRPMS',
    'beehive/updates/dist/6.2/SRPMS',
    'redhat/linux/updates/6.2/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/powertools/noarch',
    'beehive/updates/powertools/6.2/noarch',
    'redhat/linux/updates/6.2/en/powertools/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/powertools/i386',
    'beehive/updates/powertools/6.2/i386',
    'redhat/linux/updates/6.2/en/powertools/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/powertools/alpha',
    'beehive/updates/powertools/6.2/alpha',
    'redhat/linux/updates/6.2/en/powertools/alpha');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/powertools/sparc',
    'beehive/updates/powertools/6.2/sparc',
    'redhat/linux/updates/6.2/en/powertools/sparc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('6.2/en/powertools/SRPMS',
    'beehive/updates/powertools/6.2/SRPMS',
    'redhat/linux/updates/6.2/en/powertools/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/noarch',
    'beehive/updates/dist/7.0/noarch',
    'redhat/linux/updates/7.0/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/i386',
    'beehive/updates/dist/7.0/i386',
    'redhat/linux/updates/7.0/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/i586',
    'beehive/updates/dist/7.0/i586',
    'redhat/linux/updates/7.0/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/i686',
    'beehive/updates/dist/7.0/i686',
    'redhat/linux/updates/7.0/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/alpha',
    'beehive/updates/dist/7.0/alpha',
    'redhat/linux/updates/7.0/en/os/alpha');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/alphaev6',
    'beehive/updates/dist/7.0/alphaev6',
    'redhat/linux/updates/7.0/en/os/alphaev6');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/os/SRPMS',
    'beehive/updates/dist/7.0/SRPMS',
    'redhat/linux/updates/7.0/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/powertools/noarch',
    'beehive/updates/powertools/7.0/noarch',
    'redhat/linux/updates/7.0/en/powertools/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/powertools/i386',
    'beehive/updates/powertools/7.0/i386',
    'redhat/linux/updates/7.0/en/powertools/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/powertools/alpha',
    'beehive/updates/powertools/7.0/alpha',
    'redhat/linux/updates/7.0/en/powertools/alpha');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.0/en/powertools/SRPMS',
    'beehive/updates/powertools/7.0/SRPMS',
    'redhat/linux/updates/7.0/en/powertools/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/noarch',
    'beehive/updates/dist/7.1/noarch',
    'redhat/linux/updates/7.1/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/i386',
    'beehive/updates/dist/7.1/i386',
    'redhat/linux/updates/7.1/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/i586',
    'beehive/updates/dist/7.1/i586',
    'redhat/linux/updates/7.1/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/i686',
    'beehive/updates/dist/7.1/i686',
    'redhat/linux/updates/7.1/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/athlon',
    'beehive/updates/dist/7.1/athlon',
    'redhat/linux/updates/7.1/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/alpha',
    'beehive/updates/dist/7.1/alpha',
    'redhat/linux/updates/7.1/en/os/alpha');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/alphaev6',
    'beehive/updates/dist/7.1/alphaev6',
    'redhat/linux/updates/7.1/en/os/alphaev6');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/ia64',
    'beehive/updates/dist/7.1/ia64',
    'redhat/linux/updates/7.1/en/os/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/s390x',
    'beehive/updates/dist/7.1/s390x',
    'redhat/linux/updates/7.1/en/os/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/SRPMS',
    'beehive/updates/dist/7.1/SRPMS',
    'redhat/linux/updates/7.1/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/powertools/noarch',
    'beehive/updates/powertools/7.1/noarch',
    'redhat/linux/updates/7.1/en/powertools/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/powertools/i386',
    'beehive/updates/powertools/7.1/i386',
    'redhat/linux/updates/7.1/en/powertools/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/powertools/alpha',
    'beehive/updates/powertools/7.1/alpha',
    'redhat/linux/updates/7.1/en/powertools/alpha');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/powertools/SRPMS',
    'beehive/updates/powertools/7.1/SRPMS',
    'redhat/linux/updates/7.1/en/powertools/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/noarch',
    'beehive/updates/dist/7.2/noarch',
    'redhat/linux/updates/7.2/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/i386',
    'beehive/updates/dist/7.2/i386',
    'redhat/linux/updates/7.2/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/i586',
    'beehive/updates/dist/7.2/i586',
    'redhat/linux/updates/7.2/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/i686',
    'beehive/updates/dist/7.2/i686',
    'redhat/linux/updates/7.2/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/athlon',
    'beehive/updates/dist/7.2/athlon',
    'redhat/linux/updates/7.2/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/ia64',
    'beehive/updates/dist/7.2/ia64',
    'redhat/linux/updates/7.2/en/os/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/s390',
    'beehive/updates/dist/7.2/s390',
    'redhat/linux/updates/7.2/en/os/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.2/en/os/SRPMS',
    'beehive/updates/dist/7.2/SRPMS',
    'redhat/linux/updates/7.2/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.3/en/os/noarch',
    'beehive/updates/dist/7.3/noarch',
    'redhat/linux/updates/7.3/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.3/en/os/i386',
    'beehive/updates/dist/7.3/i386',
    'redhat/linux/updates/7.3/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.3/en/os/i586',
    'beehive/updates/dist/7.3/i586',
    'redhat/linux/updates/7.3/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.3/en/os/i686',
    'beehive/updates/dist/7.3/i686',
    'redhat/linux/updates/7.3/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.3/en/os/athlon',
    'beehive/updates/dist/7.3/athlon',
    'redhat/linux/updates/7.3/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.3/en/os/SRPMS',
    'beehive/updates/dist/7.3/SRPMS',
    'redhat/linux/updates/7.3/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/rhdb/i386',
    'beehive/updates/rhdb/7.1/i386',
    'rhn/updates/7.1/en/rhdb/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/rhdb/noarch',
    'beehive/updates/rhdb/7.1/noarch',
    'rhn/updates/7.1/en/rhdb/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/rhdb/SRPMS',
    'beehive/updates/rhdb/7.1/SRPMS',
    'rhn/updates/7.1/en/rhdb/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/noarch',
    'beehive/updates/dist/2.1AS/noarch',
    'rhn/updates/2.1AS/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/i386',
    'beehive/updates/dist/2.1AS/i386',
    'rhn/updates/2.1AS/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/i586',
    'beehive/updates/dist/2.1AS/i586',
    'rhn/updates/2.1AS/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/i686',
    'beehive/updates/dist/2.1AS/i686',
    'rhn/updates/2.1AS/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/athlon',
    'beehive/updates/dist/2.1AS/athlon',
    'rhn/updates/2.1AS/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/SRPMS',
    'beehive/updates/dist/2.1AS/SRPMS',
    'rhn/updates/2.1AS/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/os/ia64',
    'beehive/updates/dist/2.1AS/ia64',
    'rhn/updates/2.1AS/en/os/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AW/en/os/ia64',
    'beehive/updates/dist/2.1AW/ia64',
    'rhn/updates/2.1AW/en/os/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AW/en/os/noarch',
    'beehive/updates/dist/2.1AW/noarch',
    'rhn/updates/2.1AW/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AW/en/os/SRPMS',
    'beehive/updates/dist/2.1AW/SRPMS',
    'rhn/updates/2.1AW/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1ES/en/os/noarch',
    'beehive/updates/dist/2.1ES/noarch',
    'rhn/updates/2.1ES/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1ES/en/os/athlon',
    'beehive/updates/dist/2.1ES/athlon',
    'rhn/updates/2.1ES/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1ES/en/os/i386',
    'beehive/updates/dist/2.1ES/i386',
    'rhn/updates/2.1ES/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1ES/en/os/i686',
    'beehive/updates/dist/2.1ES/i686',
    'rhn/updates/2.1ES/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1ES/en/os/SRPMS',
    'beehive/updates/dist/2.1ES/SRPMS',
    'rhn/updates/2.1ES/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1WS/en/os/noarch',
    'beehive/updates/dist/2.1WS/noarch',
    'rhn/updates/2.1WS/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1WS/en/os/athlon',
    'beehive/updates/dist/2.1WS/athlon',
    'rhn/updates/2.1WS/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1WS/en/os/i386',
    'beehive/updates/dist/2.1WS/i386',
    'rhn/updates/2.1WS/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1WS/en/os/i686',
    'beehive/updates/dist/2.1WS/i686',
    'rhn/updates/2.1WS/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1WS/en/os/SRPMS',
    'beehive/updates/dist/2.1WS/SRPMS',
    'rhn/updates/2.1WS/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('enterprise/2.1AS/en/SH4.0/noarch',
   'beehive/updates/stronghold/2.1AS/noarch',
   'rhn/updates/stronghold/2.1AS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('enterprise/2.1AS/en/SH4.0/i386',
   'beehive/updates/stronghold/2.1AS/i386',
   'rhn/updates/stronghold/2.1AS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('enterprise/2.1AS/en/SH4.0/SRPMS',
   'beehive/updates/stronghold/2.1AS/SRPMS',
   'rhn/updates/stronghold/2.1AS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/SH4.0/noarch',
   'beehive/updates/stronghold/2.1AS/noarch',
   'rhn/updates/stronghold/2.1AS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/SH4.0/i386',
   'beehive/updates/stronghold/2.1AS/i386',
   'rhn/updates/stronghold/2.1AS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('2.1AS/en/SH4.0/SRPMS',
   'beehive/updates/stronghold/2.1AS/SRPMS',
   'rhn/updates/stronghold/2.1AS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('8.0/en/os/noarch',
    'beehive/updates/dist/8.0/noarch',
    'redhat/linux/updates/8.0/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('8.0/en/os/i386',
    'beehive/updates/dist/8.0/i386',
    'redhat/linux/updates/8.0/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('8.0/en/os/i586',
    'beehive/updates/dist/8.0/i586',
    'redhat/linux/updates/8.0/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('8.0/en/os/i686',
    'beehive/updates/dist/8.0/i686',
    'redhat/linux/updates/8.0/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('8.0/en/os/athlon',
    'beehive/updates/dist/8.0/athlon',
    'redhat/linux/updates/8.0/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('8.0/en/os/SRPMS',
    'beehive/updates/dist/8.0/SRPMS',
    'redhat/linux/updates/8.0/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('9/en/os/noarch',
    'beehive/updates/dist/9/noarch',
    'redhat/linux/updates/9/en/os/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('9/en/os/i386',
    'beehive/updates/dist/9/i386',
    'redhat/linux/updates/9/en/os/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('9/en/os/i586',
    'beehive/updates/dist/9/i586',
    'redhat/linux/updates/9/en/os/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('9/en/os/i686',
    'beehive/updates/dist/9/i686',
    'redhat/linux/updates/9/en/os/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('9/en/os/athlon',
    'beehive/updates/dist/9/athlon',
    'redhat/linux/updates/9/en/os/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('9/en/os/SRPMS',
    'beehive/updates/dist/9/SRPMS',
    'redhat/linux/updates/9/en/os/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/iSeries/noarch',
    'beehive/updates/dist/7.1-ppc-i/noarch',
    'redhat/linux/updates/7.1/en/os/iSeries/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/iSeries/ppc',
    'beehive/updates/dist/7.1-ppc-i/ppc',
    'redhat/linux/updates/7.1/en/os/iSeries/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/iSeries/ppc64',
    'beehive/updates/dist/7.1-ppc-i/ppc64',
    'redhat/linux/updates/7.1/en/os/iSeries/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/iSeries/SRPMS',
    'beehive/updates/dist/7.1-ppc-i/SRPMS',
    'redhat/linux/updates/7.1/en/os/iSeries/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/pSeries/noarch',
    'beehive/updates/dist/7.1-ppc-p/noarch',
    'redhat/linux/updates/7.1/en/os/pSeries/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/pSeries/ppc',
    'beehive/updates/dist/7.1-ppc-p/ppc',
    'redhat/linux/updates/7.1/en/os/pSeries/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/pSeries/ppc64',
    'beehive/updates/dist/7.1-ppc-p/ppc64',
    'redhat/linux/updates/7.1/en/os/pSeries/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path) values
   ('7.1/en/os/pSeries/SRPMS',
    'beehive/updates/dist/7.1-ppc-p/SRPMS',
    'redhat/linux/updates/7.1/en/os/pSeries/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('5.1/en/cms/noarch', 'beehive/updates/cms/5.1/noarch', 
        'rhn/updates/cms/5.1/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('5.1/en/cms/i386', 'beehive/updates/cms/5.1/i386', 
        'rhn/updates/cms/5.1/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('5.1/en/cms/SRPMS', 'beehive/updates/cms/5.1/SRPMS', 
        'rhn/updates/cms/5.1/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('2.1AS/en/cms-5.2/noarch', 'beehive/updates/cms/5.2/noarch', 
        'rhn/updates/cms/5.2/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('2.1AS/en/cms-5.2/i386', 'beehive/updates/cms/5.2/i386', 
        'rhn/updates/cms/5.2/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('2.1AS/en/cms-5.2/SRPMS', 'beehive/updates/cms/5.2/SRPMS', 
        'rhn/updates/cms/5.2/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('2.1AS/en/waf-5.2/noarch', 'beehive/updates/waf/5.2/noarch', 
        'rhn/updates/waf/5.2/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('2.1AS/en/waf-5.2/i386', 'beehive/updates/waf/5.2/i386', 
        'rhn/updates/waf/5.2/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('2.1AS/en/waf-5.2/SRPMS', 'beehive/updates/waf/5.2/SRPMS', 
        'rhn/updates/waf/5.2/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('2.1AS/en/cms-6.0/noarch', 'beehive/updates/cms/6.0/noarch', 
        'rhn/updates/cms/6.0/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('2.1AS/en/cms-6.0/i386', 'beehive/updates/cms/6.0/i386', 
        'rhn/updates/cms/6.0/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('2.1AS/en/cms-6.0/SRPMS', 'beehive/updates/cms/6.0/SRPMS', 
        'rhn/updates/cms/6.0/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('2.1AS/en/waf-6.0/noarch', 'beehive/updates/waf/6.0/noarch', 
        'rhn/updates/waf/6.0/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('2.1AS/en/waf-6.0/i386', 'beehive/updates/waf/6.0/i386', 
        'rhn/updates/waf/6.0/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('2.1AS/en/waf-6.0/SRPMS', 'beehive/updates/waf/6.0/SRPMS', 
        'rhn/updates/waf/6.0/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/athlon', 'beehive/updates/dist/3AS/athlon',
        'rhn/updates/3AS/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/i386', 'beehive/updates/dist/3AS/i386',
        'rhn/updates/3AS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/i686', 'beehive/updates/dist/3AS/i686',
        'rhn/updates/3AS/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/ia64', 'beehive/updates/dist/3AS/ia64',
        'rhn/updates/3AS/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/noarch', 'beehive/updates/dist/3AS/noarch',
        'rhn/updates/3AS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/ppc', 'beehive/updates/dist/3AS/ppc',
        'rhn/updates/3AS/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/ppc64', 'beehive/updates/dist/3AS/ppc64',
        'rhn/updates/3AS/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/ppc64iseries', 'beehive/updates/dist/3AS/ppc64iseries',
        'rhn/updates/3AS/ppc64iseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/ppc64pseries', 'beehive/updates/dist/3AS/ppc64pseries',
        'rhn/updates/3AS/ppc64pseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/s390', 'beehive/updates/dist/3AS/s390',
        'rhn/updates/3AS/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/s390x', 'beehive/updates/dist/3AS/s390x',
        'rhn/updates/3AS/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/SRPMS', 'beehive/updates/dist/3AS/SRPMS',
        'rhn/updates/3AS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/x86_64', 'beehive/updates/dist/3AS/x86_64',
        'rhn/updates/3AS/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/os/ia32e', 'beehive/updates/dist/3AS/ia32e',
        'rhn/updates/3AS/ia32e');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/athlon', 'beehive/updates/dist/3ES/athlon',
        'rhn/updates/3ES/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/i386', 'beehive/updates/dist/3ES/i386',
        'rhn/updates/3ES/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/i686', 'beehive/updates/dist/3ES/i686',
        'rhn/updates/3ES/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/ia64', 'beehive/updates/dist/3ES/ia64',
        'rhn/updates/3ES/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/noarch', 'beehive/updates/dist/3ES/noarch',
        'rhn/updates/3ES/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/ppc', 'beehive/updates/dist/3ES/ppc',
        'rhn/updates/3ES/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/ppc64', 'beehive/updates/dist/3ES/ppc64',
        'rhn/updates/3ES/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/ppc64iseries', 'beehive/updates/dist/3ES/ppc64iseries',
        'rhn/updates/3ES/ppc64iseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/ppc64pseries', 'beehive/updates/dist/3ES/ppc64pseries',
        'rhn/updates/3ES/ppc64pseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/s390', 'beehive/updates/dist/3ES/s390',
        'rhn/updates/3ES/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/s390x', 'beehive/updates/dist/3ES/s390x',
        'rhn/updates/3ES/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/SRPMS', 'beehive/updates/dist/3ES/SRPMS',
        'rhn/updates/3ES/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/x86_64', 'beehive/updates/dist/3ES/x86_64',
        'rhn/updates/3ES/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/os/ia32e', 'beehive/updates/dist/3ES/ia32e',
        'rhn/updates/3ES/ia32e');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/athlon', 'beehive/updates/dist/3WS/athlon',
        'rhn/updates/3WS/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/i386', 'beehive/updates/dist/3WS/i386',
        'rhn/updates/3WS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/i686', 'beehive/updates/dist/3WS/i686',
        'rhn/updates/3WS/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/ia64', 'beehive/updates/dist/3WS/ia64',
        'rhn/updates/3WS/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/noarch', 'beehive/updates/dist/3WS/noarch',
        'rhn/updates/3WS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/ppc', 'beehive/updates/dist/3WS/ppc',
        'rhn/updates/3WS/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/ppc64', 'beehive/updates/dist/3WS/ppc64',
        'rhn/updates/3WS/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/ppc64iseries', 'beehive/updates/dist/3WS/ppc64iseries',
        'rhn/updates/3WS/ppc64iseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/ppc64pseries', 'beehive/updates/dist/3WS/ppc64pseries',
        'rhn/updates/3WS/ppc64pseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/s390', 'beehive/updates/dist/3WS/s390',
        'rhn/updates/3WS/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/s390x', 'beehive/updates/dist/3WS/s390x',
        'rhn/updates/3WS/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/SRPMS', 'beehive/updates/dist/3WS/SRPMS',
        'rhn/updates/3WS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/x86_64', 'beehive/updates/dist/3WS/x86_64',
        'rhn/updates/3WS/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/os/ia32e', 'beehive/updates/dist/3WS/ia32e',
        'rhn/updates/3WS/ia32e');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHDS/athlon', 'beehive/updates/dist/3AS-DS/athlon',
        'rhn/updates/3AS-DS/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHDS/i386', 'beehive/updates/dist/3AS-DS/i386',
        'rhn/updates/3AS-DS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHDS/i686', 'beehive/updates/dist/3AS-DS/i686',
        'rhn/updates/3AS-DS/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHDS/ia32e', 'beehive/updates/dist/3AS-DS/ia32e',
        'rhn/updates/3AS-DS/ia32e');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHDS/ia64', 'beehive/updates/dist/3AS-DS/ia64',
        'rhn/updates/3AS-DS/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHDS/noarch', 'beehive/updates/dist/3AS-DS/noarch',
        'rhn/updates/3AS-DS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHDS/ppc', 'beehive/updates/dist/3AS-DS/ppc',
        'rhn/updates/3AS-DS/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHDS/ppc64', 'beehive/updates/dist/3AS-DS/ppc64',
        'rhn/updates/3AS-DS/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHDS/s390', 'beehive/updates/dist/3AS-DS/s390',
        'rhn/updates/3AS-DS/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHDS/s390x', 'beehive/updates/dist/3AS-DS/s390x',
        'rhn/updates/3AS-DS/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHDS/SRPMS', 'beehive/updates/dist/3AS-DS/SRPMS',
        'rhn/updates/3AS-DS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHDS/x86_64', 'beehive/updates/dist/3AS-DS/x86_64',
        'rhn/updates/3AS-DS/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHDS/athlon', 'beehive/updates/dist/3ES-DS/athlon',
        'rhn/updates/3ES-DS/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHDS/i386', 'beehive/updates/dist/3ES-DS/i386',
        'rhn/updates/3ES-DS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHDS/i686', 'beehive/updates/dist/3ES-DS/i686',
        'rhn/updates/3ES-DS/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHDS/ia32e', 'beehive/updates/dist/3ES-DS/ia32e',
        'rhn/updates/3ES-DS/ia32e');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHDS/ia64', 'beehive/updates/dist/3ES-DS/ia64',
        'rhn/updates/3ES-DS/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHDS/noarch', 'beehive/updates/dist/3ES-DS/noarch',
        'rhn/updates/3ES-DS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHDS/ppc', 'beehive/updates/dist/3ES-DS/ppc',
        'rhn/updates/3ES-DS/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHDS/ppc64', 'beehive/updates/dist/3ES-DS/ppc64',
        'rhn/updates/3ES-DS/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHDS/s390', 'beehive/updates/dist/3ES-DS/s390',
        'rhn/updates/3ES-DS/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHDS/s390x', 'beehive/updates/dist/3ES-DS/s390x',
        'rhn/updates/3ES-DS/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHDS/SRPMS', 'beehive/updates/dist/3ES-DS/SRPMS',
        'rhn/updates/3ES-DS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHDS/x86_64', 'beehive/updates/dist/3ES-DS/x86_64',
        'rhn/updates/3ES-DS/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/RHDS/athlon', 'beehive/updates/dist/3WS-DS/athlon',
        'rhn/updates/3WS-DS/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/RHDS/i386', 'beehive/updates/dist/3WS-DS/i386',
        'rhn/updates/3WS-DS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/RHDS/i686', 'beehive/updates/dist/3WS-DS/i686',
        'rhn/updates/3WS-DS/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/RHDS/ia32e', 'beehive/updates/dist/3WS-DS/ia32e',
        'rhn/updates/3WS-DS/ia32e');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/RHDS/ia64', 'beehive/updates/dist/3WS-DS/ia64',
        'rhn/updates/3WS-DS/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/RHDS/noarch', 'beehive/updates/dist/3WS-DS/noarch',
        'rhn/updates/3WS-DS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/RHDS/ppc', 'beehive/updates/dist/3WS-DS/ppc',
        'rhn/updates/3WS-DS/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/RHDS/ppc64', 'beehive/updates/dist/3WS-DS/ppc64',
        'rhn/updates/3WS-DS/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/RHDS/s390', 'beehive/updates/dist/3WS-DS/s390',
        'rhn/updates/3WS-DS/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/RHDS/s390x', 'beehive/updates/dist/3WS-DS/s390x',
        'rhn/updates/3WS-DS/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/RHDS/SRPMS', 'beehive/updates/dist/3WS-DS/SRPMS',
        'rhn/updates/3WS-DS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS/en/RHDS/x86_64', 'beehive/updates/dist/3WS-DS/x86_64',
        'rhn/updates/3WS-DS/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/RHDS/athlon', 'beehive/updates/dist/3DT-DS/athlon',
        'rhn/updates/3DT-DS/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/RHDS/i386', 'beehive/updates/dist/3DT-DS/i386',
        'rhn/updates/3DT-DS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/RHDS/i686', 'beehive/updates/dist/3DT-DS/i686',
        'rhn/updates/3DT-DS/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/RHDS/ia32e', 'beehive/updates/dist/3DT-DS/ia32e',
        'rhn/updates/3DT-DS/ia32e');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/RHDS/ia64', 'beehive/updates/dist/3DT-DS/ia64',
        'rhn/updates/3DT-DS/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/RHDS/noarch', 'beehive/updates/dist/3DT-DS/noarch',
        'rhn/updates/3DT-DS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/RHDS/ppc', 'beehive/updates/dist/3DT-DS/ppc',
        'rhn/updates/3DT-DS/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/RHDS/ppc64', 'beehive/updates/dist/3DT-DS/ppc64',
        'rhn/updates/3DT-DS/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/RHDS/s390', 'beehive/updates/dist/3DT-DS/s390',
        'rhn/updates/3DT-DS/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/RHDS/s390x', 'beehive/updates/dist/3DT-DS/s390x',
        'rhn/updates/3DT-DS/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/RHDS/SRPMS', 'beehive/updates/dist/3DT-DS/SRPMS',
        'rhn/updates/3DT-DS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/RHDS/x86_64', 'beehive/updates/dist/3DT-DS/x86_64',
        'rhn/updates/3DT-DS/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHCS/noarch', 'beehive/updates/dist/3AS-CS/noarch',
        'rhn/updates/3AS-CS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHCS/athlon', 'beehive/updates/dist/3AS-CS/athlon',
        'rhn/updates/3AS-CS/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHCS/i386', 'beehive/updates/dist/3AS-CS/i386',
        'rhn/updates/3AS-CS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHCS/i686', 'beehive/updates/dist/3AS-CS/i686',
        'rhn/updates/3AS-CS/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS/en/RHCS/SRPMS', 'beehive/updates/dist/3AS-CS/SRPMS',
        'rhn/updates/3AS-CS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHCS/noarch', 'beehive/updates/dist/3ES-CS/noarch',
        'rhn/updates/3ES-CS/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHCS/athlon', 'beehive/updates/dist/3ES-CS/athlon',
        'rhn/updates/3ES-CS/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHCS/i386', 'beehive/updates/dist/3ES-CS/i386',
        'rhn/updates/3ES-CS/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHCS/i686', 'beehive/updates/dist/3ES-CS/i686',
        'rhn/updates/3ES-CS/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES/en/RHCS/SRPMS', 'beehive/updates/dist/3ES-CS/SRPMS',
        'rhn/updates/3ES-CS/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS-LACD/en/os/i386', 'beehive/updates/dist/3AS-LACD/i386',
        'rhn/updates/3AS-LACD/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS-LACD/en/os/i586', 'beehive/updates/dist/3AS-LACD/i586',
        'rhn/updates/3AS-LACD/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS-LACD/en/os/i686', 'beehive/updates/dist/3AS-LACD/i686',
        'rhn/updates/3AS-LACD/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS-LACD/en/os/ia64', 'beehive/updates/dist/3AS-LACD/ia64',
        'rhn/updates/3AS-LACD/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS-LACD/en/os/noarch', 'beehive/updates/dist/3AS-LACD/noarch',
        'rhn/updates/3AS-LACD/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS-LACD/en/os/ppc', 'beehive/updates/dist/3AS-LACD/ppc',
        'rhn/updates/3AS-LACD/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS-LACD/en/os/ppc64', 'beehive/updates/dist/3AS-LACD/ppc64',
        'rhn/updates/3AS-LACD/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS-LACD/en/os/s390', 'beehive/updates/dist/3AS-LACD/s390',
        'rhn/updates/3AS-LACD/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS-LACD/en/os/s390x', 'beehive/updates/dist/3AS-LACD/s390x',
        'rhn/updates/3AS-LACD/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS-LACD/en/os/SRPMS', 'beehive/updates/dist/3AS-LACD/SRPMS',
        'rhn/updates/3AS-LACD/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3AS-LACD/en/os/x86_64', 'beehive/updates/dist/3AS-LACD/x86_64',
        'rhn/updates/3AS-LACD/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES-LACD/en/os/i386', 'beehive/updates/dist/3ES-LACD/i386',
        'rhn/updates/3ES-LACD/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES-LACD/en/os/i586', 'beehive/updates/dist/3ES-LACD/i586',
        'rhn/updates/3ES-LACD/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES-LACD/en/os/i686', 'beehive/updates/dist/3ES-LACD/i686',
        'rhn/updates/3ES-LACD/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES-LACD/en/os/ia64', 'beehive/updates/dist/3ES-LACD/ia64',
        'rhn/updates/3ES-LACD/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES-LACD/en/os/noarch', 'beehive/updates/dist/3ES-LACD/noarch',
        'rhn/updates/3ES-LACD/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES-LACD/en/os/ppc', 'beehive/updates/dist/3ES-LACD/ppc',
        'rhn/updates/3ES-LACD/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES-LACD/en/os/ppc64', 'beehive/updates/dist/3ES-LACD/ppc64',
        'rhn/updates/3ES-LACD/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES-LACD/en/os/s390', 'beehive/updates/dist/3ES-LACD/s390',
        'rhn/updates/3ES-LACD/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES-LACD/en/os/s390x', 'beehive/updates/dist/3ES-LACD/s390x',
        'rhn/updates/3ES-LACD/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES-LACD/en/os/SRPMS', 'beehive/updates/dist/3ES-LACD/SRPMS',
        'rhn/updates/3ES-LACD/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3ES-LACD/en/os/x86_64', 'beehive/updates/dist/3ES-LACD/x86_64',
        'rhn/updates/3ES-LACD/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS-LACD/en/os/i386', 'beehive/updates/dist/3WS-LACD/i386',
        'rhn/updates/3WS-LACD/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS-LACD/en/os/i586', 'beehive/updates/dist/3WS-LACD/i586',
        'rhn/updates/3WS-LACD/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS-LACD/en/os/i686', 'beehive/updates/dist/3WS-LACD/i686',
        'rhn/updates/3WS-LACD/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS-LACD/en/os/ia64', 'beehive/updates/dist/3WS-LACD/ia64',
        'rhn/updates/3WS-LACD/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS-LACD/en/os/noarch', 'beehive/updates/dist/3WS-LACD/noarch',
        'rhn/updates/3WS-LACD/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS-LACD/en/os/ppc', 'beehive/updates/dist/3WS-LACD/ppc',
        'rhn/updates/3WS-LACD/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS-LACD/en/os/ppc64', 'beehive/updates/dist/3WS-LACD/ppc64',
        'rhn/updates/3WS-LACD/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS-LACD/en/os/s390', 'beehive/updates/dist/3WS-LACD/s390',
        'rhn/updates/3WS-LACD/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS-LACD/en/os/s390x', 'beehive/updates/dist/3WS-LACD/s390x',
        'rhn/updates/3WS-LACD/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS-LACD/en/os/SRPMS', 'beehive/updates/dist/3WS-LACD/SRPMS',
        'rhn/updates/3WS-LACD/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3WS-LACD/en/os/x86_64', 'beehive/updates/dist/3WS-LACD/x86_64',
        'rhn/updates/3WS-LACD/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/athlon', 'beehive/updates/dist/3DT/athlon',
        'rhn/updates/3DT/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/i386', 'beehive/updates/dist/3DT/i386',
        'rhn/updates/3DT/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/i686', 'beehive/updates/dist/3DT/i686',
        'rhn/updates/3DT/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/ia64', 'beehive/updates/dist/3DT/ia64',
        'rhn/updates/3DT/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/noarch', 'beehive/updates/dist/3DT/noarch',
        'rhn/updates/3DT/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/ppc', 'beehive/updates/dist/3DT/ppc',
        'rhn/updates/3DT/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/ppc64', 'beehive/updates/dist/3DT/ppc64',
        'rhn/updates/3DT/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/ppc64iseries', 'beehive/updates/dist/3DT/ppc64iseries',
        'rhn/updates/3DT/ppc64iseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/ppc64pseries', 'beehive/updates/dist/3DT/ppc64pseries',
        'rhn/updates/3DT/ppc64pseries');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/s390', 'beehive/updates/dist/3DT/s390',
        'rhn/updates/3DT/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/s390x', 'beehive/updates/dist/3DT/s390x',
        'rhn/updates/3DT/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/SRPMS', 'beehive/updates/dist/3DT/SRPMS',
        'rhn/updates/3DT/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/x86_64', 'beehive/updates/dist/3DT/x86_64',
        'rhn/updates/3DT/x86_64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3desktop/en/os/ia32e', 'beehive/updates/dist/3DT/ia32e',
        'rhn/updates/3DT/ia32e');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3Desktop-LACD/en/os/athlon', 
        'beehive/updates/dist/3Desktop-LACD/athlon',
        'rhn/updates/3Desktop-LACD/athlon');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3Desktop-LACD/en/os/i386', 
        'beehive/updates/dist/3Desktop-LACD/i386',
        'rhn/updates/3Desktop-LACD/i386');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3Desktop-LACD/en/os/i586', 
        'beehive/updates/dist/3Desktop-LACD/i586',
        'rhn/updates/3Desktop-LACD/i586');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3Desktop-LACD/en/os/i686', 
        'beehive/updates/dist/3Desktop-LACD/i686',
        'rhn/updates/3Desktop-LACD/i686');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3Desktop-LACD/en/os/ia64', 
        'beehive/updates/dist/3Desktop-LACD/ia64',
        'rhn/updates/3Desktop-LACD/ia64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3Desktop-LACD/en/os/noarch', 
        'beehive/updates/dist/3Desktop-LACD/noarch',
        'rhn/updates/3Desktop-LACD/noarch');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3Desktop-LACD/en/os/ppc', 
        'beehive/updates/dist/3Desktop-LACD/ppc',
        'rhn/updates/3Desktop-LACD/ppc');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3Desktop-LACD/en/os/ppc64', 
        'beehive/updates/dist/3Desktop-LACD/ppc64',
        'rhn/updates/3Desktop-LACD/ppc64');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3Desktop-LACD/en/os/s390', 
        'beehive/updates/dist/3Desktop-LACD/s390',
        'rhn/updates/3Desktop-LACD/s390');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3Desktop-LACD/en/os/s390x', 
        'beehive/updates/dist/3Desktop-LACD/s390x',
        'rhn/updates/3Desktop-LACD/s390x');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3Desktop-LACD/en/os/SRPMS', 
        'beehive/updates/dist/3Desktop-LACD/SRPMS',
        'rhn/updates/3Desktop-LACD/SRPMS');
insert into rhnBeehivePathMap (path, beehive_path, ftp_path)
    values ('3Desktop-LACD/en/os/x86_64', 
        'beehive/updates/dist/3Desktop-LACD/x86_64',
        'rhn/updates/3Desktop-LACD/x86_64');
commit;

select 'rhnsat/tables/rhnBlacklistObsoletes.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnBlacklistObsoletes.sql
create table rhnBlacklistObsoletes
(
	name_id			number
				constraint rhn_bl_obs_nid_nn not null
				constraint rhn_bl_obs_nid_fk
					references rhnPackageName(id),
	evr_id			number
				constraint rhn_bl_obs_eid_nn not null
				constraint rhn_bl_obs_eid_fk
					references rhnPackageEVR(id),
	package_arch_id		number
				constraint rhn_bl_obs_paid_nn not null
				constraint rhn_bl_obs_paid_fk
					references rhnPackageArch(id),
	ignore_name_id		number
				constraint rhn_bl_obs_inid_nn not null
				constraint rhn_bl_obs_inid_fk
					references rhnPackageName(id),
	created			date default(sysdate)
				constraint rhn_bl_obs_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_bl_obs_modified_nn not null
)
	enable row movement
;
create index rhn_bl_obs_nepi_idx
	on rhnBlacklistObsoletes ( name_id, evr_id, package_arch_id, 
		ignore_name_id )
  ;
alter table rhnBlacklistObsoletes add constraint rhn_bl_obs_nepi_uq
	unique ( name_id, evr_id, package_arch_id, ignore_name_id );
create or replace trigger
rhn_bl_obs_mod_trig
before insert or update on rhnBlacklistObsoletes
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/procs/lookup_evr.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_evr.sql
CREATE OR REPLACE FUNCTION
LOOKUP_EVR(e_in IN VARCHAR2, v_in IN VARCHAR2, r_in IN VARCHAR2)
RETURN NUMBER
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	evr_id		NUMBER;
BEGIN
	SELECT id INTO evr_id
          FROM rhnPackageEvr 
         WHERE ((epoch IS NULL and e_in IS NULL) OR (epoch = e_in)) 
           AND version = v_in AND release = r_in;
	RETURN evr_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            INSERT INTO rhnPackageEvr (id, epoch, version, release, evr) 
            VALUES (rhn_pkg_evr_seq.nextval, e_in, v_in, r_in, 
                EVR_T(e_in, v_in, r_in))
            RETURNING id INTO evr_id;
        COMMIT;
	RETURN evr_id;
END;
/
SHOW ERRORS

select 'rhnsat/procs/lookup_package_name.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_package_name.sql
CREATE OR REPLACE FUNCTION
LOOKUP_PACKAGE_NAME(name_in IN VARCHAR2, ignore_null in number := 0)
RETURN NUMBER
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	name_id		NUMBER;
BEGIN
	if ignore_null = 1 and name_in is null then
		return null;
	end if;
	SELECT id
          INTO name_id
          FROM rhnPackageName 
         WHERE name = name_in;
	RETURN name_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            INSERT INTO rhnPackageName (id, name) 
                VALUES (rhn_pkg_name_seq.nextval, name_in)
                RETURNING id INTO name_id;
            COMMIT;
	RETURN name_id;
END;
/
SHOW ERRORS

select 'rhnsat/tables/rhnPackageNEVRA.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageNEVRA.sql
create sequence rhn_pkgnevra_id_seq;
create table
rhnPackageNEVRA
(
	id			number
				constraint rhn_pkgnevra_id_nn not null
				constraint rhn_pkgnevra_id_pk primary key
					using index tablespace [[8m_tbs]],
	name_id			number
				constraint rhn_pkgnevra_nid_nn not null
				constraint rhn_pkgnevra_nid_fk
					references rhnPackageName(id),
	evr_id			number
				constraint rhn_pkgnevra_eid_nn not null
				constraint rhn_pkgnevra_eid_fk
					references rhnPackageEVR(id),
	package_arch_id		number
				constraint rhn_pkgnevra_paid_fk
					references rhnPackageArch(id)
)
	enable row movement
  ;
create index rhn_pkgnevra_nid_evrid_id_idx
	on rhnPackageNEVRA( name_id, evr_id, id )
	tablespace [[32m_tbs]]
  ;
alter table rhnPackageNEVRA
add constraint rhn_pkgnevra_nid_eid_paid_uq
unique ( name_id, evr_id, package_arch_id );

select 'rhnsat/procs/lookup_package_nevra.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_package_nevra.sql
create or replace function
lookup_package_nevra(
	name_id_in in varchar2,
	evr_id_in in varchar2,
	package_arch_id_in in varchar2,
	ignore_null_name in number := 0
) return number
deterministic
is
	pragma autonomous_transaction;
	nevra_id number;
BEGIN
	if ignore_null_name = 1 and name_id_in is null then
		return null;
	end if;
	select	id
	into	nevra_id
	from	rhnPackageNEVRA
	where	1=1
		and name_id = name_id_in
		and evr_id = evr_id_in
		and (package_arch_id = package_arch_id_in or
			(package_arch_id is null
			 and package_arch_id_in is null));
	return nevra_id;
exception
	when no_data_found then
		insert into rhnPackageNEVRA
			(id, name_id, evr_id, package_arch_id)
			values
			(	rhn_pkgnevra_id_seq.nextval, 
				name_id_in, evr_id_in, package_arch_id_in
			) returning id into nevra_id;
		commit;
		return nevra_id;
end;
/
show errors

select 'rhnsat/procs/lookup_source_name.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_source_name.sql
CREATE OR REPLACE FUNCTION
LOOKUP_SOURCE_NAME(name_in IN VARCHAR2)
RETURN NUMBER
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	source_id	NUMBER;
BEGIN
        select	id into source_id
        from	rhnSourceRPM 
        where	name = name_in;
        RETURN source_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            insert into rhnSourceRPM(id, name)
                    values (rhn_sourcerpm_id_seq.nextval, name_in)
                    returning id into source_id;
            COMMIT;
            RETURN source_id;
END;
/
SHOW ERRORS

select 'rhnsat/tables/rhnException_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnException_data.sql
insert into rhnException values (-20002, 'testing_error', 'An error used for testing and testing only');
insert into rhnException values (-20100, 'channel_no_parent_subscription', 'A server must be subscribed to the parent channel to subscribe to the child channel');
insert into rhnException values (-20101, 'channel_must_subscribe_to_parent', 'A server must be subscribed to all parents of all children');
insert into rhnException values (-20102, 'channel_server_one_base', 'A server can be subscribed to at most one base channel');
insert into rhnException values (-20200, 'usergroup_max_members', 'User group membership cannot exceed maximum membership');
insert into rhnException values (-20220, 'servergroup_max_members', 'Server group membership cannot exceed maximum membership');
insert into rhnException values (-20230, 'ugm_different_orgs', 'User and usergroup must be in same group to make a user a member');
insert into rhnException values (-20231, 'sgm_different_orgs', 'Server and servergroup must be in same group to make a server a member');
insert into rhnException values (-20232, 'no_org_admin_group', 'Organization has no org_admin usergroup');
insert into rhnException values (-20233, 'sg_delete_typed', 'Special server groups (non-null group_type) cannot be deleted');
insert into rhnException values (-20234, 'ug_delete_typed', 'Special user groups (non-null group_type) cannot be deleted');
insert into rhnException values (-20235, 'channel_family_no_subscriptions', 'Channel family subscription count cannot exceed maximum membership');
insert into rhnException values (-20236, 'channel_subscribe_no_family', 'Attempt to subscribe to a channel with no family');
insert into rhnException values (-20237, 'invalid_enterprise_flag','Enterprise flag must be Y or N');
insert into rhnException values (-20238, 'channel_unsubscribe_no_family','Attempt to unsubscribe from a channel with no family');
insert into rhnException values (-20239, 'arch_not_found','Architecture could not be found');
insert into rhnException values (-20240, 'channel_consent_no_license','No license agreement exists for that channel');
insert into rhnException values (-20241, 'channel_subscrib_no_consent','Channel requires consent to license for subscription');
insert into rhnException values (-20242, 'channel_arch_not_found','Channel architecture could not be found');
insert into rhnException values (-20243, 'package_arch_not_found','Package architecture could not be found');
insert into rhnException values (-20244, 'server_arch_not_found','Server architecture could not be found');
insert into rhnException values (-20245, 'cpu_arch_not_found','CPU architecture could not be found');
insert into rhnException values (-20246, 'channel_unsubscribe_child_exists','Unsubscribe failed because server is subscribed to child channels');
insert into rhnException values (-20247, 'null_email_address','A user must have either a pending or a validated email address');
insert into rhnException values (-20248, 'invalid_item_code','The specified item does not exist');
insert into rhnException values (-20249, 'invalid_server_group','The specified server group does not exist');
insert into rhnException values (-20250, 'invalid_channel_family','The specified channel family does not exist');
insert into rhnException values (-20251, 'invalid_state','The specified state does not exist');
insert into rhnException values (-20253, 'invalid_state_transition','The specified transition is not allowed');
insert into rhnException values (-20254, 'ep_error','Entitlement Proxy error');
insert into rhnException values (-20255, 'cannot_delete_user','The specified user may not be deleted.');
insert into rhnException values (-20256, 'no_channel_product','No products were found to entitle this channel');
insert into rhnException values (-20257, 'no_server_multiple_swmgr_entitlements','Server is already entitled');
insert into rhnException values (-20258, 'erratafile_type_not_found','No such errata file type exists');
insert into rhnException values (-20259, 'invalid_quantity','Number fields may not be null');
insert into rhnException values (-20260, 'invalid_operation','The operation specified is not supported');
insert into rhnException values (-20261, 'sgm_insert_diff_orgs','Server does not belong to same org as server_group');
insert into rhnException values (-20262, 'invalid_transaction_operation', 'Invalid transaction operation');
insert into rhnException values (-20263, 'no_subscribe_permissions','Insufficient permissions for subscription');
insert into rhnException values (-20264, 'invalid_user_group','The specified user group does not exist');
insert into rhnException values (-20265, 'invalid_snapshot_invalid_reason','The specified reason for snapshot invalidation does not exist');
insert into rhnException values (-20266, 'action_is_child','The specified action is in a chain, but is not the first action in the chain');
insert into rhnException values (-20267, 'not_enough_quota','Insufficient available quota for the specified action');
insert into rhnException values (-20268, 'server_not_in_group','The specified server is not a member of the specified group');
insert into rhnException values (-20269, 'servergroup_use_upgrade', 'The specified server group is full, upgrades are available');
insert into rhnException values (-20270, 'invalid_upgrade', 'The specified server cannot be upgraded from management to provisioning');
insert into rhnException values (-20271, 'arch_type_not_found','Architecture type could not be found');
insert into rhnException values (-20272, 'mismatching_entitlement', 'The server architecture does not match the specified entitlement level');
insert into rhnException values (-20273, 'usgp_different_orgs', 'User and servergroup must be in same org in order to add this permission');
insert into rhnException values (-20274, 'usgp_already_allowed', 'The specified user already has permissions for this server group');
insert into rhnException values (-20275, 'usgp_not_allowed', 'The specified user does not have permissions for this server group');
insert into rhnException values (-20276, 'product_not_registered', 'The specified item is not registered to this customer');
insert into rhnException values (-20277, 'product_no_service', 'This product grants no services');
insert into rhnException values (-20278, 'webreg_duplicate', 'Registration number is already registered');
insert into rhnException values (-20279, 'webreg_not_active', 'Registration number is not active');
insert into rhnException values (-20280, 'webreg_sync_error', 'Error synchronizing, xxrh_oai_wrapper.sync_registration_uber');
insert into rhnException values (-20281, 'webreg_not_found', 'Registration number does not exist');
insert into rhnException values (-20282, 'webreg_unkown_error', 'Unknown error during web registration');
insert into rhnException values (-20283, 'invalid_feature', 'The specified feature does not exist');
insert into rhnException values (-20284, 'invalid_base_entitlement', 'The base entitlement is not valid for adding on other entitlements'); 
insert into rhnException values (-20285, 'invalid_addon_entitlement', 'The addon entitlement is not valid for adding onto other entitlements'); 
insert into rhnException values (-20286, 'no_available_server_group', 'The server can be entitled to that entitlement, but no valid server group was found');
insert into rhnException values (-20287, 'invalid_entitlement', 'The server can not be entitled to the specified level'); 
insert into rhnException values (-20288, 'invalid_server_group_member', 'The specified entitlement can not be removed from the specified server because the server does not have that entitlement level');
insert into rhnException
values (-20289,
        'invalid_virt_sub_level',
        'The specified virtualization subscription level does not exist.');
insert into rhnException
values (-20290,
        'not_enough_entitlements_in_base_org',
        'You do not have enough entitlements in the base org.');
insert into rhnException
values (-20291,
        'cannot_delete_base_org',
        'You cannot delete the base org.');
insert into rhnException values (-20292, 'package_provider_not_found', 'The specified package provider could not be found.');
insert into rhnException values (-20293, 'package_key_type_not_found', 'The specified package key type could not be found.');
commit;

select 'rhnsat/procs/lookup_arch_type.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_arch_type.sql
create or replace function
lookup_arch_type(label_in in varchar2)
return number
deterministic
is
	arch_type_id number;
begin
	select id into arch_type_id from rhnArchType where label = label_in;
	return arch_type_id;
exception
	when no_data_found then
		rhn_exception.raise_exception('arch_type_not_found');
end;
/
show errors

select 'rhnsat/tables/rhnChannelArch_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelArch_data.sql
insert into rhnChannelArch (id, label, name, arch_type_id) values
(rhn_channel_arch_id_seq.nextval, 'channel-ia32', 'IA-32', lookup_arch_type('rpm'));
insert into rhnChannelArch (id, label, name, arch_type_id) values
(rhn_channel_arch_id_seq.nextval, 'channel-ia64', 'IA-64', lookup_arch_type('rpm'));
insert into rhnChannelArch (id, label, name, arch_type_id) values
(rhn_channel_arch_id_seq.nextval, 'channel-sparc', 'Sparc', lookup_arch_type('rpm'));
insert into rhnChannelArch (id, label, name, arch_type_id) values
(rhn_channel_arch_id_seq.nextval, 'channel-alpha', 'Alpha', lookup_arch_type('rpm'));
insert into rhnChannelArch (id, label, name, arch_type_id) values
(rhn_channel_arch_id_seq.nextval, 'channel-s390', 's390', lookup_arch_type('rpm'));
insert into rhnChannelArch (id, label, name, arch_type_id) values
(rhn_channel_arch_id_seq.nextval, 'channel-s390x', 's390x', lookup_arch_type('rpm'));
insert into rhnChannelArch (id, label, name, arch_type_id) values
(rhn_channel_arch_id_seq.nextval, 'channel-iSeries', 'iSeries', lookup_arch_type('rpm'));
insert into rhnChannelArch (id, label, name, arch_type_id) values
(rhn_channel_arch_id_seq.nextval, 'channel-pSeries', 'pSeries', lookup_arch_type('rpm'));
insert into rhnChannelArch (id, label, name, arch_type_id) values
(rhn_channel_arch_id_seq.nextval, 'channel-x86_64', 'x86_64', lookup_arch_type('rpm'));
insert into rhnChannelArch (id, label, name, arch_type_id) values
(rhn_channel_arch_id_seq.nextval, 'channel-ppc', 'PPC', lookup_arch_type('rpm'));
insert into rhnChannelArch (id, label, name, arch_type_id) values
(rhn_channel_arch_id_seq.nextval, 'channel-sparc-sun-solaris', 'Sparc Solaris', lookup_arch_type('sysv-solaris'));
insert into rhnChannelArch (id, label, name, arch_type_id) values
(rhn_channel_arch_id_seq.nextval, 'channel-i386-sun-solaris', 'i386 Solaris', lookup_arch_type('sysv-solaris'));
commit;

select 'rhnsat/procs/lookup_channel_arch.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_channel_arch.sql
CREATE OR REPLACE FUNCTION
LOOKUP_CHANNEL_ARCH(label_in IN VARCHAR2)
RETURN NUMBER
IS
	channel_arch_id		NUMBER;
BEGIN
	SELECT id
          INTO channel_arch_id
          FROM rhnChannelArch
         WHERE label = label_in;
	RETURN channel_arch_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            rhn_exception.raise_exception('channel_arch_not_found');
END;
/
SHOW ERRORS

select 'rhnsat/tables/rhnServerArch_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerArch_data.sql
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'i386-redhat-linux', 'i386', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'i486-redhat-linux', 'i486', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'i586-redhat-linux', 'i586', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'i686-redhat-linux', 'i686', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'athlon-redhat-linux', 'athlon', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'alpha-redhat-linux', 'alpha', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'alphaev6-redhat-linux', 'alphaev6', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'ia64-redhat-linux', 'ia64', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'sparc-redhat-linux', 'sparc', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'sparcv9-redhat-linux', 'sparcv9', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'sparc64-redhat-linux', 'sparc64', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 's390-redhat-linux', 's390', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 's390x-redhat-linux', 's390x', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'ppc-redhat-linux', 'ppc', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'ppc64-redhat-linux', 'ppc64', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'pSeries-redhat-linux', 'pSeries', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'iSeries-redhat-linux', 'iSeries', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'x86_64-redhat-linux', 'x86_64', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'ppc64iseries-redhat-linux', 'ppc64iseries', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'ppc64pseries-redhat-linux', 'ppc64pseries', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'sparc-sun4m-solaris', 'Sparc Solaris', lookup_arch_type('sysv-solaris'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'sparc-sun4u-solaris', 'Sparc Solaris', lookup_arch_type('sysv-solaris'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'sparc-sun4v-solaris', 'Sparc Solaris', lookup_arch_type('sysv-solaris'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'ia32e-redhat-linux', 'EM64T', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'amd64-redhat-linux', 'AMD64', lookup_arch_type('rpm'));
insert into rhnServerArch (id, label, name, arch_type_id) values
(rhn_server_arch_id_seq.nextval, 'i386-i86pc-solaris', 'i386 Solaris', lookup_arch_type('sysv-solaris'));
commit;

select 'rhnsat/procs/lookup_server_arch.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_server_arch.sql
CREATE OR REPLACE FUNCTION
LOOKUP_SERVER_ARCH(label_in IN VARCHAR2)
RETURN NUMBER
IS
	server_arch_id		NUMBER;
BEGIN
	SELECT id
          INTO server_arch_id
          FROM rhnServerArch
         WHERE label = label_in;
	RETURN server_arch_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            rhn_exception.raise_exception('server_arch_not_found');
END;
/
SHOW ERRORS

select 'rhnsat/tables/rhnPackageArch_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageArch_data.sql
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'noarch', 'noarch', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'i386', 'i386', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'i486', 'i486', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'i586', 'i586', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'i686', 'i686', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'alpha', 'alpha', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'alphaev6', 'alphaev6', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'ia64', 'ia64', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'sparc', 'sparc', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'sparcv9', 'sparcv9', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'sparc64', 'sparc64', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'src', 'src', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 's390', 's390', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'athlon', 'athlon', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 's390x', 's390x', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'ppc', 'ppc', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'ppc64', 'ppc64', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'pSeries', 'pSeries', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'iSeries', 'iSeries', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'x86_64', 'x86_64', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'ppc64iseries', 'ppc64iseries', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'ppc64pseries', 'ppc64pseries', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'sparc-solaris', 'Sparc Solaris', lookup_arch_type('sysv-solaris'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'sparc.sun4u-solaris', 'Sparc Solaris sun4u', lookup_arch_type('sysv-solaris'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'sparc.sun4v-solaris', 'Sparc Solaris sun4v', lookup_arch_type('sysv-solaris'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'tar', 'TAR archive', lookup_arch_type('tar'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'ia32e', 'EM64T', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'amd64', 'AMD64', lookup_arch_type('rpm'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'i386-solaris', 'i386-solaris', lookup_arch_type('sysv-solaris'));
insert into rhnPackageArch (id, label, name, arch_type_id) values 
( rhn_package_arch_id_seq.nextval, 'nosrc', 'nosrc', lookup_arch_type('rpm') );
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'sparc-solaris-patch', 'Sparc Solaris patch', lookup_arch_type('solaris-patch'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'i386-solaris-patch', 'i386 Solaris patch', lookup_arch_type('solaris-patch'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'sparc-solaris-patch-cluster', 
'Sparc Solaris patch cluster', lookup_arch_type('solaris-patch-cluster'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'i386-solaris-patch-cluster', 
'i386 Solaris patch cluster', lookup_arch_type('solaris-patch-cluster'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'noarch-solaris', 'noarch-solaris', lookup_arch_type('sysv-solaris'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'noarch-solaris-patch', 'noarch-solaris-patch', lookup_arch_type('sysv-solaris'));
insert into rhnPackageArch (id, label, name, arch_type_id) values
(rhn_package_arch_id_seq.nextval, 'noarch-solaris-patch-cluster', 'noarch-solaris-patch-cluster', lookup_arch_type('sysv-solaris'));
commit;

select 'rhnsat/procs/lookup_package_arch.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_package_arch.sql
CREATE OR REPLACE FUNCTION
LOOKUP_PACKAGE_ARCH(label_in IN VARCHAR2)
RETURN NUMBER
IS
	package_arch_id		NUMBER;
BEGIN
   if label_in is null then
      return null;
   end if;
	SELECT id
          INTO package_arch_id
          FROM rhnPackageArch
         WHERE label = label_in;
	RETURN package_arch_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            rhn_exception.raise_exception('package_arch_not_found');
END;
/
SHOW ERRORS

select 'rhnsat/procs/lookup_package_capability.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_package_capability.sql
CREATE OR REPLACE FUNCTION
LOOKUP_PACKAGE_CAPABILITY(name_in IN VARCHAR2, 
    version_in IN VARCHAR2 DEFAULT NULL)
RETURN NUMBER
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	name_id		NUMBER;
BEGIN
	IF version_in IS NULL THEN
		SELECT id
		  INTO name_id
		  FROM rhnPackageCapability
		 WHERE name = name_in
		   AND version IS NULL;
	ELSE
		SELECT id
		  INTO name_id
		  FROM rhnPackageCapability
		 WHERE name = name_in
		   AND version = version_in;
	END IF;
	RETURN name_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            INSERT INTO rhnPackageCapability (id, name, version) 
                VALUES (rhn_pkg_capability_id_seq.nextval, name_in, version_in)
                RETURNING id INTO name_id;
            COMMIT;
	RETURN name_id;
END;
/
SHOW ERRORS

select 'rhnsat/tables/rhnErrataFileType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataFileType.sql
create sequence rhn_erratafile_type_id_seq;
create table
rhnErrataFileType
(
	id		number
			constraint rhn_erratafile_type_id_nn not null,
	label		varchar2(128)
			constraint rhn_erratafile_type_label_nn not null
)
	enable row movement
  ;
create index rhn_erratafile_type_id_idx
	on rhnErrataFileType ( id )
	tablespace [[64k_tbs]]
  ;
alter table rhnErrataFileType add constraint rhn_erratafile_type_id_pk
	primary key ( id );
create index rhn_erratafile_type_label_idx
	on rhnErrataFileType ( label )
	tablespace [[64k_tbs]]
  ;
alter table rhnErrataFileType add constraint rhn_erratafile_type_label_uq
	unique ( label );

select 'rhnsat/tables/rhnErrataFileType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataFileType_data.sql
insert into rhnErrataFileType ( id, label )
	values ( rhn_erratafile_type_id_seq.nextval, 'RPM' );
insert into rhnErrataFileType ( id, label )
	values ( rhn_erratafile_type_id_seq.nextval, 'SRPM' );
insert into rhnErrataFileType ( id, label )
	values ( rhn_erratafile_type_id_seq.nextval, 'IMG' );

select 'rhnsat/procs/lookup_erratafile_type.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_erratafile_type.sql
create or replace function
lookup_erratafile_type (
	label_in in varchar2
) return number deterministic is
	pragma autonomous_transaction;
	erratafile_type_id number;
begin
	select	id
	into	erratafile_type_id
	from	rhnErrataFileType
	where	label = label_in;
	return erratafile_type_id;
exception
	when no_data_found then
		rhn_exception.raise_exception('erratafile_type_not_found');
end;
/
show errors

select 'rhnsat/tables/rhnSnapshotInvalidReason.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSnapshotInvalidReason.sql
create sequence rhn_ssinvalid_id_seq;
create table
rhnSnapshotInvalidReason
(
	id			number
				constraint rhn_ssinvalid_id_nn not null
				constraint rhn_ssinvalid_id_pk primary key
					using index tablespace [[64k_tbs]],
	label			varchar2(32)
				constraint rhn_ssinvalid_label_nn not null,
	name			varchar2(128)
				constraint rhn_ssinvalid_name_nn not null,
	created			date default(sysdate)
				constraint rhn_ssinvalid_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_ssinvalid_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_ssinvalid_label_uq
	on rhnSnapshotInvalidReason(label)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_ssinvalid_mod_trig
before insert or update on rhnSnapshotInvalidReason
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/procs/lookup_snapshot_invalid_reason.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_snapshot_invalid_reason.sql
CREATE OR REPLACE FUNCTION
lookup_snapshot_invalid_reason(label_in IN VARCHAR2)
RETURN NUMBER
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	snapshot_invalid_reason_id number;
BEGIN
	SELECT id
          INTO snapshot_invalid_reason_id
          FROM rhnSnapshotInvalidReason
         WHERE label = label_in;
	RETURN snapshot_invalid_reason_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            rhn_exception.raise_exception('invalid_snapshot_invalid_reason');
END;
/
SHOW ERRORS

select 'rhnsat/tables/rhnTagName.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTagName.sql
create table
rhnTagName
(
        id              number
        	    	constraint rhn_tn_id_nn not null
    	    	    	constraint rhn_tn_id_pk primary key,
        name            varchar2(128)
    	    	    	constraint rhn_tn_name_nn not null,
       	created		date default(sysdate)
			constraint rhn_tn_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_tn_modified_nn not null
)
	enable row movement
	;
create unique index rhn_tn_name_uq
    	on rhnTagName(name);
create sequence rhn_tagname_id_seq;
create or replace trigger
rhn_tn_mod_trig
before insert or update on rhnTagName
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/procs/lookup_tag_name.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_tag_name.sql
CREATE OR REPLACE FUNCTION
LOOKUP_TAG_NAME(name_in IN VARCHAR2)
RETURN NUMBER
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	name_id     NUMBER;
BEGIN
        select id into name_id
	  from rhnTagName
	 where name = name_in;
        RETURN name_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            insert into rhnTagName(id, name)
                    values (rhn_tagname_id_seq.nextval, name_in)
                    returning id into name_id;
            COMMIT;
            RETURN name_id;
END;
/
SHOW ERRORS

select 'rhnsat/procs/lookup_sg_type.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_sg_type.sql
create or replace function
lookup_sg_type(label_in in varchar2)
return number
deterministic
is
	server_group_type_id number;
begin
	select	id
	into	server_group_type_id
	from	rhnServerGroupType sgt
	where	label = label_in;
	return server_group_type_id;
exception
        when no_data_found then
            rhn_exception.raise_exception('invalid_server_group');
end;
/
show errors

select 'rhnsat/tables/rhnTag.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTag.sql
create table
rhnTag
(
	id              number
			constraint rhn_tag_id_nn not null
			constraint rhn_tag_id_pk primary key,
	name_id         number
	    	    	constraint rhn_tag_nid_nn not null
			constraint rhn_tag_nid_fk
				references rhnTagName(id),
        org_id          number
                        constraint rhn_tag_oid_nn not null
                        constraint rhn_tag_oid_fk
                                references web_customer(id)
				on delete cascade,
       	created		date default(sysdate)
			constraint rhn_tag_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_tag_modified_nn not null
)
	enable row movement
	;
create unique index rhn_tag_oid_nid_uq
    	on rhnTag(org_id, name_id);
create sequence rhn_tag_id_seq;
create or replace trigger
rhn_tag_mod_trig
before insert or update on rhnTag
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/procs/lookup_tag.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_tag.sql
CREATE OR REPLACE FUNCTION
LOOKUP_TAG(org_id_in IN NUMBER, name_in IN VARCHAR2)
RETURN NUMBER
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	tag_id     NUMBER;
BEGIN
        select id into tag_id
	  from rhnTag
	 where org_id = org_id_in
	   and name_id = lookup_tag_name(name_in);
        RETURN tag_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            insert into rhnTag(id, org_id, name_id)
                    values (rhn_tag_id_seq.nextval, org_id_in, lookup_tag_name(name_in))
                    returning id into tag_id;
            COMMIT;
            RETURN tag_id;
END;
/
SHOW ERRORS

select 'rhnsat/tables/rhnBlacklistObsoletes_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnBlacklistObsoletes_data.sql
insert into rhnBlacklistObsoletes
  (name_id, evr_id, package_arch_id, ignore_name_id)
values (
    LOOKUP_PACKAGE_NAME('gated'), LOOKUP_EVR(NULL, '3.6', '12'), 
    LOOKUP_PACKAGE_ARCH('i386'), LOOKUP_PACKAGE_NAME('zebra')
);
insert into rhnBlacklistObsoletes
  (name_id, evr_id, package_arch_id, ignore_name_id)
values (
    LOOKUP_PACKAGE_NAME('zebra'), LOOKUP_EVR(NULL, '0.91a', '6'), 
    LOOKUP_PACKAGE_ARCH('i386'), LOOKUP_PACKAGE_NAME('gated')
);
insert into rhnBlacklistObsoletes
  (name_id, evr_id, package_arch_id, ignore_name_id)
select
    LOOKUP_PACKAGE_NAME('gated'), LOOKUP_EVR(NULL, '3.6', '10'), 
    pa.id, LOOKUP_PACKAGE_NAME('zebra')
from rhnPackageArch pa
where pa.label in ('i386', 'alpha');
insert into rhnBlacklistObsoletes
  (name_id, evr_id, package_arch_id, ignore_name_id)
select
    LOOKUP_PACKAGE_NAME('zebra'), LOOKUP_EVR(NULL, '0.91a', '3'), 
    pa.id, LOOKUP_PACKAGE_NAME('gated')
from rhnPackageArch pa
where pa.label in ('i386', 'alpha');
commit;

select 'rhnsat/tables/rhnCVE.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnCVE.sql
CREATE TABLE
rhnCVE
(
        id              number
			constraint rhn_cve_id_nn not null
                        constraint rhn_cve_id_pk primary key
			using index tablespace [[2m_tbs]],
        name            varchar2(13) -- like:  CXX-XXXX-XXXX
			constraint rhn_cve_name_nn not null
)
	enable row movement
  ;
create unique index rhn_cve_name_uq
	on rhnCVE(name)
	tablespace [[2m_tbs]]
  ;
create sequence rhn_cve_id_seq;

select 'rhnsat/tables/rhnChannelComps.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelComps.sql
create table
rhnChannelComps
(
   id       number
        constraint rhn_channelcomps_id_nn not null
        constraint rhn_channelcomps_id_pk primary key,
   channel_id      number
        constraint rhn_channelcomps_cid_nn not null
        constraint rhn_channelcomps_cid_fk
            references rhnChannel(id)
            on delete cascade,
    relative_filename   varchar2(256)
        constraint rhn_channelcomps_rfn_nn not null,
    last_modified   date default(sysdate)
        constraint rhn_channelcomps_lastmod_nn not null,
    created     date default(sysdate)
        constraint rhn_channelcomps_created_nn not null,
    modified    date default(sysdate)
        constraint rhn_channelcomps_modified_nn not null
)
    enable row movement
  ;
create sequence rhn_channelcomps_id_seq start with 101;
create or replace trigger
rhn_channelcomps_mod_trig
before insert or update on rhnChannelComps
for each row
begin
    :new.modified := sysdate;
    if :new.last_modified = :old.last_modified
    then
        :new.last_modified := sysdate;
        end if;
end rhn_channelcomps_mod_trig;
/
show errors

select 'rhnsat/tables/rhnChannelCloned.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelCloned.sql
create table
rhnChannelCloned
(
	original_id		number
				constraint rhn_channelclone_fcid_nn not null
				constraint rhn_channelclone_fcid_fk
					references rhnChannel(id)
					on delete cascade,
	id		        number
				constraint rhn_channelclone_tcid_nn not null
				constraint rhn_channelclone_tcid_fk
					references rhnChannel(id)
					on delete cascade,
	created			date default(sysdate)
				constraint rhn_channelclone_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_channelclone_modified_nn not null
)
	enable row movement
  ;
create index rhn_channelclone_fcid_tcid_idx
	on rhnChannelCloned ( original_id, id )
	tablespace [[2m_tbs]]
  ;
alter table rhnChannelCloned add constraint rhn_channelclone_fcid_tcid_uq
	unique ( original_id, id );
alter table rhnChannelCloned add constraint rhn_channelclone_id_pk
        primary key ( id );
create index rhn_channelclone_tcid_fcid_idx
	on rhnChannelCloned ( id, original_id )
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_channelclone_mod_trig
before insert or update on rhnChannelCloned
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnChannelCloned_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelCloned_triggers.sql
create or replace trigger
rhn_channel_cloned_comps_trig
before insert on rhnChannelCloned
for each row
begin
	insert into rhnChannelComps
		( id, channel_id, relative_filename,
			last_modified, created, modified )
	select rhn_channelcomps_id_seq.nextval, :new.id, relative_filename,
			sysdate, sysdate, sysdate
	from rhnChannelComps
	where channel_id = :new.original_id
		and not exists (
			select 1
			from rhnChannelComps x
			where x.channel_id = :new.id
		);
end;
/
show errors

select 'rhnsat/tables/rhnFile.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnFile.sql
create table
rhnFile
(
	id		number
			constraint rhn_file_id_nn not null
			constraint rhn_file_id_pk primary key
				using index tablespace [[64k_tbs]],
	org_id		number
			constraint rhn_file_oid_fk
				references web_customer(id)
				on delete cascade,
	file_size	number
			constraint rhn_file_fs_nn not null,
	md5sum		varchar2(64)
			constraint rhn_file_md5sum_nn not null,
	path		varchar2(1000)
			constraint rhn_file_path_nn not null,
	created		date default(sysdate)
			constraint rhn_file_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_file_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_file_id_seq;
create unique index rhn_file_path_uq
	on rhnFile(path)
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnDownloadType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnDownloadType.sql
create table
rhnDownloadType
(
	id		number
			constraint rhn_download_type_id_nn not null
			constraint rhn_download_type_pk primary key,
	label		varchar2(48)
			constraint rhn_download_type_label_nn not null,
	name		varchar2(96)
			constraint rhn_download_type_name_nn not null
)
	enable row movement
;
create unique index rhn_download_type_label_uq
	on rhnDownloadType(label);
create unique index rhn_download_type_name_uq
	on rhnDownloadType(name);

select 'rhnsat/tables/rhnDownloads.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnDownloads.sql
create table
rhnDownloads
(
	id		number
			constraint rhn_dl_id_nn not null
			constraint rhn_dl_id_pk primary key,
	channel_family_id  number
			constraint rhn_dl_cfid_nn not null
			constraint rhn_dl_cfid_fk
				references rhnChannelFamily(id),
	file_id 	number
			constraint rhn_dl_fid_nn not null
			constraint rhn_dl_fid_fk
			     	references rhnFile(id),
        name            varchar2(128)
	    	    	constraint rhn_dl_name_nn not null,			
        category        varchar2(128)
	    	    	constraint rhn_dl_cat_nn not null,
	ordering        number
			constraint rhn_dl_ord_nn not null,
        download_type  	number
			constraint rhn_dl_dltype_fk
				references rhnDownloadType(id),
	created		date default(sysdate)
			constraint rhn_dl_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_dl_modified_nn not null,
	release_notes_url	varchar2(512)
)
	enable row movement
  ;
create sequence rhn_download_id_seq;
create or replace trigger
rhn_download_mod_trig
before insert or update on rhnDownloads
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnChannelDownloads.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelDownloads.sql
create table
rhnChannelDownloads
(
	channel_id	number
			constraint rhn_cd_cid_nn not null 
			constraint rhn_cd_cid_fk
				references rhnChannel(id) on delete cascade,
	downloads_id	number
			constraint rhn_cd_did_nn not null
			constraint rhn_cd_did_fk
				references rhnDownloads(id),
	created		date default (sysdate)
			constraint rhn_cd_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cd_modified_nn not null
)
	enable row movement
;
create unique index rhn_cd_ce_uq
	on rhnChannelDownloads(channel_id, downloads_id);
create index rhn_cd_did_cid_idx
	on rhnChannelDownloads(downloads_id, channel_id);

select 'rhnsat/tables/rhnChannelErrata.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelErrata.sql
create table
rhnChannelErrata
(
	channel_id	number
			constraint rhn_ce_cid_nn not null 
			constraint rhn_ce_cid_fk
				references rhnChannel(id)
				on delete cascade,
	errata_id	number
			constraint rhn_ce_eid_nn not null
			constraint rhn_ce_eid_fk
				references rhnErrata(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_ce_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_ce_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_channel_errata_mod_trig
before insert or update on rhnChannelErrata
for each row
begin
	:new.modified := sysdate;
end rhn_channel_errata_mod_trig;
/
show errors
create unique index rhn_ce_ce_uq
	on rhnChannelErrata(channel_id, errata_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_ce_eid_cid_idx
	on rhnChannelErrata(errata_id, channel_id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnChannelFamilyLicense.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelFamilyLicense.sql
CREATE TABLE
rhnChannelFamilyLicense
(
        channel_family_id   number
			    constraint rhn_cfl_cfid_nn not null
    	    	    	    constraint rhn_cfl_cfid_fk
                            	references rhnChannelFamily(id)
				on delete cascade,
    	license_path        varchar2(1000)
	    	       	    constraint rhn_cfl_license_nn not null,
	created		date default (sysdate)
			constraint rhn_cfl_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cfl_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_cf_license_cfid_uq
	on rhnChannelFamilyLicense(channel_family_id)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_cf_license_mod_trig
before insert or update on rhnChannelFamilyLicense
for each row
begin
        :new.modified := sysdate;
end;
/
SHOW ERRORS;

select 'rhnsat/tables/rhnChannelFamilyLicenseConsent.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelFamilyLicenseConsent.sql
CREATE TABLE
rhnChannelFamilyLicenseConsent
(
        channel_family_id   number
			    constraint rhn_cfl_consent_cfid_nn not null
    	    	    	    constraint rhn_cfl_consent_cfid_fk
                            	references rhnChannelFamily(id) on delete cascade,
    	user_id             number
	    	       	    constraint rhn_cfl_consent_uid_nn not null
			    constraint rhn_cfl_consent_uid_fk
			    	references web_contact(id) on delete cascade,
	server_id           number
			    constraint rhn_cfl_consent_sid_nn not null
			    constraint rhn_cfl_consent_sid_fk
			    	references rhnServer(id),
       	created		date default (sysdate)
			constraint rhn_cfl_consent_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cfl_consent_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_cfl_consent_cf_s_uq
	on rhnChannelFamilyLicenseConsent(channel_family_id, server_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_cfl_consent_uid_idx
	on rhnChannelFamilyLicenseConsent ( user_id )
	tablespace [[64k_tbs]]
	nologging;
create index rhn_cfl_consent_sid_idx
	on rhnChannelFamilyLicenseConsent( server_id )
	tablespace [[8m_tbs]]
	nologging;
create or replace trigger
rhn_cfl_consent_mod_trig
before insert or update on rhnChannelFamilyLicenseConsent
for each row
begin
        :new.modified := sysdate;
end;
/
SHOW ERRORS;

select 'rhnsat/tables/rhnChannelFamilyMembers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelFamilyMembers.sql
create table
rhnChannelFamilyMembers
(
        channel_id      number
                        constraint rhn_cf_members_c_nn not null
                        constraint rhn_cf_members_c_fk
                                references rhnChannel(id) on delete cascade,
        channel_family_id number
                        constraint rhn_cf_family_nn not null
                        constraint rhn_cf_family_fk
                                references rhnChannelFamily(id),
        created         date default(sysdate)
                        constraint rhn_cf_member_cre_nn not null,
        modified        date default(sysdate)
                        constraint rhn_cf_member_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_cf_member_uq
	on rhnChannelFamilyMembers(channel_id, channel_family_id)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_cf_c_uq
	on rhnChannelFamilyMembers(channel_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_cf_member_cf_c_idx
	on rhnChannelFamilyMembers(channel_family_id, channel_id)
	tablespace [[64k_tbs]]
	nologging;
create or replace trigger
rhn_cf_member_mod_trig
before insert or update on rhnChannelFamilyMembers
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnVirtSubLevel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtSubLevel.sql
create table rhnVirtSubLevel (
    id      number
            constraint rhn_vsl_id_pk primary key,
    label   varchar2(32)
            constraint rhn_vsl_label_nn not null,
    name    varchar2(128)
            constraint rhn_vsl_name_nn not null,
    created date default sysdate
            constraint rhn_vsl_created_nn not null,
    modified date default sysdate
             constraint rhn_vsl_modified_nn not null
)
    enable row movement
  ;
create sequence rhn_virt_sl_seq;    
create index rhn_vsl_label_id_name_idx
    on rhnVirtSubLevel(label, id, name)
    tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnChannelFamilyVirtSubLevel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelFamilyVirtSubLevel.sql
create table rhnChannelFamilyVirtSubLevel (
    channel_family_id number
                      constraint rhn_cfvsl_cfid_nn not null
                      constraint rhn_cfvsl_cfid_fk 
                        references rhnChannelFamily(id),
    virt_sub_level_id number
                      constraint rhn_cfvsl_vslid_nn not null
                      constraint rhn_cfvsl_vslid_fk
                        references rhnVirtSubLevel(id),
    created           date 
                      default sysdate
                      constraint rhn_cfvsl_created_nn not null,
    modified          date
                      default sysdate
                      constraint rhn_cfvsl_modified_nn not null
)
    enable row movement
  ;
create index rhn_cfvsl_cfid_vslid_idx
    on rhnChannelFamilyVirtSubLevel(channel_family_id, virt_sub_level_id)
    tablespace [[64k_tbs]]
  ;
create index rhn_cfvsl_vslid_cfid_idx
    on rhnChannelFamilyVirtSubLevel(virt_sub_level_id, channel_family_id)
    tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnChannelNewestPackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelNewestPackage.sql
create table
rhnChannelNewestPackage
(
	channel_id		number
				constraint rhn_cnp_cid_nn not null
				constraint rhn_cnp_cid_fk
					references rhnChannel(id)
					on delete cascade,
	name_id			number
				constraint rhn_cnp_nid_nn not null
				constraint rhn_cnp_nid_fk
					references rhnPackageName(id),
	evr_id			number
				constraint rhn_cnp_eid_nn not null
				constraint rhn_cnp_eid_fk
					references rhnPackageEVR(id),
	package_arch_id		number
				constraint rhn_cnp_paid_nn not null
				constraint rhn_cnp_paid_fk
					references rhnPackageArch(id),
	package_id		number
				constraint rhn_cnp_pid_nn not null
				constraint rhn_cnp_pid_fk
					references rhnPackage(id)
					on delete cascade
)
	enable row movement
  ;
create index rhn_cnp_cnep_idx
	on rhnChannelNewestPackage(channel_id, name_id, 
		package_arch_id, evr_id, package_id)
	tablespace [[8m_tbs]]
  ;
alter table rhnChannelNewestPackage add constraint rhn_cnp_cid_nid_uq
	unique ( channel_id, name_id, package_arch_id );
create index rhn_cnp_necp_idx
	on rhnChannelNewestPackage(name_id, evr_id, channel_id, package_id)
	tablespace [[8m_tbs]]
  ;
create index rhn_cnp_pid_idx
	on rhnChannelNewestPackage( package_id )
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnChannelNewestPackageAudit.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelNewestPackageAudit.sql
create table
rhnChannelNewestPackageAudit
(
        refresh_time            date default sysdate
                                constraint rhn_cnp_at_rt_nn not null,
	channel_id		number
				constraint rhn_cnp_at_cid_nn not null
				constraint rhn_cnp_at_cid_fk
					references rhnChannel(id)
                                        on delete cascade,
        caller                  varchar2(256)
                                constraint rhn_cnp_at_caller_nn not null
)
	enable row movement
  ;
create index rhn_cnp_a_t_all_idx
	on rhnChannelNewestPackageAudit(channel_id, refresh_time, caller)
	tablespace [[8m_tbs]]
  ;

select 'rhnsat/tables/rhnChannelPackageArchCompat.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelPackageArchCompat.sql
create table
rhnChannelPackageArchCompat
(
        channel_arch_id	number
                        constraint rhn_cp_ac_caid_nn not null
                        constraint rhn_cp_ac_caid_fk 
				references rhnChannelArch(id),
	package_arch_id	number
			constraint rhn_cp_ac_paid_nn not null
			constraint rhn_cp_ac_paid_fk
				references rhnPackageArch(id),
	created		date default(sysdate)
			constraint rhn_cp_ac_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_cp_ac_modified_nn not null
)
	enable row movement
  ;
create index rhn_cp_ac_caid_paid
	on rhnChannelPackageArchCompat(
		channel_arch_id, package_arch_id)
	tablespace [[64k_tbs]]
  ;
alter table rhnChannelPackageArchCompat add constraint rhn_cp_ac_caid_paid_uq
	unique ( channel_arch_id, package_arch_id );
create index rhn_cp_ac_paid_caid
	on rhnChannelPackageArchCompat(
	 	package_arch_id, channel_arch_id)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_cp_ac_mod_trig
before insert or update on rhnChannelPackageArchCompat
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnChannelPackageArchCompat_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelPackageArchCompat_data.sql
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('i386'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('i486'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('i586'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('i686'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('athlon'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('i386'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('i486'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('i586'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('i686'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('ia64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc'), LOOKUP_PACKAGE_ARCH('sparc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc'), LOOKUP_PACKAGE_ARCH('sparcv9'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc'), LOOKUP_PACKAGE_ARCH('sparc64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-alpha'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-alpha'), LOOKUP_PACKAGE_ARCH('alpha'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-alpha'), LOOKUP_PACKAGE_ARCH('alphaev6'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-alpha'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390'), LOOKUP_PACKAGE_ARCH('s390'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390x'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390x'), LOOKUP_PACKAGE_ARCH('s390'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390x'), LOOKUP_PACKAGE_ARCH('s390x'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390x'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-iSeries'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-iSeries'), LOOKUP_PACKAGE_ARCH('s390x'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-iSeries'), LOOKUP_PACKAGE_ARCH('ppc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-iSeries'), LOOKUP_PACKAGE_ARCH('ppc64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-iSeries'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-pSeries'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-pSeries'), LOOKUP_PACKAGE_ARCH('ppc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-pSeries'), LOOKUP_PACKAGE_ARCH('ppc64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-pSeries'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('i386'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('i486'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('i586'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('i686'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('athlon'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('ia32e'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('amd64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('x86_64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('noarch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('ppc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('ppc64'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('ppc64iseries'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('ppc64pseries'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('src'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc-sun-solaris'), LOOKUP_PACKAGE_ARCH('sparc-solaris'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc-sun-solaris'), LOOKUP_PACKAGE_ARCH('sparc.sun4u-solaris'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc-sun-solaris'), LOOKUP_PACKAGE_ARCH('sparc.sun4v-solaris'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc-sun-solaris'), LOOKUP_PACKAGE_ARCH('sparc-solaris-patch-cluster'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc-sun-solaris'), LOOKUP_PACKAGE_ARCH('sparc-solaris-patch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia32'), LOOKUP_PACKAGE_ARCH('nosrc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ia64'), LOOKUP_PACKAGE_ARCH('nosrc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc'), LOOKUP_PACKAGE_ARCH('nosrc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-alpha'), LOOKUP_PACKAGE_ARCH('nosrc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390'), LOOKUP_PACKAGE_ARCH('nosrc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-s390x'), LOOKUP_PACKAGE_ARCH('nosrc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-iSeries'), LOOKUP_PACKAGE_ARCH('nosrc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-pSeries'), LOOKUP_PACKAGE_ARCH('nosrc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-x86_64'), LOOKUP_PACKAGE_ARCH('nosrc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-ppc'), LOOKUP_PACKAGE_ARCH('nosrc'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-i386-sun-solaris'), LOOKUP_PACKAGE_ARCH('i386-solaris'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-i386-sun-solaris'), LOOKUP_PACKAGE_ARCH('i386-solaris-patch-cluster'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-i386-sun-solaris'), LOOKUP_PACKAGE_ARCH('i386-solaris-patch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-i386-sun-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-i386-sun-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris-patch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-i386-sun-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris-patch-cluster'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc-sun-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc-sun-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris-patch'));
insert into rhnChannelPackageArchCompat (channel_arch_id, package_arch_id)
values (LOOKUP_CHANNEL_ARCH('channel-sparc-sun-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris-patch-cluster'));
commit;

select 'rhnsat/tables/rhnSnapshot.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSnapshot.sql
create sequence rhn_snapshot_id_seq;
create table
rhnSnapshot
(
	id			number
				constraint rhn_snapshot_id_nn not null
				constraint rhn_snapshot_id_pk primary key
					using index tablespace [[8m_tbs]],
	org_id			number
				constraint rhn_snapshot_oid_nn not null
				constraint rhn_snapshot_oid_fk
					references web_customer(id),
	invalid			number
				constraint rhn_snapshot_invalid_fk
					references rhnSnapshotInvalidReason(id),
	reason			varchar2(4000)
				constraint rhn_snapshot_reason_nn not null,
	server_id		number
				constraint rhn_snapshot_sid_nn not null
				constraint rhn_snapshot_sid_fk
					references rhnServer(id),
	created			date default(sysdate)
				constraint rhn_snapshot_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_snapshot_modified_nn not null
)
	enable row movement
  ;
create index rhn_snapshot_sid_idx
	on rhnSnapshot( server_id )
	tablespace [[2m_tbs]]
	nologging;
create index rhn_snapshot_oid_idx
	on rhnSnapshot( org_id )
	tablespace [[2m_tbs]]
	nologging;

select 'rhnsat/tables/rhnSnapshotChannel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSnapshotChannel.sql
create table
rhnSnapshotChannel
(
	snapshot_id		number
				constraint rhn_snapchan_sid_nn not null
				constraint rhn_snapchan_sid_fk
					references rhnSnapshot(id)
					on delete cascade,
	channel_id		number
				constraint rhn_snapchan_cid_nn not null
				constraint rhn_snapchan_cid_fk
					references rhnChannel(id)
)
	enable row movement
  ;
create unique index rhn_snapchan_sid_cid_uq
	on rhnSnapshotChannel( snapshot_id, channel_id )
	tablespace [[8m_tbs]]
  ;
create index rhn_snapshot_cid_idx
	on rhnSnapshotChannel( channel_id )
	tablespace [[4m_tbs]]
	nologging;
create or replace trigger
rhn_snapchan_mod_trig
before insert or update on rhnSnapshotChannel
for each row
begin
	update rhnSnapshot set modified = sysdate where id = :new.snapshot_id;
end;
/
show errors

select 'rhnsat/tables/rhnChannelPackage_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelPackage_triggers.sql
create or replace trigger
rhn_channel_package_mod_trig
before insert or update on rhnChannelPackage
for each row
begin
	:new.modified := sysdate;
end rhn_channel_package_mod_trig;
/
show errors

select 'rhnsat/tables/rhnChannelParent.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelParent.sql
create table
rhnChannelParent
(
        channel 	number 
			constraint rhn_cp_ch_nn not null
   			constraint rhn_cp_ch_fk
				references rhnChannel(id) on delete cascade,
	parent_channel 	number
			constraint rhn_cp_parent_ch_nn not null
   			constraint rhn_cp_parent_ch_fk
                        	references rhnChannel(id),
        created         date default (sysdate)
                        constraint rhn_chp_created_nn not null,
        modified        date default (sysdate)
                        constraint rhn_chp_modified_nn not null
)
	enable row movement
;
create unique index rhn_cp_c_uq
	on rhnChannelParent(channel, parent_channel);

select 'rhnsat/tables/rhnChannelPermissionRole.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelPermissionRole.sql
create sequence rhn_cperm_role_id_seq;
create table
rhnChannelPermissionRole
(
	id		number
			constraint rhn_cperm_role_id_nn not null,
	label		varchar2(32)
			constraint rhn_cperm_role_label_nn not null,
	description	varchar2(128)
			constraint rhn_cperm_role_desc_nn not null,
	created		date default(sysdate)
			constraint rhn_cperm_role_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_cperm_role_modified_nn not null
)
	enable row movement
  ;
create index rhn_cperm_role_id_pk
	on rhnChannelPermissionRole ( id )
	tablespace [[64k_tbs]]
  ;
alter table rhnChannelPermissionRole add constraint
	rhn_cperm_role_id_pk primary key ( id );
create index rhn_cperm_role_label_id_idx
	on rhnChannelPermissionRole ( label, id )
	tablespace [[64k_tbs]]
  ;
alter table rhnChannelPermissionRole add constraint
	rhn_cperm_role_label_uq unique ( label );
create or replace trigger
rhn_cperm_role_mod_trig
before insert or update on rhnChannelPermissionRole
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnChannelPermission.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelPermission.sql
create table
rhnChannelPermission
(
	channel_id	number
			constraint rhn_cperm_cid_nn not null
			constraint rhn_cperm_cidffk
				references rhnChannel(id)
				on delete cascade,
	user_id		number
			constraint rhn_cperm_uid_nn not null
			constraint rhn_cperm_uid_fk
				references web_contact(id)
				on delete cascade,
	role_id		number
			constraint rhn_cperm_rid_nn not null
			constraint rhn_cperm_rid_fk
				references rhnChannelPermissionRole(id),
	created		date default(sysdate)
			constraint rhn_cperm_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_cperm_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_cperm_cid_uid_rid_idx
	on rhnChannelPermission(channel_id, user_id, role_id)
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_cperm_mod_trig
before insert or update on rhnChannelPermission
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnChannelPermissionRole_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelPermissionRole_data.sql
insert into rhnChannelPermissionRole (id, label, description)
	values (rhn_cperm_role_id_seq.nextval,
		'subscribe',
		'Permission to subscribe to channel');
insert into rhnChannelPermissionRole (id, label, description)
	values (rhn_cperm_role_id_seq.nextval,
		'manage',
		'Permission to manage channel');

select 'rhnsat/tables/rhnChannelTrust.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannelTrust.sql
create table
rhnChannelTrust
(
	channel_id	number
			constraint rhn_channel_trust_cid_nn not null
			constraint rhn_channel_trust_cid_fk
				references rhnChannel(id)
                                on delete cascade,
	org_trust_id	number
			constraint rhn_channel_trust_otid_nn not null
			constraint rhn_channel_trust_otid_fk
				references web_customer(id)
                                on delete cascade,
        created         date default (sysdate)
                        constraint rhn_channel_trust_created_nn not null,
        modified        date default (sysdate)
                        constraint rhn_channel_trust_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_channel_trust_cid_uq
	on rhnChannelTrust(channel_id,org_trust_id)
	tablespace [[2m_tbs]]
  ;
create index rhn_channel_trust_org_trust
	on rhnChannelTrust(org_trust_id)
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnChannel_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnChannel_triggers.sql
create or replace trigger
rhn_channel_mod_trig
before insert or update on rhnChannel
for each row
begin
	:new.last_modified := sysdate;
	if updating then
		if (:old.id != :new.id) or
		  (:old.parent_channel != :new.parent_channel) or
		  (:old.org_id != :new.org_id) or
		  (:old.channel_arch_id != :new.channel_arch_id) or
		  (:old.label != :new.label) or
		  (:old.basedir != :new.basedir) or
		  (:old.name != :new.name) or
		  (:old.summary != :new.summary) or
		  (:old.description != :new.description) then
			:new.modified := sysdate;
		end if;
	end if;
end;
/
show errors
create or replace trigger
rhn_channel_del_trig
before delete on rhnChannel
for each row
declare
	cursor snapshots is
		select	snapshot_id id
		from	rhnSnapshotChannel
		where	channel_id = :old.id;
begin
	for snapshot in snapshots loop
		update rhnSnapshot
			set invalid = lookup_snapshot_invalid_reason('channel_removed')
			where id = snapshot.id;
		delete from rhnSnapshotChannel
			where snapshot_id = snapshot.id
				and channel_id = :old.id;
	end loop;
end;
/
create or replace trigger rhn_channel_access_trig
after update on rhnChannel
for each row
begin
   if :old.channel_access = 'protected' and
      :new.channel_access != 'protected'
   then
      delete from rhnChannelTrust where channel_id = :old.id;
   end if;
end;
/
show errors

select 'rhnsat/tables/rhnClientCapabilityName.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnClientCapabilityName.sql
create table
rhnClientCapabilityName
(
	id		number
			constraint rhn_clientcapnam_id_nn not null
			constraint rhn_clientcapnam_id_pk primary key 
				using index tablespace [[8m_tbs]],
	name		varchar2(32)
			constraint rhn_clientcapnam_name_nn not null
			constraint rhn_clientcapnam_name_unq unique
) 
	enable row movement
  ;
create sequence rhn_client_capname_id_seq;

select 'rhnsat/tables/rhnClientCapability.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnClientCapability.sql
create table
rhnClientCapability
(
	server_id	number
			constraint rhn_clientcap_sid_nn not null
			constraint rhn_clientcap_sid_fk
				references rhnServer(id),
	capability_name_id	number
			constraint rhn_clientcap_cap_nid_nn not null
			constraint rhn_clientcap_cap_nid_fk
				references rhnClientCapabilityName(id),
	version		varchar2(32)
			constraint rhn_clientcap_ver_nn not null,
	created		date default(sysdate)
			constraint rhn_clientcap_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_clientcap_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_clientcap_sid_cap_uq
	on rhnClientCapability(server_id, capability_name_id)
	tablespace [[32m_tbs]]
  ;
create or replace trigger
rhn_clientcap_mod_trig
before insert or update on rhnClientCapability
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnConfigChannelType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigChannelType_data.sql
insert into rhnConfigChannelType(id, label, name, priority) values (
	rhn_confchantype_id_seq.nextval, 'normal',
	'A general purpose configuration channel', 1);
insert into rhnConfigChannelType(id, label, name, priority) values (
	rhn_confchantype_id_seq.nextval, 'local_override',
	'Files on disk win', 0);
insert into rhnConfigChannelType(id, label, name, priority) values (
	rhn_confchantype_id_seq.nextval, 'server_import',
	'Files imported from the server', 2);
commit;

select 'rhnsat/tables/rhnSnapshotConfigChannel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSnapshotConfigChannel.sql
create table
rhnSnapshotConfigChannel
(
	snapshot_id		number
				constraint rhn_snapshotcc_sid_nn not null
				constraint rhn_snapshotcc_sid_fk
					references rhnSnapshot(id)
					on delete cascade,
	config_channel_id	number
				constraint rhn_snapshotcc_ccid_nn not null
				constraint rhn_snapshotcc_ccid_fk
					references rhnConfigChannel(id),
	created			date default(sysdate)
				constraint rhn_snapshotcc_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_snapshotcc_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_snapshotcc_sid_ccid_uq
	on rhnSnapshotConfigChannel( snapshot_id, config_channel_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_snpsht_cc_ccid_sid_idx
on rhnSnapshotConfigChannel ( config_channel_id, snapshot_id )
        tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_snapshotcc_mod_trig
before insert or update on rhnSnapshotConfigChannel
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnConfigChannel_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigChannel_triggers.sql
create or replace trigger
rhn_confchan_mod_trig
before insert or update on rhnConfigChannel
for each row
begin
	:new.modified := sysdate;
end;
/
show errors
create or replace trigger
rhn_confchan_del_trig
before delete on rhnConfigChannel
for each row
declare
	cursor snapshots is
		select	snapshot_id id
		from	rhnSnapshotConfigChannel
		where	config_channel_id = :old.id;
begin
	for snapshot in snapshots loop
		update rhnSnapshot
			set invalid = lookup_snapshot_invalid_reason('cc_removed')
			where id = snapshot.id;
		delete from rhnSnapshotConfigChannel
			where snapshot_id = snapshot.id
				and config_channel_id = :old.id;
	end loop;
end;
/
show errors

select 'rhnsat/tables/rhnConfigFileFailure_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigFileFailure_data.sql
insert into rhnConfigFileFailure (id, label, name) values
    (rhn_conffile_failure_id_seq.nextval, 'missing',
    'Missing file');
insert into rhnConfigFileFailure (id, label, name) values
    (rhn_conffile_failure_id_seq.nextval, 'too_big',
    'File too big');
insert into rhnConfigFileFailure (id, label, name) values
    (rhn_conffile_failure_id_seq.nextval, 'binary_file',
    'Binary file');
insert into rhnConfigFileFailure (id, label, name) values
    (rhn_conffile_failure_id_seq.nextval, 'insufficient_quota',
    'Insufficient free quota space');
commit;

select 'rhnsat/tables/rhnConfigFileState_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigFileState_data.sql
insert into rhnConfigFileState(id, label, name) values
	(rhn_cfstate_id_seq.nextval, 'dead', 'Will not be deployed');
insert into rhnConfigFileState(id, label, name) values
	(rhn_cfstate_id_seq.nextval, 'alive', 'Will be deployed');
commit;

select 'rhnsat/tables/rhnConfigFileType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigFileType_data.sql
insert into rhnConfigFileType values (1, 'file', 'File', sysdate, sysdate);
insert into rhnConfigFileType values (2, 'directory', 'Directory', sysdate, sysdate);

select 'rhnsat/tables/rhnConfigFile_foreignkeys.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigFile_foreignkeys.sql
alter table rhnConfigFile add constraint rhn_conffile_lcrid_fk
	foreign key ( latest_config_revision_id )
	references rhnConfigRevision(id)
	on delete set null;

select 'rhnsat/tables/rhnSnapshotConfigRevision.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSnapshotConfigRevision.sql
create table
rhnSnapshotConfigRevision
(
	snapshot_id		number
				constraint rhn_snapshotcr_sid_nn not null
				constraint rhn_snapshotcr_sid_fk
					references rhnSnapshot(id)
					on delete cascade,
	config_revision_id	number
				constraint rhn_snapshotcr_crid_nn not null
				constraint rhn_snapshotcr_crid_fk
					references rhnConfigRevision(id),
	created			date default(sysdate)
				constraint rhn_snapshotcr_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_snapshotcr_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_snapshotcr_sid_crid_uq
	on rhnSnapshotConfigRevision( snapshot_id, config_revision_id )
	tablespace [[2m_tbs]]
  ;
create index rhn_sscr_crid_sid_idx
on rhnSnapshotConfigRevision ( config_revision_id, snapshot_id )
        tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_snapshotcr_mod_trig
before insert or update on rhnSnapshotConfigRevision
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnOrgQuota.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnOrgQuota.sql
create table
rhnOrgQuota
(
	org_id		number
			constraint rhn_orgquota_oid_nn not null
			constraint rhn_orgquota_oid_fk
				references web_customer(id),
	total		number default(0)
			constraint rhn_orgquota_total_nn not null,
	bonus		number default(0)
			constraint rhn_orgquota_bonus_nn not null,
	used		number default(0)
			constraint rhn_orgquota_used_nn not null,
	created		date default(sysdate)
			constraint rhn_orgquota_creat_nn not null,
	modified	date default(sysdate)
			constraint rhn_orgquota_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_orgquota_oid_uq
	on rhnOrgQuota(org_id)
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_orgquota_mod_trig
before insert or update on rhnOrgQuota
for each row
declare
	available_quota number;
begin
	:new.modified := sysdate;
	available_quota := :new.total + :new.bonus;
	if :new.used > available_quota then
		rhn_exception.raise_exception('not_enough_quota');
	end if;
end;
/
show errors

select 'rhnsat/tables/rhnConfigRevision_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnConfigRevision_triggers.sql
create or replace trigger
rhn_confrevision_mod_trig
before insert or update on rhnConfigRevision
for each row
begin
	:new.modified := sysdate;
end;
/
show errors
create or replace trigger
rhn_confrevision_acct_trig
after insert on rhnConfigRevision
for each row
declare
	org_id number;
	available number;
	added number;
begin
	select	cc.org_id id,
			oq.total + oq.bonus - oq.used available,
			content.file_size added
	into	org_id, available, added
	from	rhnConfigContent	content,
			rhnOrgQuota			oq,
			rhnConfigChannel	cc,
			rhnConfigFile		cf
	where	cf.id = :new.config_file_id
			and cf.config_channel_id = cc.id
			and cc.org_id = oq.org_id
			and :new.config_content_id = content.id;
	if added > available then
		rhn_exception.raise_exception('not_enough_quota');
	end if;
end;
/
show errors
create or replace trigger
rhn_confrevision_del_trig
before delete on rhnConfigRevision
for each row
declare
	cursor snapshots is
		select	snapshot_id id
		from	rhnSnapshotConfigRevision
		where	config_revision_id = :old.id;
begin
	for snapshot in snapshots loop
		update rhnSnapshot
			set invalid = lookup_snapshot_invalid_reason('cr_removed')
			where id = snapshot.id;
		delete from rhnSnapshotConfigRevision
			where snapshot_id = snapshot.id
				and config_revision_id = :old.id;
	end loop;
end;
/
show errors

select 'rhnsat/tables/rhnCpuArch.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnCpuArch.sql
create table
rhnCpuArch
(
	id		number
			constraint rhn_cpuarch_id_nn not null,
	label		varchar2(64)
			constraint rhn_cpuarch_label_nn not null,
	name		varchar2(64)
			constraint rhn_cpuarch_name_nn not null,
	created		date default(sysdate)
			constraint rhn_cpuarch_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_cpuarch_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_cpu_arch_id_seq start with 200;
create index rhn_cpuarch_id_l_n_idx
	on rhnCpuArch(id,label,name)
	tablespace [[2m_tbs]]
  ;
alter table rhnCpuArch add constraint rhn_cpuarch_id_pk primary key (id);
create index rhn_cpuarch_l_id_n_idx
	on rhnCpuArch(label,id,name)
	tablespace [[2m_tbs]]
  ;
alter table rhnCpuArch add constraint rhn_cpuarch_label_uq unique ( label );
create or replace trigger
rhn_cpuarch_mod_trig
before insert or update on rhnCpuArch
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnCpu.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnCpu.sql
create table
rhnCpu
(
	id		number
			constraint rhn_cpu_id_nn not null
			constraint rhn_cpu_id_pk primary key
			using index tablespace [[4m_tbs]],
	server_id	number
			constraint rhn_cpu_server_nn not null
			constraint rhn_cpu_server_fk
			references rhnServer(id),
	cpu_arch_id	number
			constraint rhn_cpu_caid_nn not null
			constraint rhn_cpu_caid_fk
				references rhnCpuArch(id),
	bogomips	varchar2(16),
	cache		varchar2(16),
	family		varchar2(32),
	MHz		varchar2(16),
	stepping	varchar2(16),
	flags		varchar2(2048),
	model		varchar2(64),
	version		varchar2(32),
	vendor		varchar2(32),
	nrcpu		number default 1,
	acpiVersion	varchar2(64),
	apic		varchar2(32),
	apmVersion	varchar2(32),
	chipset		varchar2(64),
	created		date default (sysdate)
			constraint rhn_cpu_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cpu_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_cpu_id_seq;
create index rhn_cpu_server_id_idx on
	rhnCpu(server_id)
	tablespace [[4m_tbs]]
	nologging;
create or replace trigger
rhn_cpu_mod_trig
before insert or update on rhnCpu
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnCpuArch_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnCpuArch_data.sql
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'i386', 'i386');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'i486', 'i486');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'i586', 'i586');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'i686', 'i686');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'athlon', 'athlon');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'alpha', 'alpha');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'alphaev6', 'alphaev6');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'ia64', 'ia64');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'sparc', 'sparc');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'sparcv9', 'sparcv9');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'sparc64', 'sparc64');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 's390', 's390');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 's390x', 's390x');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'ppc', 'ppc');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'ppc64', 'ppc64');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'pSeries', 'pSeries');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'iSeries', 'iSeries');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'x86_64', 'x86_64');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'sun4u', 'sun4u');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'sun4v', 'sun4v');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'sun4m', 'sun4m');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'ia32e', 'EM64T');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'amd64', 'AMD64');
insert into rhnCpuArch (id, label, name) values
(rhn_cpu_arch_id_seq.nextval, 'i86pc', 'i86pc');
commit;

select 'rhnsat/tables/rhnCryptoKeyType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnCryptoKeyType.sql
create sequence rhn_cryptokeytype_id_seq;
create table
rhnCryptoKeyType
(
	id			number
				constraint rhn_cryptokeytype_id_nn not null
				constraint rhn_cryptokeytype_id_pk primary key
					using index tablespace [[64k_tbs]],
	label			varchar2(32)
				constraint rhn_cryptokeytype_label_nn not null,
	description		varchar2(256)
				constraint rhn_cryptokeytype_desc_nn not null,
	created			date default(sysdate)
				constraint rhn_cryptokeytype_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_cryptokeytype_mod_nn not null
)
	enable row movement
  ;
create index rhn_cryptokeytype_label_id_idx
	on rhnCryptoKeyType( label, id )
	tablespace [[64k_tbs]]
  ;
alter table rhnCryptoKeyType add constraint rhn_cryptokeytype_label_uq
	unique ( label );
create or replace trigger
rhn_cryptokeytype_mod_trig
before insert or update on rhnCryptoKeyType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnCryptoKey.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnCryptoKey.sql
create sequence rhn_cryptokey_id_seq;
create table
rhnCryptoKey
(
	id			number
				constraint rhn_cryptokey_id_nn not null
				constraint rhn_cryptokey_id_pk primary key
					using index tablespace [[2m_tbs]],
	org_id			number
				constraint rhn_cryptokey_oid_nn not null
				constraint rhn_cryptokey_oid_fk
					references web_customer(id)
					on delete cascade,
	description		varchar2(1024)
				constraint rhn_cryptokey_desc_nn not null,
	crypto_key_type_id	number
				constraint rhn_cryptokey_cktid_nn not null
				constraint rhn_cryptokey_cktid_fk
					references rhnCryptoKeyType(id),
	key			blob
)
	enable row movement
  ;
create unique index rhn_cryptokey_oid_desc_uq
	on rhnCryptoKey( org_id, description )
	tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnCryptoKeyKickstart.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnCryptoKeyKickstart.sql
create table
rhnCryptoKeyKickstart
(
	crypto_key_id	number
			constraint rhn_ckey_ks_ckid_nn not null
			constraint rhn_ckey_ks_ckid_fk
				references rhnCryptoKey(id)
				on delete cascade,
        ksdata_id number
                        constraint rhn_ckey_ks_ksd_nn not null
                        constraint rhn_ckey_ks_ksd_fk
                                references rhnKSData(id)
				on delete cascade
)
	enable row movement
  ;
create unique index rhn_ckey_ks_uq
	on rhnCryptoKeyKickstart(crypto_key_id, ksdata_id)
	tablespace [[4m_tbs]]
  ;
create index rhn_ckey_ks__ckuq
	on rhnCryptoKeyKickstart(ksdata_id, crypto_key_id)
	tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnCryptoKeyType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnCryptoKeyType_data.sql
insert into rhnCryptoKeyType(id, label, description) values
	(rhn_cryptokeytype_id_seq.nextval,'GPG','GPG');
insert into rhnCryptoKeyType(id, label, description) values
	(rhn_cryptokeytype_id_seq.nextval,'SSL','SSL');
commit;

select 'rhnsat/tables/rhnCustomDataKey.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnCustomDataKey.sql
create sequence rhn_cdatakey_id_seq;
create table
rhnCustomDataKey
(
	id		number
			constraint rhn_cdatakey_id_nn not null
			constraint rhn_cdatakey_pk primary key,
	org_id		number
			constraint rhn_cdatakey_oid_nn not null
			constraint rhn_cdatakey_oid_fk
			     references web_customer(id)
			     on delete cascade,
	label		varchar2(64)
			constraint rhn_cdatakey_label_nn not null,
	description	varchar2(4000)
			constraint rhn_cdatakey_desc_nn not null,
	created_by	number
			constraint rhn_cdatakey_cb_fk
			     references web_contact(id)
			     on delete set null,
	last_modified_by number
			constraint rhn_cdatakey_lmb_fk
				references web_contact(id)
				on delete set null,
	created		date default (sysdate)
			constraint rhn_cdatakey_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_cdatakey_modified_nn not null
)
	enable row movement
  ;
create index rhn_cdatakey_oid_label_id_idx
	on rhnCustomDataKey(org_id, label, id)
	tablespace [[2m_tbs]]
  ;
alter table rhnCustomDataKey add constraint rhn_cdatakey_oid_label_uq
	unique ( org_id, label );
create or replace trigger
rhn_cdatakey_mod_trig
before insert or update on rhnCustomDataKey
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnDaemonState.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnDaemonState.sql
create table
rhnDaemonState
(
	label		varchar2(64)
			constraint rhn_daemonstate_label_nn not null
			constraint rhn_daemonstate_label_pk primary key
			using index tablespace [[64k_tbs]],
	last_poll	date
			constraint rhn_daemonstate_lp_nn not null
)
	enable row movement
  ;

select 'rhnsat/tables/rhnDaemonState_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnDaemonState_data.sql
insert into rhnDaemonState values ('entitlement_run_me',sysdate-1000);
insert into rhnDaemonState values ('email_engine',sysdate-1000);
insert into rhnDaemonState values ('payloader_engine',sysdate-1000);
insert into rhnDaemonState values ('pushed_users',sysdate-1000);
commit;

select 'rhnsat/tables/rhnDailySummaryQueue.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnDailySummaryQueue.sql
create table
rhnDailySummaryQueue
(
	org_id		number
			constraint rhn_dsqueue_oid_nn not null
			constraint rhn_dsqueue_oid_fk
				references web_customer(id),
	created		date default(sysdate)
			constraint rhn_dsqueue_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_dsqueue_modified_nn not null
)
	enable row movement
  ;
create index rhn_dsqueue_oid_idx
	on rhnDailySummaryQueue ( org_id )
	tablespace [[2m_tbs]]
  ;
alter table rhnDailySummaryQueue add constraint rhn_dsqueue_oid_uq
	unique ( org_id );

select 'rhnsat/tables/rhnDevice.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnDevice.sql
create table
rhnDevice
(
	id		number
			constraint rhn_device_id_nn not null
			constraint rhn_device_id_pk primary key
				using index tablespace [[32m_tbs]],
	server_id	number
			constraint rhn_device_sid_nn not null
			constraint rhn_device_sid_fk
				references rhnServer(id) on delete cascade,
	class		varchar2(16),
	bus		varchar2(16),
	detached	number,
	device		varchar2(16),
	driver		varchar2(256),
	description	varchar2(256),
	pcitype		number default -1,
	prop1		varchar2(256),
	prop2		varchar2(256),
	prop3		varchar2(256),
	prop4		varchar2(256),
	created		date default (sysdate)
			constraint rhn_device_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_device_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_hw_dev_id_seq;
create index rhn_device_server_id_idx
	on rhnDevice(server_id)
	tablespace [[32m_tbs]]
	nologging;
create or replace trigger
rhn_device_mod_trig
before insert or update on rhnDevice
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnDistChannelMap.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnDistChannelMap.sql
create table
rhnDistChannelMap 
(
	os		varchar2(64)
			constraint rhn_dcm_os_nn not null,
	release		varchar2(64)
			constraint rhn_dcm_release_nn not null,
	channel_arch_id	number
			constraint rhn_dcm_caid_nn not null
			constraint rhn_dcm_caid_fk
				references rhnChannelArch(id),
	channel_id	number
			constraint rhn_dcm_cid_nn not null 
			constraint rhn_dcm_cid_fk
				references rhnChannel(id) on delete cascade
)
	enable row movement
  ;
create index rhn_dcm_os_release_caid_idx
	on rhnDistChannelMap(os, release, channel_arch_id)
	tablespace [[64k_tbs]]
  ;
alter table rhnDistChannelMap add constraint rhn_dcm_os_release_caid_uq
	unique ( os, release, channel_arch_id );

select 'rhnsat/tables/rhnDownloadType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnDownloadType_data.sql
insert into rhnDownloadType values (1, 'iso', 'ISO Images');
insert into rhnDownloadType values (2, 'channel-xml-dump', 'Channel Dump');
insert into rhnDownloadType values (3, 'disabled', 'Disabled download');
commit;

select 'rhnsat/tables/rhnEmailAddressState.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnEmailAddressState.sql
create table
rhnEmailAddressState
(
	id			number
				constraint rhn_eastate_id_nn not null,
	label			varchar2(32)
				constraint rhn_eastate_label_nn not null,
	created			date default(sysdate)
				constraint rhn_eastate_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_eastate_modified_nn not null
)
	tablespace [[8m_data_tbs]]
	enable row movement
  ;
create sequence rhn_eastate_id_seq;
create index rhn_eastate_id_label_idx
	on rhnEmailAddressState ( id, label )
	tablespace [[64k_tbs]]
  ;
alter table rhnEmailAddressState add
	constraint rhn_eastate_id_pk primary key ( id );
create index rhn_eastate_label_id_idx
	on rhnEmailAddressState ( label, id )
	tablespace [[64k_tbs]]
  ;
alter table rhnEmailAddressState add
	constraint rhn_eastate_label_uq unique ( label );
create or replace trigger
rhn_eastate_mod_trig
before insert or update on rhnEmailAddressState
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnEmailAddress.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnEmailAddress.sql
create table
rhnEmailAddress
(
	id			number
				constraint rhn_eaddress_id_nn not null,
	address			varchar2(128)
				constraint rhn_eaddress_a_nn not null,
	user_id			number
				constraint rhn_eaddress_uid_nn not null
				constraint rhn_eaddress_uid_fk
					references web_contact(id)
					on delete cascade,
	state_id		constraint rhn_eaddress_sid_nn not null
				constraint rhn_eaddress_sid_fk
					references rhnEmailAddressState(id),
	next_action		date,
	created			date default(sysdate)
				constraint rhn_eaddress_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_eaddress_modified_nn not null
)
	tablespace [[8m_data_tbs]]
	enable row movement
  ;
create sequence rhn_eaddress_id_seq;
create or replace trigger
rhn_eaddress_mod_trig
before insert or update on rhnEmailAddress
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnEmailAddressLog.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnEmailAddressLog.sql
create table
rhnEmailAddressLog
(
	user_id			number
				constraint rhn_eaddresslog_uid_nn not null
				constraint rhn_eaddresslog_uid_fk
					references web_contact(id)
					on delete cascade,
	address			varchar2(128)
				constraint rhn_eaddresslog_a_nn not null,
	reason			varchar2(4000),
	created			date default(sysdate)
				constraint rhn_eaddresslog_created_nn not null
)
	tablespace [[8m_data_tbs]]
	enable row movement
  ;
create index rhn_eaddresslog_uid_idx
	on rhnEmailAddressLog(user_id)
	tablespace [[4m_tbs]]
  ;
create index rhn_eaddresslog_a_idx
	on rhnEmailAddressLog(address)
	tablespace [[4m_tbs]]
  ;
create index rhn_eaddresslog_created_idx
	on rhnEmailAddressLog(created)
	tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnEmailAddressState_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnEmailAddressState_data.sql
insert into rhnEmailAddressState ( id, label )
	values (rhn_eastate_id_seq.nextval, 'unverified');
insert into rhnEmailAddressState ( id, label )
	values (rhn_eastate_id_seq.nextval, 'pending');
insert into rhnEmailAddressState ( id, label )
	values (rhn_eastate_id_seq.nextval, 'pending_warned');
insert into rhnEmailAddressState ( id, label )
	values (rhn_eastate_id_seq.nextval, 'verified');
insert into rhnEmailAddressState ( id, label )
	values (rhn_eastate_id_seq.nextval, 'needs_verifying');
commit;

select 'rhnsat/tables/rhnEmailAddress_indexes.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnEmailAddress_indexes.sql
create index rhn_eaddress_id_idx
	on rhnEmailAddress ( id )
	tablespace [[8m_tbs]]
  ;
alter table rhnEmailAddress add
	constraint rhn_eaddress_id_pk primary key ( id );
create index rhn_eaddress_uid_sid_addr_idx
	on rhnEmailAddress ( user_id, state_id, address )
	tablespace [[8m_tbs]]
  ;
alter table rhnEmailAddress add
	constraint rhn_eaddress_uid_sid_uq unique ( user_id, state_id );
create index rhn_eaddress_niusa_idx
	on rhnEmailAddress ( next_action, id, user_id, state_id, address )
	tablespace [[8m_tbs]]
  ;

select 'rhnsat/tables/rhnEntitlementLog.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnEntitlementLog.sql
create table
rhnEntitlementLog
(
	run_time	date default(sysdate)
			constraint rhn_entitlement_log_rt_nn not null,
	bdate		date
			constraint rhn_entitlement_log_bdate_nn not null,
	edate		date
			constraint rhn_entitlement_log_edate_nn not null
)
	enable row movement
  ;

select 'rhnsat/tables/rhnErrataBuglist.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataBuglist.sql
create table
rhnErrataBuglist
(
	errata_id	number
			constraint rhn_errata_buglist_errata_nn not null
			constraint rhn_errata_buglist_errata_fk
				references rhnErrata(id)
				on delete cascade,
	bug_id		number
			constraint rhn_errata_buglist_bug_nn not null,
	summary		varchar2(4000),
	created		date default (sysdate)
			constraint rhn_errata_buglist_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_errata_buglist_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_errata_buglist_mod_trig
before insert or update on rhnErrataBuglist
for each row
begin
	:new.modified := sysdate;
end rhn_errata_buglist_mod_trig;
/
show errors
create unique index rhn_err_bug_list_uq
	on rhnErrataBuglist(errata_Id,bug_Id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnErrataTmp.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataTmp.sql
create table
rhnErrataTmp
(
        id              number
			constraint rhn_erratatmp_id_nn not null
                        constraint rhn_erratatmp_id_pk primary key
                        using index tablespace [[64k_tbs]],
        advisory        varchar2(37) -- advisory code
			constraint rhn_erratatmp_advisory_nn not null,
        advisory_type   varchar2(32) -- plain text type of advisory
			constraint rhn_erratatmp_adv_type_nn not null
			constraint rhn_erratatmp_adv_type_ck
			           check (advisory_type in ('Bug Fix Advisory',
				                            'Product Enhancement Advisory',
							    'Security Advisory')),
      	advisory_name	varchar2(32)  -- advisory name and version
			constraint rhn_erratatmp_advisory_name_nn not null,
	advisory_rel	number
			constraint rhn_erratatmp_advisory_rel_nn not null,
        product         varchar2(64),
        description     varchar2(4000), -- description
        synopsis        varchar2(4000), -- Short description
        topic           varchar2(4000), -- Problem description
        solution        varchar2(4000), -- how to resolve it
        issue_date      date default (sysdate)
			constraint rhn_erratatmp_issue_nn not null,
        update_date     date default (sysdate)
			constraint rhn_erratatmp_update_nn not null,
        refers_to	varchar2(4000),
        notes           varchar2(4000),
        org_id          number
                        constraint rhn_erratatmp_oid_fk
                                references web_customer(id)
				on delete cascade,
       locally_modified char(1)
			constraint rhn_erratatmp_lm_ck check
				(locally_modified in ('Y','N')),
        created         date default (sysdate)
			constraint rhn_erratatmp_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_erratatmp_modified_nn not null,
       last_modified  date default (sysdate)
                  constraint rhn_erratatmp_last_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_erratatmp_advisory_uq
	on rhnerratatmp(advisory)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_erratatmp_advisory_name_uq
	on rhnerratatmp(advisory_name)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_erratatmp_mod_trig
before insert or update on rhnerratatmp
for each row
begin
        :new.modified := sysdate;
        :new.last_modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnErrataBuglistTmp.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataBuglistTmp.sql
create table
rhnErrataBuglistTmp
(
	errata_id	number
			constraint rhn_errata_buglisttmp_eid_nn not null
			constraint rhn_errata_buglisttmp_eid_fk
				references rhnErrataTmp(id)
				on delete cascade,
	bug_id		number
			constraint rhn_errata_buglisttmp_bid_nn not null,
	summary		varchar2(4000),
	created		date default (sysdate)
			constraint rhn_errata_buglisttmp_c_nn not null,
	modified	date default (sysdate)
			constraint rhn_errata_buglisttmp_m_nn not null
)
	enable row movement
  ;
create unique index rhn_err_buglisttmp_uq
	on rhnErrataBuglistTmp(errata_Id,bug_Id)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_errata_buglisttmp_mod_trig
before insert or update on rhnErrataBuglistTmp
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnErrataCVE.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataCVE.sql
create table
rhnErrataCVE
(
	errata_id	number
			constraint rhn_err_cve_eid_nn not null
			constraint rhn_err_cve_eid_fk
				references rhnErrata(id)
				on delete cascade,
	cve_id	        number
			constraint rhn_err_cve_cid_nn not null
			constraint rhn_err_cve_cid_fk
				references rhnCVE(id),
	created		date default (sysdate)
			constraint rhn_err_cve_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_err_cve_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_errata_cve_mod_trig
before insert or update on rhnErrataCVE
for each row
begin
	:new.modified := sysdate;
end rhn_errata_cve_mod_trig;
/
show errors
create unique index rhn_err_cve_eid_cid_uq
	on rhnErrataCVE(errata_id, cve_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_err_cve_cid_eid_idx
	on rhnErrataCVE(cve_id, errata_id)
	tablespace [[64k_tbs]]
	nologging;

select 'rhnsat/tables/rhnErrataCloned.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataCloned.sql
create table
rhnErrataCloned
(
	original_id		number
				constraint rhn_errataclone_feid_nn not null
				constraint rhn_errataclone_feid_fk
					references rhnErrata(id)
					on delete cascade,
	id		        number
				constraint rhn_errataclone_teid_nn not null
				constraint rhn_errataclone_teid_fk
					references rhnErrata(id)
					on delete cascade,
	created			date default(sysdate)
				constraint rhn_errataclone_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_errataclone_modified_nn not null
)
	enable row movement
  ;
create index rhn_errataclone_feid_teid_idx
	on rhnErrataCloned ( original_id, id )
	tablespace [[2m_tbs]]
  ;
alter table rhnErrataCloned add constraint rhn_errataclone_feid_teid_uq
	unique ( original_id, id );
alter table rhnErrataCloned add constraint rhn_errataclone_id_pk
        primary key ( id );
create index rhn_errataclone_teid_feid_idx
	on rhnErrataCloned ( id, original_id )
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_errataclone_mod_trig
before insert or update on rhnErrataCloned
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnErrataClonedTmp.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataClonedTmp.sql
create table
rhnErrataClonedTmp
(
	original_id		number
				constraint rhn_eclonedtmp_feid_nn not null
				constraint rhn_eclonedtmp_feid_fk
					references rhnErrata(id)
					on delete cascade,
	id		                                                                number
				constraint rhn_eclonedtmp_teid_nn not null
				constraint rhn_eclonedtmp_teid_fk
					references rhnErrataTmp(id)
					on delete cascade,
	created			date default(sysdate)
				constraint rhn_eclonedtmp_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_eclonedtmp_modified_nn not null
)
	enable row movement
  ;
create index rhn_eclonedtmp_feid_teid_idx
	on rhnErrataClonedTmp ( original_id, id )
	tablespace [[2m_tbs]]
  ;
alter table rhnErrataClonedTmp add constraint rhn_eclonedtmp_feid_teid_uq
	unique ( original_id, id );
alter table rhnErrataClonedTmp add constraint rhn_eclonedtmp_id_pk
        primary key ( id );
create index rhn_eclonedtmp_teid_feid_idx
	on rhnErrataClonedTmp ( id, original_id )
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_eclonedtmp_mod_trig
before insert or update on rhnErrataClonedTmp
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnErrataFile.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataFile.sql
create sequence rhn_erratafile_id_seq;
create table
rhnErrataFile
(
	id		number
			constraint rhn_erratafile_id_nn not null,
	errata_id       number
			constraint rhn_erratafile_errata_nn not null
			constraint rhn_erratafile_errata_fk
				references rhnErrata(id)
				on delete cascade,
	type		number
			constraint rhn_erratafile_type_nn not null
			constraint rhn_erratafile_type_fk
				references rhnErrataFileType(id),
	md5sum		varchar2(64)
			constraint rhn_erratafile_md5_nn not null,
	filename	varchar2(1024)
			constraint rhn_erratafile_name_nn not null,
	created		date default(sysdate)
			constraint rhn_erratafile_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_erratafile_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_errata_file_mod_trig
before insert or update on rhnErrataFile
for each row
begin
	:new.modified := sysdate;
end rhn_errata_file_mod_trig;
/
show errors
create index rhn_erratafile_id_idx
	on rhnErrataFile ( id )
	tablespace [[64k_tbs]]
  ;
alter table rhnErrataFile add constraint rhn_erratafile_id_pk
	primary key ( id );
create index rhn_erratafile_eid_file_idx
	on rhnErrataFile ( errata_id, filename )
	tablespace [[64k_tbs]]
  ;
alter table rhnErrataFile add constraint rhn_erratafile_eid_file_uq
       unique ( errata_id, filename );

select 'rhnsat/tables/rhnErrataFileChannel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataFileChannel.sql
create table
rhnErrataFileChannel
(
	channel_id	number
			constraint rhn_efilec_cid_nn not null 
			constraint rhn_efilec_cid_fk
				references rhnChannel(id)
				on delete cascade,
	errata_file_id	number
			constraint rhn_efilec_eid_nn not null
			constraint rhn_efilec_eid_fk
				references rhnErrataFile(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_efilec_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_efilec_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_efilec_mod_trig
before insert or update on rhnErrataFileChannel
for each row
begin
	:new.modified := sysdate;
end rhn_efilec_mod_trig;
/
show errors
create index rhn_efilec_efid_cid_idx
	on rhnErrataFileChannel(errata_file_id, channel_id)
	tablespace [[64k_tbs]]
  ;
alter table rhnErrataFileChannel add constraint rhn_efilec_efid_cid_uq
	unique ( errata_file_id, channel_id );
create index rhn_efilec_cid_efid_idx
	on rhnErrataFileChannel(channel_id, errata_file_id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnErrataFileTmp.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataFileTmp.sql
create table
rhnErrataFileTmp
(
	id		number
			constraint rhn_erratafiletmp_id_nn not null,
	errata_id       number
			constraint rhn_erratafiletmp_errata_nn not null
			constraint rhn_erratafiletmp_errata_fk
				references rhnErrataTmp(id)
				on delete cascade,
	type		number
			constraint rhn_erratafiletmp_type_nn not null
			constraint rhn_erratafiletmp_type_fk
				references rhnErrataFileType(id),
	md5sum		varchar2(64)
			constraint rhn_erratafiletmp_md5_nn not null,
	filename	varchar2(128)
			constraint rhn_erratafiletmp_name_nn not null,
	created		date default(sysdate)
			constraint rhn_erratafiletmp_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_erratafiletmp_modified_nn not null
)
	enable row movement
  ;
create index rhn_erratafiletmp_id_idx
	on rhnErrataFileTmp ( id )
	tablespace [[64k_tbs]]
  ;
alter table rhnErrataFileTmp add constraint rhn_erratafiletmp_id_pk
	primary key ( id );
create index rhn_erratafiletmp_eid_file_idx
	on rhnErrataFileTmp ( errata_id, filename )
	tablespace [[64k_tbs]]
  ;
alter table rhnErrataFileTmp add constraint rhn_erratafiletmp_eid_file_uq
	unique ( errata_id, filename );
create or replace trigger
rhn_erratafiletmp_mod_trig
before insert or update on rhnErrataFileTmp
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnErrataFileChannelTmp.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataFileChannelTmp.sql
create table
rhnErrataFileChannelTmp
(
	channel_id	number
			constraint rhn_efilectmp_cid_nn not null 
			constraint rhn_efilectmp_cid_fk
				references rhnChannel(id)
				on delete cascade,
	errata_file_id	number
			constraint rhn_efilectmp_eid_nn not null
			constraint rhn_efilectmp_eid_fk
				references rhnErrataFileTmp(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_efilectmp_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_efilectmp_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_efilectmp_mod_trig
before insert or update on rhnErrataFileChannelTmp
for each row
begin
	:new.modified := sysdate;
end rhn_efilectmp_mod_trig;
/
show errors
create index rhn_efilectmp_efid_cid_idx
	on rhnErrataFileChannelTmp(errata_file_id, channel_id)
	tablespace [[64k_tbs]]
  ;
alter table rhnErrataFileChannelTmp add constraint rhn_efilectmp_efid_cid_uq
	unique ( errata_file_id, channel_id );
create index rhn_efilectmp_cid_efid_idx
	on rhnErrataFileChannelTmp(channel_id, errata_file_id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnErrataPackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataPackage.sql
create table
rhnErrataPackage
(
	errata_id	number
			constraint rhn_err_pkg_eid_nn not null
			constraint rhn_err_pkg_eid_fk
				references rhnErrata(id)
				on delete cascade,
	package_id	number
			constraint rhn_err_pkg_pid_nn not null
			constraint rhn_err_pkg_pid_fk
				references rhnPackage(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_err_pkg_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_err_pkg_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_err_pkg_eid_pid_uq
	on rhnErrataPackage(errata_id, package_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_err_pkg_pid_eid_idx
	on rhnErrataPackage(package_id, errata_id)
	tablespace [[64k_tbs]]
	nologging; 

select 'rhnsat/tables/rhnErrataFilePackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataFilePackage.sql
create table
rhnErrataFilePackage
(
	package_id	number
			constraint rhn_efilep_pid_nn not null 
			constraint rhn_efilep_pid_fk
				references rhnPackage(id)
				on delete cascade,
	errata_file_id	number
			constraint rhn_efilep_fileid_nn not null
			constraint rhn_efilep_fileid_fk
				references rhnErrataFile(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_efilep_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_efilep_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_efilep_mod_trig
before insert or update on rhnErrataFilePackage
for each row
begin
	:new.modified := sysdate;
end rhn_efilep_mod_trig;
/
show errors
create index rhn_efilep_efid_pid_idx
	on rhnErrataFilePackage( errata_file_id, package_id )
	tablespace [[2m_tbs]]
  ;
alter table rhnErrataFilePackage add constraint rhn_efilep_efid_uq
	unique ( errata_file_id );
create index rhn_efilep_pid_idx
	on rhnErrataFilePackage ( package_id )
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnPackageSource.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageSource.sql
create table
rhnPackageSource
(
        id              number
			constraint rhn_pkgsrc_id_nn not null
                        constraint rhn_pkgsrc_id_pk primary key
				using index tablespace [[64k_tbs]]
			,
        org_id          number
                        constraint rhn_pkgsrc_oid_fk
				references web_customer(id)
				on delete cascade,
	source_rpm_id	number
			constraint rhn_pkgsrc_srid_nn not null
			constraint rhn_pkgsrc_srid_fk
				references rhnSourceRPM(id),
        package_group   number
			constraint rhn_pkgsrc_group_nn not null
                        constraint rhn_pkgsrc_group_fk
				references rhnPackageGroup(id),
        rpm_version     varchar2(16)
			constraint rhn_pkgsrc_rpm_ver_nn not null,
        payload_size    number
			constraint rhn_pkgsrc_paysize_nn not null,
        build_host      varchar2(256)
			constraint rhn_pkgsrc_bh_nn not null,
        build_time      date
			constraint rhn_pkgsrc_bt_nn not null,
        sigmd5          varchar2(64)
			constraint rhn_package_sigmd5_nn not null,
        vendor          varchar2(64)
			constraint rhn_pkgsrc_vendor_nn not null,
	cookie		varchar2(128)
			constraint rhn_pkgsrc_cookie_nn not null,
        path            varchar2(1000),
        md5sum          varchar2(64)
	                constraint rhn_pkgsrc_md5sum_nn not null,
        package_size    number
	                constraint rhn_pkgsrc_ps_nn not null,
	last_modified	date default (sysdate)
			constraint rhn_pkgsrc_lm_nn not null,
        created         date default (sysdate)
			constraint rhn_pkgsrc_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_pkgsrc_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_package_source_id_seq;
create unique index rhn_pkgsrc_srid_oid_uq
	on rhnPackageSource(source_rpm_id, org_id)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_pkgsrc_mod_trig
before insert or update on rhnPackageSource
for each row
begin
        :new.modified := sysdate;
	:new.last_modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnErrataFilePackageSource.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataFilePackageSource.sql
create table
rhnErrataFilePackageSource
(
	package_id	number
			constraint rhn_efileps_pid_nn not null 
			constraint rhn_efileps_pid_fk
				references rhnPackageSource(id)
				on delete cascade,
	errata_file_id	number
			constraint rhn_efileps_fileid_nn not null
			constraint rhn_efileps_fileid_fk
				references rhnErrataFile(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_efileps_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_efileps_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_efileps_mod_trig
before insert or update on rhnErrataFilePackageSource
for each row
begin
	:new.modified := sysdate;
end rhn_efileps_mod_trig;
/
show errors
create index rhn_efileps_efid_pid_idx
	on rhnErrataFilePackageSource ( errata_file_id, package_id )
	tablespace [[64k_tbs]]
  ;
alter table rhnErrataFilePackageSource add constraint rhn_efileps_efid_uq
	unique ( errata_file_id );

select 'rhnsat/tables/rhnErrataFilePackageTmp.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataFilePackageTmp.sql
create table
rhnErrataFilePackageTmp
(
	package_id	number
			constraint rhn_efileptmp_pid_nn not null 
			constraint rhn_efileptmp_pid_fk
				references rhnPackage(id)
				on delete cascade,
	errata_file_id	number
			constraint rhn_efileptmp_fileid_nn not null
			constraint rhn_efileptmp_fileid_fk
				references rhnErrataFileTmp(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_efileptmp_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_efileptmp_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_efileptmp_mod_trig
before insert or update on rhnErrataFilePackageTmp
for each row
begin
	:new.modified := sysdate;
end rhn_efilep_mod_trig;
/
show errors
create index rhn_efileptmp_efid_pid_idx
	on rhnErrataFilePackageTmp( errata_file_id, package_id )
	tablespace [[2m_tbs]]
  ;
alter table rhnErrataFilePackageTmp add constraint rhn_efileptmp_efid_uq
	unique ( errata_file_id );
create index rhn_efileptmp_pid_idx
	on rhnErrataFilePackageTmp ( package_id )
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnErrataKeyword.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataKeyword.sql
create table
rhnErrataKeyword
(
	errata_id       number
			constraint rhn_err_keyword_eid_nn not null
			constraint rhn_err_keyword_eid_fk
				references rhnErrata(id)
				on delete cascade,
	keyword		varchar2(64),
	created		date default(sysdate)
			constraint rhn_err_keyword_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_err_keyword_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_errata_keyword_mod_trig
before insert or update on rhnErrataKeyword
for each row
begin
	:new.modified := sysdate;
end rhn_errata_keyword_mod_trig;
/
show errors
create unique index rhn_err_keyword_eid_uq
	on rhnErrataKeyword(keyword,errata_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_errkw_eid_idx
	on rhnErrataKeyword(errata_id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnErrataKeywordTmp.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataKeywordTmp.sql
create table
rhnErrataKeywordTmp
(
	errata_id       number
			constraint rhn_err_keywordtmp_eid_nn not null
			constraint rhn_err_keywordtmp_eid_fk
				references rhnErrataTmp(id)
				on delete cascade,
	keyword		varchar2(64),
	created		date default(sysdate)
			constraint rhn_err_keywordtmp_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_err_keywordtmp_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_err_keywordtmp_eid_uq
	on rhnErrataKeywordTmp(keyword,errata_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_errkwtmp_eid_idx
	on rhnErrataKeywordTmp(errata_id)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_errata_keywordtmp_mod_trig
before insert or update on rhnErrataKeywordTmp
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnErrataNotificationQueue.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataNotificationQueue.sql
create table
rhnErrataNotificationQueue
(
	errata_id		number
				constraint rhn_enqueue_eid_nn not null
				constraint rhn_enqueue_eid_fk
					references rhnErrata(id)
					on delete cascade,
        org_id                  number
                            	constraint rhn_enqueue_oid_nn not null
                            	constraint rhn_enqueue_oid_fk
                                	references web_customer(id)
					on delete cascade,
	next_action		date default(sysdate),
	created			date default(sysdate)
				constraint rhn_enqueue_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_enqueue_modified_nn not null
)
	enable row movement
  ;
create index rhn_enqueue_eid_idx
	on rhnErrataNotificationQueue ( errata_id, org_id )
	tablespace [[4m_tbs]]
  ;
alter table rhnErrataNotificationQueue add constraint rhn_enqueue_eoid_uq
	unique ( errata_id, org_id );
create index rhn_enqueue_na_eid_idx
	on rhnErrataNotificationQueue ( next_action, errata_id )
	tablespace [[8m_tbs]]
  ;
create or replace trigger
rhn_enqueue_mod_trig
before insert or update on rhnErrataNotificationQueue
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnErrataPackageTmp.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataPackageTmp.sql
create table
rhnErrataPackageTmp
(
	errata_id	number
			constraint rhn_err_pkgtmp_eid_nn not null
			constraint rhn_err_pkgtmp_eid_fk
				references rhnErrataTmp(id)
				on delete cascade,
	package_id	number
			constraint rhn_err_pkgtmp_pid_nn not null
			constraint rhn_err_pkgtmp_pid_fk
				references rhnPackage(id),
	created		date default (sysdate)
			constraint rhn_err_pkgtmp_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_err_pkgtmp_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_err_pkgtmp_eid_pid_uq
	on rhnErrataPackageTmp(errata_id, package_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_err_pkgtmp_pid_eid_idx
	on rhnErrataPackageTmp(package_id, errata_id)
	tablespace [[64k_tbs]]
	nologging;
create or replace trigger
rhn_errata_packagetmp_mod_trig
before insert or update on rhnErrataPackageTmp
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnErrataPackage_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataPackage_triggers.sql
create or replace trigger
rhn_errata_package_mod_trig
before insert or update or delete on rhnErrataPackage
for each row
begin
	if inserting or updating then	
		:new.modified := sysdate;
	end if;
	if deleting then
		update rhnErrata
		set rhnErrata.last_modified = sysdate
		where rhnErrata.id in ( :old.errata_id );
	end if;
end rhn_errata_package_mod_trig;
/
show errors

select 'rhnsat/tables/rhnErrataQueue.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataQueue.sql
create table
rhnErrataQueue
(
	errata_id		number
				constraint rhn_equeue_eid_nn not null
				constraint rhn_equeue_eid_fk
					references rhnErrata(id)
					on delete cascade,
	next_action		date,
	created			date default(sysdate)
				constraint rhn_equeue_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_equeue_modified_nn not null
)
	enable row movement
  ;
create index rhn_equeue_eid_idx
	on rhnErrataQueue ( errata_id )
	tablespace [[4m_tbs]]
  ;
alter table rhnErrataQueue add constraint rhn_equeue_eoid_uq
	unique ( errata_id );
create index rhn_equeue_na_eid_idx
	on rhnErrataQueue ( next_action, errata_id )
	tablespace [[8m_tbs]]
  ;

select 'rhnsat/tables/rhnErrataSeverity_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrataSeverity_data.sql
INSERT INTO RHNErrataSeverity VALUES (0, 0, 'errata.sev.label.critical');
INSERT INTO RHNErrataSeverity VALUES (1, 1, 'errata.sev.label.important');
INSERT INTO RHNErrataSeverity VALUES (2, 2, 'errata.sev.label.moderate');
INSERT INTO RHNErrataSeverity VALUES (3, 3, 'errata.sev.label.low');

select 'rhnsat/tables/rhnErrata_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnErrata_triggers.sql
create or replace trigger
rhn_errata_mod_trig
before insert or update on rhnErrata
for each row
begin
     if ( :new.last_modified = :old.last_modified ) or
        ( :new.last_modified is null )  then
        :new.last_modified := sysdate;
     end if;
	  	:new.modified := sysdate;
end rhn_errata_mod_trig;
/
show errors

select 'rhnsat/tables/rhnFAQClass.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnFAQClass.sql
create table
rhnFAQClass
(
	id	    number
		    constraint rhn_faq_class_id_nn not null
		    constraint rhn_faq_class_id_pk primary key
			using index tablespace [[64k_tbs]]
			,
	name	    varchar2(128),
	label       varchar2(32)
	    	    constraint rhn_faq_class_label_nn not null,
	ordering  number
	            constraint rhn_faq_class_or_nn not null
)
	enable row movement
  ;
CREATE SEQUENCE RHN_FAQ_CLASS_ID_SEQ START WITH 101;
create unique index rhn_faqclass_label_uq
	on rhnFAQClass(label)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_faqclass_or_uq
	on rhnFAQClass(ordering)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnFAQ.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnFAQ.sql
create table
rhnFAQ
(
	id		number
			constraint rhn_faq_id_nn not null
			constraint rhn_faq_id_pk primary key
				using index tablespace [[64k_tbs]] 
                                ,
	class_id	number
			constraint rhn_faq_class_fk
				references rhnFAQClass(id),
	subject		varchar2(200),
	details		varchar2(4000),
	private		number default(0)
			constraint rhn_faq_private_nn not null,
	usage_count     number default(0)
	    	    	constraint rhn_faq_usage_nn not null,
        created         date default(sysdate)
                        constraint rhn_faq_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_faq_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_faq_id_seq;
create or replace trigger
rhn_faq_mod_trig
before insert or update on rhnFAQ
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnFAQClass_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnFAQClass_data.sql
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
1, 'General', 'general', 100); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
2, 'Account Management', 'account_management', 120); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
3, 'Getting Started', 'getting_started', 140); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
4, 'Service Levels', 'service_levels', 160); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
5, 'Using Spacewalk', 'using_rhn', 180); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
6, 'Technical Questions', 'technical_questions', 200); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
7, 'Management Service', 'enterprise_service', 220); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
8, 'Privacy/Legal', 'legal', 240); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
9, 'Policies', 'policy', 260); 
INSERT INTO RHNFAQCLASS ( ID, NAME, LABEL, ORDERING ) VALUES ( 
11, 'Definitions', 'definitions', 270); 
COMMIT;
COMMIT;

select 'rhnsat/tables/rhnFAQ_satdata.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnFAQ_satdata.sql
SET SQLBLANKLINES ON
SET SCAN OFF
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
64, 'pvt: This message is being forwarded to customerservice@redhat.com', 'This message has been forwarded to customerservice@redhat.com.  That group handles all billing and purchasing related questions.'
, 1,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/12/2003 10:18:24 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 22, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
65, 'I''m having trouble registering my Red Hat Enterprise Linux product.  Why?', 'Enterprise entitlements are required for use with Red Hat Enterprise Linux.
A customer who registers an Enterprise Linux system with Spacewalk without having any Enterprise Linux entitlements will receive an error message similar to:
"No public channels available for ("2.1AS'', ''i686'')"
In order to register your system, you first need to activate your Spacewalk Enterprise Linux entitlements at:
http://www.redhat.com/support
Use the product ID that came with your Red Hat Enterprise Linux product.
'
, 0,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:12 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 13, 7); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
66, 'pvt: I bought service with Spacewalk, but it won''t let me use Priority FTP access.  Why not?vp'
, 'Instant ISO access is not the same as Priority FTP access; they are separate entities.  Customers who purchase Spacewalk service have Instant ISO access only.  Priority FTP access is available only to legacy users, and is in the process of being phased out.
'
, 1,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/24/2003 09:34:56 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 6, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
67, 'How do I register a system for Spacewalk service on Red Hat Linux?', 'To register a system for Spacewalk service on Red Hat Linux please run "rhn_register". Refer to the Spacewalk User Guide (also available through the Help link at the Spacewalk website) for additional instructions.
Note: for Red Hat Linux 8.0 and later, please run "up2date --register" instead of "rhn_register".
'
, 0,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/16/2003 09:09:30 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 19, 3); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
25, 'The Spacewalk website and up2date do not agree on what errata is needed for my system.'
, 'You can refresh the profile package list by running "up2date -p" on the machine itself.  Alternatively, you can schedule this from the website by clicking on the system in the System List, choosing the Packages tab, and then clicking on the "Update Package List" button at the bottom of the page.
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/14/2003 09:24:01 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 10, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
26, 'I had to re-install my system. How do I re-register and get my entitlement back?'
, 'You''ll need to re-register the client system if you haven''t already, and then move an entitlement to the new profile.
* Log into our website at:  https://rhn.redhat.com.
* Click on "Systems" in the top navigation bar, then the name of the old system in the System List.
* Click "delete system" on the top-right corner of the page.
* As root at the command line, delete the file /etc/sysconfig/rhn/systemid from your system.
* Run "rhn_register" (Red Hat Linux 7.x) or "up2date --register" (Red Hat Linux 8.0 and newer) on your system.
* Once the system is registered, log in at https://rhn.redhat.com.
* Click "Systems" in the top navigation bar, then "System Entitlements" on the left.
* Select the appropriate entitlement level for the new system and click "Update Entitlements."'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/18/2003 09:42:55 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 411, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
27, 'How can I request a new feature or improvement for the Spacewalk?', 'For technical requests, you can make a "Request for Enhancement" (RFE) at http://bugzilla.redhat.com/bugzilla.  The product is "Spacewalk" and the various components are prefaced by "Spacewalk/".  Please put "[RFE]" at the beginning of the summary line of your request.
If you would like to provide non-technical feedback to Spacewalk, please go to https://rhn.redhat.com/help/contact.pxt and follow the directions for "feedback".
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/18/2003 09:56:14 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 74, 9); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
28, 'Where do I report a bug in the Spacewalk website or update agent?', 'Bugs can be reported at http://bugzilla.redhat.com/bugzilla -- the product is "Spacewalk", and the various components are prefixed with "Spacewalk/".
Please be sure to read the FAQ and review all of the open bugs before submitting your bug.
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/15/2003 10:47:49 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 45, 9); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
30, 'What is the difference between i386, i586, and i686 packages?', 'i386 is a generic designation for all processors backwardly compatible with the Intel 80386; i586 is for all processors backwardly compatible with the Intel Pentium; and i686 is for Intel processors backwardly compatible with the Pentium Pro chip (Pentium II, III, IV, etc).  Only the kernel has i586 and i686 versions, and glibc has an i686 version.  up2date should automatically determine which versions of the kernel and glibc packages are appropriate for your systems.
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/15/2003 10:33:49 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 8, 11); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
1, 'What is Spacewalk?', 'Spacewalk is a systems support and management environment for Red Hat Linux systems and networks. For more information, please see the Spacewalk product information page:
http://www.redhat.com/software/rhn/products/
For individual systems and small networks, see http://www.redhat.com/software/rhn
For enterprise deployments, see http://www.redhat.com/software/rhen
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/14/2003 05:00:08 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 26, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
3, 'Does Spacewalk only work on Linux? Which versions?', 'Yes. Spacewalk currently only supports versions of Red Hat Linux and Red Hat Enterprise Linux that are still active (have not yet reached End of Life status). For a list of currently maintained Red Hat versions, please go to http://www.redhat.com/apps/support/errata/
Please note that Red Hat''s Enterprise Network Monitoring Module does support different platforms. For more information, please go to http://www.redhat.com/software/rhen/system_mgmt/
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:12 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 4, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
5, 'I can''t find the Spacewalk Registration Client.  What is it and where do I find it?'
, 'The Spacewalk Registration Client steps you through the process of creating a user account if you do not already have one and registering your system by creating a System Profile. It can be started by using one of the following methods:
* On the GNOME desktop, go to the Main Menu Button (on the Panel) => Programs => System => Spacewalk.
* On the KDE desktop, go to the Main Menu Button (on the Panel) => System => Spacewalk
* At a shell prompt, type the command "rhn_register".
In Red Hat Linux 8.0 and newer, rhn_register exists as a mode of the up2date client, so:
* On the GNOME and KDE desktops, go to the Main Menu Button (on the Panel) => System Tools => Spacewalk. (If the system is unregistered, it will automatically launch in registration mode.)
* At a shell prompt (for example, an xterm or gnome-terminal), type the command "up2date --register".
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/19/2003 01:31:52 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 126, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
7, 'I forgot my username and password. How do I access my account?', 'From the front page, click on the "Lost Password?" link, enter your username and email address, and then click the "Send Password" button.
If you have neither your username nor your password, enter your email address in the second field provided, and then click the "Send Account List" button.
If the email address matches the email address on file for your account, your information will be sent to you. If this does not work for you, please call our customer service desk at 1-866-2-RedHat.
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/16/2003 09:14:22 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 16, 2); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
8, 'What are the service levels for Spacewalk?', 'Spacewalk currently offers three levels of service: Spacewalk Demo Service, Spacewalk Update Service and Spacewalk Management Service.  For more details, go to http://www.redhat.com/software/rhn/offerings
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/08/2003 03:43:45 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 50, 4); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
69, 'pvt: You are sending packets to my machine! (Firewall log attached)', 'As you can see, the packets you are seeing are response packets coming from our host and port 443 to your machine.
These packets have the SYN/ACK flags set up. These types of packets are sent only in response to a connection request from your computer.
TCP uses a three-way handshake protocol to establish a connection:
* the client sends a SYN packet to the server requesting a connection
* the server acknowledges the request and sends back a SYN/ACK packet
* the client responds back with an ACK packet and the connection is established
Your firewall rules are not allowing the server responses to pass through.  The rhnsd daemon is initiating these requests. You have 2 choices:
* fix the firewall rules so you allow the reply packets to pass through and therefore allow your host to connect outside; or
* disable the rhnsd daemon: service rhnsd stop
'
, 1,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 3, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
125, 'pvt: no RHL support at rhn-help', 'This address is intended for support questions related only to Red Hat
Network. General Red Hat Linux support is not available from this address.
If you have not already done so, you can activate your product and receive advanced support at:
https://www.redhat.com/apps/support/
Even if you are not registered with Red Hat Support, you are welcome to browse
our documentation and online resources available at:
https://www.redhat.com/docs/
You may also get access to Tips, FAQs, and online HOWTOs to guide you through
Linux-related tasks if you start looking from our Support Resources Home Page
available at:
https://www.redhat.com/apps/support/resources/
The Red Hat mailing lists are also good venues for finding answers to your
questions. For more information on the Red Hat mailing lists, please see:
http://www.redhat.com/mailing-lists/
If you would like to report a bug or a problem with a component of the Red Hat Linux distribution, we encourage you to visit our bug tracking system and file a bug report at:
http://bugzilla.redhat.com/bugzilla
'
, 1,  TO_Date( '12/11/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:12 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 288, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
126, 'How do I change my Spacewalk password?', 'To change your password:
* Log in to the Spacewalk website with your existing username and password.
* If you are not at Your Spacewalk page, click its link in the top navigation bar.
* Click "Your Account" in the left navigation bar.
* Type your new password in both the Password and Password Confirmation fields.
* Click the "Update" button.
'
, 0,  TO_Date( '12/12/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:12 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 9, 2); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
13, 'What is "rhnsd" and why is it running on my system?', '"rhnsd" is the Spacewalk Daemon. Every other hour, it sends a request to Spacewalk asking for any notifications or updates and works in coordination with Spacewalk to schedule automated tasks. It sends information to Spacewalk only requested by you. If you add a new system using the Spacewalk web interface, the next time the Spacewalk Daemon probes Spacewalk it receives a request to return the information you requested as part of your System Profile, such as what package versions are installed on your system.
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/08/2003 10:52:29 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 9, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
15, 'My systems are not checking in.  What does that mean?', 'When the Spacewalk client connects to Spacewalk to see if there are any updates available, or if any actions have been scheduled, this is considered a checkin.
If you are seeing a message indicating that checkins are not happening, it means that the Spacewalk client on your system is not successfully reaching Spacewalk for some reason. Things to check:
* Make certain that your client is configured correctly.
* Make sure that your system can communicate with Spacewalk via SSL (port 443).  You may test this by running the following command from a shell prompt: telnet xmlrpc.rhn.redhat.com 443
* Make sure that the rhnsd daemon is activated and running.  You may ensure this by running the following commands:
chkconfig --level 345 rhnsd on
service rhnsd start
If these settings are correct and your system still is not checking in, the ''Repairing a corrupt rpm database'' faq at http://rhn.redhat.com/help/faq/technical_questions.pxt#227 , or get in touch with our technical support team.
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/14/2003 05:04:29 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 151, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
17, 'Can I use Spacewalk to upgrade my Red Hat Linux kernel?', 'Yes. You must use Red Hat Update Agent version 2.5.4 or higher. If you choose the kernel packages and allow Spacewalk to install them to your system, it will modify your LILO or GRUB configuration file so that your system boots the new kernel the next time it is rebooted.
'
, 0,  TO_Date( '03/07/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:12 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 11, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
41, 'pvt: Updates to newer versions recommended by third-party security advisories.'
, 'We have released fixes for all known vulnerabilities you are mentioning.  Red Hat does not usually update to a new code base for the core applications and libraries if we have other options available. In the cases you have mentioned we choose to backport the security fixes to the code base we initially shipped to our customers. We do this in order to minimize the impact on the stability and the QA resources that both we and the customers invest in qualifying a particular release for a particular task.
The latest versions of those packages provided by Red Hat are not vulnerable to the issues you mention.
'
, 1,  TO_Date( '10/01/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/13/2003 11:31:22 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 10, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
62, 'Is Red Hat Technical Support available in other languages besides English?', 'At this time, Spacewalk technical support is English only.
'
, 0,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/27/2003 10:32:41 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 26, 4); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
63, 'How do I download RPMs for a system without using up2date?', 'It is possible for Spacewalk users to download updated packages directly from the Spacewalk website without using up2date.
To download them:
* Log in to the Spacewalk web site.
* Click "Software" in the top navigation bar.
* Click the appropriate channel name.
* On the Channel Details page, click the "Packages" tab.
* Select the RPMs you want and click the "Download" button. You will be presented with a confirmation screen.
* Click "Download Selected Packages Now!"
* You will then be asked for the location to save the tar archive containing all the packages you selected.
* To extract the packages once the download is complete, run: tar -xvf rhn-packages.tar
'
, 0,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:12 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 9, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
31, 'The update agent wants to install an older version of a package.  Why?', 'This is probably because of the epoch number of the package.  RPM checks three things when it tries to determine whether a package is newer: epoch, version, and release, in that order.  A higher epoch number trumps both version and release.  To see the epoch number on an installed package, use the command:
rpm -q --queryformat "%{NAME}-%{VERSION}-%{RELEASE}:%{EPOCH}\n" packagename
The epoch is the number after the colon.  On the Spacewalk website, you can also see the epoch for the package on the Installed Packages list for the system, (again, the number after the colon).
Epoch numbers are used to preserve RPM''s concept of "newer" when package versions are changed inconveniently. The classic example of the need for an epoch is perl, which changed from version 5.00503 to 5.6, thereby breaking rpm''s segmented version comparison (i.e the integer 6 < 503, rather than 5.6 > 5.00503).
To keep the update agent from trying to update your package, add it to the package skip list (pkgSkipList) in your up2date configuration:
up2date --configure --nox
However, the package will still show up on your list of applicable errata.
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/06/2003 10:26:15 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 7, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
32, 'pvt: Red Hat Linux support', 'This address is intended for support questions related only to Spacewalk. General Red Hat Linux support is not available from this address.  If you are registered with Red Hat Support, you may address your questions at:
http://www.redhat.com/support
If you have not already done so, you can activate your product and receive advanced support at:
https://www.redhat.com/apps/support/
Even if you are not registered with Red Hat Support, you are welcome to browse
our documentation and online resources available at:
https://www.redhat.com/docs/
You may also get access to Tips, FAQs, and online HOWTOs to guide you through
Linux-related tasks if you start looking from our Support Resources Home Page
available at:
https://www.redhat.com/apps/support/resources/
The Red Hat mailing lists are also good venues for finding answers to your
questions. For more information on the Red Hat mailing lists, please see:
http://www.redhat.com/mailing-lists/
If you would like to report a bug or a problem with a component of the Red Hat Linux distribution, we encourage you to visit our bug tracking system and file a bug report at:
http://bugzilla.redhat.com/bugzilla
'
, 1,  TO_Date( '06/22/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/19/2003 01:13:04 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 768, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
33, 'How do I delete System Profiles?', 'In order to delete System Profiles from Spacewalk, you need to log in to the Spacewalk website at https://rhn.redhat.com.  Once logged in, click on the "Systems" link in the top navigation bar, which will take you to a list of the profiles you have registered with Spacewalk. (If you instead see System Groups, click "View Systems" near the top of the page.)
Click on the name of the profile you wish to delete from the service. This will bring up its System Details page. Click the "delete system" button at the top-right corner of the page. Then confirm that you wish to delete the profile.
The profile will be removed after confirmation.
'
, 0,  TO_Date( '06/24/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/12/2003 10:57:15 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 89, 7); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
36, 'pvt: Educational Channel', 'The educational channel and Red Hat educational initiative is currently undergoing some changes (all for the positive). Please stay tuned and periodically check the following websites for more information:
www.redhat.com
www.redhat.com/index2.html
www.redhat.com/software/rhn
'
, 1,  TO_Date( '08/20/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:13 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 14, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
35, 'An errata install fails with dependency errors, but dependencies are satisfied.  Why?'
, 'Sometimes the application of an errata from the Spacewalk web site will fail because the errata applies to packages that are set to be skipped in the local skip list for a system''s up2date client.  The error message in the history log will incorrectly cite a dependency problem.
To fix this problem, run:
up2date --configure
...as root from the client system, and remove the relevant packages from the skip list.  Rescheduling the errata should then work as expected.
'
, 0,  TO_Date( '08/20/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/13/2003 10:24:11 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 23, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
249, 'Where can I see a copy of the SLA (Service Level Agreement) for Spacewalk Technical Support?'
, 'This can be viewed online at the following site:
http://www.redhat.com/services/techsupport/production/RHN_basic.html'
, 0,  TO_Date( '03/31/2003 11:55:25 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/09/2003 11:00:32 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 6, 4); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
288, 'My system''s IP address and hostname have changed, but Spacewalk doesn''t reflect this. What should I do?'
, 'Spacewalk stores a profile for each registered system. In addition to properties set by the user during registration, this profile may contain various kinds of information about the system''s hardware, including processor type, networking addresses, and storage devices. This information can be found in the Spacewalk website:
1. Once logged in, click on Systems in the top navigation bar.
2. Click on the name of a system in one of the lists. (This may require leaving a System Groups view.)
3. In the System Details page, click the Hardware subtab. All of the hardware information Spacewalk has collected about your system will appear on the resulting page.
4. To update this information, click the Schedule Hardware Refresh button. The hardware profile will be updated at the system''s next connection to Spacewalk.'
, 0,  TO_Date( '04/22/2003 04:00:05 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/23/2003 09:45:57 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
290, 'Why does up2date tell me "Your system is fully updated" when the Spacewalk website lists updates for my system?'
, 'This error is likely caused by one of two problems: Either the system''s package profile on Spacewalk is out of date or up2date''s package exceptions list is preventing the updates from occurring.
Since updating the package profile is simplest, try this first. Log into the Spacewalk website, click "Systems" in the top navigation bar, and then click the name of the system. In the System Details page, click the "Packages" tab and then click the "Update Package List" button. The profile will be updated when the system next connects to Spacewalk. This should either remove the updates listed for your system or allow you to conduct the updates if they remain.
If this still does not resolve the error, check your package exceptions list, which enables you to identify packages to be exempt from updates. To ensure your settings are not preventing the updates, launch the Update Agent Configuration Tool by running the command:
up2date-config
In the tool, click the "Package Exceptions" tab and look for the packages listed as requiring updating.
To check the package skip list in the up2date configuration file, open the file /etc/sysconfig/rhn/up2date and look for the package entries under the pkgSkipList setting. To override the package exceptions and force an update of the entire system, run the command:
up2date -uf
If the packages aren''t updated, the Spacewalk website will continue to list them as outdated, regardless of their inclusion in the system''s package exceptions list.'
, 0,  TO_Date( '04/22/2003 06:32:03 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/25/2003 08:04:45 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
291, 'Why does Apache fail to restart after I update my Spacewalk Management Satellite Server?', 'Apache RPMs do not restart the httpd service upon installation. Therefore, after conducting a full update of an Spacewalk Management Satellite Server (such as with the command up2date -uf), Apache fails. The error will look something like:
[Mon Feb 10 11:50:12 2003] [notice] SIGHUP received.  Attempting to restart
Syntax error on line 214 of /etc/httpd/conf/httpd.conf: Cannot load /etc/httpd/modules/mod_log_config.so into server: /etc/httpd/modules/mod_log_config.so: undefined symbol: ap_escape_logitem
To resolve this, restart the httpd service.'
, 0,  TO_Date( '04/22/2003 08:27:51 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/23/2003 09:48:30 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 7); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
308, 'How do I resolve dropped connections during ISO downloads?', 'Red Hat recommends using the Curl open source tool for downloading ISO images. This tool enables you to resume downloads that have been interrupted. If you use Spacewalk and don''t currently have Curl, you may install it by running the command "up2date curl" from a shell prompt.
Once Curl is installed, at a shell prompt, cut and paste the URL for the ISO into the Curl command as follows:
[user@localhost home]$ curl -C - -O ''very_long_url''
The URL, which can be derived from the Easy ISOs page of the Spacewalk website, is very long because it contains session authentication information. Be sure to include the single quotation marks around it. The ''-C -'' option allows you to continue the download if it is interrupted, such as by a lost connection. The ''-O'' (the letter ''O'', not a zero) option will save the file with the same name as on the Spacewalk Servers.'
, 0,  TO_Date( '04/30/2003 07:02:36 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/02/2003 11:41:21 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
310, 'Why does the registration process prompt me for an organization ID if I don''t need one to register?'
, 'The organization ID is legacy from the days in which Spacewalk allowed users to request addition to an existing organization, which then required an Organization Administrator to approve the new user.
Now, the Spacewalk website allows Organization Administrators to create user accounts directly. Unfortunately, older versions of the registration tools (both rhn_register and up2date) still contain organization ID and password fields. You may disregard them.'
, 0,  TO_Date( '05/02/2003 08:51:09 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/03/2003 09:07:56 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 3); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
221, 'How do I get more legal information?', 'Please go to http://www.redhat.com/software/rhn/legal'
, 0,  TO_Date( '03/27/2003 06:47:21 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 8); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
224, 'What is an ISO?', 'An ISO is an image file of the contents of a CD.
For example, by downloading the Red Hat Linux ISOs to your system, you can then burn a CD that will be identical to the Red Hat Linux CDs that are available in retail stores.'
, 0,  TO_Date( '03/28/2003 11:22:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/16/2003 09:07:32 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 11); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
225, 'What is Errata?', 'An Errata is a message about new updates for your system, usually accompanied by updated packages.
Spacewalk is a tool to update your system with these errata packages.'
, 0,  TO_Date( '03/28/2003 11:25:25 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/16/2003 09:08:17 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 11); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
227, 'How do I repair a corrupt RPM database?', 'Occasionally, the RPM database on a Red Hat Linux machine will become corrupt.  This usually happens when an RPM transaction is interrupted at a critical time.  Symptoms of this problem include one of the following programs not responding or freezing:
* up2date
* The Spacewalk alert notification tool (applet in the Gnome or KDE panel)
* rhn_check
* rpm
This problem can also cause a system to stop checking in with Spacewalk.
To fix this problem, run the following commands as root:
* kill all RPM processes (rhn_check, up2date, rpm, rhn-applet):
     $ ps -axwww | grep rhn_check
In the list of processes, the first number on each line is the PID.  For all PIDs listed except for the one associated with grep:
     $ kill -9 <PID>
Repeat the above steps for each of the programs listed.
* remove any RPM lock files (/var/lib/rpm/__db*):
     $ rm -rf /var/lib/rpm/__db*
* rebuild the rpm database:
     $ rpm --rebuilddb
If the above steps do not work, please contact technical support for more assistance.'
, 0,  TO_Date( '03/28/2003 11:34:34 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/07/2003 11:31:57 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 2, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
231, 'How do I move my Spacewalk entitlement to another machine?', 'All of the systems that you want to entitle, or un-entitle, must be registered with Spacewalk. Please see the FAQ question relating to registering new systems.
First Step - unentitle old system
1) Sign in with Spacewalk
2) Click on "Systems"
3) Click on "Systems Entitlements"
4) Change entitlement of old system to "none"
5) Click "Update Entitlements"
Next Step - entitle new system
From same screen, change the entitlement on the new system to the entitlement you would like to have. Click "Update Entitlements".'
, 0,  TO_Date( '03/28/2003 12:07:10 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/14/2003 09:33:40 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 2, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
230, 'I just upgraded my system. How do I re-register it with Spacewalk?', 'If you are running a version of Red Hat Linux 7.3 (or prior release), do the following:
1) Log in as root
2) Type "rhn_register"
If you are running a version of Red Hat Linux 8.0 (or later release), do the following:
1) Log in as root
2) Type "up2date --register"'
, 0,  TO_Date( '03/28/2003 12:01:49 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/24/2003 10:47:23 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 2, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
232, 'How do I get copies of the latest release notes for Spacewalk?', 'Click on the Help button in the upper right hand corner. Then click on Release Notes listed on the navigation bar on the left.'
, 0,  TO_Date( '03/28/2003 12:16:19 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
70, 'pvt: Updating kernel and config files', 'Because of the wide range of changes and setups involved in the scenarios you describe we have chosen the conservative path in the default configuration.
We recommend that you upgrade the kernel on the boxes while you can observe the process (ie, running "up2date --force kernel" from the command line). The same goes for the packages which have config files DBmodified - please check the results of the upgrade process to make sure you will not have an interruption of service due to changed config files.
Once you have been through this process a few times and get a better feel for how Spacewalk handles your particular setup, you can decide to let Spacewalk perform these updates for you automatically.
'
, 1,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/14/2003 10:30:31 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 26, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
73, 'pvt: I can''t get into ftp.redhat.com. Why?', '
Due to the popularity of Red Hat Linux 8.0, our ftp servers are currently heavily loaded, and are at their capacity. We apologize for any inconvenience this may cause.
If you are not able to log into the ftp.redhat.com ftp site, it is probably because the servers are serving the maximum number of users currently. You can try later, or better yet, try one of the many Red Hat mirror sites. They are listed at:
https://www.redhat.com/download/mirror.html
  '
, 1,  TO_Date( '10/02/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/24/2003 09:35:36 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 3, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
82, 'Red Hat''s "GPG Key" - what is it and how do I install it?', 'The first time you run the graphical version of the Red Hat Update Agent, it prompts you to install the Red Hat GPG key. This key is required to authenticate the packages downloaded from Spacewalk. If you run the command line version the first time you start Red Hat Update Agent, you need to install the Red Hat GPG key manually; follow the instructions that up2date displays.'
, 0,  TO_Date( '10/17/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/06/2003 11:15:40 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 10, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
124, 'pvt: no RHL support at rhn-feedback', 'This address is intended for feedback related only to Red Hat
Network. General Red Hat Linux support is not available from this address.
If you are registered with Red Hat Support, you may address your questions
at:
http://www.redhat.com/support
Even if you are not registered with Red Hat Support, you are welcome to browse
our documentation and online resources available at:
https://www.redhat.com/docs/
You may also get access to Tips, FAQs, and online HOWTOs to guide you through
Linux-related tasks if you start looking from our Support Resources Home Page
available at:
https://www.redhat.com/apps/support/resources/
The Red Hat mailing lists are also good venues for finding answers to your
questions. For more information on the Red Hat mailing lists, please see:
http://www.redhat.com/mailing-lists/
If you would like to report a bug or a problem with a component of the Red Hat Linux distribution, we encourage you to visit our bug tracking system and file a bug report at:
http://bugzilla.redhat.com/bugzilla'
, 1,  TO_Date( '12/11/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 10, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
191, 'pvt: I want to unsubscribe from the maillist !', 'To stop receiving mails from Spacewalk , please see below:
Use your Spacewalk account to login, then go to "Your Spacewalk"==>"Your preferences" .
The Your Preferences page allows you to configure Spacewalk options, including:
      Errata Email Notification — Determine whether you want to receive email every time an Errata Alert is applicable to one or more systems in your Spacewalk account.
      Spacewalk List Page Size — Maximum number of items that will appear in a list on a single page. If more items are in the list, clicking the Next button will display the next group of items. This preference applies to system lists, Errata lists, package lists, and so on.
      Time Zone — Set your time zone so that scheduled actions are scheduled according to the time in your time zone.
      Red Hat Contact Options — Identify what ways (email, phone, fax, or mail) Red Hat may contact you.
After making changes to any of these options, click the Save Preferences button on the bottom right-hand corner.
'
, 1,  TO_Date( '02/19/2003 08:20:46 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/27/2003 11:53:51 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 89, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
209, 'I can''t log in with my username or password.  What should I do?', 'First, please check to see if you are using the correct username and password (see answers to questions in this section). If you are using the correct username and password, please call customer service at 1-866-2-RedHat or contact them at customerservice@redhat.com'
, 0,  TO_Date( '03/27/2003 03:57:30 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:10 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 2); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
228, 'pvt: How can I subscribe for Red Hat 9 now?', 'Red Hat Linux 9 ISOs will be available to paid subscribers starting March 31, 2003--a week before they will be available on redhat.com, in stores, or on Red Hat FTP. A paid subscription also gets you access to Spacewalk technical support, errata updates, priority access during peak times, and immediate email notification. It''s the quickest way to get Red Hat Linux 9.
Note: Spacewalk does not include printed documentation or Red Hat Linux Installation Support. If that''s what you''re looking for,  you can purchase Red Hat Linux 9 at redhat.com or at retail stores, available April 7, 2003. Red Hat Linux 9 or Red Hat Linux 9 Professional includes source code and documentation CDs, printed documentation manuals, installation support, and 1- or 2- month Update Subscription to Spacewalk.
For more informations please visit this page:
http://www.redhat.com/mktg/rh9iso/
'
, 1,  TO_Date( '03/25/2003 03:09:59 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/06/2003 09:07:11 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 9, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
208, 'I am new to Spacewalk. How do I create an account?', 'Go to http://rhn.redhat.com and click on the link that says "Create Account". From here, please follow the directions.'
, 0,  TO_Date( '03/27/2003 03:55:40 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 3); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
210, 'How do I login to Spacewalk?', 'Go to http://rhn.redhat.com
From this page, enter in your username and password in the box. If you do not have your username and password, please see the FAQ relating to this.'
, 0,  TO_Date( '03/27/2003 03:59:43 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 3); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
212, 'How do I contact Spacewalk?', 'To contact Spacewalk, please go to: http://www.redhat.com/software/rhn/contact'
, 0,  TO_Date( '03/27/2003 04:02:07 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
215, 'How do I know when I need to update my system?', 'Once your system is registered on Spacewalk, a small icon will appear on your tool bar (Red Hat Linux 7.3 and higher). The icon will display either an exclamation point with red background (meaning that there is an update waiting to be downloaded) or a check mark with blue background (meaning that there are no updates waiting). If your icon portrays a question mark, it means that Spacewalk is not able to see your system.
By double clicking on the icon, this will activate Spacewalk update tool.'
, 0,  TO_Date( '03/27/2003 04:27:48 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
217, 'Can I use Spacewalk to upgrade to a newer version of Red Hat Linux?', 'No. While Spacewalk always supports the latest version of Red Hat Linux, Spacewalk cannot be used today to upgrade your system from one version of Red Hat Linux to the next. You will need to do a CD based install. However, if you are a paid subscriber to Spacewalk (Update or Management), you have access to the new Red Hat Linux ISOs the moment they are made available. For more information, see http://www.redhat.com/software/rhn/offerings
'
, 0,  TO_Date( '03/27/2003 04:39:01 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 5); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
219, 'What are the terms and conditions of Spacewalk?', 'To see a copy of the Spacewalk Terms and Conditions, please go to http://www.redhat.com/licenses/rhn.html'
, 0,  TO_Date( '03/27/2003 06:03:20 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:11 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 0, 8); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
23, 'How do I remove a pending action?', 'A pending action will be removed when there are no longer any systems scheduled for it.  For Demo or Update entitlements this will always be done on a per system basis:
* Log into the Spacewalk website.
* Click "Schedule" on the top navigation bar, then "Pending Actions" in the left navigation bar.
* Click on the numeral in the "In Progress" column of the row for the action you want to remove.
* Click on the desired system name.
* Click on the "Events" tab in the System Details navigation.
* Click on the "Pending" subtab.
* Select the event you wish to cancel, and click "Cancel Events"
* Click the "Cancel Selected Events" on the confirmation page.
For systems with Management entitlements, simply remove the systems from the action:
* Click "Schedule" on the top navigation bar, then "Pending Actions" in the left navigation bar.
* Click on the numeral in the "In Progress" column of the row for the action you want to remove.
* Select the systems for removal from the action and then click on the "Unschedule Action" button.
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/18/2003 09:53:59 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 14, 7); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
24, 'Why do scheduled kernel errata fail to install?', 'By default, the kernel packages are marked to be skipped by the update agent.  You can change this configuration by running:
up2date --configure --nox
...and changing or clearing the "pkgSkipList" parameter.  You should then be able to schedule your kernel update.
'
, 0,  TO_Date( '06/14/2002 12:00:00 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/30/2003 04:21:47 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 11, 6); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
131, 'pvt: openssl packages', 'The latest releases of the OpenSSL packages from Red Hat include fixes for all known security vulnerabilities, including the various types of worms that float around.
Please remember that just upgrading the packages is not sufficient. You will have to restart at least your Apache server in order for the new libraries to be loaded by the running Apache process.
More details about the applicable OpenSSL errata can be found at:
https://rhn.redhat.com/errata/RHSA-2002-160.html
and
https://rhn.redhat.com/network/errata/errata_details.pxt?eid=1143
'
, 1,  TO_Date( '12/19/2002 07:33:20 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:10 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 4, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
148, 'pvt: delayed response', 'Due to significant interest & volume in Spacewalk services, we have been unable to respond to your question in a timely manner.  We apologize for the delay and any inconvenience this delay may have caused you.  In response to your question, below is a response to your question.  If this solution does not resolve your issue, please resubmit with additional information.
'
, 1,  TO_Date( '02/05/2003 12:41:33 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/03/2003 11:24:13 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 39, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
168, 'pvt: New To Linux', 'This address is intended for support questions from paid subscribers and is related only to Spacewalk. General Red Hat Linux support is not available from this address.  If you are registered with Red Hat Support, you may address your questions at:
http://www.redhat.com/support
If you have not already done so, you can activate your product and receive advanced support at:
https://www.redhat.com/apps/support/
Even if you are not registered with Red Hat Support, you are welcome to browse
our documentation and online resources available at:
https://www.redhat.com/docs/
You may also get access to Tips, FAQs, and online HOWTOs to guide you through
Linux-related tasks if you start looking from our Support Resources Home Page
available at:
https://www.redhat.com/apps/support/resources/
The Red Hat mailing lists are also good venues for finding answers to your
questions. For more information on the Red Hat mailing lists, please see:
http://www.redhat.com/mailing-lists/
If you would like to report a bug or a problem with a component of the Red Hat Linux distribution, we encourage you to visit our bug tracking system and file a bug report at:
http://bugzilla.redhat.com/bugzilla
'
, 1,  TO_Date( '02/13/2003 04:23:15 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:10 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 6, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
169, 'How do I change my email address?', 'To change your email:
* Log in to the Spacewalk website with your existing username and password.
* If you are not at Your Spacewalk page, click its link in the top navigation bar.
* Click "Your Account" in the left navigation bar.
* Click "Change Email"
* Type your new email in field.
* Click the "Send Verification" or "Update" button.'
, 0,  TO_Date( '02/13/2003 10:03:56 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/13/2003 09:15:55 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 16, 2); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
170, 'pvt: How to entitle system in my Spacewalk', '* Once the system is registered, log in at https://rhn.redhat.com.
* Click "Systems" in the top navigation bar, then "System Entitlements" on the left.
* Select the appropriate entitlement level for the new system and click "Update Entitlements."'
, 1,  TO_Date( '02/13/2003 10:36:28 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '05/15/2003 09:36:58 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 54, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
188, 'pvt: system on a closed net , but still want to update', 'Spacewalk Management Satellite Server provides for local management of system profiles, thus allowing for completely disconnected operation from external networks.
More information, please follow this link:
https://rhn.redhat.com/info/purchase_info.pxt
'
, 1,  TO_Date( '02/18/2003 09:35:22 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/07/2003 11:03:00 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 8, 1); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
189, 'What are the differences between Update, Management, and Demo Accounts?', 'Update service level subscriptions to Spacewalk allow individuals to register one or more systems, manage these systems independently, receive priority access to Spacewalk, and download Easy ISOs (full versions of Red Hat Linux). Update subscriptions are $60 per system and renew annually. Customers may receive also limited time (less than one year) Update subscriptions with the Red Hat Linux distribution products.
Management service level subscriptions to Spacewalk allow organizations to manage multiple systems, individually or in groups of systems. Management subscriptions efficiently combine the power and flexibility of fine-grained control with the scalability to support thousands of systems.
Demo refers to our complimentary service level. Any user may receive one Demo account with Spacewalk to receive notifications and system updates. Demo users are asked to take a short survey every 60 days in order to provide Red Hat with valued customer input and to validate that the account is still active. Please note that there can be only one demo account per email address.
Note: A Demo account does not provide guaranteed access to errata or bandwidth allocation during peak times, as these resources are reserved for paying subscribers. For this reason, Red Hat strongly recommends purchasing at least an Update service level if you are using your Linux system for home or business production use.
For more information, please follow this link:
http://www.redhat.com/software/rhn/offerings'
, 0,  TO_Date( '02/18/2003 10:53:18 PM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '04/21/2003 12:08:01 PM', 'MM/DD/YYYY HH:MI:SS AM')
, 48, 4); 
INSERT INTO RHNFAQ ( ID, SUBJECT, DETAILS, PRIVATE, CREATED, MODIFIED, USAGE_COUNT,
CLASS_ID ) VALUES ( 
190, 'pvt:How can i delete my account in Spacewalk?', 'Sorry,you can not delete your account in Spacewalk now. But your account will be disabled if you do not accept the survey per 60 days.'
, 1,  TO_Date( '02/19/2003 04:22:18 AM', 'MM/DD/YYYY HH:MI:SS AM'),  TO_Date( '03/31/2003 09:26:10 AM', 'MM/DD/YYYY HH:MI:SS AM')
, 25, 1); 
COMMIT;

select 'rhnsat/tables/rhnFeature.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnFeature.sql
create table
rhnFeature
(
        id              number
                        constraint rhn_feature_id primary key
                                using index tablespace [[64k_tbs]],
        label           varchar2(32)
                        constraint rhn_feature_label_nn not null,
        name            varchar2(64)
                        constraint rhn_feature_name_nn not null,
        created         date default(sysdate)
                        constraint rhn_feature_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_feature_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_feature_seq;
create unique index rhn_feature_label_uq_idx 
	on rhnFeature(label)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnFeature_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnFeature_data.sql
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_package_updates', 'Update Packages',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_errata_updates', 'Errata Updates',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_hardware_refresh', 'Refresh Hardware Profile',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_package_refresh', 'Refresh Packages Profile',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_package_remove', 'Remove Packages',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_auto_errata_updates', 'Auto Errata Update',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_system_grouping', 'System Groups',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_package_verify', 'Verify Packages',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_profile_compare', 'Compare Package Profiles',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_proxy_capable', 'Proxy Capable',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_sat_capable', 'Satellite Capable',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_reboot', 'Reboot System',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_satellite_applet', 'Satellite Applet',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_osa_bus', 'OSA Bus',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_kickstart', 'Kickstart',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_config', 'Config File Management',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_custom_info', 'Custom Information',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_delta_action', 'Package Profile Sync',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_snapshotting', 'System Snapshotting',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_agent_smith', 'Agent Smith',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_remote_command', 'Execute Remote Command',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_schedule_probe', 'Schedule Probe',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_probes', 'Probes',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_nonlinux_support', 'Non-Linux Support',
        sysdate, sysdate);
insert into rhnFeature (id, label, name, created, modified)
values (rhn_feature_seq.nextval, 'ftr_daily_summary', 'Daily Summary',
        sysdate, sysdate);
insert into rhnFeature (id, label, name)
values (rhn_feature_seq.nextval, 'ftr_xen_provision_domain', 'Provision new Xen domains');
insert into rhnFeature (id, label, name)
values (rhn_feature_seq.nextval, 'ftr_xen_manage_domains', 'Manage existing Xen domains');

select 'rhnsat/tables/rhnFileDownload.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnFileDownload.sql
create table
rhnFileDownload
(
	file_id			number
				constraint rhn_filedl_fid_nn not null
				constraint rhn_filedl_fid_fk
					references rhnFile(id),
	location		varchar2(2000)
				constraint rhn_filedl_location_nn not null,
	token			varchar2(48),
	requestor_ip		varchar2(15)
				constraint rhn_filedl_rip_nn not null,
	start_time		date default(sysdate)
				constraint rhn_filedl_start_nn not null,
	user_id			number
				constraint rhn_filedl_uid_fk
					references web_contact(id)
					on delete set null
)
	enable row movement
  ;
create index rhn_filedl_uid_fid_idx
	on rhnFileDownload ( user_id, file_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_filedl_token_idx
	on rhnFileDownload ( token )
	tablespace [[8m_tbs]]
  ;
create index rhn_filedl_start_idx
        on rhnFileDownload ( start_time )
        tablespace [[8m_tbs]]
  ;

select 'rhnsat/tables/rhnFileListMembers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnFileListMembers.sql
create table
rhnFileListMembers
(
	file_list_id		number
				constraint rhn_flmembers_flid_nn not null
				constraint rhn_flmembers_flid_fk
					references rhnFileList(id)
					on delete cascade,
	config_file_name_id	number
				constraint rhn_flmembers_cfnid_nn not null
				constraint rhn_flmembers_cfnid_fk
					references rhnConfigFileName(id),
	created			date default (sysdate)	
				constraint rhn_flmembers_creat_nn not null,
	modified		date default (sysdate)
				constraint rhn_flmembers_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_flmembers_flid_cfnid_uq
	on rhnFileListMembers( file_list_id, config_file_name_id )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_flmembers_mod_trig
before insert or update on rhnFileListMembers
for each row
begin
	:new.modified := sysdate;
end rhn_flmembers_mod_trig;
/
show errors

select 'rhnsat/tables/rhnFileLocation.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnFileLocation.sql
create table
rhnFileLocation
(
	file_id 	number
			constraint rhn_fileloc_fid_nn not null
			constraint rhn_fileloc_fid_fk
			     	references rhnFile(id),
        location        varchar2(128)
	    	    	constraint rhn_fileloc_loc_nn not null
)
	enable row movement
  ;
create unique index rhn_fileloc_file_loc_uq
	on rhnFileLocation(file_id, location)
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnGrailComponentChoices.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnGrailComponentChoices.sql
create table
rhnGrailComponentChoices
(
        user_id         number
                        constraint rhn_grail_comp_ch_nn not null
                        constraint rhn_grail_comp_ch_user_fk
                                   references web_contact(id)
				   on delete cascade,
        ordering        number
                        constraint rhn_grail_comp_ch_order_nn not null,
        component_pkg   varchar2(64)
                        constraint rhn_grail_comp_ch_pkg_nn not null,
        component_mode  varchar2(64)
                        constraint rhn_grail_comp_ch_mode_nn not null
)
	enable row movement
  ;
create unique index rhn_grail_comp_ch_user_ord_uq
	on rhnGrailComponentChoices(user_id,ordering)
	tablespace [[64k_tbs]]
  ;
create index rhn_grail_cmp_ch_user
	on rhnGrailComponentChoices(user_id)
	tablespace [[64k_tbs]]
	nologging;

select 'rhnsat/tables/rhnUserGroupType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserGroupType.sql
create table
rhnUserGroupType
(
	id		number
			constraint rhn_userGroupType_id_nn not null
			constraint rhn_userGroupType_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(64)
			constraint rhn_userGroupType_label_nn not null,
	name		varchar2(64)
			constraint rhn_userGroupType_name_nn not null,
	created		date default(sysdate)
			constraint rhn_userGroupType_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_userGroupType_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_usergroup_type_seq;
create index rhn_usergrouptype_label_id_idx
	on rhnUserGroupType ( label, id )
	tablespace [[64k_tbs]]
  ;
alter table rhnUserGroupType add
	constraint rhn_usergrouptype_label_uq unique ( label );

select 'rhnsat/tables/rhnGrailComponents.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnGrailComponents.sql
create table
rhnGrailComponents
(
        id              number
                        constraint rhn_grail_comp_pk primary key
                                using index tablespace [[64k_tbs]],
        component_pkg   varchar2(64)
                        constraint rhn_grail_comp_pkg_nn not null,
        component_mode  varchar2(64)
                        constraint rhn_grail_comp_mode_nn not null,
        config_mode     varchar2(64),
        component_label varchar2(128),
        role_required   number
                        constraint rhn_grail_comp_role_type_fk
                                references rhnUserGroupType(id)
)
	enable row movement
  ;
create sequence rhn_grail_components_seq;
create unique index rhn_grail_comp_pkg_mode_uq
	on rhnGrailComponents(component_pkg, component_mode)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_grail_comp_label_uq
	on rhnGrailComponents(component_label)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnIndexerWork.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnIndexerWork.sql
create table rhnIndexerWork (
  object_type varchar2(40) not null,
  last_id number not null,
  last_modified date default (sysdate) not null
)
	enable row movement
;

select 'rhnsat/tables/rhnInfoPane.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnInfoPane.sql
create table rhnInfoPane (
    id      number 
            constraint rhn_info_pane_id_pk primary key,
    label   varchar2(64)
            constraint rhn_info_pane_labl_nn not null,
    acl     varchar2(4000)
)
    enable row movement
  ;
create sequence rhn_info_pane_id_seq;
create unique index rhn_info_pane_labl_uq
    on rhnInfoPane (label)
    tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnInfoPane_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnInfoPane_data.sql
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'tasks',null);
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'critical-systems',null);
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'critical-probes','show_monitoring();');
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'warning-probes','show_monitoring();');
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'system-groups-widget','org_entitlement(sw_mgr_enterprise);');
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'latest-errata',null);
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'inactive-systems',null);
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval,'pending-actions',null);
insert into RHNINFOPANE(ID,LABEL,ACL) values (rhn_info_pane_id_seq.nextval, 'recently-registered-systems', null);

select 'rhnsat/tables/rhnKSInstallType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKSInstallType_data.sql
insert into rhnKSInstallType (id, label, name)
        values (rhn_ksinstalltype_id_seq.nextval,
                'rhel_5','Red Hat Enterprise Linux 5'
        );
insert into rhnKSInstallType (id, label, name)
        values (rhn_ksinstalltype_id_seq.nextval,
                'rhel_4','Red Hat Enterprise Linux 4'
        );
insert into rhnKSInstallType (id, label, name)
        values (rhn_ksinstalltype_id_seq.nextval,
                'rhel_3','Red Hat Enterprise Linux 3'
        );
insert into rhnKSInstallType (id, label, name)
        values (rhn_ksinstalltype_id_seq.nextval,
                'rhel_2.1','Red Hat Enterprise Linux 2.1'
        );
insert into rhnKSInstallType (id, label, name)
        values (rhn_ksinstalltype_id_seq.nextval,
                'fedora_8','Fedora 8'
        );
insert into rhnKSInstallType (id, label, name)
        values (rhn_ksinstalltype_id_seq.nextval,
                'fedora_9','Fedora 9'
        );
insert into rhnKSInstallType (id, label, name)
        values (rhn_ksinstalltype_id_seq.nextval,
                'fedora_10','Fedora 10'
        );
insert into rhnKSInstallType (id, label, name)
        values (rhn_ksinstalltype_id_seq.nextval,
                'generic_rpm','Generic RPM'
        );
commit;

select 'rhnsat/tables/rhnKSTreeFile.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKSTreeFile.sql
create table
rhnKSTreeFile
(
	kstree_id		number
				constraint rhn_kstreefile_kid_nn not null
				constraint rhn_kstreefile_kid_fk
					references rhnKickstartableTree(id)
					on delete cascade,
	relative_filename	varchar2(256)
				constraint rhn_kstreefile_rfn_nn not null,
	md5sum			varchar2(64)
				constraint rhn_kstreefile_md5sum_nn not null,
	file_size		number
				constraint rhn_kstreefile_file_size_nn not null,
	last_modified		date default(sysdate)
				constraint rhn_kstreefile_lastmod_nn not null,
	created			date default(sysdate)
				constraint rhn_kstreefile_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_kstreefile_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_kstreefile_mod_trig
before insert or update on rhnKSTreeFile
for each row
begin
	:new.modified := sysdate;
	if :new.last_modified = :old.last_modified
	then
  	    :new.last_modified := sysdate;
        end if;
end rhn_kstreefile_mod_trig;
/
show errors
create unique index rhn_kstreefile_kid_rfn_uq
	on rhnKSTreeFile ( kstree_id, relative_filename )
	tablespace [[8m_tbs]]
  ;

select 'rhnsat/tables/rhnKSTreeType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKSTreeType_data.sql
insert into rhnKSTreeType (id, label, name)
        values (rhn_kstree_type_seq.nextval,
                'rhn-managed','Spacewalk managed kickstart tree'
        );
insert into rhnKSTreeType (id, label, name)
        values (rhn_kstree_type_seq.nextval,
                'externally-managed','Externally managed kickstart tree'
        );
commit;

select 'rhnsat/tables/rhnKickstartChildChannel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartChildChannel.sql
create table
rhnKickstartChildChannel
(
        channel_id   number
                         constraint rhn_ks_cc_cid_nn not null
                         constraint rhn_ks_cc_cid_fk
                                references rhnChannel(id)
                                on delete cascade,
        ksdata_id number
                        constraint rhn_ks_cc_ksd_nn not null
                        constraint rhn_ks_cc_ksd_fk
                                references rhnKSData(id)
                                on delete cascade,
        created         date default(sysdate)
                        constraint rhn_ks_cc_cre_nn not null,
        modified        date default(sysdate)
                        constraint rhn_ks_cc_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_ks_cc_uq
        on rhnKickstartChildChannel(channel_id, ksdata_id)
        tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_ks_cc_mod_trig
before insert or update on rhnKickstartChildChannel
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnKickstartCommandName.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartCommandName.sql
create table
rhnKickstartCommandName
(
        id              number
            			constraint rhn_kscommandname_id_nn not null
                        constraint rhn_kscommandname_id_pk primary key
        				using index tablespace [[2m_tbs]],
        name            varchar2(128)
		            	constraint rhn_kscommand_name_nn not null,
        uses_arguments  char(1)
                        constraint rhn_kscommandname_uses_args_nn not null
                        constraint rhn_kscommandname_uses_args_ck 
                        check (uses_arguments in ('Y','N')),
        sort_order      number
                        constraint rhn_kscommandname_sortordr_nn not null,
        required        char(1) default 'N'
                        constraint rhn_kscommandname_reqrd_nn not null
                        constraint rhn_kscommandname_reqrd_ck
                            check ( required in ('Y', 'N') )
)
	enable row movement
  ;
create sequence rhn_kscommandname_id_seq;
create index rhn_kscommandname_name_id_idx
	on rhnKickstartCommandName( name, id )
	tablespace [[2m_tbs]]
  ;
alter table rhnKickstartCommandName add constraint rhn_kscommandname_name_uq
	unique ( name );

select 'rhnsat/tables/rhnKickstartCommand.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartCommand.sql
create table
rhnKickstartCommand
(
    id                  number
                        constraint rhn_kscommand_id_pk primary key
                        using index tablespace [[4m_tbs]],
	kickstart_id		number
				constraint rhn_kscommand_ksid_nn not null
				constraint rhn_kscommand_ksid_fk
					references rhnKSData(id)
					on delete cascade,
	ks_command_name_id	number
				constraint rhn_kscommand_kcnid_nn not null
				constraint rhn_kscommand_kcnid_fk
					references rhnKickstartCommandName(id),
    	arguments               varchar2(2048),
	created			date default(sysdate)
				constraint rhn_kscommand_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_kscommand_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_kscommand_id_seq;
create index rhn_kscommand_ksid_idx
	on rhnKickstartCommand( kickstart_id )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_kscommand_mod_trig
before insert or update on rhnKickstartCommand
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnKickstartCommandName_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartCommandName_data.sql
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'deviceprobe', 'Y', 17, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'device', 'Y', 16, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'driverdisk', 'Y', 18, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'include', 'Y', 23, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'nfs', 'Y', 10, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'interactive', 'N', 2, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'harddrive', 'Y', 9, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'upgrade', 'N', 4, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'install', 'N', 3, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'lilocheck', 'N', 5, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'text', 'N', 6, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'network', 'Y', 7, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'url', 'Y', 11, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'lang', 'Y', 12, 'Y');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'langsupport', 'Y', 13, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'keyboard', 'Y', 14, 'Y');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'mouse', 'Y', 15, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'zerombr', 'Y', 19, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'clearpart', 'Y', 20, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'bootloader', 'Y', 26, 'Y');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'timezone', 'Y', 27, 'Y');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'auth', 'Y', 28, 'Y');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'reboot', 'N', 31, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'xconfig', 'Y', 32, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'partitions', 'Y', 21, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'rootpw', 'Y', 29, 'Y');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'firewall', 'Y', 31, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'skipx', 'N', 32, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'volgroups', 'Y', 24, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'logvols', 'Y', 25, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'raids', 'Y', 22, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'cdrom', 'N', 8, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'selinux', 'Y', 30, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'autostep', 'Y', 1, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'repo', 'Y', 33, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'key', 'Y', 34, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'ignoredisk', 'Y', 35, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'autopart', 'N', 36, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'cmdline', 'N', 37, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'firstboot', 'Y', 38, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'graphical', 'N', 39, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'iscsi', 'Y', 40, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'iscsiname', 'Y', 41, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'logging', 'Y', 42, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'monitor', 'Y', 43, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'multipath', 'Y', 44, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'poweroff', 'N', 45, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'halt', 'N', 46, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'services', 'Y', 47, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'shutdown', 'N', 48, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'user', 'Y', 49, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'vnc', 'Y', 50, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'zfcp', 'Y', 51, 'N');
insert into rhnKickstartCommandName (id, name, uses_arguments, sort_order, required)
values (rhn_kscommandname_id_seq.nextval, 'custom', 'Y', 52, 'N');
commit;

select 'rhnsat/tables/rhnKickstartDefaultRegToken.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartDefaultRegToken.sql
create table
rhnKickstartDefaultRegToken
(
	kickstart_id		number
				constraint rhn_ksdrt_ksid_nn not null
				constraint rhn_ksdrt_ksid_fk
					references rhnKSData(id)
					on delete cascade,
	regtoken_id		number
				constraint rhn_ksdrt_rtid_nn not null
				constraint rhn_ksdrt_rtid_fk
					references rhnRegToken(id)
					on delete cascade,
	created			date default (sysdate)
				constraint rhn_ksdrt_creat_nn not null,
	modified		date default (sysdate)
				constraint rhn_ksdrt_mod_nn not null
)
	enable row movement
  ;
create index rhn_ksdrt_ksid_rtid_idx
	on rhnKickstartDefaultRegToken( kickstart_id, regtoken_id )
	tablespace [[8m_tbs]]
  ;
create index rhn_ksdrt_rtid_idx
	on rhnKickstartDefaultRegToken( regtoken_id )
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_ksdrt_mod_trig
before insert or update on rhnKickstartDefaultRegToken
for each row
begin
	:new.modified := sysdate;
end rhn_ksdrt_mod_trig;
/
show errors

select 'rhnsat/tables/rhnKickstartDefaults.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartDefaults.sql
create table
rhnKickstartDefaults
(
        kickstart_id            number
                                constraint rhn_ksd_ksid_nn not null
                                constraint rhn_ksd_ksid_uq unique
                                constraint rhn_ksd_ksid_fk
                                        references rhnKSData(id)
                                        on delete cascade,
        kstree_id               number
                                constraint rhn_ksd_kstid_nn not null
                                constraint rhn_ksd_kstid_fk
                                        references rhnKickstartableTree(id)
                                        on delete cascade,
        server_profile_id       number
                                constraint rhn_ksd_spid_fk
                                        references rhnServerProfile(id)
                                        on delete set null,
        cfg_management_flag     char(1) default ('Y')
                                constraint rhn_ksd_cmf_nn not null
                                constraint rhn_ksd_cmf_ck
                                        check (cfg_management_flag in ('Y','N')),
        remote_command_flag    char(1) default('N')
                constraint rhn_ksd_rmf_nn not null
                constraint rhn_ksd_rmf_ck
                    check (remote_command_flag in ('Y','N')),
        virtualization_type     number
            constraint rhn_ksd_kvt_nn not null
            constraint rhn_ksd_kvt_fk
            references rhnKickstartVirtualizationType(id)
            on delete set null,
        created                 date default(sysdate)
                                    constraint rhn_ksd_created_nn not null,
        modified                date default(sysdate)
                                    constraint rhn_ksd_modified_nn not null
)
    enable row movement
  ;
create index rhn_ksd_kstid_idx
        on rhnKickstartDefaults( kstree_id )
        tablespace [[8m_tbs]]
  ;
create or replace trigger
rhn_ksd_mod_trig
before insert or update on rhnKickstartDefaults
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnKickstartIPRange.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartIPRange.sql
create table
rhnKickstartIPRange
(
        kickstart_id            number
                                constraint rhn_ksip_ksid_nn not null
                                constraint rhn_ksip_ksid_fk
                                        references rhnKSData(id)
                                        on delete cascade,
        org_id                  number
                                constraint rhn_ksip_oid_nn not null
                                constraint rhn_ksip_oid_fk
                                        references  web_customer(id)
                                        on delete cascade,
        min                     number
                                constraint rhn_ksip_min_nn not null,
        max                     number
                                constraint rhn_ksip_max_nn not null,
        created                 date default(sysdate)
                                constraint rhn_ksip_created_nn not null,
        modified                date default(sysdate)
                                constraint rhn_ksip_modified_nn not null
)
	enable row movement
  ;
create index rhn_ksip_kickstart_id_idx
        on rhnKickstartIPRange( kickstart_id )
        tablespace [[4m_tbs]]
  ;
create index rhn_ksip_org_id_idx
        on rhnKickstartIPRange( org_id )
        tablespace [[4m_tbs]]
  ;
alter table rhnKickstartIPRange add constraint rhn_ksip_oid_min_max_uq
       	unique ( org_id, min, max );
create or replace trigger
rhn_ksip_mod_trig
before insert or update on rhnKickstartIPRange
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnKickstartPackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartPackage.sql
create table
rhnKickstartPackage
(
	kickstart_id		number
				constraint rhn_kspackage_ksid_nn not null
				constraint rhn_kspackage_ksid_fk
					references rhnKSData(id)
					on delete cascade,
	package_name_id		number
				constraint rhn_kspackage_pnid_nn not null
				constraint rhn_kspackage_pnid_fk
					references rhnPackageName(id),
                    position number not null,
	created			date default(sysdate)
				constraint rhn_kspackage_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_kspackage_modified_nn not null
)
	enable row movement
  ;
create index rhn_kspackage_id_idx
	on rhnKickstartPackage( kickstart_id )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_kspackage_mod_trig
before insert or update on rhnKickstartPackage
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnKickstartPreserveFileList.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartPreserveFileList.sql
create table
rhnKickstartPreserveFileList
(
	kickstart_id	number
			constraint rhn_kspreservefl_ksid_nn not null
			constraint rhn_kspreservefl_ksid_fk
				references rhnKSData(id)
				on delete cascade,
	file_list_id	number
			constraint rhn_kspreservefl_flid_nn not null
			constraint rhn_kspreservefl_flid_fk
				references rhnFileList(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_kspreservefl_creat_nn not null,
	modified	date default (sysdate)
			constraint rhn_kspreservefl_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_kspreservefl_ksid_flid_uq
	on rhnKickstartPreserveFileList( kickstart_id, file_list_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_kspreservefl_flid_ksid_idx
	on rhnKickstartPreserveFileList( file_list_id, kickstart_id )
	tablespace [[8m_tbs]]
  ;
create or replace trigger
rhn_kspreservefl_mod_trig
before insert or update on rhnKickstartPreserveFileList
for each row
begin
	:new.modified := sysdate;
end rhn_kspreservefl_mod_trig;
/
show errors

select 'rhnsat/tables/rhnKickstartScript.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartScript.sql
create sequence rhn_ksscript_id_seq;
create table
rhnKickstartScript
(
	id			number
				constraint rhn_ksscript_id_nn not null,
	kickstart_id		number
				constraint rhn_ksscript_ksid_nn not null
				constraint rhn_ksscript_ksid_fk
					references rhnKSData(id)
					on delete cascade,
	position		number
				constraint rhn_ksscript_pos_nn not null,
	script_type		varchar2(4)
				constraint rhn_ksscript_st_nn not null
				constraint rhn_ksscript_st_ck
					check (script_type in ('pre','post')),
	chroot			char(1) default ('Y')
				constraint rhn_ksscript_chroot_nn not null
				constraint rhn_ksscript_chroot_ck
					check (chroot in ('Y','N')),
	interpreter		varchar2(80),
	data			blob,
	created			date default (sysdate)
				constraint rhn_ksscript_creat_nn not null,
	modified		date default (sysdate)
				constraint rhn_ksscript_mod_nn not null
)
	enable row movement
  ;
create index rhn_ksscript_id_idx
	on rhnKickstartScript( id )
	tablespace [[2m_tbs]]
  ;
alter table rhnKickstartScript add constraint rhn_ksscript_id_pk
	primary key ( id );
create index rhn_ksscript_ksid_pos_idx
	on rhnKickstartScript( kickstart_id, position )
	tablespace [[8m_tbs]]
  ;
alter table rhnKickstartScript add constraint rhn_ksscript_ksid_pos_uq
	unique ( kickstart_id, position );
create or replace trigger
rhn_ksscript_mod_trig
before insert or update on rhnKickstartSession
for each row
begin
	:new.modified := sysdate;
end rhn_ksscript_mod_trig;
/
show errors

select 'rhnsat/tables/rhnKickstartSessionHistory.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartSessionHistory.sql
create sequence rhn_ks_sessionhist_id_seq;
create table
rhnKickstartSessionHistory
(
	id			number
				constraint rhn_ks_sessionhist_id_nn not null
				constraint rhn_ks_sessionhist_id_pk primary key
					using index tablespace [[8m_tbs]],
	kickstart_session_id	number
				constraint rhn_ks_sessionhist_ksid_nn not null
				constraint rhn_ks_sessionhist_ksid_fk
					references rhnKickstartSession(id)
					on delete cascade,
        action_id               number
				constraint rhn_ks_sessionhist_aid_fk
					references rhnAction(id)
					on delete set null,
	state_id		number
				constraint rhn_ks_sessionhist_stat_nn not null
				constraint rhn_ks_sessionhist_stat_fk
					references rhnKickstartSessionState(id),
	time			date default(sysdate)
				constraint rhn_ks_sessionhist_time_nn not null,
	message			varchar2(4000),
	created			date default(sysdate)
				constraint rhn_ks_sessionhist_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_ks_sessionhist_mod_nn not null
)
	enable row movement
  ;
create index rhn_ks_sessionhist_ksid_idx
	on rhnKickstartSessionHistory( kickstart_session_id )
	tablespace [[8m_tbs]]
  ;
create or replace trigger
rhn_ks_sessionhist_mod_trig
before insert or update on rhnKickstartSessionHistory
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnKickstartSessionState_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartSessionState_data.sql
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Created', 'created',
        'Kickstart session created, but has not yet been used.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Deployed', 'deployed',
        'Files required for kickstart action have been installed.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Injected', 'injected',
        'The system configuration has been modified to begin kickstart upon next boot.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Restarted', 'restarted',
        'The system has been restarted in order to begin the kickstart process.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Configuration accessed', 'configuration_accessed',
        'The system has downloaded the kickstart configuraton file from Spacewalk.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Started', 'started',
        'The initial files required for anaconda have been downloaded.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'In Progress', 'in_progress',
        'The system is downloading the RPMs required to install.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Registration Complete', 'registered',
        'The system has successfully registered with Spacewalk after kickstarting.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Package Synch', 'package_synch',
        'Package synchronization in progress.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Package Synch Scheduled', 
        'package_synch_scheduled', 'Package synchronization scheduled.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Configuration Deployment', 
        'configuration_deploy', 'Configuration files are being deployed.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Complete', 'complete',
        'Kickstart complete.'
       );
insert
  into rhnKickstartSessionState
       (id, name, label, description)
values (rhn_ks_session_state_id_seq.nextval, 'Failed', 'failed',
        'Kickstart failed.'
       );
commit;

select 'rhnsat/tables/rhnKickstartSession_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartSession_triggers.sql
create or replace trigger
rhn_ks_session_mod_trig
before insert or update on rhnKickstartSession
for each row
begin
	:new.modified := sysdate;
end;
/
show errors
create or replace trigger
rhn_ks_session_history_trigger
after insert or update on rhnKickstartSession
for each row
begin
	if inserting or (updating and :new.state_id != :old.state_id) then
		insert into rhnKickstartSessionHistory (
				id, kickstart_session_id, action_id, state_id
			) values (
				rhn_ks_sessionhist_id_seq.nextval,
				:new.id,
				:new.action_id,
				:new.state_id
			);
	end if;
end;
/
show errors

select 'rhnsat/tables/rhnKickstartTimezone.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartTimezone.sql
create table
rhnKickstartTimezone
(
	id			number
				constraint rhn_ks_timezone_id_nn not null
				constraint rhn_ks_timezone_pk primary key
					using index tablespace [[64k_tbs]],
	label			varchar2(128)
				constraint rhn_ks_timezone_label_nn not null,
	name			varchar2(128)
				constraint rhn_ks_timezone_name_nn not null,
	install_type            number
				constraint rhn_ks_timezone_it_nn not null
				constraint rhn_ks_timezone_it_fk
				    references rhnKSInstallType(id)
)
	enable row movement
  ;
create sequence rhn_ks_timezone_id_seq;
create unique index rhn_ks_timezone_it_label_uq
	on rhnKickstartTimezone(install_type, label)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_ks_timezone_it_name_uq
	on rhnKickstartTimezone(install_type, name)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnKickstartTimezone_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartTimezone_data.sql
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Andorra',
	    	'Europe/Andorra',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dubai',
	    	'Asia/Dubai',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kabul',
	    	'Asia/Kabul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Antigua',
	    	'America/Antigua',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Anguilla',
	    	'America/Anguilla',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Tirane',
	    	'Europe/Tirane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Yerevan',
	    	'Asia/Yerevan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Curacao',
	    	'America/Curacao',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Luanda',
	    	'Africa/Luanda',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/McMurdo',
	    	'Antarctica/McMurdo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/South_Pole',
	    	'Antarctica/South_Pole',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Palmer',
	    	'Antarctica/Palmer',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Mawson',
	    	'Antarctica/Mawson',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Davis',
	    	'Antarctica/Davis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Casey',
	    	'Antarctica/Casey',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Vostok',
	    	'Antarctica/Vostok',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/DumontDUrville',
	    	'Antarctica/DumontDUrville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Syowa',
	    	'Antarctica/Syowa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Buenos_Aires',
	    	'America/Buenos_Aires',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cordoba',
	    	'America/Cordoba',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Jujuy',
	    	'America/Jujuy',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Catamarca',
	    	'America/Catamarca',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Mendoza',
	    	'America/Mendoza',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Pago_Pago',
	    	'Pacific/Pago_Pago',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vienna',
	    	'Europe/Vienna',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Lord_Howe',
	    	'Australia/Lord_Howe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Hobart',
	    	'Australia/Hobart',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Melbourne',
	    	'Australia/Melbourne',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Sydney',
	    	'Australia/Sydney',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Broken_Hill',
	    	'Australia/Broken_Hill',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Brisbane',
	    	'Australia/Brisbane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Lindeman',
	    	'Australia/Lindeman',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Adelaide',
	    	'Australia/Adelaide',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Darwin',
	    	'Australia/Darwin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Perth',
	    	'Australia/Perth',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Aruba',
	    	'America/Aruba',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Baku',
	    	'Asia/Baku',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Sarajevo',
	    	'Europe/Sarajevo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Barbados',
	    	'America/Barbados',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dhaka',
	    	'Asia/Dhaka',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Brussels',
	    	'Europe/Brussels',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Ouagadougou',
	    	'Africa/Ouagadougou',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Sofia',
	    	'Europe/Sofia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Bahrain',
	    	'Asia/Bahrain',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bujumbura',
	    	'Africa/Bujumbura',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Porto-Novo',
	    	'Africa/Porto-Novo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Bermuda',
	    	'Atlantic/Bermuda',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Brunei',
	    	'Asia/Brunei',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/La_Paz',
	    	'America/La_Paz',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Noronha',
	    	'America/Noronha',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Belem',
	    	'America/Belem',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Fortaleza',
	    	'America/Fortaleza',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Recife',
	    	'America/Recife',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Araguaina',
	    	'America/Araguaina',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Maceio',
	    	'America/Maceio',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Sao_Paulo',
	    	'America/Sao_Paulo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cuiaba',
	    	'America/Cuiaba',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Porto_Velho',
	    	'America/Porto_Velho',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Boa_Vista',
	    	'America/Boa_Vista',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Manaus',
	    	'America/Manaus',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Eirunepe',
	    	'America/Eirunepe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Rio_Branco',
	    	'America/Rio_Branco',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Nassau',
	    	'America/Nassau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Thimphu',
	    	'Asia/Thimphu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Gaborone',
	    	'Africa/Gaborone',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Minsk',
	    	'Europe/Minsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Belize',
	    	'America/Belize',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Johns',
	    	'America/St_Johns',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Halifax',
	    	'America/Halifax',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Glace_Bay',
	    	'America/Glace_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Goose_Bay',
	    	'America/Goose_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Montreal',
	    	'America/Montreal',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Nipigon',
	    	'America/Nipigon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Thunder_Bay',
	    	'America/Thunder_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Pangnirtung',
	    	'America/Pangnirtung',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Iqaluit',
	    	'America/Iqaluit',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Rankin_Inlet',
	    	'America/Rankin_Inlet',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Winnipeg',
	    	'America/Winnipeg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Rainy_River',
	    	'America/Rainy_River',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cambridge_Bay',
	    	'America/Cambridge_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Regina',
	    	'America/Regina',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Swift_Current',
	    	'America/Swift_Current',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Edmonton',
	    	'America/Edmonton',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Yellowknife',
	    	'America/Yellowknife',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Inuvik',
	    	'America/Inuvik',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Dawson_Creek',
	    	'America/Dawson_Creek',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Vancouver',
	    	'America/Vancouver',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Whitehorse',
	    	'America/Whitehorse',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Dawson',
	    	'America/Dawson',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Cocos',
	    	'Indian/Cocos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Kinshasa',
	    	'Africa/Kinshasa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lubumbashi',
	    	'Africa/Lubumbashi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bangui',
	    	'Africa/Bangui',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Brazzaville',
	    	'Africa/Brazzaville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Zurich',
	    	'Europe/Zurich',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Abidjan',
	    	'Africa/Abidjan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Rarotonga',
	    	'Pacific/Rarotonga',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Santiago',
	    	'America/Santiago',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Easter',
	    	'Pacific/Easter',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Douala',
	    	'Africa/Douala',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Shanghai',
	    	'Asia/Shanghai',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Harbin',
	    	'Asia/Harbin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Chongqing',
	    	'Asia/Chongqing',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Urumqi',
	    	'Asia/Urumqi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kashgar',
	    	'Asia/Kashgar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Bogota',
	    	'America/Bogota',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Costa_Rica',
	    	'America/Costa_Rica',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Havana',
	    	'America/Havana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Cape_Verde',
	    	'Atlantic/Cape_Verde',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Christmas',
	    	'Indian/Christmas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Nicosia',
	    	'Asia/Nicosia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Prague',
	    	'Europe/Prague',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Berlin',
	    	'Europe/Berlin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Djibouti',
	    	'Africa/Djibouti',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Copenhagen',
	    	'Europe/Copenhagen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Dominica',
	    	'America/Dominica',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Santo_Domingo',
	    	'America/Santo_Domingo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Algiers',
	    	'Africa/Algiers',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guayaquil',
	    	'America/Guayaquil',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Galapagos',
	    	'Pacific/Galapagos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Tallinn',
	    	'Europe/Tallinn',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Cairo',
	    	'Africa/Cairo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/El_Aaiun',
	    	'Africa/El_Aaiun',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Asmera',
	    	'Africa/Asmera',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Madrid',
	    	'Europe/Madrid',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Ceuta',
	    	'Africa/Ceuta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Canary',
	    	'Atlantic/Canary',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Addis_Ababa',
	    	'Africa/Addis_Ababa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Helsinki',
	    	'Europe/Helsinki',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Fiji',
	    	'Pacific/Fiji',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Stanley',
	    	'Atlantic/Stanley',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Yap',
	    	'Pacific/Yap',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Truk',
	    	'Pacific/Truk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Ponape',
	    	'Pacific/Ponape',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Kosrae',
	    	'Pacific/Kosrae',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Faeroe',
	    	'Atlantic/Faeroe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Paris',
	    	'Europe/Paris',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Libreville',
	    	'Africa/Libreville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/London',
	    	'Europe/London',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Belfast',
	    	'Europe/Belfast',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Grenada',
	    	'America/Grenada',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tbilisi',
	    	'Asia/Tbilisi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cayenne',
	    	'America/Cayenne',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Accra',
	    	'Africa/Accra',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Gibraltar',
	    	'Europe/Gibraltar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Godthab',
	    	'America/Godthab',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Danmarkshavn',
	    	'America/Danmarkshavn',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Scoresbysund',
	    	'America/Scoresbysund',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Thule',
	    	'America/Thule',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Banjul',
	    	'Africa/Banjul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Conakry',
	    	'Africa/Conakry',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guadeloupe',
	    	'America/Guadeloupe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Malabo',
	    	'Africa/Malabo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Athens',
	    	'Europe/Athens',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/South_Georgia',
	    	'Atlantic/South_Georgia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guatemala',
	    	'America/Guatemala',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Guam',
	    	'Pacific/Guam',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bissau',
	    	'Africa/Bissau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guyana',
	    	'America/Guyana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Hong_Kong',
	    	'Asia/Hong_Kong',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Tegucigalpa',
	    	'America/Tegucigalpa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Zagreb',
	    	'Europe/Zagreb',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Port-au-Prince',
	    	'America/Port-au-Prince',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Budapest',
	    	'Europe/Budapest',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Jakarta',
	    	'Asia/Jakarta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Pontianak',
	    	'Asia/Pontianak',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Makassar',
	    	'Asia/Makassar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Jayapura',
	    	'Asia/Jayapura',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Dublin',
	    	'Europe/Dublin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Jerusalem',
	    	'Asia/Jerusalem',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Calcutta',
	    	'Asia/Calcutta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Chagos',
	    	'Indian/Chagos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Baghdad',
	    	'Asia/Baghdad',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tehran',
	    	'Asia/Tehran',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Reykjavik',
	    	'Atlantic/Reykjavik',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Rome',
	    	'Europe/Rome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Jamaica',
	    	'America/Jamaica',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Amman',
	    	'Asia/Amman',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tokyo',
	    	'Asia/Tokyo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Nairobi',
	    	'Africa/Nairobi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Bishkek',
	    	'Asia/Bishkek',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Phnom_Penh',
	    	'Asia/Phnom_Penh',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Tarawa',
	    	'Pacific/Tarawa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Enderbury',
	    	'Pacific/Enderbury',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Kiritimati',
	    	'Pacific/Kiritimati',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Comoro',
	    	'Indian/Comoro',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Kitts',
	    	'America/St_Kitts',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Pyongyang',
	    	'Asia/Pyongyang',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Seoul',
	    	'Asia/Seoul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kuwait',
	    	'Asia/Kuwait',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cayman',
	    	'America/Cayman',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Almaty',
	    	'Asia/Almaty',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Qyzylorda',
	    	'Asia/Qyzylorda',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Aqtobe',
	    	'Asia/Aqtobe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Aqtau',
	    	'Asia/Aqtau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Oral',
	    	'Asia/Oral',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Vientiane',
	    	'Asia/Vientiane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Beirut',
	    	'Asia/Beirut',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Lucia',
	    	'America/St_Lucia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vaduz',
	    	'Europe/Vaduz',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Colombo',
	    	'Asia/Colombo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Monrovia',
	    	'Africa/Monrovia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Maseru',
	    	'Africa/Maseru',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vilnius',
	    	'Europe/Vilnius',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Luxembourg',
	    	'Europe/Luxembourg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Riga',
	    	'Europe/Riga',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Tripoli',
	    	'Africa/Tripoli',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Casablanca',
	    	'Africa/Casablanca',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Monaco',
	    	'Europe/Monaco',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Chisinau',
	    	'Europe/Chisinau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Antananarivo',
	    	'Indian/Antananarivo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Majuro',
	    	'Pacific/Majuro',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Kwajalein',
	    	'Pacific/Kwajalein',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Skopje',
	    	'Europe/Skopje',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bamako',
	    	'Africa/Bamako',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Timbuktu',
	    	'Africa/Timbuktu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Rangoon',
	    	'Asia/Rangoon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Ulaanbaatar',
	    	'Asia/Ulaanbaatar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Hovd',
	    	'Asia/Hovd',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Choibalsan',
	    	'Asia/Choibalsan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Macau',
	    	'Asia/Macau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Saipan',
	    	'Pacific/Saipan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Martinique',
	    	'America/Martinique',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Nouakchott',
	    	'Africa/Nouakchott',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Montserrat',
	    	'America/Montserrat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Malta',
	    	'Europe/Malta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Mauritius',
	    	'Indian/Mauritius',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Maldives',
	    	'Indian/Maldives',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Blantyre',
	    	'Africa/Blantyre',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Mexico_City',
	    	'America/Mexico_City',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cancun',
	    	'America/Cancun',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Merida',
	    	'America/Merida',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Monterrey',
	    	'America/Monterrey',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Mazatlan',
	    	'America/Mazatlan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Chihuahua',
	    	'America/Chihuahua',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Hermosillo',
	    	'America/Hermosillo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Tijuana',
	    	'America/Tijuana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kuala_Lumpur',
	    	'Asia/Kuala_Lumpur',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kuching',
	    	'Asia/Kuching',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Maputo',
	    	'Africa/Maputo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Windhoek',
	    	'Africa/Windhoek',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Noumea',
	    	'Pacific/Noumea',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Niamey',
	    	'Africa/Niamey',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Norfolk',
	    	'Pacific/Norfolk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lagos',
	    	'Africa/Lagos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Managua',
	    	'America/Managua',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Amsterdam',
	    	'Europe/Amsterdam',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Oslo',
	    	'Europe/Oslo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Katmandu',
	    	'Asia/Katmandu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Nauru',
	    	'Pacific/Nauru',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Niue',
	    	'Pacific/Niue',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Auckland',
	    	'Pacific/Auckland',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Chatham',
	    	'Pacific/Chatham',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Muscat',
	    	'Asia/Muscat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Panama',
	    	'America/Panama',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Lima',
	    	'America/Lima',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Tahiti',
	    	'Pacific/Tahiti',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Marquesas',
	    	'Pacific/Marquesas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Gambier',
	    	'Pacific/Gambier',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Port_Moresby',
	    	'Pacific/Port_Moresby',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Manila',
	    	'Asia/Manila',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Karachi',
	    	'Asia/Karachi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Warsaw',
	    	'Europe/Warsaw',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Miquelon',
	    	'America/Miquelon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Pitcairn',
	    	'Pacific/Pitcairn',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Puerto_Rico',
	    	'America/Puerto_Rico',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Gaza',
	    	'Asia/Gaza',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Lisbon',
	    	'Europe/Lisbon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Madeira',
	    	'Atlantic/Madeira',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Azores',
	    	'Atlantic/Azores',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Palau',
	    	'Pacific/Palau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Asuncion',
	    	'America/Asuncion',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Qatar',
	    	'Asia/Qatar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Reunion',
	    	'Indian/Reunion',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Bucharest',
	    	'Europe/Bucharest',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Kaliningrad',
	    	'Europe/Kaliningrad',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Moscow',
	    	'Europe/Moscow',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Samara',
	    	'Europe/Samara',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Yekaterinburg',
	    	'Asia/Yekaterinburg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Omsk',
	    	'Asia/Omsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Novosibirsk',
	    	'Asia/Novosibirsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Krasnoyarsk',
	    	'Asia/Krasnoyarsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Irkutsk',
	    	'Asia/Irkutsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Yakutsk',
	    	'Asia/Yakutsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Vladivostok',
	    	'Asia/Vladivostok',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Sakhalin',
	    	'Asia/Sakhalin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Magadan',
	    	'Asia/Magadan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kamchatka',
	    	'Asia/Kamchatka',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Anadyr',
	    	'Asia/Anadyr',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Kigali',
	    	'Africa/Kigali',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Riyadh',
	    	'Asia/Riyadh',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Guadalcanal',
	    	'Pacific/Guadalcanal',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Mahe',
	    	'Indian/Mahe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Khartoum',
	    	'Africa/Khartoum',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Stockholm',
	    	'Europe/Stockholm',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Singapore',
	    	'Asia/Singapore',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/St_Helena',
	    	'Atlantic/St_Helena',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Ljubljana',
	    	'Europe/Ljubljana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Arctic/Longyearbyen',
	    	'Arctic/Longyearbyen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Jan_Mayen',
	    	'Atlantic/Jan_Mayen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Bratislava',
	    	'Europe/Bratislava',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Freetown',
	    	'Africa/Freetown',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/San_Marino',
	    	'Europe/San_Marino',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Dakar',
	    	'Africa/Dakar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Mogadishu',
	    	'Africa/Mogadishu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Paramaribo',
	    	'America/Paramaribo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Sao_Tome',
	    	'Africa/Sao_Tome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/El_Salvador',
	    	'America/El_Salvador',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Damascus',
	    	'Asia/Damascus',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Mbabane',
	    	'Africa/Mbabane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Grand_Turk',
	    	'America/Grand_Turk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Ndjamena',
	    	'Africa/Ndjamena',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Kerguelen',
	    	'Indian/Kerguelen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lome',
	    	'Africa/Lome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Bangkok',
	    	'Asia/Bangkok',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dushanbe',
	    	'Asia/Dushanbe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Fakaofo',
	    	'Pacific/Fakaofo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Ashgabat',
	    	'Asia/Ashgabat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Tunis',
	    	'Africa/Tunis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Tongatapu',
	    	'Pacific/Tongatapu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dili',
	    	'Asia/Dili',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Istanbul',
	    	'Europe/Istanbul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Port_of_Spain',
	    	'America/Port_of_Spain',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Funafuti',
	    	'Pacific/Funafuti',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Taipei',
	    	'Asia/Taipei',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Dar_es_Salaam',
	    	'Africa/Dar_es_Salaam',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Kiev',
	    	'Europe/Kiev',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Uzhgorod',
	    	'Europe/Uzhgorod',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Zaporozhye',
	    	'Europe/Zaporozhye',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Simferopol',
	    	'Europe/Simferopol',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Kampala',
	    	'Africa/Kampala',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Johnston',
	    	'Pacific/Johnston',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Midway',
	    	'Pacific/Midway',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Wake',
	    	'Pacific/Wake',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/New_York',
	    	'America/New_York',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Detroit',
	    	'America/Detroit',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Louisville',
	    	'America/Louisville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Kentucky/Monticello',
	    	'America/Kentucky/Monticello',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indianapolis',
	    	'America/Indianapolis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indiana/Marengo',
	    	'America/Indiana/Marengo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indiana/Knox',
	    	'America/Indiana/Knox',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indiana/Vevay',
	    	'America/Indiana/Vevay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Chicago',
	    	'America/Chicago',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Menominee',
	    	'America/Menominee',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/North_Dakota/Center',
	    	'America/North_Dakota/Center',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Denver',
	    	'America/Denver',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Boise',
	    	'America/Boise',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Shiprock',
	    	'America/Shiprock',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Phoenix',
	    	'America/Phoenix',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Los_Angeles',
	    	'America/Los_Angeles',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Anchorage',
	    	'America/Anchorage',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Juneau',
	    	'America/Juneau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Yakutat',
	    	'America/Yakutat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Nome',
	    	'America/Nome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Adak',
	    	'America/Adak',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Honolulu',
	    	'Pacific/Honolulu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Montevideo',
	    	'America/Montevideo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Samarkand',
	    	'Asia/Samarkand',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tashkent',
	    	'Asia/Tashkent',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vatican',
	    	'Europe/Vatican',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Vincent',
	    	'America/St_Vincent',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Caracas',
	    	'America/Caracas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Tortola',
	    	'America/Tortola',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Thomas',
	    	'America/St_Thomas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Saigon',
	    	'Asia/Saigon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Efate',
	    	'Pacific/Efate',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Wallis',
	    	'Pacific/Wallis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Apia',
	    	'Pacific/Apia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Aden',
	    	'Asia/Aden',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Mayotte',
	    	'Indian/Mayotte',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Belgrade',
	    	'Europe/Belgrade',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Johannesburg',
	    	'Africa/Johannesburg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lusaka',
	    	'Africa/Lusaka',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Harare',
	    	'Africa/Harare',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Toronto',
	    	'America/Toronto',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_2.1')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Andorra',
	    	'Europe/Andorra',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dubai',
	    	'Asia/Dubai',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kabul',
	    	'Asia/Kabul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Antigua',
	    	'America/Antigua',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Anguilla',
	    	'America/Anguilla',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Tirane',
	    	'Europe/Tirane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Yerevan',
	    	'Asia/Yerevan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Curacao',
	    	'America/Curacao',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Luanda',
	    	'Africa/Luanda',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/McMurdo',
	    	'Antarctica/McMurdo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/South_Pole',
	    	'Antarctica/South_Pole',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Palmer',
	    	'Antarctica/Palmer',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Mawson',
	    	'Antarctica/Mawson',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Davis',
	    	'Antarctica/Davis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Casey',
	    	'Antarctica/Casey',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Vostok',
	    	'Antarctica/Vostok',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/DumontDUrville',
	    	'Antarctica/DumontDUrville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Syowa',
	    	'Antarctica/Syowa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Buenos_Aires',
	    	'America/Buenos_Aires',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cordoba',
	    	'America/Cordoba',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Jujuy',
	    	'America/Jujuy',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Catamarca',
	    	'America/Catamarca',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Mendoza',
	    	'America/Mendoza',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Pago_Pago',
	    	'Pacific/Pago_Pago',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vienna',
	    	'Europe/Vienna',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Lord_Howe',
	    	'Australia/Lord_Howe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Hobart',
	    	'Australia/Hobart',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Melbourne',
	    	'Australia/Melbourne',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Sydney',
	    	'Australia/Sydney',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Broken_Hill',
	    	'Australia/Broken_Hill',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Brisbane',
	    	'Australia/Brisbane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Lindeman',
	    	'Australia/Lindeman',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Adelaide',
	    	'Australia/Adelaide',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Darwin',
	    	'Australia/Darwin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Perth',
	    	'Australia/Perth',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Aruba',
	    	'America/Aruba',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Baku',
	    	'Asia/Baku',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Sarajevo',
	    	'Europe/Sarajevo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Barbados',
	    	'America/Barbados',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dhaka',
	    	'Asia/Dhaka',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Brussels',
	    	'Europe/Brussels',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Ouagadougou',
	    	'Africa/Ouagadougou',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Sofia',
	    	'Europe/Sofia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Bahrain',
	    	'Asia/Bahrain',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bujumbura',
	    	'Africa/Bujumbura',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Porto-Novo',
	    	'Africa/Porto-Novo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Bermuda',
	    	'Atlantic/Bermuda',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Brunei',
	    	'Asia/Brunei',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/La_Paz',
	    	'America/La_Paz',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Noronha',
	    	'America/Noronha',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Belem',
	    	'America/Belem',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Fortaleza',
	    	'America/Fortaleza',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Recife',
	    	'America/Recife',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Araguaina',
	    	'America/Araguaina',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Maceio',
	    	'America/Maceio',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Sao_Paulo',
	    	'America/Sao_Paulo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cuiaba',
	    	'America/Cuiaba',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Porto_Velho',
	    	'America/Porto_Velho',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Boa_Vista',
	    	'America/Boa_Vista',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Manaus',
	    	'America/Manaus',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Eirunepe',
	    	'America/Eirunepe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Rio_Branco',
	    	'America/Rio_Branco',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Nassau',
	    	'America/Nassau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Thimphu',
	    	'Asia/Thimphu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Gaborone',
	    	'Africa/Gaborone',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Minsk',
	    	'Europe/Minsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Belize',
	    	'America/Belize',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Johns',
	    	'America/St_Johns',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Halifax',
	    	'America/Halifax',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Glace_Bay',
	    	'America/Glace_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Goose_Bay',
	    	'America/Goose_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Montreal',
	    	'America/Montreal',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Nipigon',
	    	'America/Nipigon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Thunder_Bay',
	    	'America/Thunder_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Pangnirtung',
	    	'America/Pangnirtung',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Iqaluit',
	    	'America/Iqaluit',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Rankin_Inlet',
	    	'America/Rankin_Inlet',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Winnipeg',
	    	'America/Winnipeg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Rainy_River',
	    	'America/Rainy_River',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cambridge_Bay',
	    	'America/Cambridge_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Regina',
	    	'America/Regina',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Swift_Current',
	    	'America/Swift_Current',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Edmonton',
	    	'America/Edmonton',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Yellowknife',
	    	'America/Yellowknife',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Inuvik',
	    	'America/Inuvik',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Dawson_Creek',
	    	'America/Dawson_Creek',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Vancouver',
	    	'America/Vancouver',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Whitehorse',
	    	'America/Whitehorse',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Dawson',
	    	'America/Dawson',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Cocos',
	    	'Indian/Cocos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Kinshasa',
	    	'Africa/Kinshasa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lubumbashi',
	    	'Africa/Lubumbashi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bangui',
	    	'Africa/Bangui',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Brazzaville',
	    	'Africa/Brazzaville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Zurich',
	    	'Europe/Zurich',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Abidjan',
	    	'Africa/Abidjan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Rarotonga',
	    	'Pacific/Rarotonga',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Santiago',
	    	'America/Santiago',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Easter',
	    	'Pacific/Easter',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Douala',
	    	'Africa/Douala',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Shanghai',
	    	'Asia/Shanghai',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Harbin',
	    	'Asia/Harbin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Chongqing',
	    	'Asia/Chongqing',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Urumqi',
	    	'Asia/Urumqi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kashgar',
	    	'Asia/Kashgar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Bogota',
	    	'America/Bogota',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Costa_Rica',
	    	'America/Costa_Rica',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Havana',
	    	'America/Havana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Cape_Verde',
	    	'Atlantic/Cape_Verde',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Christmas',
	    	'Indian/Christmas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Nicosia',
	    	'Asia/Nicosia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Prague',
	    	'Europe/Prague',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Berlin',
	    	'Europe/Berlin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Djibouti',
	    	'Africa/Djibouti',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Copenhagen',
	    	'Europe/Copenhagen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Dominica',
	    	'America/Dominica',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Santo_Domingo',
	    	'America/Santo_Domingo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Algiers',
	    	'Africa/Algiers',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guayaquil',
	    	'America/Guayaquil',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Galapagos',
	    	'Pacific/Galapagos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Tallinn',
	    	'Europe/Tallinn',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Cairo',
	    	'Africa/Cairo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/El_Aaiun',
	    	'Africa/El_Aaiun',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Asmera',
	    	'Africa/Asmera',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Madrid',
	    	'Europe/Madrid',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Ceuta',
	    	'Africa/Ceuta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Canary',
	    	'Atlantic/Canary',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Addis_Ababa',
	    	'Africa/Addis_Ababa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Helsinki',
	    	'Europe/Helsinki',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Fiji',
	    	'Pacific/Fiji',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Stanley',
	    	'Atlantic/Stanley',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Yap',
	    	'Pacific/Yap',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Truk',
	    	'Pacific/Truk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Ponape',
	    	'Pacific/Ponape',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Kosrae',
	    	'Pacific/Kosrae',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Faeroe',
	    	'Atlantic/Faeroe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Paris',
	    	'Europe/Paris',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Libreville',
	    	'Africa/Libreville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/London',
	    	'Europe/London',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Belfast',
	    	'Europe/Belfast',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Grenada',
	    	'America/Grenada',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tbilisi',
	    	'Asia/Tbilisi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cayenne',
	    	'America/Cayenne',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Accra',
	    	'Africa/Accra',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Gibraltar',
	    	'Europe/Gibraltar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Godthab',
	    	'America/Godthab',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Danmarkshavn',
	    	'America/Danmarkshavn',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Scoresbysund',
	    	'America/Scoresbysund',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Thule',
	    	'America/Thule',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Banjul',
	    	'Africa/Banjul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Conakry',
	    	'Africa/Conakry',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guadeloupe',
	    	'America/Guadeloupe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Malabo',
	    	'Africa/Malabo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Athens',
	    	'Europe/Athens',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/South_Georgia',
	    	'Atlantic/South_Georgia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guatemala',
	    	'America/Guatemala',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Guam',
	    	'Pacific/Guam',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bissau',
	    	'Africa/Bissau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guyana',
	    	'America/Guyana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Hong_Kong',
	    	'Asia/Hong_Kong',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Tegucigalpa',
	    	'America/Tegucigalpa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Zagreb',
	    	'Europe/Zagreb',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Port-au-Prince',
	    	'America/Port-au-Prince',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Budapest',
	    	'Europe/Budapest',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Jakarta',
	    	'Asia/Jakarta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Pontianak',
	    	'Asia/Pontianak',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Makassar',
	    	'Asia/Makassar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Jayapura',
	    	'Asia/Jayapura',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Dublin',
	    	'Europe/Dublin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Jerusalem',
	    	'Asia/Jerusalem',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Calcutta',
	    	'Asia/Calcutta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Chagos',
	    	'Indian/Chagos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Baghdad',
	    	'Asia/Baghdad',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tehran',
	    	'Asia/Tehran',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Reykjavik',
	    	'Atlantic/Reykjavik',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Rome',
	    	'Europe/Rome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Jamaica',
	    	'America/Jamaica',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Amman',
	    	'Asia/Amman',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tokyo',
	    	'Asia/Tokyo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Nairobi',
	    	'Africa/Nairobi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Bishkek',
	    	'Asia/Bishkek',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Phnom_Penh',
	    	'Asia/Phnom_Penh',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Tarawa',
	    	'Pacific/Tarawa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Enderbury',
	    	'Pacific/Enderbury',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Kiritimati',
	    	'Pacific/Kiritimati',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Comoro',
	    	'Indian/Comoro',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Kitts',
	    	'America/St_Kitts',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Pyongyang',
	    	'Asia/Pyongyang',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Seoul',
	    	'Asia/Seoul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kuwait',
	    	'Asia/Kuwait',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cayman',
	    	'America/Cayman',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Almaty',
	    	'Asia/Almaty',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Qyzylorda',
	    	'Asia/Qyzylorda',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Aqtobe',
	    	'Asia/Aqtobe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Aqtau',
	    	'Asia/Aqtau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Oral',
	    	'Asia/Oral',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Vientiane',
	    	'Asia/Vientiane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Beirut',
	    	'Asia/Beirut',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Lucia',
	    	'America/St_Lucia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vaduz',
	    	'Europe/Vaduz',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Colombo',
	    	'Asia/Colombo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Monrovia',
	    	'Africa/Monrovia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Maseru',
	    	'Africa/Maseru',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vilnius',
	    	'Europe/Vilnius',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Luxembourg',
	    	'Europe/Luxembourg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Riga',
	    	'Europe/Riga',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Tripoli',
	    	'Africa/Tripoli',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Casablanca',
	    	'Africa/Casablanca',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Monaco',
	    	'Europe/Monaco',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Chisinau',
	    	'Europe/Chisinau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Antananarivo',
	    	'Indian/Antananarivo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Majuro',
	    	'Pacific/Majuro',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Kwajalein',
	    	'Pacific/Kwajalein',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Skopje',
	    	'Europe/Skopje',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bamako',
	    	'Africa/Bamako',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Timbuktu',
	    	'Africa/Timbuktu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Rangoon',
	    	'Asia/Rangoon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Ulaanbaatar',
	    	'Asia/Ulaanbaatar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Hovd',
	    	'Asia/Hovd',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Choibalsan',
	    	'Asia/Choibalsan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Macau',
	    	'Asia/Macau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Saipan',
	    	'Pacific/Saipan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Martinique',
	    	'America/Martinique',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Nouakchott',
	    	'Africa/Nouakchott',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Montserrat',
	    	'America/Montserrat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Malta',
	    	'Europe/Malta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Mauritius',
	    	'Indian/Mauritius',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Maldives',
	    	'Indian/Maldives',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Blantyre',
	    	'Africa/Blantyre',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Mexico_City',
	    	'America/Mexico_City',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cancun',
	    	'America/Cancun',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Merida',
	    	'America/Merida',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Monterrey',
	    	'America/Monterrey',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Mazatlan',
	    	'America/Mazatlan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Chihuahua',
	    	'America/Chihuahua',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Hermosillo',
	    	'America/Hermosillo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Tijuana',
	    	'America/Tijuana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kuala_Lumpur',
	    	'Asia/Kuala_Lumpur',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kuching',
	    	'Asia/Kuching',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Maputo',
	    	'Africa/Maputo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Windhoek',
	    	'Africa/Windhoek',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Noumea',
	    	'Pacific/Noumea',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Niamey',
	    	'Africa/Niamey',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Norfolk',
	    	'Pacific/Norfolk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lagos',
	    	'Africa/Lagos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Managua',
	    	'America/Managua',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Amsterdam',
	    	'Europe/Amsterdam',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Oslo',
	    	'Europe/Oslo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Katmandu',
	    	'Asia/Katmandu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Nauru',
	    	'Pacific/Nauru',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Niue',
	    	'Pacific/Niue',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Auckland',
	    	'Pacific/Auckland',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Chatham',
	    	'Pacific/Chatham',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Muscat',
	    	'Asia/Muscat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Panama',
	    	'America/Panama',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Lima',
	    	'America/Lima',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Tahiti',
	    	'Pacific/Tahiti',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Marquesas',
	    	'Pacific/Marquesas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Gambier',
	    	'Pacific/Gambier',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Port_Moresby',
	    	'Pacific/Port_Moresby',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Manila',
	    	'Asia/Manila',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Karachi',
	    	'Asia/Karachi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Warsaw',
	    	'Europe/Warsaw',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Miquelon',
	    	'America/Miquelon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Pitcairn',
	    	'Pacific/Pitcairn',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Puerto_Rico',
	    	'America/Puerto_Rico',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Gaza',
	    	'Asia/Gaza',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Lisbon',
	    	'Europe/Lisbon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Madeira',
	    	'Atlantic/Madeira',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Azores',
	    	'Atlantic/Azores',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Palau',
	    	'Pacific/Palau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Asuncion',
	    	'America/Asuncion',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Qatar',
	    	'Asia/Qatar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Reunion',
	    	'Indian/Reunion',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Bucharest',
	    	'Europe/Bucharest',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Kaliningrad',
	    	'Europe/Kaliningrad',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Moscow',
	    	'Europe/Moscow',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Samara',
	    	'Europe/Samara',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Yekaterinburg',
	    	'Asia/Yekaterinburg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Omsk',
	    	'Asia/Omsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Novosibirsk',
	    	'Asia/Novosibirsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Krasnoyarsk',
	    	'Asia/Krasnoyarsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Irkutsk',
	    	'Asia/Irkutsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Yakutsk',
	    	'Asia/Yakutsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Vladivostok',
	    	'Asia/Vladivostok',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Sakhalin',
	    	'Asia/Sakhalin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Magadan',
	    	'Asia/Magadan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kamchatka',
	    	'Asia/Kamchatka',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Anadyr',
	    	'Asia/Anadyr',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Kigali',
	    	'Africa/Kigali',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Riyadh',
	    	'Asia/Riyadh',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Guadalcanal',
	    	'Pacific/Guadalcanal',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Mahe',
	    	'Indian/Mahe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Khartoum',
	    	'Africa/Khartoum',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Stockholm',
	    	'Europe/Stockholm',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Singapore',
	    	'Asia/Singapore',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/St_Helena',
	    	'Atlantic/St_Helena',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Ljubljana',
	    	'Europe/Ljubljana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Arctic/Longyearbyen',
	    	'Arctic/Longyearbyen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Jan_Mayen',
	    	'Atlantic/Jan_Mayen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Bratislava',
	    	'Europe/Bratislava',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Freetown',
	    	'Africa/Freetown',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/San_Marino',
	    	'Europe/San_Marino',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Dakar',
	    	'Africa/Dakar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Mogadishu',
	    	'Africa/Mogadishu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Paramaribo',
	    	'America/Paramaribo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Sao_Tome',
	    	'Africa/Sao_Tome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/El_Salvador',
	    	'America/El_Salvador',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Damascus',
	    	'Asia/Damascus',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Mbabane',
	    	'Africa/Mbabane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Grand_Turk',
	    	'America/Grand_Turk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Ndjamena',
	    	'Africa/Ndjamena',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Kerguelen',
	    	'Indian/Kerguelen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lome',
	    	'Africa/Lome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Bangkok',
	    	'Asia/Bangkok',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dushanbe',
	    	'Asia/Dushanbe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Fakaofo',
	    	'Pacific/Fakaofo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Ashgabat',
	    	'Asia/Ashgabat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Tunis',
	    	'Africa/Tunis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Tongatapu',
	    	'Pacific/Tongatapu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dili',
	    	'Asia/Dili',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Istanbul',
	    	'Europe/Istanbul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Port_of_Spain',
	    	'America/Port_of_Spain',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Funafuti',
	    	'Pacific/Funafuti',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Taipei',
	    	'Asia/Taipei',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Dar_es_Salaam',
	    	'Africa/Dar_es_Salaam',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Kiev',
	    	'Europe/Kiev',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Uzhgorod',
	    	'Europe/Uzhgorod',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Zaporozhye',
	    	'Europe/Zaporozhye',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Simferopol',
	    	'Europe/Simferopol',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Kampala',
	    	'Africa/Kampala',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Johnston',
	    	'Pacific/Johnston',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Midway',
	    	'Pacific/Midway',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Wake',
	    	'Pacific/Wake',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/New_York',
	    	'America/New_York',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Detroit',
	    	'America/Detroit',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Louisville',
	    	'America/Louisville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Kentucky/Monticello',
	    	'America/Kentucky/Monticello',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indianapolis',
	    	'America/Indianapolis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indiana/Marengo',
	    	'America/Indiana/Marengo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indiana/Knox',
	    	'America/Indiana/Knox',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indiana/Vevay',
	    	'America/Indiana/Vevay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Chicago',
	    	'America/Chicago',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Menominee',
	    	'America/Menominee',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/North_Dakota/Center',
	    	'America/North_Dakota/Center',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Denver',
	    	'America/Denver',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Boise',
	    	'America/Boise',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Shiprock',
	    	'America/Shiprock',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Phoenix',
	    	'America/Phoenix',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Los_Angeles',
	    	'America/Los_Angeles',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Anchorage',
	    	'America/Anchorage',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Juneau',
	    	'America/Juneau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Yakutat',
	    	'America/Yakutat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Nome',
	    	'America/Nome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Adak',
	    	'America/Adak',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Honolulu',
	    	'Pacific/Honolulu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Montevideo',
	    	'America/Montevideo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Samarkand',
	    	'Asia/Samarkand',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tashkent',
	    	'Asia/Tashkent',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vatican',
	    	'Europe/Vatican',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Vincent',
	    	'America/St_Vincent',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Caracas',
	    	'America/Caracas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Tortola',
	    	'America/Tortola',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Thomas',
	    	'America/St_Thomas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Saigon',
	    	'Asia/Saigon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Efate',
	    	'Pacific/Efate',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Wallis',
	    	'Pacific/Wallis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Apia',
	    	'Pacific/Apia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Aden',
	    	'Asia/Aden',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Mayotte',
	    	'Indian/Mayotte',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Belgrade',
	    	'Europe/Belgrade',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Johannesburg',
	    	'Africa/Johannesburg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lusaka',
	    	'Africa/Lusaka',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Harare',
	    	'Africa/Harare',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Toronto',
	    	'America/Toronto',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_3')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Andorra',
	    	'Europe/Andorra',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dubai',
	    	'Asia/Dubai',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kabul',
	    	'Asia/Kabul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Antigua',
	    	'America/Antigua',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Anguilla',
	    	'America/Anguilla',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Tirane',
	    	'Europe/Tirane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Yerevan',
	    	'Asia/Yerevan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Curacao',
	    	'America/Curacao',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Luanda',
	    	'Africa/Luanda',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/McMurdo',
	    	'Antarctica/McMurdo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/South_Pole',
	    	'Antarctica/South_Pole',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Palmer',
	    	'Antarctica/Palmer',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Mawson',
	    	'Antarctica/Mawson',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Davis',
	    	'Antarctica/Davis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Casey',
	    	'Antarctica/Casey',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Vostok',
	    	'Antarctica/Vostok',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/DumontDUrville',
	    	'Antarctica/DumontDUrville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Syowa',
	    	'Antarctica/Syowa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Buenos_Aires',
	    	'America/Buenos_Aires',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cordoba',
	    	'America/Cordoba',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Jujuy',
	    	'America/Jujuy',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Catamarca',
	    	'America/Catamarca',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Mendoza',
	    	'America/Mendoza',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Pago_Pago',
	    	'Pacific/Pago_Pago',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vienna',
	    	'Europe/Vienna',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Lord_Howe',
	    	'Australia/Lord_Howe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Hobart',
	    	'Australia/Hobart',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Melbourne',
	    	'Australia/Melbourne',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Sydney',
	    	'Australia/Sydney',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Broken_Hill',
	    	'Australia/Broken_Hill',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Brisbane',
	    	'Australia/Brisbane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Lindeman',
	    	'Australia/Lindeman',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Adelaide',
	    	'Australia/Adelaide',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Darwin',
	    	'Australia/Darwin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Perth',
	    	'Australia/Perth',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Aruba',
	    	'America/Aruba',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Baku',
	    	'Asia/Baku',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Sarajevo',
	    	'Europe/Sarajevo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Barbados',
	    	'America/Barbados',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dhaka',
	    	'Asia/Dhaka',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Brussels',
	    	'Europe/Brussels',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Ouagadougou',
	    	'Africa/Ouagadougou',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Sofia',
	    	'Europe/Sofia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Bahrain',
	    	'Asia/Bahrain',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bujumbura',
	    	'Africa/Bujumbura',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Porto-Novo',
	    	'Africa/Porto-Novo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Bermuda',
	    	'Atlantic/Bermuda',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Brunei',
	    	'Asia/Brunei',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/La_Paz',
	    	'America/La_Paz',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Noronha',
	    	'America/Noronha',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Belem',
	    	'America/Belem',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Fortaleza',
	    	'America/Fortaleza',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Recife',
	    	'America/Recife',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Araguaina',
	    	'America/Araguaina',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Maceio',
	    	'America/Maceio',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Sao_Paulo',
	    	'America/Sao_Paulo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cuiaba',
	    	'America/Cuiaba',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Porto_Velho',
	    	'America/Porto_Velho',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Boa_Vista',
	    	'America/Boa_Vista',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Manaus',
	    	'America/Manaus',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Eirunepe',
	    	'America/Eirunepe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Rio_Branco',
	    	'America/Rio_Branco',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Nassau',
	    	'America/Nassau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Thimphu',
	    	'Asia/Thimphu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Gaborone',
	    	'Africa/Gaborone',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Minsk',
	    	'Europe/Minsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Belize',
	    	'America/Belize',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Johns',
	    	'America/St_Johns',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Halifax',
	    	'America/Halifax',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Glace_Bay',
	    	'America/Glace_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Goose_Bay',
	    	'America/Goose_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Montreal',
	    	'America/Montreal',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Nipigon',
	    	'America/Nipigon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Thunder_Bay',
	    	'America/Thunder_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Pangnirtung',
	    	'America/Pangnirtung',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Iqaluit',
	    	'America/Iqaluit',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Rankin_Inlet',
	    	'America/Rankin_Inlet',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Winnipeg',
	    	'America/Winnipeg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Rainy_River',
	    	'America/Rainy_River',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cambridge_Bay',
	    	'America/Cambridge_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Regina',
	    	'America/Regina',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Swift_Current',
	    	'America/Swift_Current',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Edmonton',
	    	'America/Edmonton',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Yellowknife',
	    	'America/Yellowknife',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Inuvik',
	    	'America/Inuvik',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Dawson_Creek',
	    	'America/Dawson_Creek',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Vancouver',
	    	'America/Vancouver',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Whitehorse',
	    	'America/Whitehorse',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Dawson',
	    	'America/Dawson',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Cocos',
	    	'Indian/Cocos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Kinshasa',
	    	'Africa/Kinshasa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lubumbashi',
	    	'Africa/Lubumbashi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bangui',
	    	'Africa/Bangui',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Brazzaville',
	    	'Africa/Brazzaville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Zurich',
	    	'Europe/Zurich',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Abidjan',
	    	'Africa/Abidjan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Rarotonga',
	    	'Pacific/Rarotonga',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Santiago',
	    	'America/Santiago',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Easter',
	    	'Pacific/Easter',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Douala',
	    	'Africa/Douala',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Shanghai',
	    	'Asia/Shanghai',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Harbin',
	    	'Asia/Harbin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Chongqing',
	    	'Asia/Chongqing',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Urumqi',
	    	'Asia/Urumqi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kashgar',
	    	'Asia/Kashgar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Bogota',
	    	'America/Bogota',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Costa_Rica',
	    	'America/Costa_Rica',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Havana',
	    	'America/Havana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Cape_Verde',
	    	'Atlantic/Cape_Verde',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Christmas',
	    	'Indian/Christmas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Nicosia',
	    	'Asia/Nicosia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Prague',
	    	'Europe/Prague',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Berlin',
	    	'Europe/Berlin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Djibouti',
	    	'Africa/Djibouti',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Copenhagen',
	    	'Europe/Copenhagen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Dominica',
	    	'America/Dominica',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Santo_Domingo',
	    	'America/Santo_Domingo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Algiers',
	    	'Africa/Algiers',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guayaquil',
	    	'America/Guayaquil',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Galapagos',
	    	'Pacific/Galapagos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Tallinn',
	    	'Europe/Tallinn',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Cairo',
	    	'Africa/Cairo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/El_Aaiun',
	    	'Africa/El_Aaiun',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Asmera',
	    	'Africa/Asmera',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Madrid',
	    	'Europe/Madrid',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Ceuta',
	    	'Africa/Ceuta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Canary',
	    	'Atlantic/Canary',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Addis_Ababa',
	    	'Africa/Addis_Ababa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Helsinki',
	    	'Europe/Helsinki',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Fiji',
	    	'Pacific/Fiji',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Stanley',
	    	'Atlantic/Stanley',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Yap',
	    	'Pacific/Yap',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Truk',
	    	'Pacific/Truk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Ponape',
	    	'Pacific/Ponape',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Kosrae',
	    	'Pacific/Kosrae',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Faeroe',
	    	'Atlantic/Faeroe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Paris',
	    	'Europe/Paris',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Libreville',
	    	'Africa/Libreville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/London',
	    	'Europe/London',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Belfast',
	    	'Europe/Belfast',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Grenada',
	    	'America/Grenada',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tbilisi',
	    	'Asia/Tbilisi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cayenne',
	    	'America/Cayenne',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Accra',
	    	'Africa/Accra',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Gibraltar',
	    	'Europe/Gibraltar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Godthab',
	    	'America/Godthab',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Danmarkshavn',
	    	'America/Danmarkshavn',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Scoresbysund',
	    	'America/Scoresbysund',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Thule',
	    	'America/Thule',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Banjul',
	    	'Africa/Banjul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Conakry',
	    	'Africa/Conakry',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guadeloupe',
	    	'America/Guadeloupe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Malabo',
	    	'Africa/Malabo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Athens',
	    	'Europe/Athens',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/South_Georgia',
	    	'Atlantic/South_Georgia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guatemala',
	    	'America/Guatemala',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Guam',
	    	'Pacific/Guam',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bissau',
	    	'Africa/Bissau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guyana',
	    	'America/Guyana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Hong_Kong',
	    	'Asia/Hong_Kong',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Tegucigalpa',
	    	'America/Tegucigalpa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Zagreb',
	    	'Europe/Zagreb',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Port-au-Prince',
	    	'America/Port-au-Prince',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Budapest',
	    	'Europe/Budapest',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Jakarta',
	    	'Asia/Jakarta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Pontianak',
	    	'Asia/Pontianak',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Makassar',
	    	'Asia/Makassar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Jayapura',
	    	'Asia/Jayapura',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Dublin',
	    	'Europe/Dublin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Jerusalem',
	    	'Asia/Jerusalem',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Calcutta',
	    	'Asia/Calcutta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Chagos',
	    	'Indian/Chagos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Baghdad',
	    	'Asia/Baghdad',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tehran',
	    	'Asia/Tehran',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Reykjavik',
	    	'Atlantic/Reykjavik',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Rome',
	    	'Europe/Rome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Jamaica',
	    	'America/Jamaica',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Amman',
	    	'Asia/Amman',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tokyo',
	    	'Asia/Tokyo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Nairobi',
	    	'Africa/Nairobi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Bishkek',
	    	'Asia/Bishkek',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Phnom_Penh',
	    	'Asia/Phnom_Penh',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Tarawa',
	    	'Pacific/Tarawa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Enderbury',
	    	'Pacific/Enderbury',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Kiritimati',
	    	'Pacific/Kiritimati',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Comoro',
	    	'Indian/Comoro',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Kitts',
	    	'America/St_Kitts',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Pyongyang',
	    	'Asia/Pyongyang',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Seoul',
	    	'Asia/Seoul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kuwait',
	    	'Asia/Kuwait',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cayman',
	    	'America/Cayman',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Almaty',
	    	'Asia/Almaty',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Qyzylorda',
	    	'Asia/Qyzylorda',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Aqtobe',
	    	'Asia/Aqtobe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Aqtau',
	    	'Asia/Aqtau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Oral',
	    	'Asia/Oral',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Vientiane',
	    	'Asia/Vientiane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Beirut',
	    	'Asia/Beirut',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Lucia',
	    	'America/St_Lucia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vaduz',
	    	'Europe/Vaduz',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Colombo',
	    	'Asia/Colombo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Monrovia',
	    	'Africa/Monrovia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Maseru',
	    	'Africa/Maseru',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vilnius',
	    	'Europe/Vilnius',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Luxembourg',
	    	'Europe/Luxembourg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Riga',
	    	'Europe/Riga',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Tripoli',
	    	'Africa/Tripoli',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Casablanca',
	    	'Africa/Casablanca',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Monaco',
	    	'Europe/Monaco',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Chisinau',
	    	'Europe/Chisinau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Antananarivo',
	    	'Indian/Antananarivo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Majuro',
	    	'Pacific/Majuro',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Kwajalein',
	    	'Pacific/Kwajalein',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Skopje',
	    	'Europe/Skopje',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bamako',
	    	'Africa/Bamako',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Timbuktu',
	    	'Africa/Timbuktu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Rangoon',
	    	'Asia/Rangoon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Ulaanbaatar',
	    	'Asia/Ulaanbaatar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Hovd',
	    	'Asia/Hovd',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Choibalsan',
	    	'Asia/Choibalsan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Macau',
	    	'Asia/Macau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Saipan',
	    	'Pacific/Saipan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Martinique',
	    	'America/Martinique',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Nouakchott',
	    	'Africa/Nouakchott',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Montserrat',
	    	'America/Montserrat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Malta',
	    	'Europe/Malta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Mauritius',
	    	'Indian/Mauritius',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Maldives',
	    	'Indian/Maldives',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Blantyre',
	    	'Africa/Blantyre',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Mexico_City',
	    	'America/Mexico_City',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cancun',
	    	'America/Cancun',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Merida',
	    	'America/Merida',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Monterrey',
	    	'America/Monterrey',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Mazatlan',
	    	'America/Mazatlan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Chihuahua',
	    	'America/Chihuahua',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Hermosillo',
	    	'America/Hermosillo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Tijuana',
	    	'America/Tijuana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kuala_Lumpur',
	    	'Asia/Kuala_Lumpur',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kuching',
	    	'Asia/Kuching',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Maputo',
	    	'Africa/Maputo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Windhoek',
	    	'Africa/Windhoek',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Noumea',
	    	'Pacific/Noumea',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Niamey',
	    	'Africa/Niamey',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Norfolk',
	    	'Pacific/Norfolk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lagos',
	    	'Africa/Lagos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Managua',
	    	'America/Managua',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Amsterdam',
	    	'Europe/Amsterdam',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Oslo',
	    	'Europe/Oslo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Katmandu',
	    	'Asia/Katmandu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Nauru',
	    	'Pacific/Nauru',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Niue',
	    	'Pacific/Niue',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Auckland',
	    	'Pacific/Auckland',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Chatham',
	    	'Pacific/Chatham',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Muscat',
	    	'Asia/Muscat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Panama',
	    	'America/Panama',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Lima',
	    	'America/Lima',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Tahiti',
	    	'Pacific/Tahiti',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Marquesas',
	    	'Pacific/Marquesas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Gambier',
	    	'Pacific/Gambier',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Port_Moresby',
	    	'Pacific/Port_Moresby',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Manila',
	    	'Asia/Manila',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Karachi',
	    	'Asia/Karachi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Warsaw',
	    	'Europe/Warsaw',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Miquelon',
	    	'America/Miquelon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Pitcairn',
	    	'Pacific/Pitcairn',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Puerto_Rico',
	    	'America/Puerto_Rico',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Gaza',
	    	'Asia/Gaza',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Lisbon',
	    	'Europe/Lisbon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Madeira',
	    	'Atlantic/Madeira',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Azores',
	    	'Atlantic/Azores',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Palau',
	    	'Pacific/Palau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Asuncion',
	    	'America/Asuncion',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Qatar',
	    	'Asia/Qatar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Reunion',
	    	'Indian/Reunion',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Bucharest',
	    	'Europe/Bucharest',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Kaliningrad',
	    	'Europe/Kaliningrad',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Moscow',
	    	'Europe/Moscow',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Samara',
	    	'Europe/Samara',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Yekaterinburg',
	    	'Asia/Yekaterinburg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Omsk',
	    	'Asia/Omsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Novosibirsk',
	    	'Asia/Novosibirsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Krasnoyarsk',
	    	'Asia/Krasnoyarsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Irkutsk',
	    	'Asia/Irkutsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Yakutsk',
	    	'Asia/Yakutsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Vladivostok',
	    	'Asia/Vladivostok',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Sakhalin',
	    	'Asia/Sakhalin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Magadan',
	    	'Asia/Magadan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kamchatka',
	    	'Asia/Kamchatka',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Anadyr',
	    	'Asia/Anadyr',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Kigali',
	    	'Africa/Kigali',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Riyadh',
	    	'Asia/Riyadh',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Guadalcanal',
	    	'Pacific/Guadalcanal',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Mahe',
	    	'Indian/Mahe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Khartoum',
	    	'Africa/Khartoum',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Stockholm',
	    	'Europe/Stockholm',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Singapore',
	    	'Asia/Singapore',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/St_Helena',
	    	'Atlantic/St_Helena',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Ljubljana',
	    	'Europe/Ljubljana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Arctic/Longyearbyen',
	    	'Arctic/Longyearbyen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Jan_Mayen',
	    	'Atlantic/Jan_Mayen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Bratislava',
	    	'Europe/Bratislava',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Freetown',
	    	'Africa/Freetown',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/San_Marino',
	    	'Europe/San_Marino',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Dakar',
	    	'Africa/Dakar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Mogadishu',
	    	'Africa/Mogadishu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Paramaribo',
	    	'America/Paramaribo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Sao_Tome',
	    	'Africa/Sao_Tome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/El_Salvador',
	    	'America/El_Salvador',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Damascus',
	    	'Asia/Damascus',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Mbabane',
	    	'Africa/Mbabane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Grand_Turk',
	    	'America/Grand_Turk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Ndjamena',
	    	'Africa/Ndjamena',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Kerguelen',
	    	'Indian/Kerguelen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lome',
	    	'Africa/Lome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Bangkok',
	    	'Asia/Bangkok',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dushanbe',
	    	'Asia/Dushanbe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Fakaofo',
	    	'Pacific/Fakaofo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Ashgabat',
	    	'Asia/Ashgabat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Tunis',
	    	'Africa/Tunis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Tongatapu',
	    	'Pacific/Tongatapu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dili',
	    	'Asia/Dili',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Istanbul',
	    	'Europe/Istanbul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Port_of_Spain',
	    	'America/Port_of_Spain',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Funafuti',
	    	'Pacific/Funafuti',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Taipei',
	    	'Asia/Taipei',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Dar_es_Salaam',
	    	'Africa/Dar_es_Salaam',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Kiev',
	    	'Europe/Kiev',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Uzhgorod',
	    	'Europe/Uzhgorod',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Zaporozhye',
	    	'Europe/Zaporozhye',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Simferopol',
	    	'Europe/Simferopol',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Kampala',
	    	'Africa/Kampala',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Johnston',
	    	'Pacific/Johnston',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Midway',
	    	'Pacific/Midway',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Wake',
	    	'Pacific/Wake',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/New_York',
	    	'America/New_York',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Detroit',
	    	'America/Detroit',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Louisville',
	    	'America/Louisville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Kentucky/Monticello',
	    	'America/Kentucky/Monticello',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indianapolis',
	    	'America/Indianapolis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indiana/Marengo',
	    	'America/Indiana/Marengo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indiana/Knox',
	    	'America/Indiana/Knox',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indiana/Vevay',
	    	'America/Indiana/Vevay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Chicago',
	    	'America/Chicago',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Menominee',
	    	'America/Menominee',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/North_Dakota/Center',
	    	'America/North_Dakota/Center',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Denver',
	    	'America/Denver',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Boise',
	    	'America/Boise',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Shiprock',
	    	'America/Shiprock',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Phoenix',
	    	'America/Phoenix',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Los_Angeles',
	    	'America/Los_Angeles',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Anchorage',
	    	'America/Anchorage',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Juneau',
	    	'America/Juneau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Yakutat',
	    	'America/Yakutat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Nome',
	    	'America/Nome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Adak',
	    	'America/Adak',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Honolulu',
	    	'Pacific/Honolulu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Montevideo',
	    	'America/Montevideo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Samarkand',
	    	'Asia/Samarkand',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tashkent',
	    	'Asia/Tashkent',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vatican',
	    	'Europe/Vatican',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Vincent',
	    	'America/St_Vincent',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Caracas',
	    	'America/Caracas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Tortola',
	    	'America/Tortola',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Thomas',
	    	'America/St_Thomas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Saigon',
	    	'Asia/Saigon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Efate',
	    	'Pacific/Efate',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Wallis',
	    	'Pacific/Wallis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Apia',
	    	'Pacific/Apia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Aden',
	    	'Asia/Aden',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Mayotte',
	    	'Indian/Mayotte',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Belgrade',
	    	'Europe/Belgrade',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Johannesburg',
	    	'Africa/Johannesburg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lusaka',
	    	'Africa/Lusaka',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Harare',
	    	'Africa/Harare',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Toronto',
	    	'America/Toronto',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_4')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Andorra',
	    	'Europe/Andorra',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dubai',
	    	'Asia/Dubai',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kabul',
	    	'Asia/Kabul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Antigua',
	    	'America/Antigua',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Anguilla',
	    	'America/Anguilla',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Tirane',
	    	'Europe/Tirane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Yerevan',
	    	'Asia/Yerevan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Curacao',
	    	'America/Curacao',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Luanda',
	    	'Africa/Luanda',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/McMurdo',
	    	'Antarctica/McMurdo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/South_Pole',
	    	'Antarctica/South_Pole',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Palmer',
	    	'Antarctica/Palmer',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Mawson',
	    	'Antarctica/Mawson',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Davis',
	    	'Antarctica/Davis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Casey',
	    	'Antarctica/Casey',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Vostok',
	    	'Antarctica/Vostok',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/DumontDUrville',
	    	'Antarctica/DumontDUrville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Antarctica/Syowa',
	    	'Antarctica/Syowa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Buenos_Aires',
	    	'America/Buenos_Aires',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cordoba',
	    	'America/Cordoba',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Jujuy',
	    	'America/Jujuy',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Catamarca',
	    	'America/Catamarca',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Mendoza',
	    	'America/Mendoza',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Pago_Pago',
	    	'Pacific/Pago_Pago',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vienna',
	    	'Europe/Vienna',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Lord_Howe',
	    	'Australia/Lord_Howe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Hobart',
	    	'Australia/Hobart',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Melbourne',
	    	'Australia/Melbourne',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Sydney',
	    	'Australia/Sydney',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Broken_Hill',
	    	'Australia/Broken_Hill',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Brisbane',
	    	'Australia/Brisbane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Lindeman',
	    	'Australia/Lindeman',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Adelaide',
	    	'Australia/Adelaide',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Darwin',
	    	'Australia/Darwin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Australia/Perth',
	    	'Australia/Perth',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Aruba',
	    	'America/Aruba',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Baku',
	    	'Asia/Baku',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Sarajevo',
	    	'Europe/Sarajevo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Barbados',
	    	'America/Barbados',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dhaka',
	    	'Asia/Dhaka',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Brussels',
	    	'Europe/Brussels',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Ouagadougou',
	    	'Africa/Ouagadougou',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Sofia',
	    	'Europe/Sofia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Bahrain',
	    	'Asia/Bahrain',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bujumbura',
	    	'Africa/Bujumbura',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Porto-Novo',
	    	'Africa/Porto-Novo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Bermuda',
	    	'Atlantic/Bermuda',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Brunei',
	    	'Asia/Brunei',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/La_Paz',
	    	'America/La_Paz',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Noronha',
	    	'America/Noronha',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Belem',
	    	'America/Belem',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Fortaleza',
	    	'America/Fortaleza',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Recife',
	    	'America/Recife',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Araguaina',
	    	'America/Araguaina',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Maceio',
	    	'America/Maceio',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Sao_Paulo',
	    	'America/Sao_Paulo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cuiaba',
	    	'America/Cuiaba',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Porto_Velho',
	    	'America/Porto_Velho',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Boa_Vista',
	    	'America/Boa_Vista',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Manaus',
	    	'America/Manaus',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Eirunepe',
	    	'America/Eirunepe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Rio_Branco',
	    	'America/Rio_Branco',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Nassau',
	    	'America/Nassau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Thimphu',
	    	'Asia/Thimphu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Gaborone',
	    	'Africa/Gaborone',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Minsk',
	    	'Europe/Minsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Belize',
	    	'America/Belize',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Johns',
	    	'America/St_Johns',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Halifax',
	    	'America/Halifax',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Glace_Bay',
	    	'America/Glace_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Goose_Bay',
	    	'America/Goose_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Montreal',
	    	'America/Montreal',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Nipigon',
	    	'America/Nipigon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Thunder_Bay',
	    	'America/Thunder_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Pangnirtung',
	    	'America/Pangnirtung',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Iqaluit',
	    	'America/Iqaluit',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Rankin_Inlet',
	    	'America/Rankin_Inlet',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Winnipeg',
	    	'America/Winnipeg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Rainy_River',
	    	'America/Rainy_River',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cambridge_Bay',
	    	'America/Cambridge_Bay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Regina',
	    	'America/Regina',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Swift_Current',
	    	'America/Swift_Current',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Edmonton',
	    	'America/Edmonton',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Yellowknife',
	    	'America/Yellowknife',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Inuvik',
	    	'America/Inuvik',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Dawson_Creek',
	    	'America/Dawson_Creek',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Vancouver',
	    	'America/Vancouver',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Whitehorse',
	    	'America/Whitehorse',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Dawson',
	    	'America/Dawson',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Cocos',
	    	'Indian/Cocos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Kinshasa',
	    	'Africa/Kinshasa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lubumbashi',
	    	'Africa/Lubumbashi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bangui',
	    	'Africa/Bangui',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Brazzaville',
	    	'Africa/Brazzaville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Zurich',
	    	'Europe/Zurich',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Abidjan',
	    	'Africa/Abidjan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Rarotonga',
	    	'Pacific/Rarotonga',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Santiago',
	    	'America/Santiago',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Easter',
	    	'Pacific/Easter',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Douala',
	    	'Africa/Douala',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Shanghai',
	    	'Asia/Shanghai',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Harbin',
	    	'Asia/Harbin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Chongqing',
	    	'Asia/Chongqing',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Urumqi',
	    	'Asia/Urumqi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kashgar',
	    	'Asia/Kashgar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Bogota',
	    	'America/Bogota',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Costa_Rica',
	    	'America/Costa_Rica',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Havana',
	    	'America/Havana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Cape_Verde',
	    	'Atlantic/Cape_Verde',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Christmas',
	    	'Indian/Christmas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Nicosia',
	    	'Asia/Nicosia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Prague',
	    	'Europe/Prague',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Berlin',
	    	'Europe/Berlin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Djibouti',
	    	'Africa/Djibouti',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Copenhagen',
	    	'Europe/Copenhagen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Dominica',
	    	'America/Dominica',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Santo_Domingo',
	    	'America/Santo_Domingo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Algiers',
	    	'Africa/Algiers',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guayaquil',
	    	'America/Guayaquil',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Galapagos',
	    	'Pacific/Galapagos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Tallinn',
	    	'Europe/Tallinn',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Cairo',
	    	'Africa/Cairo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/El_Aaiun',
	    	'Africa/El_Aaiun',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Asmera',
	    	'Africa/Asmera',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Madrid',
	    	'Europe/Madrid',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Ceuta',
	    	'Africa/Ceuta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Canary',
	    	'Atlantic/Canary',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Addis_Ababa',
	    	'Africa/Addis_Ababa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Helsinki',
	    	'Europe/Helsinki',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Fiji',
	    	'Pacific/Fiji',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Stanley',
	    	'Atlantic/Stanley',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Yap',
	    	'Pacific/Yap',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Truk',
	    	'Pacific/Truk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Ponape',
	    	'Pacific/Ponape',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Kosrae',
	    	'Pacific/Kosrae',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Faeroe',
	    	'Atlantic/Faeroe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Paris',
	    	'Europe/Paris',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Libreville',
	    	'Africa/Libreville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/London',
	    	'Europe/London',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Belfast',
	    	'Europe/Belfast',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Grenada',
	    	'America/Grenada',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tbilisi',
	    	'Asia/Tbilisi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cayenne',
	    	'America/Cayenne',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Accra',
	    	'Africa/Accra',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Gibraltar',
	    	'Europe/Gibraltar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Godthab',
	    	'America/Godthab',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Danmarkshavn',
	    	'America/Danmarkshavn',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Scoresbysund',
	    	'America/Scoresbysund',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Thule',
	    	'America/Thule',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Banjul',
	    	'Africa/Banjul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Conakry',
	    	'Africa/Conakry',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guadeloupe',
	    	'America/Guadeloupe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Malabo',
	    	'Africa/Malabo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Athens',
	    	'Europe/Athens',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/South_Georgia',
	    	'Atlantic/South_Georgia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guatemala',
	    	'America/Guatemala',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Guam',
	    	'Pacific/Guam',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bissau',
	    	'Africa/Bissau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Guyana',
	    	'America/Guyana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Hong_Kong',
	    	'Asia/Hong_Kong',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Tegucigalpa',
	    	'America/Tegucigalpa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Zagreb',
	    	'Europe/Zagreb',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Port-au-Prince',
	    	'America/Port-au-Prince',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Budapest',
	    	'Europe/Budapest',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Jakarta',
	    	'Asia/Jakarta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Pontianak',
	    	'Asia/Pontianak',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Makassar',
	    	'Asia/Makassar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Jayapura',
	    	'Asia/Jayapura',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Dublin',
	    	'Europe/Dublin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Jerusalem',
	    	'Asia/Jerusalem',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Calcutta',
	    	'Asia/Calcutta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Chagos',
	    	'Indian/Chagos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Baghdad',
	    	'Asia/Baghdad',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tehran',
	    	'Asia/Tehran',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Reykjavik',
	    	'Atlantic/Reykjavik',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Rome',
	    	'Europe/Rome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Jamaica',
	    	'America/Jamaica',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Amman',
	    	'Asia/Amman',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tokyo',
	    	'Asia/Tokyo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Nairobi',
	    	'Africa/Nairobi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Bishkek',
	    	'Asia/Bishkek',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Phnom_Penh',
	    	'Asia/Phnom_Penh',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Tarawa',
	    	'Pacific/Tarawa',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Enderbury',
	    	'Pacific/Enderbury',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Kiritimati',
	    	'Pacific/Kiritimati',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Comoro',
	    	'Indian/Comoro',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Kitts',
	    	'America/St_Kitts',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Pyongyang',
	    	'Asia/Pyongyang',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Seoul',
	    	'Asia/Seoul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kuwait',
	    	'Asia/Kuwait',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cayman',
	    	'America/Cayman',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Almaty',
	    	'Asia/Almaty',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Qyzylorda',
	    	'Asia/Qyzylorda',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Aqtobe',
	    	'Asia/Aqtobe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Aqtau',
	    	'Asia/Aqtau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Oral',
	    	'Asia/Oral',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Vientiane',
	    	'Asia/Vientiane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Beirut',
	    	'Asia/Beirut',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Lucia',
	    	'America/St_Lucia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vaduz',
	    	'Europe/Vaduz',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Colombo',
	    	'Asia/Colombo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Monrovia',
	    	'Africa/Monrovia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Maseru',
	    	'Africa/Maseru',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vilnius',
	    	'Europe/Vilnius',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Luxembourg',
	    	'Europe/Luxembourg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Riga',
	    	'Europe/Riga',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Tripoli',
	    	'Africa/Tripoli',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Casablanca',
	    	'Africa/Casablanca',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Monaco',
	    	'Europe/Monaco',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Chisinau',
	    	'Europe/Chisinau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Antananarivo',
	    	'Indian/Antananarivo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Majuro',
	    	'Pacific/Majuro',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Kwajalein',
	    	'Pacific/Kwajalein',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Skopje',
	    	'Europe/Skopje',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Bamako',
	    	'Africa/Bamako',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Timbuktu',
	    	'Africa/Timbuktu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Rangoon',
	    	'Asia/Rangoon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Ulaanbaatar',
	    	'Asia/Ulaanbaatar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Hovd',
	    	'Asia/Hovd',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Choibalsan',
	    	'Asia/Choibalsan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Macau',
	    	'Asia/Macau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Saipan',
	    	'Pacific/Saipan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Martinique',
	    	'America/Martinique',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Nouakchott',
	    	'Africa/Nouakchott',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Montserrat',
	    	'America/Montserrat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Malta',
	    	'Europe/Malta',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Mauritius',
	    	'Indian/Mauritius',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Maldives',
	    	'Indian/Maldives',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Blantyre',
	    	'Africa/Blantyre',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Mexico_City',
	    	'America/Mexico_City',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Cancun',
	    	'America/Cancun',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Merida',
	    	'America/Merida',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Monterrey',
	    	'America/Monterrey',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Mazatlan',
	    	'America/Mazatlan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Chihuahua',
	    	'America/Chihuahua',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Hermosillo',
	    	'America/Hermosillo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Tijuana',
	    	'America/Tijuana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kuala_Lumpur',
	    	'Asia/Kuala_Lumpur',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kuching',
	    	'Asia/Kuching',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Maputo',
	    	'Africa/Maputo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Windhoek',
	    	'Africa/Windhoek',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Noumea',
	    	'Pacific/Noumea',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Niamey',
	    	'Africa/Niamey',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Norfolk',
	    	'Pacific/Norfolk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lagos',
	    	'Africa/Lagos',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Managua',
	    	'America/Managua',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Amsterdam',
	    	'Europe/Amsterdam',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Oslo',
	    	'Europe/Oslo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Katmandu',
	    	'Asia/Katmandu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Nauru',
	    	'Pacific/Nauru',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Niue',
	    	'Pacific/Niue',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Auckland',
	    	'Pacific/Auckland',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Chatham',
	    	'Pacific/Chatham',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Muscat',
	    	'Asia/Muscat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Panama',
	    	'America/Panama',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Lima',
	    	'America/Lima',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Tahiti',
	    	'Pacific/Tahiti',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Marquesas',
	    	'Pacific/Marquesas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Gambier',
	    	'Pacific/Gambier',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Port_Moresby',
	    	'Pacific/Port_Moresby',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Manila',
	    	'Asia/Manila',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Karachi',
	    	'Asia/Karachi',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Warsaw',
	    	'Europe/Warsaw',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Miquelon',
	    	'America/Miquelon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Pitcairn',
	    	'Pacific/Pitcairn',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Puerto_Rico',
	    	'America/Puerto_Rico',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Gaza',
	    	'Asia/Gaza',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Lisbon',
	    	'Europe/Lisbon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Madeira',
	    	'Atlantic/Madeira',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Azores',
	    	'Atlantic/Azores',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Palau',
	    	'Pacific/Palau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Asuncion',
	    	'America/Asuncion',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Qatar',
	    	'Asia/Qatar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Reunion',
	    	'Indian/Reunion',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Bucharest',
	    	'Europe/Bucharest',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Kaliningrad',
	    	'Europe/Kaliningrad',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Moscow',
	    	'Europe/Moscow',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Samara',
	    	'Europe/Samara',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Yekaterinburg',
	    	'Asia/Yekaterinburg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Omsk',
	    	'Asia/Omsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Novosibirsk',
	    	'Asia/Novosibirsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Krasnoyarsk',
	    	'Asia/Krasnoyarsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Irkutsk',
	    	'Asia/Irkutsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Yakutsk',
	    	'Asia/Yakutsk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Vladivostok',
	    	'Asia/Vladivostok',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Sakhalin',
	    	'Asia/Sakhalin',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Magadan',
	    	'Asia/Magadan',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Kamchatka',
	    	'Asia/Kamchatka',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Anadyr',
	    	'Asia/Anadyr',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Kigali',
	    	'Africa/Kigali',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Riyadh',
	    	'Asia/Riyadh',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Guadalcanal',
	    	'Pacific/Guadalcanal',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Mahe',
	    	'Indian/Mahe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Khartoum',
	    	'Africa/Khartoum',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Stockholm',
	    	'Europe/Stockholm',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Singapore',
	    	'Asia/Singapore',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/St_Helena',
	    	'Atlantic/St_Helena',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Ljubljana',
	    	'Europe/Ljubljana',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Arctic/Longyearbyen',
	    	'Arctic/Longyearbyen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Atlantic/Jan_Mayen',
	    	'Atlantic/Jan_Mayen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Bratislava',
	    	'Europe/Bratislava',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Freetown',
	    	'Africa/Freetown',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/San_Marino',
	    	'Europe/San_Marino',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Dakar',
	    	'Africa/Dakar',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Mogadishu',
	    	'Africa/Mogadishu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Paramaribo',
	    	'America/Paramaribo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Sao_Tome',
	    	'Africa/Sao_Tome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/El_Salvador',
	    	'America/El_Salvador',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Damascus',
	    	'Asia/Damascus',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Mbabane',
	    	'Africa/Mbabane',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Grand_Turk',
	    	'America/Grand_Turk',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Ndjamena',
	    	'Africa/Ndjamena',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Kerguelen',
	    	'Indian/Kerguelen',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lome',
	    	'Africa/Lome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Bangkok',
	    	'Asia/Bangkok',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dushanbe',
	    	'Asia/Dushanbe',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Fakaofo',
	    	'Pacific/Fakaofo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Ashgabat',
	    	'Asia/Ashgabat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Tunis',
	    	'Africa/Tunis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Tongatapu',
	    	'Pacific/Tongatapu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Dili',
	    	'Asia/Dili',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Istanbul',
	    	'Europe/Istanbul',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Port_of_Spain',
	    	'America/Port_of_Spain',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Funafuti',
	    	'Pacific/Funafuti',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Taipei',
	    	'Asia/Taipei',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Dar_es_Salaam',
	    	'Africa/Dar_es_Salaam',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Kiev',
	    	'Europe/Kiev',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Uzhgorod',
	    	'Europe/Uzhgorod',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Zaporozhye',
	    	'Europe/Zaporozhye',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Simferopol',
	    	'Europe/Simferopol',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Kampala',
	    	'Africa/Kampala',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Johnston',
	    	'Pacific/Johnston',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Midway',
	    	'Pacific/Midway',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Wake',
	    	'Pacific/Wake',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/New_York',
	    	'America/New_York',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Detroit',
	    	'America/Detroit',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Louisville',
	    	'America/Louisville',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Kentucky/Monticello',
	    	'America/Kentucky/Monticello',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indianapolis',
	    	'America/Indianapolis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indiana/Marengo',
	    	'America/Indiana/Marengo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indiana/Knox',
	    	'America/Indiana/Knox',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Indiana/Vevay',
	    	'America/Indiana/Vevay',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Chicago',
	    	'America/Chicago',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Menominee',
	    	'America/Menominee',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/North_Dakota/Center',
	    	'America/North_Dakota/Center',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Denver',
	    	'America/Denver',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Boise',
	    	'America/Boise',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Shiprock',
	    	'America/Shiprock',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Phoenix',
	    	'America/Phoenix',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Los_Angeles',
	    	'America/Los_Angeles',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Anchorage',
	    	'America/Anchorage',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Juneau',
	    	'America/Juneau',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Yakutat',
	    	'America/Yakutat',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Nome',
	    	'America/Nome',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Adak',
	    	'America/Adak',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Honolulu',
	    	'Pacific/Honolulu',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Montevideo',
	    	'America/Montevideo',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Samarkand',
	    	'Asia/Samarkand',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Tashkent',
	    	'Asia/Tashkent',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Vatican',
	    	'Europe/Vatican',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Vincent',
	    	'America/St_Vincent',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Caracas',
	    	'America/Caracas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Tortola',
	    	'America/Tortola',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/St_Thomas',
	    	'America/St_Thomas',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Saigon',
	    	'Asia/Saigon',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Efate',
	    	'Pacific/Efate',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Wallis',
	    	'Pacific/Wallis',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Pacific/Apia',
	    	'Pacific/Apia',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Asia/Aden',
	    	'Asia/Aden',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Indian/Mayotte',
	    	'Indian/Mayotte',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Europe/Belgrade',
	    	'Europe/Belgrade',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Johannesburg',
	    	'Africa/Johannesburg',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Lusaka',
	    	'Africa/Lusaka',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'Africa/Harare',
	    	'Africa/Harare',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
insert into rhnKickstartTimezone (id, label, name, install_type)
        values (rhn_ks_timezone_id_seq.nextval,
	    	'America/Toronto',
	    	'America/Toronto',
    	    	(SELECT IT.id FROM rhnKSInstallType IT WHERE IT.label = 'rhel_5')
        );
commit;

select 'rhnsat/tables/rhnKickstartVirtualizationType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnKickstartVirtualizationType_data.sql
insert into rhnKickstartVirtualizationType (id, name, label)
     values (rhn_kvt_id_seq.nextval, 'Para-Virtualized Host', 'para_host');
insert into rhnKickstartVirtualizationType (id, name, label)
    values (rhn_kvt_id_seq.nextval, 'KVM Virtualized Guest', 'qemu');
insert into rhnKickstartVirtualizationType (id, name, label)
    values (rhn_kvt_id_seq.nextval, 'XEN Fully-Virtualized Guest', 'xenfv');
insert into rhnKickstartVirtualizationType (id, name, label)
    values (rhn_kvt_id_seq.nextval, 'XEN Para-Virtualized Guest', 'xenpv');
insert into rhnKickstartVirtualizationType (id, name, label)
     values (rhn_kvt_id_seq.nextval, 'Auto', 'auto');

select 'rhnsat/tables/rhnMessageType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnMessageType.sql
create table
rhnMessageType
(
	id		number
			constraint rhn_m_type_id_nn not null
			constraint rhn_m_type_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(48)
			constraint rhn_m_type_label_nn not null,
	name		varchar2(96)
			constraint rhn_m_type_name_nn not null
)
	enable row movement
  ;
create sequence rhn_mt_id_seq;
create unique index rhn_m_type_label_uq
	on rhnMessageType(label)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_m_type_name_uq
	on rhnMessageType(name)
	tablespace [[64k_tbs]]
  ;
create index rhn_m_type_label_id_idx
	on rhnMessageType(label,id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnMessagePriority.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnMessagePriority.sql
create table
rhnMessagePriority
(
	id		number
			constraint rhn_m_priority_id_nn not null
			constraint rhn_m_priority_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(48)
			constraint rhn_m_priority_label_nn not null
)
	enable row movement
  ;
create sequence rhn_m_priority_id_seq;
create unique index rhn_m_priority_label_uq
	on rhnMessagePriority(label)
	tablespace [[64k_tbs]]
  ;
create index rhn_m_priority_label_id_idx
	on rhnMessagePriority(label,id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnMessage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnMessage.sql
create table
rhnMessage
(
	id		number
			constraint rhn_m_id_nn not null
			constraint rhn_m_id_pk primary key
				using index tablespace [[64k_tbs]],
	message_type	number
			constraint rhn_m_mt_nn not null
			constraint rhn_m_mt_fk
				references rhnMessageType(id),
	priority	number default 0
			constraint rhn_m_priority_nn not null
			constraint rhn_m_priority_fk
				references rhnMessagePriority(id),
	created		date default (sysdate)
			constraint rhn_m_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_m_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_m_id_seq;
create or replace trigger
rhn_m_mod_trig
before insert or update on rhnMessage
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnMessagePriority_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnMessagePriority_data.sql
insert into rhnMessagePriority values (
	rhn_m_priority_id_seq.nextval, 'warning'
);
insert into rhnMessagePriority values (
	rhn_m_priority_id_seq.nextval, 'error'
);

select 'rhnsat/tables/rhnMessageType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnMessageType_data.sql
insert into rhnMessageType (id, label, name) values (
    rhn_mt_id_seq.nextval, 'server', 'System Message'
);

select 'rhnsat/tables/rhnMonitorGranularity.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnMonitorGranularity.sql
create table
rhnMonitorGranularity
(
	id		number
			constraint rhn_monitorgran_id_nn not null
			constraint rhn_monitorgran_id_pk primary key
				using index tablespace [[4m_tbs]],
	label		varchar2(16)
			constraint rhn_monitorgran_label_nn not null
)
	enable row movement
  ;
create sequence rhn_monitorgranularity_id_seq;
create unique index rhn_monitorgran_label_uq
	on rhnMonitorGranularity(label)
	tablespace [[64k_tbs]]
  ;
create index rhn_monitorgran_label_id_idx
	on rhnMonitorGranularity(label,id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnMonitor.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnMonitor.sql
create table
rhnMonitor
(
    batch_id    number
    	    	constraint rhn_monitor_bid_nn not null,
    server_id	number
    	    	constraint rhn_monitor_sid_nn not null
		constraint rhn_monitor_sid_fk
			references rhnServer(id)
			on delete cascade,
    probe_id	number
    	    	constraint rhn_monitor_probe_nn not null,
    component	varchar2(128),
    field	varchar2(128),
    timestamp	date
    	    	constraint rhn_monitor_ts_nn not null,
    granularity	number
    		constraint rhn_monitor_granularity_nn not null
		constraint rhn_monitor_granularity_fk
			references rhnMonitorGranularity(id),
    value       varchar2(4000)
)
	enable row movement
  ;
create sequence rhn_monitor_bid_seq;
create index rhn_monitor_bid_idx
    	on rhnMonitor(batch_id)
	tablespace [[8m_tbs]]
  ;
create unique index rhn_monitor_idx
    	on rhnMonitor(server_id, probe_id, granularity, timestamp, component, field)
	tablespace [[8m_tbs]]
  ;

select 'rhnsat/tables/rhnMonitorGranularity_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnMonitorGranularity_data.sql
insert into rhnMonitorGranularity values (
	rhn_monitorgranularity_id_seq.nextval, 'daily'
);
commit;

select 'rhnsat/tables/rhnOrgChannelSettingsType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnOrgChannelSettingsType.sql
create sequence rhn_ocstngs_type_id_seq;
create table
rhnOrgChannelSettingsType
(
	id		number
			constraint rhn_ocstngs_type_id_nn not null
			constraint rhn_ocstngs_type_id_pk primary key,
	label		varchar2(32)
			constraint rhn_ocstngs_type_label_nn not null,
	created		date default(sysdate)
			constraint rhn_ocstngs_type_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_ocstngs_type_modified_nn not null
)
	enable row movement
  ;
create index rhn_ocstngs_type_l_id_idx
	on rhnOrgChannelSettingsType( label, id )
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_orgcsettings_type_mod_trig
before insert or update on rhnOrgChannelSettingsType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnOrgChannelSettings.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnOrgChannelSettings.sql
create table
rhnOrgChannelSettings
(
	org_id		number
			constraint rhn_orgcsettings_oid_nn not null
			constraint rhn_orgcsettings_oid_fk
				references web_customer(id)
				on delete cascade,
	channel_id	number
			constraint rhn_orgcsettings_cid_nn not null
			constraint rhn_orgcsettings_cid_fk
				references rhnChannel(id)
				on delete cascade,
	setting_id	number
			constraint rhn_orgcsettings_sid_nn not null
			constraint rhn_orgcsettings_sid_fk
				references rhnOrgChannelSettingsType(id),
	created		date default(sysdate)
			constraint rhn_orgcsettings_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_orgcsettings_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_orgcsettings_oid_cid_uq
	on rhnOrgChannelSettings(org_id, channel_id, setting_id)
	tablespace [[8m_tbs]]
  ;
create or replace trigger
rhn_orgcsettings_mod_trig
before insert or update on rhnOrgChannelSettings
for each row
begin
	:new.modified := sysdate;	
end;
/
show errors

select 'rhnsat/tables/rhnOrgChannelSettingsType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnOrgChannelSettingsType_data.sql
insert into rhnOrgChannelSettingsType ( id, label )
	values ( rhn_ocstngs_type_id_seq.nextval, 'not_globally_subscribable' );
commit;

select 'rhnsat/tables/rhnOrgEntitlementType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnOrgEntitlementType.sql
create table
rhnOrgEntitlementType
(
        id              number
			constraint rhn_org_ent_type_id_nn not null
                        constraint rhn_org_ent_type_id_pk primary key
                                using index tablespace [[64k_tbs]],
        label           varchar2(32)
                        constraint rhn_org_ent_type_label_nn not null,
        name            varchar2(64)
                        constraint rhn_org_ent_type_name_nn not null,
        created         date default(sysdate)
                        constraint rhn_org_ent_type_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_org_ent_type_mod_nn not null
)
	enable row movement
  ;
create sequence rhn_org_entitlement_type_seq;
create unique index rhn_org_entitle_type_label_uq 
	on rhnOrgEntitlementType(label)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_org_ent_type_mod_trig
before insert or update on rhnOrgEntitlementType
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnOrgEntitlementType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnOrgEntitlementType_data.sql
insert into rhnOrgEntitlementType (id, label, name)
        values (rhn_org_entitlement_type_seq.nextval,
                'sw_mgr_enterprise','Software Manager Enterprise'
        );
insert into rhnOrgEntitlementType (id, label, name)
        values (rhn_org_entitlement_type_seq.nextval,
                'rhn_monitor','Spacewalk Monitoring'
        );
insert into rhnOrgEntitlementType (id, label, name)
        values (rhn_org_entitlement_type_seq.nextval,
                'rhn_provisioning','Spacewalk Provisioning'
        );
insert into rhnOrgEntitlementType (id, label, name)
        values (rhn_org_entitlement_type_seq.nextval,
                'rhn_nonlinux','Spacewalk Non-Linux'
        );
insert into rhnOrgEntitlementType (id, label, name)
        values (rhn_org_entitlement_type_seq.nextval,
                'rhn_virtualization', 'Spacewalk Virtualization'
        );
insert into rhnOrgEntitlementType (id, label, name)
        values (rhn_org_entitlement_type_seq.nextval,
                'rhn_virtualization_platform', 'Spacewalk Virtualization Platform'
        );
commit;

select 'rhnsat/tables/rhnOrgEntitlements.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnOrgEntitlements.sql
create table
rhnOrgEntitlements
(
        org_id          number
                        constraint rhn_org_ent_nn not null
                        constraint rhn_org_ent_fk
                                references web_customer(id)
				on delete cascade,
        entitlement_id  number
                        constraint rhn_org_ent_eid_nn not null
                        constraint rhn_org_ent_eid_fk
                                references rhnOrgEntitlementType(id),
        created         date default(sysdate)
                        constraint rhn_org_ent_cre_nn not null,
        modified        date default(sysdate)
                        constraint rhn_org_ent_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_org_ent_org_eid_uq
	on rhnOrgEntitlements(org_id, entitlement_id)
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_org_ent_mod_trig
before insert or update on rhnOrgEntitlements
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnOrgErrataCacheQueue.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnOrgErrataCacheQueue.sql
create table rhnOrgErrataCacheQueue
(
        org_id          number
                        constraint rhn_oecq_oid_nn not null
                        constraint rhn_oecq_oid_fk
                                references web_customer(id)
				on delete cascade,
        server_count    number constraint rhn_oecq_sc_nn not null,
        processed       number default(0)
                        constraint rhn_oecq_oid_processed_nn not null
)
	enable row movement
  ;
create unique index rhn_oecq_oid_uq
        on rhnOrgErrataCacheQueue(org_id)
        tablespace [[4m_tbs]]
  ;
alter table rhnOrgErrataCacheQueue nologging;
alter index rhn_oecq_oid_uq nologging;

select 'rhnsat/tables/rhnOrgInfo.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnOrgInfo.sql
create table
rhnOrgInfo
(
	org_id			number
				constraint rhn_orginfo_oid_nn not null
				constraint rhn_orginfo_oid_fk
					references web_customer(id),
	default_group_type	number default(2)
				constraint rhn_orginfo_dgt_nn not null
				constraint rhn_orginfo_dgt_fk
					references rhnServerGroupType(id),
	created			date default(sysdate)
				constraint rhn_orginfo_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_orginfo_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_orginfo_oid_uq
	on rhnOrgInfo(org_id)
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_orginfo_mod_trig
before insert or update on rhnOrgInfo
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPackageChangeLog.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageChangeLog.sql
create table
rhnPackageChangelog
(
        id              number
			constraint rhn_pkg_cl_id_nn not null
                        constraint rhn_pkg_cl_id_pk primary key
                        using index tablespace [[64k_tbs]],
	package_id      number
                        constraint rhn_pkg_changelog_pid_nn not null
                        constraint rhn_pkg_changelog_pid_fk
				references rhnPackage(id),
        name            varchar2(128)
			constraint rhn_pkg_changelog_name not null,
        text            varchar2(3000)
			constraint rhn_pkg_changelog_text not null,
        time            date
			constraint rhn_pkg_changelog_time not null,
        created         date default(sysdate)
			constraint rhn_pkg_changelog_created_nn not null,
        modified        date default(sysdate)
			constraint rhn_pkg_changelog_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_pkg_cl_id_seq;
create unique index rhn_pkg_cl_pid_n_txt_time_uq
        on rhnPackageChangelog(package_id, name, text, time)
        nologging tablespace [[32m_tbs]]
  ;
create or replace trigger 
rhn_package_changelog_mod_trig
before insert or update on rhnPackageChangelog
for each row 
begin 
        :new.modified := sysdate; 
end;
/
create or replace trigger
rhn_package_changelog_id_trig
before insert on rhnPackageChangelog
for each row
when (new.id is null)
begin
        select rhn_pkg_cl_id_seq.nextval into :new.id from dual;
end;
/ 
show errors 

select 'rhnsat/tables/rhnPackageConflicts.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageConflicts.sql
create table
rhnPackageConflicts
(
        package_id      number
                        constraint rhn_pkg_conflicts_pid_nn not null
                        constraint rhn_pkg_conflicts_package_fk
                                references rhnPackage(id),
        capability_id   number
                        constraint rhn_pkg_conflicts_cid_nn not null
                        constraint rhn_pkg_conflicts_cap_fk
                                references rhnPackageCapability(id),
        sense           number default(0) -- comes from RPMSENSE_*
                        constraint rhn_pkg_conflicts_sense_nn not null,
        created         date default (sysdate)
                        constraint rhn_pkg_conflicts_ctime_nn not null,
        modified        date default (sysdate)
                        constraint rhn_pkg_conflicts_mtime_nn not null
)
	enable row movement
  ;
create unique index rhn_pkg_confl_pid_cid_s_uq
	on rhnPackageConflicts(package_id, capability_id, sense)
	tablespace [[64k_tbs]]
  ;
create index rhn_pkg_conflicts_cid_idx
	on rhnPackageConflicts(capability_id)
        tablespace [[64k_tbs]]
	nologging;
create or replace trigger
rhn_pkg_conflicts_mod_trig
before insert or update on rhnPackageConflicts
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnTransactionOperation.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTransactionOperation.sql
create table
rhnTransactionOperation
(
	id		number
			constraint rhn_transop_id_nn not null
			constraint rhn_transop_id_pk primary key
				using index tablespace [[8m_tbs]],
	label		varchar2(32)
			constraint rhn_transop_label_nn not null
			constraint rhn_transop_label_uq unique
				using index tablespace [[8m_tbs]],
	created		date default(sysdate)
			constraint rhn_transop_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_transop_modified_nn not null
)
	enable row movement
  ;
create index rhn_transop_label_id_idx
	on rhnTransactionOperation(label,id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnTransactionPackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTransactionPackage.sql
create table
rhnTransactionPackage
(
	id		number
			constraint rhn_transpack_id_nn not null
			constraint rhn_transpack_id_pk primary key
				using index tablespace [[8m_tbs]],
	operation	number
			constraint rhn_transpack_op_nn not null
			constraint rhn_transpack_op_fk
				references rhnTransactionOperation(id),
	name_id		number
			constraint rhn_transpack_nid_nn not null
			constraint rhn_transpack_nid_fk
				references rhnPackageName(id),
	evr_id		number
			constraint rhn_transpack_eid_nn not null
			constraint rhn_transpack_eid_fk
				references rhnPackageEVR(id),
	package_arch_id	number
			constraint rhn_transpack_paid_fk
				references rhnPackageArch(id)
)
	enable row movement
  ;
create unique index rhn_transpack_onea_uq
	on rhnTransactionPackage(operation, name_id, evr_id, package_arch_id)
	tablespace [[8m_tbs]]
  ;
create sequence rhn_transpack_id_seq;

select 'rhnsat/tables/rhnPackageDeltaElement.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageDeltaElement.sql
create table
rhnPackageDeltaElement
(
	package_delta_id	number
				constraint rhn_pdelement_pdid_nn not null
				constraint rhn_pdelement_pdid_fk
					references rhnPackageDelta(id)
					on delete cascade,
	transaction_package_id	number
				constraint rhn_pdelement_tpid_nn not null
				constraint rhn_pdelement_tpid_fk
					references rhnTransactionPackage(id)
)
	enable row movement
  ;
create unique index rhn_pdelement_pdid_tpid_uq
	on rhnPackageDeltaElement(package_delta_id, transaction_package_id)
	tablespace [[8m_tbs]]
  ;

select 'rhnsat/tables/rhnPackageFile.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageFile.sql
create table
rhnPackageFile
(
	package_id	number
			constraint rhn_package_file_pid_nn not null
			constraint rhn_package_file_pid_fk
				references rhnPackage(id),
	capability_id	number
			constraint rhn_package_file_cid_nn not null
			constraint rhn_package_file_cid_fk
				references rhnPackageCapability(id),
	device		number
			constraint rhn_package_file_devices_nn not null,
	inode		number
			constraint rhn_package_file_inode_nn not null,
	file_mode	number
			constraint rhn_package_file_mode_nn not null,
	username	varchar2(32)
			constraint rhn_package_file_username_nn not null,
	groupname	varchar2(32)
			constraint rhn_package_file_groupname_nn not null,
	rdev		number
			constraint rhn_package_file_dev_nn not null,
	file_size	number
			constraint rhn_package_file_size_nn not null,
	mtime		date
			constraint rhn_package_file_mtime_nn not null,
	md5		varchar2(32),
	linkto		varchar2(256),
	flags		number
			constraint rhn_package_file_flags_nn not null,
	verifyflags	number
			constraint rhn_package_file_verify_nn not null,
	lang		varchar2(32),
	created		date default (sysdate)
			constraint rhn_package_file_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_package_file_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_package_file_pid_cid_uq
	on rhnPackageFile(package_id, capability_id)
	tablespace [[32m_tbs]]
  ;
create index rhn_package_file_cid_pid_idx
	on rhnPackageFile(capability_id, package_id)
	tablespace [[32m_tbs]]
	nologging;
create or replace trigger
rhn_packagefile_mod_trig
before insert or update on rhnPackageFile
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPackageFileDeleteQueue.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageFileDeleteQueue.sql
create table
rhnPackageFileDeleteQueue
(
        path            varchar2(1000),
	created			date default(sysdate)
				constraint rhn_pfdqueue_created_nn not null
)
	enable row movement
  ;
alter table rhnPackageFileDeleteQueue add constraint rhn_pfdqueue_path_uq
	unique ( path );

select 'rhnsat/tables/rhnPackageGroup_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageGroup_data.sql
insert into rhnPackageGroup values (rhn_package_group_id_seq.nextval,'NoGroup',
        sysdate,sysdate);
commit;

select 'rhnsat/tables/rhnPackageKeyType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageKeyType.sql
create table
rhnPackageKeyType
(
	id		number
			constraint rhn_pkg_key_type_id_nn not null,
	label		varchar2(64)
			constraint rhn_pkg_key_type_label_nn not null,
	created		date default(sysdate)
			constraint rhn_pkg_key_type_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_pkg_key_type_modified_nn not null
)
  ;
create sequence rhn_package_key_type_id_seq start with 100;
create index rhn_pkg_key_type_id_n_idx
	on rhnPackageKeyType(id,label)
	tablespace [[2m_tbs]]
  ;
alter table rhnPackageKeyType add constraint rhn_pkg_key_type_id_pk primary key (id);
alter table rhnPackageKeyType add constraint rhn_pkg_key_type_label_uq unique ( label );
create or replace trigger
rhn_pkg_key_type_mod_trig
before insert or update on rhnPackageKeyType
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPackageProvider.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageProvider.sql
create table
rhnPackageProvider
(
	id		number
			constraint rhn_pkg_provider_id_nn not null,
	name		varchar2(64)
			constraint rhn_pkg_provider_key_nn not null,
	created		date default(sysdate)
			constraint rhn_pkg_provider_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_pkg_provider_modified_nn not null
)
  ;
create sequence rhn_package_provider_id_seq start with 100;
create index rhn_pkg_provider_id_n_idx
	on rhnPackageProvider(id,name)
	tablespace [[2m_tbs]]
  ;
alter table rhnPackageProvider add constraint rhn_pkg_provider_id_pk primary key (id);
alter table rhnPackageProvider add constraint rhn_pkg_provider_name_uq unique ( name );
create or replace trigger
rhn_pkg_provider_mod_trig
before insert or update on rhnPackageProvider
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPackageKey.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageKey.sql
create table
rhnPackageKey
(
	id		number
			constraint rhn_pkey_id_nn not null,
	key_id		varchar2(64)
			constraint rhn_pkey_key_nn not null,
	key_type_id	number
			constraint rhn_pkey_type_id_nn not null
                        constraint rhn_pkey_type_id_prid_fk
                                references rhnPackageKeyType(id),
	provider_id	number
                        constraint rhn_pkey_prid_fk
				references rhnPackageProvider(id),
	created		date default(sysdate)
			constraint rhn_pkey_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_pkey_modified_nn not null
)
  ;
create sequence rhn_pkey_id_seq start with 100;
create index rhn_pkey_id_k_pid_idx
	on rhnPackageKey(id,key_id,provider_id,key_type_id)
	tablespace [[2m_tbs]]
  ;
alter table rhnPackageKey add constraint rhn_pkey_id_pk primary key (id);
alter table rhnPackageKey add constraint rhn_pkey_keyid_uq unique ( key_id );
create or replace trigger
rhn_pkg_gpg_mod_trig
before insert or update on rhnPackageKey
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPackageKeyAssociation.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageKeyAssociation.sql
create table
rhnPackageKeyAssociation
(
	package_id	number
			constraint rhn_pkeya_pid_nn not null 
			constraint rhn_pkeya_pid_fk
				references rhnPackage(id) on delete cascade,
	key_id	number
			constraint rhn_pkeya_kid_nn not null
			constraint rhn_pkeya_kid_fk
				references rhnPackageKey(id),
	created		date default (sysdate)
			constraint rhn_pkeya_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_pkeya_modified_nn not null
)
  ;
create unique index rhn_pkeya_pk_uq
	on rhnPackageKeyAssociation(package_id,key_id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnPackageKeyType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageKeyType_data.sql
insert into rhnPackageKeyType (id, label) values
(rhn_package_key_type_id_seq.nextval, 'gpg' );
insert into rhnPackageKeyType (id, label) values
(rhn_package_key_type_id_seq.nextval, 'pgp' );
insert into rhnPackageKeyType (id, label) values
(rhn_package_key_type_id_seq.nextval, 'rsa' );
insert into rhnPackageKeyType (id, label) values
(rhn_package_key_type_id_seq.nextval, 'dsa' );
commit;

select 'rhnsat/procs/lookup_package_provider.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_package_provider.sql
create or replace function
lookup_package_provider(name_in in varchar2)
return number
is
	package_provider_id number;
begin
	select id into package_provider_id from rhnPackageProvider where name = name_in;
	return package_provider_id;
exception
	when no_data_found then
		rhn_exception.raise_exception('package_provider_not_found');
end;
/
show errors

select 'rhnsat/procs/lookup_package_key_type.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_package_key_type.sql
create or replace function
lookup_package_key_type(label_in in varchar2)
return number
is
	package_key_type_id number;
begin
	select id into package_key_type_id from rhnPackageKeyType where label = label_in;
	return package_key_type_id;
exception
	when no_data_found then
		rhn_exception.raise_exception('package_key_type_not_found');
end;
/
show errors

select 'rhnsat/tables/rhnPackageProvider_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageProvider_data.sql
insert into rhnPackageProvider (id, name) values
(rhn_package_provider_id_seq.nextval, 'Red Hat Inc.' );
insert into rhnPackageProvider (id, name) values
(rhn_package_provider_id_seq.nextval, 'Fedora' );
insert into rhnPackageProvider (id, name) values
(rhn_package_provider_id_seq.nextval, 'CentOS' );
insert into rhnPackageProvider (id, name) values
(rhn_package_provider_id_seq.nextval, 'Scientific Linux' );
insert into rhnPackageProvider (id, name) values
(rhn_package_provider_id_seq.nextval, 'Suse' );
insert into rhnPackageProvider (id, name) values
(rhn_package_provider_id_seq.nextval, 'Oracle Inc.' );
commit;

select 'rhnsat/tables/rhnPackageKey_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageKey_data.sql
insert into rhnPackageKey (id, key_id, key_type_id, provider_id) values
(rhn_pkey_id_seq.nextval, '5326810137017186', lookup_package_key_type('gpg'), lookup_package_provider('Red Hat Inc.'));
insert into rhnPackageKey (id, key_id, key_type_id, provider_id) values
(rhn_pkey_id_seq.nextval, '219180cddb42a60e', lookup_package_key_type('gpg'), lookup_package_provider('Red Hat Inc.'));
insert into rhnPackageKey (id, key_id, key_type_id, provider_id) values
(rhn_pkey_id_seq.nextval, 'b44269d04f2a6fd2', lookup_package_key_type('gpg'), lookup_package_provider('Fedora'));
insert into rhnPackageKey (id, key_id, key_type_id, provider_id) values
(rhn_pkey_id_seq.nextval, 'a8a447dce8562897', lookup_package_key_type('gpg'), lookup_package_provider('CentOS'));
insert into rhnPackageKey (id, key_id, key_type_id, provider_id) values
(rhn_pkey_id_seq.nextval, '2802e89216ff0e46', lookup_package_key_type('gpg'), lookup_package_provider('CentOS'));
insert into rhnPackageKey (id, key_id, key_type_id, provider_id) values
(rhn_pkey_id_seq.nextval, 'a53d0bab443e1821', lookup_package_key_type('gpg'), lookup_package_provider('CentOS'));
insert into rhnPackageKey (id, key_id, key_type_id, provider_id) values
(rhn_pkey_id_seq.nextval, '7049e44d025e513b', lookup_package_key_type('gpg'), lookup_package_provider('CentOS'));
insert into rhnPackageKey (id, key_id, key_type_id, provider_id) values
(rhn_pkey_id_seq.nextval, '25dbef78a7048f8d', lookup_package_key_type('gpg'), lookup_package_provider('Scientific Linux'));
insert into rhnPackageKey (id, key_id, key_type_id, provider_id) values
(rhn_pkey_id_seq.nextval, '66ced3de1e5e0159', lookup_package_key_type('gpg'), lookup_package_provider('Oracle Inc.'));
insert into rhnPackageKey (id, key_id, key_type_id, provider_id) values
(rhn_pkey_id_seq.nextval, '2e2bcdbcb38a8516', lookup_package_key_type('gpg'), lookup_package_provider('Oracle Inc.'));
insert into rhnPackageKey (id, key_id, key_type_id, provider_id) values
(rhn_pkey_id_seq.nextval, 'a84edae89c800aca', lookup_package_key_type('gpg'), lookup_package_provider('Suse'));
commit;

select 'rhnsat/tables/rhnPackageObsoletes.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageObsoletes.sql
create table
rhnPackageObsoletes
(
        package_id      number
                        constraint rhn_pkg_obsoletes_pid_nn not null
                        constraint rhn_pkg_obsoletes_package_fk
                                references rhnPackage(id),
        capability_id   number
                        constraint rhn_pkg_obsoletes_cid_nn not null
                        constraint rhn_pkg_obsoletes_cap_fk
                                references rhnPackageCapability(id),
        sense           number default(0) -- comes from RPMSENSE_*
                        constraint rhn_pkg_obsoletes_sense_nn not null,
        created         date default (sysdate)
                        constraint rhn_pkg_obsoletes_ctime_nn not null,
        modified        date default (sysdate)
                        constraint rhn_pkg_obsoletes_mtime_nn not null
)
	enable row movement
  ;
create unique index rhn_pkg_obsol_pid_cid_s_uq
	on rhnPackageObsoletes(package_id, capability_id, sense)
	tablespace [[64k_tbs]]
  ;
create index rhn_pkg_obsoletes_cid_idx
	on rhnPackageObsoletes(capability_id)
        nologging tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_pkg_obsoletes_mod_trig
before insert or update on rhnPackageObsoletes
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPackageProvides.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageProvides.sql
create table
rhnPackageProvides
(
        package_id      number
                        constraint rhn_pkg_provides_pid_nn not null
                        constraint rhn_pkg_provides_package_fk
                                references rhnPackage(id),
        capability_id   number
                        constraint rhn_pkg_provides_cid_nn not null
                        constraint rhn_pkg_provides_capability_fk
                                references rhnPackageCapability(id),
        sense           number default(0) -- comes from RPMSENSE_*
                        constraint rhn_pkg_provides_sense_nn not null,
        created         date default (sysdate)
                        constraint rhn_pkg_provides_ctime_nn not null,
        modified        date default (sysdate)
                        constraint rhn_pkg_provides_mtime_nn not null
)
	enable row movement
  ;
create unique index rhn_pkg_prov_cid_pid_s_uq
	on rhnPackageProvides(capability_id, package_id, sense)
	tablespace [[2m_tbs]]
  ;
create index rhn_pkg_provides_pid_idx
	on rhnPackageProvides(package_id)
        nologging tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_pkg_provides_mod_trig
before insert or update on rhnPackageProvides
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPackageRequires.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageRequires.sql
create table
rhnPackageRequires
(
        package_id      number
                        constraint rhn_pkg_requires_pid_nn not null
                        constraint rhn_pkg_requires_package_fk
                                references rhnPackage(id),
        capability_id   number
                        constraint rhn_pkg_requires_cid_nn not null
                        constraint rhn_pkg_requires_capability_fk
                                references rhnPackageCapability(id),
        sense           number default(0) -- comes from RPMSENSE_*
                        constraint rhn_pkg_requires_sense_nn not null,
        created         date default (sysdate)
                        constraint rhn_pkg_requires_ctime_nn not null,
        modified        date default (sysdate)
                        constraint rhn_pkg_requires_mtime_nn not null
)
	enable row movement
  ;
create unique index rhn_pkg_req_pid_cid_s_uq
	on rhnPackageRequires(package_id, capability_id, sense)
	tablespace [[4m_tbs]]
  ;
create index rhn_pkg_requires_cid_idx
	on rhnPackageRequires(capability_id)
        nologging tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_pkg_requires_mod_trig
before insert or update on rhnPackageRequires
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPackageSense.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageSense.sql
create table
rhnPackageSense
(
	id		number
			constraint rhn_pkg_sense_id_nn not null
			constraint rhn_pkg_sense_id_pk primary key
			using index tablespace [[64k_tbs]],
	label		varchar2(32)
			constraint rhn_pkg_sense_label_nn not null
)
	enable row movement
  ;
create unique index rhn_pkg_sense_label_uq
	on rhnPackageSense(label)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnPackageSenseMap.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageSenseMap.sql
create table
rhnPackageSenseMap
(
	sense		number
			constraint rhn_pkg_sensemap_sense_nn not null,
	sense_id	number
			constraint rhn_pkg_sensemap_sid_nn not null
			constraint rhn_pkg_sensemap_sid_fk
				references rhnPackageSense(id)
)
	enable row movement
  ;
create unique index rhn_pkg_sensemap_s_sid_uq
	on rhnPackageSenseMap(sense,sense_id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnPackageSense_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageSense_data.sql
insert into rhnPackageSense(id, label) values (       0,'RPMSENSE_ANY');
insert into rhnPackageSense(id, label) values (       1,'RPMSENSE_SERIAL');
insert into rhnPackageSense(id, label) values (       2,'RPMSENSE_LESS');
insert into rhnPackageSense(id, label) values (       4,'RPMSENSE_GREATER');
insert into rhnPackageSense(id, label) values (       8,'RPMSENSE_EQUAL');
insert into rhnPackageSense(id, label) values (      16,'RPMSENSE_PROVIDES');
insert into rhnPackageSense(id, label) values (      32,'RPMSENSE_CONFLICTS');
insert into rhnPackageSense(id, label) values (      64,'RPMSENSE_PREREQ');
insert into rhnPackageSense(id, label) values (     128,'RPMSENSE_OBSOLETES');
insert into rhnPackageSense(id, label) values (     256,'RPMSENSE_INTERP');
insert into rhnPackageSense(id, label) values (     512,'RPMSENSE_SCRIPT_PRE');
insert into rhnPackageSense(id, label) values (    1024,'RPMSENSE_SCRIPT_POST');
insert into rhnPackageSense(id, label) values (    2048,'RPMSENSE_SCRIPT_PREUN');
insert into rhnPackageSense(id, label) values (    4096,'RPMSENSE_SCRIPT_POSTUN');
insert into rhnPackageSense(id, label) values (    8192,'RPMSENSE_SCRIPT_VERIFY');
insert into rhnPackageSense(id, label) values (   16384,'RPMSENSE_FIND_REQUIRES');
insert into rhnPackageSense(id, label) values (   32768,'RPMSENSE_FIND_PROVIDES');
insert into rhnPackageSense(id, label) values (   65536,'RPMSENSE_TRIGGERIN');
insert into rhnPackageSense(id, label) values (  131072,'RPMSENSE_TRIGGERUN');
insert into rhnPackageSense(id, label) values (  262144,'RPMSENSE_TRIGGERPOSTUN');
insert into rhnPackageSense(id, label) values (  524288,'RPMSENSE_MULTILIB');
insert into rhnPackageSense(id, label) values ( 1048576,'RPMSENSE_SCRIPT_PREP');
insert into rhnPackageSense(id, label) values ( 2097152,'RPMSENSE_SCRIPT_BUILD');
insert into rhnPackageSense(id, label) values ( 4194304,'RPMSENSE_SCRIPT_INSTALL');
insert into rhnPackageSense(id, label) values ( 8388608,'RPMSENSE_SCRIPT_CLEAN');
insert into rhnPackageSense(id, label) values (16777216,'RPMSENSE_RPMLIB');
insert into rhnPackageSense(id, label) values (33554432,'RPMSENSE_TRIGGERPREIN');

select 'rhnsat/tables/rhnPackageSyncBlacklist.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageSyncBlacklist.sql
create table
rhnPackageSyncBlacklist
(
	package_name_id		number
				constraint rhn_packagesyncbl_pnid_nn not null
				constraint rhn_packagesyncbl_pnid_fk
					references rhnPackageName(id),
	org_id			number
				constraint rhn_packagesyncbl_oid_fk
					references web_customer(id)
					on delete cascade,
	created			date default(sysdate)
				constraint rhn_packagesyncbl_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_packagesyncbl_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_packagesyncbl_pnid_oid_uq on
	rhnPackageSyncBlacklist( package_name_id, org_id )
	tablespace [[64k_tbs]]
  ;
create index rhn_packagesyncbl_oid_idx on
	rhnPackageSyncBlacklist( org_id )
	tablespace [[64k_tbs]]
	nologging;
create or replace trigger
rhn_packagesyncbl_mod_trig
before insert or update on rhnPackageSyncBlacklist
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPackageSyncBlacklist_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPackageSyncBlacklist_data.sql
insert into rhnPackageSyncBlacklist (package_name_id)
	values (lookup_package_name('gpg-pubkey'));
insert into rhnPackageSyncBlacklist (package_name_id)
	values (lookup_package_name('rhns-ca-cert'));
insert into rhnPackageSyncBlacklist (package_name_id)
	values (lookup_package_name('rhn-org-trusted-ssl-cert'));
commit;

select 'rhnsat/tables/rhnPaidErrataTempCache.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPaidErrataTempCache.sql
create global temporary table rhnPaidErrataTempCache
(
  errata_id number,
  user_id number,
  server_id number
) on commit preserve rows;
create index rhnpec_u_idx on rhnPaidErrataTempCache(user_id);

select 'rhnsat/tables/rhnPathChannelMap.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPathChannelMap.sql
create table rhnPathChannelMap
(
	path		varchar2(128)
			constraint rhn_path_channel_map_p_nn not null,
	channel_id	number
			constraint rhn_path_channel_map_cid_nn not null
			constraint rhn_path_channel_map_cid_fk
				references rhnChannel(id) on delete cascade,
	is_source	varchar2(1),
	created		date default SYSDATE,
	modified	date default SYSDATE
)
	enable row movement
  ;
create unique index rhn_path_channel_map_p_cid_uq 
	on rhnPathChannelMap(path, channel_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_path_channel_map_cid_p_idx
	on rhnPathChannelMap(channel_id, path)
	tablespace [[64k_tbs]]
	nologging;
create or replace trigger
rhn_path_channel_map_mod_trig
before insert or update on rhnPathChannelMap
for each row
begin
	:new.modified := SYSDATE;
end rhn_beehive_mod_trig;
/
show errors

select 'rhnsat/tables/rhnPrivateChannelFamily_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPrivateChannelFamily_triggers.sql
create or replace trigger
rhn_privcf_mod_trig
before insert or update on rhnPrivateChannelFamily
for each row
begin
    :new.modified := sysdate;
end;
/
show errors;

select 'rhnsat/tables/rhnProductLine.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnProductLine.sql
create sequence rhn_prod_line_id_seq start with 101;
create table
rhnProductLine
(
	id		number
			constraint rhn_prod_line_id_nn not null,
	label		varchar2(128)
			constraint rhn_prod_line_label_nn not null,
	name		varchar2(128)
			constraint rhn_prod_line_name_nn not null,
	last_modified	date default (sysdate)
			constraint rhn_prod_line_lm_nn not null,
	created		date default (sysdate)
			constraint rhn_prod_line_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_prod_line_modified_nn not null
)
	enable row movement
  ;
create index rhn_prod_line_id_idx
	on rhnProductLine ( id )
	tablespace [[64k_tbs]]
  ;
alter table rhnProductLine add constraint rhn_prod_line_id_pk
	primary key ( id );
create index rhn_prod_line_label_idx
	on rhnProductLine(label)
	tablespace [[64k_tbs]]
  ;
alter table rhnProductLine add constraint rhn_prod_line_label_uq
	unique ( label );
create index rhn_prod_line_name_idx
	on rhnProductLine(name)
	tablespace [[64k_tbs]]
  ;
alter table rhnProductLine add constraint rhn_prod_line_name_uq
	unique ( name );
create or replace trigger
rhn_prod_line_mod_trig
before insert or update on rhnProductLine
for each row
begin
	:new.modified := sysdate;
	:new.last_modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnProduct.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnProduct.sql
create sequence rhn_product_id_seq start with 101;
create table
rhnProduct
(
	id		number
			constraint rhn_product_id_nn not null,
	label		varchar2(128)
			constraint rhn_product_label_nn not null,
	name		varchar2(128)
			constraint rhn_product_name_nn not null,
	product_line_id	number
        		constraint rhn_product_cat_nn not null 
			constraint rhn_product_cat_fk
				references rhnProductLine(id)
				on delete cascade,
	last_modified	date default (sysdate)
			constraint rhn_product_lm_nn not null,
	created		date default (sysdate)
			constraint rhn_product_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_product_modified_nn not null
)
	enable row movement
  ;
create index rhn_product_id_idx
	on rhnProduct(id)
	tablespace [[64k_tbs]]
  ;
alter table rhnProduct add constraint rhn_product_id_pk
	primary key ( id );
create index rhn_product_label_idx
	on rhnProduct(label)
	tablespace [[64k_tbs]]
  ;
alter table rhnProduct add constraint rhn_product_label_uq
	unique ( label );
create index rhn_product_name_idx
	on rhnProduct(name)
	tablespace [[64k_tbs]]
  ;
alter table rhnProduct add constraint rhn_product_name_uq
	unique ( name );
create or replace trigger
rhn_product_mod_trig
before insert or update on rhnProduct
for each row
begin
	:new.modified := sysdate;
	:new.last_modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnProductChannel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnProductChannel.sql
create table
rhnProductChannel
(
	channel_id	number
			constraint rhn_pc_cid_nn not null 
			constraint rhn_pc_cid_fk
				references rhnChannel(id)
				on delete cascade,
	product_id	number
			constraint rhn_pc_pid_nn not null
			constraint rhn_pc_pid_fk
				references rhnProduct(id),
	created		date default (sysdate)
			constraint rhn_pc_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_pc_modified_nn not null
)
	enable row movement
  ;
create index rhn_pc_cid_pid_idx
	on rhnProductChannel ( channel_id, product_id )
	tablespace [[64k_tbs]]
  ;
alter table rhnProductChannel add constraint rhn_pc_cid_pid_idx
	unique ( channel_id, product_id );
create index rhn_pc_pid_cid_idx
	on rhnProductChannel ( product_id, channel_id )
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnProductLine_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnProductLine_data.sql
insert into rhnProductLine
(id, label, name)
values
(1, 'rhl', 'Red Hat Linux');
insert into rhnProductLine
(id, label, name)
values
(2, 'rhel', 'Red Hat Enterprise Linux');
insert into rhnProductLine
(id, label, name)
values
(3, 'rhdb', 'Red Hat Database');
insert into rhnProductLine
(id, label, name)
values
(4, 'stronghold', 'Stronghold');

select 'rhnsat/tables/rhnProxyInfo.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnProxyInfo.sql
create table
rhnProxyInfo
(
        server_id       number
			constraint rhn_proxy_info_sid_nn not null
                        constraint rhn_proxy_info_sid_fk
				references rhnServer(id),
	proxy_evr_id	number
			constraint rhn_proxy_info_peid_fk
				references rhnPackageEVR(id)
)
	enable row movement
  ;
create unique index rhn_proxy_info_sid_unq on
        rhnProxyInfo(server_id)
  ;

select 'rhnsat/tables/rhnPushClientState.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPushClientState.sql
create sequence rhn_pclient_state_id_seq;
create table
rhnPushClientState
(
	id		number
			constraint rhn_pclient_state_id_nn not null
			constraint rhn_pclient_state_id_pk primary key
				using index tablespace [[4m_tbs]],
	label		varchar2(64)
			constraint rhn_pclient_state_label_nn not null,
	name		varchar2(256)
			constraint rhn_pclient_state_name_nn not null,
	created		date default sysdate
			constraint rhn_pclient_state_created_nn not null,
	modified	date default sysdate
			constraint rhn_pclient_state_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_pclient_state_label_uq
	on rhnPushClientState( label )
	tablespace [[4m_tbs]]
  ;
create unique index rhn_pclient_state_name_uq
	on rhnPushClientState( name )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_pclient_state_mod_trig
before insert or update on rhnPushClientState
for each row
begin
	:new.modified := sysdate;
end rhn_pclient_state_mod_trig;
/
show errors

select 'rhnsat/tables/rhnPushClient.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPushClient.sql
create sequence rhn_pclient_id_seq;
create table
rhnPushClient
(
	id		number
			constraint rhn_pclient_id_nn not null
			constraint rhn_pclient_id_pk primary key
				using index tablespace [[4m_tbs]],
	name		varchar2(64)
			constraint rhn_pclient_name_nn not null,
	server_id	number
			constraint rhn_pclient_sid_nn not null,
	jabber_id	varchar2(128),
	shared_key	varchar2(64)
			constraint rhn_pclient_skey_nn not null,
        state_id        number
			constraint rhn_pclient_stid_nn not null
                        references rhnPushClientState(id),
        next_action_time    date,
        last_message_time   date,
        last_ping_time      date,
	created		date default sysdate
			constraint rhn_pclient_created_nn not null,
	modified	date default sysdate
			constraint rhn_pclient_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_pclient_name_uq
	on rhnPushClient( name )
	tablespace [[8m_tbs]]
  ;
create unique index rhn_pclient_sid_uq
	on rhnPushClient( server_id )
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_pclient_mod_trig
before insert or update on rhnPushClient
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnPushClientState_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPushClientState_data.sql
insert into rhnPushClientState (id, label, name)
    values (rhn_pclient_state_id_seq.nextval, 'online', 'online');
insert into rhnPushClientState (id, label, name)
    values (rhn_pclient_state_id_seq.nextval, 'offline', 'offline');
commit;

select 'rhnsat/tables/rhnPushDispatcher.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnPushDispatcher.sql
create sequence rhn_pushdispatch_id_seq;
create table
rhnPushDispatcher
(
		id		number
				constraint rhn_pushdispatch_id_nn not null
				constraint rhn_pushdispatch_id_pk primary key
					using index tablespace [[8m_tbs]],
		jabber_id	varchar2(128)
				constraint rhn_pushdispatch_jid_nn not null,
		last_checkin	date default sysdate
				constraint rhn_pushdispatch_lc_nn not null,
		hostname	varchar2(256)
				constraint rhn_pushdispatch_hn_nn not null,
		port		number
				constraint rhn_pushdispatch_port_nn not null,
		created		date default sysdate
				constraint rhn_pushdispatch_creat_nn not null,
		modified	date default sysdate
				constraint rhn_pushdispatch_mod_nn not null
)
	enable row movement
  ;
create index rhn_pushdispatch_jid_id_idx
	on rhnPushDispatcher( jabber_id, id )
	tablespace [[4m_tbs]]
  ;
alter table rhnPushDispatcher add constraint rhn_pushdispatch_jid_uq
	unique ( jabber_id );
create or replace trigger
rhn_pushdispatch_mod_trig
before insert or update on rhnPushDispatcher
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnRam.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnRam.sql
create table
rhnRam
(
        id              number
			constraint rhn_ram_id_nn not null
                        constraint rhn_ram_id_pk primary key
                        using index tablespace [[4m_tbs]],
        server_id       number
			constraint rhn_ram_server_nn not null
                        constraint rhn_ram_server_fk
                                references rhnServer(id),
        ram             number
			constraint rhn_ram_ram_nn not null,
        swap            number
			constraint rhn_ram_swap_nn not null,
        created         date default(sysdate)
			constraint rhn_ram_created_nn not null,
        modified        date default(sysdate)
			constraint rhn_ram_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_ram_id_seq;
create index rhn_ram_sid_idx on
        rhnRam(server_id)
        tablespace [[4m_tbs]]
	nologging;
create or replace trigger
rhn_ram_mod_trig
before insert or update on rhnRam
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnRedHatCanonVersion.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnRedHatCanonVersion.sql
create table rhnRedHatCanonVersion
(
        version         varchar2(32)
                        constraint rhn_rh_canon_ver_v_nn not null
                        constraint rhn_rh_canon_ver_v_pk primary key,
        canon_version   varchar2(32)
                        constraint rhn_rh_canon_ver_cv_nn not null,
	created		date default(sysdate)
			constraint rhn_rh_canon_ver_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_rh_canon_ver_modified_nn not null
)
	enable row movement
  ;

select 'rhnsat/tables/rhnRedHatCanonVersion_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnRedHatCanonVersion_data.sql
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7.1'         , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red_Hat_Linux_7.1'         , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.1sbe'                    , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7.0.91'      , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7.0.95'      , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0.90'                    , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0.91'                    , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0.93'                    , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0.95'                    , '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7'           , '7.0');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7.0j'        , '7.0');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0J'                      , '7.0');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0.1J'                    , '7.0');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 6.2'         , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red_Hat_Linux_6.2'         , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red_Hat_Linux_6.1'         , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2EE'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2.2'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2de'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2fr'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2es'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2it'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2ja'                     , '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7.2'         , '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red Hat Linux 7.2 i386'    , '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'redhat-linux-i686-7.0'     , '7.0');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    'Red_Hat_Linux_7.2'         , '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '6.2-1'			, '6.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.0.98'			, '7.1');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.1.90'			, '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.1.90EE'			, '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.1.91AS'			, '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.1.93'			, '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.1.94'			, '7.2');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.2.93'                    , '7.3');
insert into rhnRedHatCanonVersion (version, canon_version) values (
    '7.2.94'                    , '7.3');
commit;

select 'rhnsat/tables/rhnRegTokenChannels.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnRegTokenChannels.sql
create table
rhnRegTokenChannels
(
	token_id	number
			constraint rhn_reg_tok_chn_tid_nn not null
			constraint rhn_reg_tok_chn_id_fk
				references rhnRegToken(id)
				on delete cascade,
        channel_id number
                        constraint rhn_reg_tok_chn_sg_nn not null
                        constraint rhn_reg_tok_chn_sgs_fk
                                references rhnChannel(id)
				on delete cascade
)
	enable row movement
  ;
create unique index rhn_reg_tok_chn_uq
	on rhnRegTokenChannels(token_id, channel_id)
	tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnRegTokenConfigChannels.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnRegTokenConfigChannels.sql
create table
rhnRegTokenConfigChannels
(
	token_id		number
				constraint rhn_regtok_confchan_tid_nn not null
				constraint rhn_regtok_confchan_tid_fk
					references rhnRegToken(id)
					on delete cascade,
	config_channel_id	number
				constraint rhn_regtok_confchan_ccid_nn not null
				constraint rhn_regtok_confchan_ccid_fk
					references rhnConfigChannel(id)
					on delete cascade,
	position		number
				constraint rhn_regtok_confchan_pos_nn not null
)
	enable row movement
  ;
create unique index rhn_regtok_confchan_t_cc_uq
	on rhnRegTokenConfigChannels( token_id, config_channel_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_regtok_confchan_ccid_idx
	on rhnRegTokenConfigChannels( config_channel_id )
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnRegTokenEntitlement.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnRegTokenEntitlement.sql
create table rhnRegTokenEntitlement (
   reg_token_id         number
                        constraint rhn_reg_tok_ent_rtid_nn not null
                        constraint rhn_reg_tok_ent_rtid_fk references rhnRegToken(id)
                        on delete cascade,
   server_group_type_id number
                        constraint rhn_reg_tok_ent_sgtid_nn not null
                        constraint rhn_reg_tok_ent_sgtid_fk references rhnServerGroupType(id)
                        on delete cascade
)
   enable row movement
  ;
create unique index rhn_rte_rtid_sgtid_uq_idx
on rhnRegTokenEntitlement (reg_token_id, server_group_type_id)
   tablespace [[64k_tbs]]
   nologging;

select 'rhnsat/tables/rhnRegTokenGroups.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnRegTokenGroups.sql
create table
rhnRegTokenGroups
(
	token_id	number
			constraint rhn_reg_tok_grp_tid_nn not null
			constraint rhn_reg_tok_grp_id_fk
				references rhnRegToken(id)
				on delete cascade,
        server_group_id number
                        constraint rhn_reg_tok_grp_sg_nn not null
                        constraint rhn_reg_tok_grp_sgs_fk
                                references rhnServerGroup(id)
				on delete cascade
)
	enable row movement
  ;
create unique index rhn_reg_tok_grp_uq
	on rhnRegTokenGroups(token_id, server_group_id)
	tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnRegTokenOrgDefault.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnRegTokenOrgDefault.sql
create table
rhnRegTokenOrgDefault
(
	org_id		number
			constraint rhn_reg_token_def_oid_nn not null
			constraint rhn_reg_token_def_oid_fk
				references web_customer(id)
				on delete cascade,
	reg_token_id	number
			constraint rhn_reg_token_def_tokid_fk
				references rhnRegToken(id)
				on delete cascade
)
	enable row movement
	;
create unique index rhn_reg_token_def_org_id_idx
	on rhnRegTokenOrgDefault(org_id)
  ;
create index rhn_reg_token_def_uid_idx
	on rhnRegTokenOrgDefault (reg_token_id, org_id)
  ;

select 'rhnsat/tables/rhnRegTokenPackages.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnRegTokenPackages.sql
create table
rhnRegTokenPackages
(
        id              number
                        constraint rhn_reg_tok_pkg_id_nn not null
                        constraint rhn_reg_tok_pkg_id_pk primary key,
	token_id	number
			constraint rhn_reg_tok_pkg_tid_nn not null
			constraint rhn_reg_tok_pkg_id_fk
				references rhnRegToken(id)
				on delete cascade,
        name_id         number
                        constraint rhn_reg_tok_pkg_sg_nn not null
                        constraint rhn_reg_tok_pkg_sgs_fk
                                references rhnPackageName(id)
				on delete cascade,
        arch_id         number
                        constraint rhn_reg_tok_pkg_aid_fk
                                references rhnPackageArch(id)
                                on delete cascade
)
	enable row movement
  ;
create unique index rhn_reg_tok_pkg_uq
	on rhnRegTokenPackages(id, token_id, name_id, arch_id)
	tablespace [[4m_tbs]]
  ;
create index rhn_reg_tok_pkg_nid_idx
	on rhnRegtokenPackages(name_id)
	tablespace [[2m_tbs]]
  ;
create sequence rhn_reg_tok_pkg_id_seq;

select 'rhnsat/tables/rhnRelationshipType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnRelationshipType.sql
create sequence rhn_reltype_id_seq;
create table
rhnRelationshipType
(
	id			number
				constraint rhn_reltype_id_nn not null,
	label			varchar2(32)
				constraint rhn_reltype_label_nn not null,
	description		varchar2(256),
	created			date default(sysdate)
				constraint rhn_reltype_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_reltype_modified_nn not null
)
	enable row movement
  ;
create index rhn_reltype_id_label_idx
	on rhnRelationshipType ( id, label )
	tablespace [[64k_tbs]]
  ;
alter table rhnRelationshipType add constraint rhn_reltype_id_pk
	primary key ( id );
create index rhn_reltype_label_id_idx
	on rhnRelationshipType ( label, id )
	tablespace [[64k_tbs]]
  ;
alter table rhnRelationshipType add constraint rhn_reltype_label_uq
	unique ( label );
create or replace trigger
rhn_reltype_mod_trig
before insert or update on rhnRelationshipType
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnRelationshipType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnRelationshipType_data.sql
insert into rhnRelationshipType ( id, label, description ) values (
	rhn_reltype_id_seq.nextval, 'cloned_from',
	'was cloned from'
);

select 'rhnsat/tables/rhnReleaseChannelMap.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnReleaseChannelMap.sql
create table
rhnReleaseChannelMap 
(
	product	        	varchar2(64)
                        constraint rhn_rcm_prodct_nn not null,
    version             varchar2(64)
                        constraint rhn_rcm_versn_nn not null,
    release             varchar2(64)
                        constraint rhn_rcm_relse_nn not null,
    channel_arch_id     number
                        constraint rhn_rcm_caid_nn not null,
    channel_id          number
                        constraint rhn_rcm_cid_nn not null,
    is_default          char(1)
                        constraint rhn_rcm_default_nn not null,
                        constraint rhn_rcm_default_ck
                            check (is_default in ('Y', 'N'))
)
	enable row movement
  ;
create index rhn_rcm_prod_ver_rel_caid_idx
	on rhnReleaseChannelMap(product, version, release, channel_arch_id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnSGTypeBaseAddonCompat.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSGTypeBaseAddonCompat.sql
create table
rhnSGTypeBaseAddonCompat
(
   base_id     number
               constraint rhn_sgt_bac_bid_nn not null
               constraint rhn_sgt_bac_bid_fk references rhnServerGroupType(id),
   addon_id    number
               constraint rhn_sgt_bac_aid_nn not null
               constraint rhn_sgt_bac_aid_fk references rhnServerGroupType(id)
)
	enable row movement
  ;

select 'rhnsat/tables/rhnServerGroupType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerGroupType_data.sql
insert into rhnServerGroupType (id, label, name, permanent, is_base)
        values (rhn_servergroup_type_seq.nextval,
                'sw_mgr_entitled', 'Spacewalk Update Entitled Servers', 
                'N', 'Y'
        );
insert into rhnServerGroupType (id, label, name, permanent, is_base)
        values (rhn_servergroup_type_seq.nextval,
                'enterprise_entitled', 'Spacewalk Management Entitled Servers', 
                'N', 'Y'
        );
insert into rhnServerGroupType (id, label, name, permanent, is_base)
        values (rhn_servergroup_type_seq.nextval,
                'provisioning_entitled', 'Spacewalk Provisioning Entitled Servers', 
                'N', 'N'
        );
insert into rhnServerGroupType (id, label, name, permanent, is_base)
	values (rhn_servergroup_type_seq.nextval,
		'monitoring_entitled', 'Spacewalk Monitoring Entitled Servers', 
        'N', 'N'
	);
insert into rhnServerGroupType ( id, label, name, permanent, is_base)
   values ( rhn_servergroup_type_seq.nextval,
      'nonlinux_entitled', 'Non-Linux Entitled Servers',
      'N', 'Y'
   );
insert into rhnServerGroupType ( id, label, name, permanent, is_base)
   values ( rhn_servergroup_type_seq.nextval,
      'virtualization_host', 'Virtualization Host Entitled Servers',
      'N', 'N'
   );      
insert into rhnServerGroupType ( id, label, name, permanent, is_base)
   values ( rhn_servergroup_type_seq.nextval,
      'virtualization_host_platform', 
      'Virtualization Host Platform Entitled Servers',
      'N', 'N'
   );      
commit;

select 'rhnsat/tables/rhnSGTypeBaseAddonCompat_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSGTypeBaseAddonCompat_data.sql
insert into rhnSGTypeBaseAddonCompat (base_id, addon_id)
values (lookup_sg_type('enterprise_entitled'), 
        lookup_sg_type('monitoring_entitled'));
insert into rhnSGTypeBaseAddonCompat (base_id, addon_id)
values (lookup_sg_type('enterprise_entitled'), 
        lookup_sg_type('provisioning_entitled'));
insert into rhnSGTypeBaseAddonCompat (base_id, addon_id)
values (lookup_sg_type('enterprise_entitled'), 
        lookup_sg_type('virtualization_host'));
insert into rhnSGTypeBaseAddonCompat (base_id, addon_id)
values (lookup_sg_type('enterprise_entitled'), 
        lookup_sg_type('virtualization_host_platform'));
insert into rhnSGTypeBaseAddonCompat (base_id, addon_id)
values (lookup_sg_type('sw_mgr_entitled'), 
        lookup_sg_type('virtualization_host'));
insert into rhnSGTypeBaseAddonCompat (base_id, addon_id)
values (lookup_sg_type('sw_mgr_entitled'), 
        lookup_sg_type('virtualization_host_platform'));
commit;

select 'rhnsat/tables/rhnSGTypeVirtSubLevel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSGTypeVirtSubLevel.sql
create table rhnSGTypeVirtSubLevel (
    server_group_type_id    number
                            constraint rhn_sgtvsl_sgtid_nn not null
                            constraint rhn_sgtvsl_sgtid_fk
                                references rhnServerGroupType(id),
    virt_sub_level_id number
                      constraint rhn_sgtvsl_vslid_nn not null
                      constraint rhn_sgtvsl_vslid_fk
                        references rhnVirtSubLevel(id),
    created           date
                      default sysdate
                      constraint rhn_sgtvsl_created_nn not null,
    modified          date
                      default sysdate
                      constraint rhn_sgtvsl_modified_nn not null
)
    enable row movement
  ;
create index rhn_sgtvsl_sgtid_vslid
    on rhnSGTypeVirtSubLevel(server_group_type_id, virt_sub_level_id)
    tablespace [[64k_tbs]]
  ;
create index rhn_sgtvsl_vslid_sgtid
    on rhnSGTypeVirtSubLevel(virt_sub_level_id, server_group_type_id)
    tablespace [[64k_tbs]]
  ;

select 'rhnsat/procs/lookup_virt_sub_level.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_virt_sub_level.sql
create or replace function
lookup_virt_sub_level(label_in in varchar2)
return number
deterministic
is
	virt_sub_level_id number;
begin
	select	vsl.id
	into	virt_sub_level_id
	from	rhnVirtSubLevel vsl
	where	vsl.label = label_in;
	return virt_sub_level_id;
exception
        when no_data_found then
            rhn_exception.raise_exception('invalid_virt_sub_level');
end;
/
show errors

select 'rhnsat/tables/rhnVirtSubLevel_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtSubLevel_data.sql
insert into rhnVirtSubLevel(id, label, name, created, modified)
values(rhn_virt_sl_seq.nextval, 'virtualization_free',
       'Virtualization free content group',
       sysdate, sysdate);
insert into rhnVirtSubLevel(id, label, name, created, modified)
values(rhn_virt_sl_seq.nextval, 'virtualization_platform_free',
       'Virtualization Platform free content group',
       sysdate, sysdate);
commit;

select 'rhnsat/tables/rhnSGTypeVirtSubLevel_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSGTypeVirtSubLevel_data.sql
insert into rhnSGTypeVirtSubLevel
values(lookup_sg_type('virtualization_host'),
       lookup_virt_sub_level('virtualization_free'),
       sysdate, sysdate);
insert into rhnSGTypeVirtSubLevel
values(lookup_sg_type('virtualization_host_platform'),
       lookup_virt_sub_level('virtualization_platform_free'),
       sysdate, sysdate);
commit;

select 'rhnsat/tables/rhnSNPErrataQueue.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSNPErrataQueue.sql
create table rhnSNPErrataQueue
(
    	errata_id       number
	    	    	constraint rhn_snpErrQueue_eid_nn not null
	    	    	constraint rhn_snpErrQueue_eid_fk
				references rhnErrata(id)
				on delete cascade,
	processed	number default(0) -- this should get a check as well?
			constraint rhn_snpErrQueue_processed_nn not null
)
	enable row movement
  ;
create unique index rhn_snpErrQueue_eid_uq
	on rhnSNPErrataQueue(errata_id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnSNPServerQueue.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSNPServerQueue.sql
create table rhnSNPServerQueue
(
    	server_id       number
	    	    	constraint rhn_sec_np_sid_nn not null
	    	    	constraint rhn_sec_np_sid_fk
				references rhnServer(id),
	processed	number default(0)
			constraint rhn_sec_np_processed_nn not null
)
	enable row movement
  ;
create index rhn_sec_np_sid_idx
	on rhnSNPServerQueue( server_id )
	tablespace [[8m_tbs]]
	nologging;

select 'rhnsat/tables/rhnSatelliteCert.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSatelliteCert.sql
create table
rhnSatelliteCert
(
	label			varchar2(64)
				constraint rhn_satcert_label_nn not null,
	version			number,
	cert			blob
				constraint rhn_satcert_cert_nn not null,
	issued			date default(sysdate),
	expires			date default(sysdate),
	created			date default(sysdate)
				constraint rhn_satcert_created_nn not null,
	modified		date default(sysdate)
				constraint rhn_satcert_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_satcert_mod_trig
before insert or update on rhnSatelliteCert 
for each row
begin
	:new.modified := sysdate;
end;
/
show errors
create unique index rhn_satcert_label_version_uq on
	rhnSatelliteCert ( label, version )
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnSatelliteChannelFamily.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSatelliteChannelFamily.sql
create table
rhnSatelliteChannelFamily
(
        server_id       number
                        constraint rhn_sat_cf_sid_nn not null
                        constraint rhn_sat_cf_sid_fk
                                references rhnServer(id),
        channel_family_id   number
                        constraint rhn_sat_cf_cfid_nn not null
                        constraint rhn_sat_cf_cfid_fk
                                references rhnChannelFamily(id)
                                on delete cascade,
        quantity        number,
        created         date default (sysdate)
                        constraint rhn_sat_cf_created_nn not null,
        modified        date default (sysdate)
                        constraint rhn_sat_cf_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_sat_cf_mod_trig
before insert or update on rhnSatelliteChannelFamily
for each row
begin
    :new.modified := sysdate;
end;
/
show errors
create index rhn_sat_cf_sid_cfid_idx on
	rhnSatelliteChannelFamily ( server_id, channel_family_id )
	tablespace [[2m_tbs]]
  ;
alter table rhnSatelliteChannelFamily add constraint rhn_sat_cf_sid_cfid_uq
	unique ( server_id, channel_family_id );
create index rhn_sat_cf_cfid_sid_idx on
        rhnSatelliteChannelFamily( channel_family_id, server_id )
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnSatelliteInfo.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSatelliteInfo.sql
create table
rhnSatelliteInfo
(
        server_id       number
                        constraint rhn_satellite_info_sid_nn not null
                        constraint rhn_satellite_info_sid_fk
                                references rhnServer(id),
	evr_id		number
			constraint rhn_satellite_info_eid_fk
				references rhnPackageEVR(id),
        cert            blob
                        constraint rhn_satellite_info_cert_nn not null,
        product         varchar2(256)
                        constraint rhn_satellite_info_product_nn not null,
        owner           varchar2(256)
                        constraint rhn_satellite_info_owner_nn not null,
        issued_string   varchar2(256),
        expiration_string varchar2(256),
        created         date default (sysdate)
                        constraint rhn_satellite_info_created_nn not null,
        modified        date default (sysdate)
                        constraint rhn_satellite_info_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_satellite_info_mod_trig
before insert or update on rhnSatelliteInfo
for each row
begin
    :new.modified := sysdate;
end;
/
show errors
create index rhn_satellite_info_sid_idx on
	rhnSatelliteInfo ( server_id )
	tablespace [[2m_tbs]]
  ;
alter table rhnSatelliteInfo add constraint rhn_satellite_info_sid_uq
	unique ( server_id );

select 'rhnsat/tables/rhnSatelliteServerGroup.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSatelliteServerGroup.sql
create table
rhnSatelliteServerGroup
(
	server_id		number
				constraint rhn_satsg_sid_nn not null
				constraint rhn_satsg_sid_fk
					references rhnSatelliteInfo(server_id)
					on delete cascade,
	server_group_type	number
				constraint rhn_satsg_sgtype_nn not null
				constraint rhn_satsg_sgtype_fk
					references rhnServerGroupType(id),
	max_members		number,
	created			date default(sysdate)
				constraint rhn_satsg_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_satsg_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_satsg_sid_sgt_uq
	on rhnSatelliteServerGroup( server_id, server_group_type )
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_satsg_mod_trig
before insert or update on rhnSatelliteServerGroup
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnSavedSearchType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSavedSearchType.sql
create table
rhnSavedSearchType
(
	id		number
			constraint rhn_sstype_id_nn not null,
	label		varchar2(8)
			constraint rhn_sstype_label_nn not null,
	created		date default(sysdate)
			constraint rhn_sstype_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_sstype_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_sstype_id_seq;
create index rhn_sstype_id_label_idx
	on rhnSavedSearchType(id,label)
	tablespace [[64k_tbs]]
  ;
alter table rhnSavedSearchType add
	constraint rhn_sstype_id_pk primary key (id);
create index rhn_sstype_label_id_idx
	on rhnSavedSearchType(label,id)
	tablespace [[64k_tbs]]
  ;
alter table rhnSavedSearchType add
	constraint rhn_sstype_label_uq unique (label);
insert into rhnSavedSearchType (id, label)
	values (rhn_sstype_id_seq.nextval, 'system');
insert into rhnSavedSearchType (id, label)
	values (rhn_sstype_id_seq.nextval, 'package');
insert into rhnSavedSearchType (id, label)
	values (rhn_sstype_id_seq.nextval, 'errata');
commit;

select 'rhnsat/tables/rhnSavedSearch.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSavedSearch.sql
create table
rhnSavedSearch
(
	id		number
			constraint rhn_savedsearch_id_nn not null,
	web_contact_id	number
			constraint rhn_savedsearch_wcid_nn not null
			constraint rhn_savedsearch_wcid_fk
				references web_contact(id)
				on delete cascade,
	name		varchar2(16)
			constraint rhn_savedsearch_name_nn not null,
	type		number
			constraint rhn_savedsearch_type_nn not null
			constraint rhn_savedsearch_type_fk
				references rhnSavedSearchType(id),
	search_string	varchar2(4000)
			constraint rhn_savedsearch_sstring_nn not null,
	search_set	varchar2(16)
			constraint rhn_savedsearch_sset_nn not null
			constraint rhn_savedsearch_sset_ck
				check ( search_set in ('all','system_list')),
	search_field	varchar2(128)
			constraint rhn_savedsearch_sfield_nn not null,
	invert		char default('N')
			constraint rhn_savedsearch_invert_nn not null
			constraint rhn_savedsearch_invert_ck
				check (invert in ('Y','N'))
)
	enable row movement
  ;
create sequence rhn_savedsearch_id_seq;
create index rhn_savedsearch_id_wcid_idx
	on rhnSavedSearch(id, web_contact_id)
	tablespace [[2m_tbs]]
  ;
alter table rhnSavedSearch add
	constraint rhn_savedsearch_id_pk primary key (id);
create index rhn_savedsearch_wcid_id_idx
	on rhnSavedSearch(web_contact_id, id)
	tablespace [[2m_tbs]]
  ;
create index rhn_savedsearch_name_wcid_idx
	on rhnSavedSearch(name, web_contact_id)
	tablespace [[2m_tbs]]
  ;
alter table rhnSavedSearch add 
	constraint rhn_savedsearch_name_wcid_uq unique (name, web_contact_id);

select 'rhnsat/tables/rhnServerActionPackageResult.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerActionPackageResult.sql
create table
rhnServerActionPackageResult
(
	server_id		number
				constraint rhn_sap_result_sid_nn not null
				constraint rhn_sap_result_sid_fk
					references rhnServer(id),
	action_package_id	number
				constraint rhn_sap_result_apid_nn not null
				constraint rhn_sap_result_apid_fk
					references rhnActionPackage(id)
					on delete cascade,
	result_code		number
				constraint rhn_sap_result_rc_nn not null,
	stdout			blob,
	stderr			blob,
	created			date default(sysdate)
				constraint rhn_sap_result_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_sap_result_mod_nn not null
)
	tablespace [[blob]]
	enable row movement
  ;
create unique index rhn_sap_result_sid_apid_uq
	on rhnServerActionPackageResult( server_id, action_package_id )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_sap_result_mod_trig
before insert or update on rhnServerActionPackageResult
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerActionScriptResult.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerActionScriptResult.sql
create table
rhnServerActionScriptResult
(
	server_id		number
				constraint rhn_serveras_result_sid_nn not null
				constraint rhn_serveras_result_sid_fk
					references rhnServer(id),
	action_script_id	number
				constraint rhn_serveras_result_asid_nn not null
				constraint rhn_serveras_result_asid_fk
					references rhnActionScript(id)
					on delete cascade,
	output			blob,
	start_date		date
				constraint rhn_serveras_result_start_nn not null,
	stop_date		date
				constraint rhn_serveras_result_stop_nn not null,
	return_code		number
				constraint rhn_serveras_result_return_nn not null,
	created			date default(sysdate)
				constraint rhn_serveras_result_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_serveras_result_mod_nn not null
)
	tablespace [[blob]]
	enable row movement
  ;
create unique index rhn_serveras_result_sas_uq
	on rhnServerActionScriptResult( server_id, action_script_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_serveras_result_asid_idx
	on rhnServerActionScriptResult( action_script_id )
	tablespace [[4m_tbs]]
	nologging;
create or replace trigger
rhn_serveras_result_mod_trig
before insert or update on rhnServerActionScriptResult
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerActionVerifyMissing.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerActionVerifyMissing.sql
create table
rhnServerActionVerifyMissing
(
	server_id		number
				constraint rhn_sactionvm_sid_nn not null
				constraint rhn_sactionvm_sid_fk
					references rhnServer(id),
	action_id		number
				constraint rhn_sactionvm_aid_nn not null
				constraint rhn_sactionvm_aid_fk
					references rhnAction(id)
					on delete cascade,
	package_name_id		number
				constraint rhn_sactionvm_pnid_nn not null
				constraint rhn_sactionvm_pnid_fk
					references rhnPackageName(id),
	package_evr_id		number
				constraint rhn_sactionvm_peid_nn not null
				constraint rhn_sactionvm_peid_fk
					references rhnPackageevr(id),
	package_arch_id		number
				constraint rhn_sactionvm_paid_nn not null
				constraint rhn_sactionvm_paid_fk
					references rhnPackageArch(id),
	package_capability_id	number
				constraint rhn_sactionvm_pcid_nn not null
				constraint rhn_sactionvm_pcid_fk
					references rhnPackageCapability(id),
	created			date default(sysdate)
				constraint rhn_sactionvm_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_sactionvm_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_sactionvm_sanec_uq
	on rhnServerActionVerifyMissing(
		server_id, action_id,
		package_name_id, package_evr_id, package_arch_id,
		package_capability_id )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_sactionvm_mod_trig
before insert or update on rhnServerActionVerifyMissing
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerActionVerifyResult.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerActionVerifyResult.sql
create table
rhnServerActionVerifyResult
(
	server_id		number
				constraint rhn_sactionvr_sid_nn not null
				constraint rhn_sactionvr_sid_fk
					references rhnServer(id),
	action_id		number
				constraint rhn_sactionvr_aid_nn not null
				constraint rhn_sactionvr_aid_fk
					references rhnAction(id)
					on delete cascade,
	package_name_id		number
				constraint rhn_sactionvr_pnid_nn not null
				constraint rhn_sactionvr_pnid_fk
					references rhnPackageName(id),
	package_evr_id		number
				constraint rhn_sactionvr_peid_nn not null
				constraint rhn_sactionvr_peid_fk
					references rhnPackageEVR(id),
	package_arch_id		number
				constraint rhn_sactionvr_paid_nn not null
				constraint rhn_sactionvr_paid_fk
					references rhnPackageArch(id),
	package_capability_id	number
				constraint rhn_sactionvr_pcid_nn not null
				constraint rhn_sactionvr_pcid_fk
					references rhnPackageCapability(id),
	attribute		char(1)
				constraint rhn_sactionvr_attr_ck
					check (attribute in ('c','d','g','l','r')),
	size_differs		char(1)
				constraint rhn_sactionvr_size_nn not null
				constraint rhn_sactionvr_size_ck
					check (size_differs in ('Y','N','?')),
	mode_differs		char(1)
				constraint rhn_sactionvr_mode_nn not null
				constraint rhn_sactionvr_mode_ck
					check (mode_differs in ('Y','N','?')),
	md5_differs		char(1)
				constraint rhn_sactionvr_md5_nn not null
				constraint rhn_sactionvr_md5_ck
					check (md5_differs in ('Y','N','?')),
	devnum_differs		char(1)
				constraint rhn_sactionvr_devnum_nn not null
				constraint rhn_sactionvr_devnum_ck
					check (devnum_differs in ('Y','N','?')),
	readlink_differs		char(1)
				constraint rhn_sactionvr_readlink_nn not null
				constraint rhn_sactionvr_readlink_ck
					check (readlink_differs in ('Y','N','?')),
	uid_differs		char(1)
				constraint rhn_sactionvr_uid_nn not null
				constraint rhn_sactionvr_uid_ck
					check (uid_differs in ('Y','N','?')),
	gid_differs		char(1)
				constraint rhn_sactionvr_gid_nn not null
				constraint rhn_sactionvr_gid_ck
					check (gid_differs in ('Y','N','?')),
	mtime_differs		char(1)
				constraint rhn_sactionvr_mtime_nn not null
				constraint rhn_sactionvr_mtime_ck
					check (mtime_differs in ('Y','N','?')),
	created			date default(sysdate)
				constraint rhn_sactionvr_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_sactionvr_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_sactionvr_sanec_uq
	on rhnServerActionVerifyResult(
		server_id, action_id,
		package_name_id, package_evr_id, package_arch_id,
		package_capability_id )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_sactionvr_mod_trig
before insert or update on rhnServerActionVerifyResult
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerCacheInfo.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerCacheInfo.sql
create table
rhnServerCacheInfo
(
  server_id       number
                  constraint rhn_server_cache_info_sid_nn not null
                  constraint rhn_server_cache_info_sid_fk 
                     references rhnServer(id),
   update_time    date
)
	enable row movement
  ;
create unique index rhn_server_cache_info_sid_idx
        on rhnServerCacheInfo(server_id)
        tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnServerChannelArchCompat.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerChannelArchCompat.sql
create table
rhnServerChannelArchCompat
(
        server_arch_id	number
                        constraint rhn_sc_ac_said_nn not null
                        constraint rhn_sc_ac_said_fk 
				references rhnServerArch(id),
	channel_arch_id	number
			constraint rhn_sc_ac_caid_nn not null
			constraint rhn_sc_ac_caid_fk
				references rhnChannelArch(id),
	created		date default(sysdate)
			constraint rhn_sc_ac_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_sc_ac_modified_nn not null
)
	enable row movement
  ;
create index rhn_sc_ac_caid_paid
	on rhnServerChannelArchCompat(server_arch_id, channel_arch_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_sc_ac_paid_caid
	on rhnServerChannelArchCompat(channel_arch_id, server_arch_id)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_sc_ac_mod_trig
before insert or update on rhnServerChannelArchCompat
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerChannelArchCompat_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerChannelArchCompat_data.sql
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('i386-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ia32'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('i486-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ia32'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('i586-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ia32'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('i686-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ia32'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ia32'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('alpha-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-alpha'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('alphaev6-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-alpha'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ia64'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('sparc-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-sparc'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('sparcv9-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-sparc'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('sparc64-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-sparc'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('s390-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-s390'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('s390x-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-s390x'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('pSeries-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-pSeries'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('iSeries-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-iSeries'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-x86_64'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('ia32e-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-x86_64'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('amd64-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-x86_64'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('ppc64iseries-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ppc'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('ppc64pseries-redhat-linux'), LOOKUP_CHANNEL_ARCH('channel-ppc'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('sparc-sun4m-solaris'), LOOKUP_CHANNEL_ARCH('channel-sparc-sun-solaris'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('sparc-sun4u-solaris'), LOOKUP_CHANNEL_ARCH('channel-sparc-sun-solaris'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('sparc-sun4v-solaris'), LOOKUP_CHANNEL_ARCH('channel-sparc-sun-solaris'));
insert into rhnServerChannelArchCompat (server_arch_id, channel_arch_id) values
(LOOKUP_SERVER_ARCH('i386-i86pc-solaris'), LOOKUP_CHANNEL_ARCH('channel-i386-sun-solaris'));
commit;

select 'rhnsat/tables/rhnServerChannel_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerChannel_triggers.sql
create or replace trigger
rhn_server_channel_mod_trig
before insert or update on rhnServerChannel
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerConfigChannel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerConfigChannel.sql
create table
rhnServerConfigChannel
(
	server_id		number
				constraint rhn_servercc_sid_nn not null
				constraint rhn_servercc_sid_fk
					references rhnServer(id),
	config_channel_id	number
				constraint rhn_servercc_ccid_nn not null
				constraint rhn_servercc_ccid_fk
					references rhnConfigChannel(id)
					on delete cascade,
	position		number,
	created			date default(sysdate)
				constraint rhn_servercc_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_servercc_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_servercc_sid_ccid_uq
	on rhnServerConfigChannel( server_id, config_channel_id )
	tablespace [[2m_tbs]]
  ;
create index rhn_servercc_ccid_idx
	on rhnServerConfigChannel( config_channel_id )
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_servercc_mod_trig
before insert or update on rhnServerConfigChannel
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerCustomDataValue.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerCustomDataValue.sql
create table
rhnServerCustomDataValue
(
	server_id	number
			constraint rhn_scdv_sid_nn not null
			constraint rhn_scdv_sid_fk
				references rhnServer(id),
	key_id		number
			constraint rhn_scdv_kid_nn not null
			constraint rhn_scdv_kid_fk
				references rhnCustomDataKey(id),
	value		varchar2(4000),  -- nullable?
	created_by	number
			constraint rhn_scdv_cb_fk
				references web_contact(id)
				on delete set null,
	last_modified_by number
			constraint rhn_scdv_lmb_fk
				references web_contact(id)
				on delete set null,
	created		date default (sysdate)
			constraint rhn_scdv_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_scdv_modified_nn not null	
)
	enable row movement
  ;
create unique index rhn_scdv_sid_kid_uq
	on rhnServerCustomDataValue(server_id, key_id);
create index rhn_scdv_kid_sid_idx
	on rhnServerCustomDataValue(key_id, server_id);
create or replace trigger
rhn_scdv_mod_trig
before insert or update on rhnServerCustomDataValue
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerDMI.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerDMI.sql
create table
rhnServerDMI
(
        id              number
			constraint rhn_server_dmi_id_nn not null
                        constraint rhn_server_dmi_pk primary key
                        using index tablespace [[2m_tbs]],
        server_id       number
			constraint rhn_server_dmi_sid_nn not null
                        constraint rhn_server_dmi_sid_fk
                                references rhnServer(id),
	vendor		varchar2(256),
	system		varchar2(256),
	product		varchar2(256),
	bios_vendor	varchar2(256),
	bios_version	varchar2(256),
	bios_release	varchar2(256),
	asset		varchar2(256),
	board		varchar2(256),
        created         date default(sysdate)
			constraint rhn_server_dmi_created_nn not null,
        modified        date default(sysdate)
			constraint rhn_server_dmi_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_server_dmi_id_seq;
create index rhn_server_dmi_sid_idx on
        rhnServerDMI(server_id)
        tablespace [[2m_tbs]]
	nologging;
create or replace trigger
rhn_server_dmi_mod_trig
before insert or update on rhnServerDMI
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerEvent.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerEvent.sql
create table
rhnServerEvent
(
	id		number
			constraint rhn_se_id_nn not null
			constraint rhn_se_id_pk primary key
				using index tablespace [[64k_tbs]],
	server_id	number
			constraint rhn_se_server_id_nn not null
			constraint rhn_se_server_id_fk
			       references rhnServer(id),
	details 	varchar2(4000)
			constraint rhn_se_details_nn not null,
	created		date default (sysdate)
			constraint rhn_se_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_se_modified_nn not null
)
	enable row movement
  ;
create index rhn_se_idx
	on rhnServerEvent(server_id)
	tablespace [[64k_tbs]]
  ;
create sequence rhn_se_id_seq;
create or replace trigger
rhn_se_mod_trig
before insert or update on rhnServerEvent
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerGroupMembers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerGroupMembers.sql
create table
rhnServerGroupMembers
(
        server_id       number
                        constraint rhn_sg_members_nn not null
                        constraint rhn_sg_members_fk
                                references rhnServer(id),
        server_group_id number
                        constraint rhn_sg_group_nn not null
                        constraint rhn_sg_groups_fk
                                references rhnServerGroup(id),
        created         date default(sysdate)
                        constraint rhn_sg_member_cre_nn not null,
        modified        date default(sysdate)
                        constraint rhn_sg_member_mod_nn not null
)
	enable row movement
  ;

select 'rhnsat/tables/rhnServerGroupMembers_indexes.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerGroupMembers_indexes.sql
create unique index rhn_sgmembers_sid_sgid_uq
	on rhnServerGroupMembers(server_id, server_group_id)
	tablespace [[4m_tbs]]
  ;
create index rhn_sgmembers_sgid_sid_idx
	on rhnServerGroupMembers(server_group_id, server_id)
	parallel 6
        tablespace [[4m_tbs]]
	nologging;

select 'rhnsat/tables/rhnServerGroupMembers_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerGroupMembers_triggers.sql
create or replace trigger
rhn_sg_member_mod_trig
before insert or update on rhnServerGroupMembers
for each row
begin
        :new.modified := sysdate;
end;
/
show errors
CREATE OR REPLACE TRIGGER
rhn_server_group_org_mapping
BEFORE INSERT OR UPDATE ON rhnServerGroupMembers
FOR EACH ROW
DECLARE
        same_org        NUMBER;
BEGIN
        same_org := 0;
        SELECT 1 INTO same_org
          FROM rhnServer S, rhnServerGroup SG
         WHERE SG.org_id = S.org_id
           AND S.id = :new.server_id
           AND SG.id = :new.server_group_id;
        IF same_org = 0 THEN
          rhn_exception.raise_exception('sgm_insert_diff_orgs');
        END IF;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
          rhn_exception.raise_exception('sgm_insert_diff_orgs');
END;
/
SHOW ERRORS

select 'rhnsat/tables/rhnServerGroupNotes.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerGroupNotes.sql
create table
rhnServerGroupNotes
(
        id              number
                        constraint rhn_servergrp_note_id_nn not null
                        constraint rhn_servergrp_note_id_pk primary key
                                using index tablespace [[64k_tbs]],
        creator         number
                        constraint rhn_servergrp_note_creator_fk
                                   references web_contact(id)
				   on delete set null,
        server_group_id number
                        constraint rhn_servergrp_note_nn not null
                        constraint rhn_servergrp_note_fk
                                references rhnServerGroup(id) on delete cascade,
        subject         varchar2(80)
                        constraint rhn_servergrp_note_subject_nn not null,
        note            varchar2(4000)
                        constraint rhn_servergrp_note_note_nn not null,
        created         date default(sysdate)
                        constraint rhn_servergrp_note_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_servergrp_note_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_servergrp_note_id_seq;
create index rhn_servergrp_note_srvr_id_idx
	on rhnServerGroupNotes(server_group_id)
	tablespace [[64k_tbs]]
	nologging;
create index rhn_servergrp_note_creator_idx
	on rhnServerGroupNotes ( creator )
	tablespace [[64k_tbs]]
	nologging;
CREATE OR REPLACE TRIGGER
rhn_servergroup_note_mod_trig
BEFORE INSERT OR UPDATE ON rhnServerGroupNotes
FOR EACH ROW
BEGIN
        :new.modified := sysdate;
END;
/
SHOW ERRORS

select 'rhnsat/tables/rhnServerGroupTypeFeature.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerGroupTypeFeature.sql
create table
rhnServerGroupTypeFeature
(
        server_group_type_id     number
                                 constraint rhn_sgt_sgtid_nn not null
                                 constraint rhn_sgt_sgid_fk references rhnServerGroupType(id),
        feature_id               number
                                 constraint rhn_sgt_fid_nn not null
                                 constraint rhn_sgt_fid_fk references rhnFeature(id),
        created                  date default(sysdate)
                                 constraint rhn_sgt_feat_created_nn not null,
        modified                 date default(sysdate)
                                 constraint rhn_sgt_feat_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_sgt_feat_sgtid_fid_uq_idx
        on rhnServerGroupTypeFeature(server_group_type_id, feature_id)
        tablespace [[64k_tbs]]
  ;

select 'rhnsat/procs/lookup_feature_type.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_feature_type.sql
create or replace function
lookup_feature_type(label_in in varchar2)
return number
deterministic
is
	feature_id number;
begin
	select	id
	into	feature_id
	from  rhnFeature 	
	where	label = label_in;
	return feature_id;
exception
        when no_data_found then
            rhn_exception.raise_exception('invalid_feature');
end;
/
show errors

select 'rhnsat/tables/rhnServerGroupTypeFeature_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerGroupTypeFeature_data.sql
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id, 
                                       created, modified)
values (lookup_sg_type('sw_mgr_entitled'), lookup_feature_type('ftr_package_updates'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id, 
                                       created, modified)
values (lookup_sg_type('sw_mgr_entitled'), lookup_feature_type('ftr_errata_updates'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id, 
                                       created, modified)
values (lookup_sg_type('sw_mgr_entitled'), lookup_feature_type('ftr_hardware_refresh'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id, 
                                       created, modified)
values (lookup_sg_type('sw_mgr_entitled'), lookup_feature_type('ftr_package_refresh'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id, 
                                       created, modified)
values (lookup_sg_type('sw_mgr_entitled'), lookup_feature_type('ftr_package_remove'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id, 
                                       created, modified)
values (lookup_sg_type('sw_mgr_entitled'), lookup_feature_type('ftr_auto_errata_updates'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('sw_mgr_entitled'), lookup_feature_type('ftr_daily_summary'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_package_updates'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_errata_updates'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_hardware_refresh'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_package_refresh'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_package_remove'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_auto_errata_updates'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_system_grouping'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_package_verify'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_profile_compare'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_proxy_capable'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_sat_capable'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_reboot'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_satellite_applet'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_osa_bus'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('enterprise_entitled'), lookup_feature_type('ftr_daily_summary'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('provisioning_entitled'), lookup_feature_type('ftr_kickstart'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('provisioning_entitled'), lookup_feature_type('ftr_config'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('provisioning_entitled'), lookup_feature_type('ftr_custom_info'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('provisioning_entitled'), lookup_feature_type('ftr_delta_action'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('provisioning_entitled'), lookup_feature_type('ftr_snapshotting'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('provisioning_entitled'), lookup_feature_type('ftr_agent_smith'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('provisioning_entitled'), lookup_feature_type('ftr_remote_command'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('monitoring_entitled'), lookup_feature_type('ftr_schedule_probe'),
        sysdate,sysdate);
insert into rhnServerGroupTypeFeature (server_group_type_id, feature_id,
                                       created, modified)
values (lookup_sg_type('monitoring_entitled'), lookup_feature_type('ftr_probes'),
        sysdate,sysdate);

select 'rhnsat/tables/rhnServerGroup_indexes.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerGroup_indexes.sql
create index rhn_sg_id_oid_name_idx
	on rhnServerGroup(id,org_id,name)
	parallel 6
        tablespace [[4m_tbs]]
	nologging;
create index rhn_sg_oid_id_name_idx
	on rhnServerGroup(org_id,id,name)
	parallel 6
        tablespace [[8m_tbs]]
	nologging;
create index rhn_sg_type_id_idx
	on rhnServerGroup(group_type,id)
	parallel 6
        tablespace [[4m_tbs]]
	nologging;
create index rhn_sg_oid_type_id_idx
	on rhnServerGroup(org_id, group_type, id)
	parallel 6
        tablespace [[4m_tbs]]
	nologging;

select 'rhnsat/tables/rhnUserGroup.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserGroup.sql
create table
rhnUserGroup
(
        id              number
                        constraint rhn_user_group_id_nn not null
                        constraint rhn_user_group_pk primary key
                                using index tablespace [[8m_tbs]]
				,
        name            varchar2(64)
                        constraint rhn_user_group_name_nn not null,
        description     varchar2(1024)
                        constraint rhn_user_group_desc_nn not null,
        max_members     number,
        current_members number default(0)
                        constraint rhn_user_group_cm_nn not null,
        group_type      number
                        constraint rhn_usergroup_type_nn not null
                        constraint rhn_usergroup_type_fk
                                references rhnUserGroupType(id),
        org_id          number
                        constraint rhn_user_group_org_id_nn not null
                        constraint rhn_user_group_org_fk
                                references web_customer(id)
				on delete cascade,
        created         date default(sysdate)
                        constraint rhn_usergroup_type_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_usergroup_type_modified_nn not null
)
	enable row movement
  ;

select 'rhnsat/tables/rhnSnapshotServerGroup.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSnapshotServerGroup.sql
create table
rhnSnapshotServerGroup
(
	snapshot_id		number
				constraint rhn_snapshotsg_sid_nn not null
				constraint rhn_snapshotsg_sid_fk
					references rhnSnapshot(id)
					on delete cascade,
	server_group_id		number
				constraint rhn_snapshotsg_sgid_nn not null
				constraint rhn_snapshotsg_sgid_fk
					references rhnServerGroup(id)
)
	enable row movement
  ;
create unique index rhn_snapshotsg_sid_sgid_uq
	on rhnSnapshotServerGroup( snapshot_id, server_group_id )
	tablespace [[4m_tbs]]
  ;
create index rhn_snapshotsg_sgid_idx
	on rhnSnapshotServerGroup( server_group_id )
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_snapshotsg_mod_trig
before insert or update on rhnSnapshotServerGroup
for each row
begin
	update rhnSnapshot set modified = sysdate where id = :new.snapshot_id;
end;
/
show errors

select 'rhnsat/tables/rhnServerGroup_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerGroup_triggers.sql
create or replace trigger
rhn_server_group_mod_trig
before insert or update on rhnServerGroup
for each row
begin
        :new.modified := sysdate;
end;
/
show errors
CREATE OR REPLACE TRIGGER
rhn_server_group_creation
AFTER INSERT ON rhnServerGroup
FOR EACH ROW
DECLARE
        org_admin_group      NUMBER;
        org_id_val           NUMBER;	
BEGIN
    	org_id_val := :new.org_id;
    	SELECT UG.id INTO org_admin_group
	  FROM rhnUserGroup UG,
	       rhnUserGroupType UGT
	 WHERE UGT.label = 'org_admin'
	   AND UGT.id = UG.group_type
	   AND UG.org_id = org_id_val;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
          rhn_exception.raise_exception_val('no_org_admin_group', org_id_val);
END;
/
SHOW ERRORS
create or replace trigger
rhn_sg_del_trig
before delete on rhnServerGroup
for each row
declare
	cursor snapshots is
		select	snapshot_id id
		from	rhnSnapshotServerGroup
		where	server_group_id = :old.id;
begin
	for snapshot in snapshots loop
		update rhnSnapshot
			set invalid = lookup_snapshot_invalid_reason('sg_removed')
			where id = snapshot.id;
		delete from rhnSnapshotServerGroup
			where snapshot_id = snapshot.id
				and server_group_id = :old.id;
	end loop;
end;
/
show errors

select 'rhnsat/tables/rhnServerHistory.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerHistory.sql
create table
rhnServerHistory
(
        id              number
			constraint rhn_serverhistory_id_nn not null
                        constraint rhn_serverhistory_id_pk primary key
                        using index tablespace [[2m_tbs]],
        server_Id       number
			constraint rhn_serverhistory_sid_nn not null
                        constraint rhn_serverhistory_sid_fk
                                references rhnServer(id),
        summary         varchar2(256)
			constraint rhn_serverhistory_summary_nn not null,
        details         varchar2(4000),
        created         date default (sysdate)
			constraint rhn_serverhistory_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_serverhistory_modified_nn not null
)
	enable row movement
  ;
create index rhn_server_hist_server_id_idx
	on rhnServerHistory(server_id)
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_serverhistory_mod_trig
before insert or update on rhnServerHistory
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerInfo.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerInfo.sql
create table
rhnServerInfo
(
        server_id       number
			constraint rhn_server_info_sid_nn not null
                        constraint rhn_server_info_sid_fk
				references rhnServer(id),
	checkin		date default(sysdate),
	checkin_counter number default(0)
)
	enable row movement
	nologging;
create unique index rhn_server_info_sid_unq on
        rhnServerInfo(server_id)
	tablespace [[4m_tbs]]
	nologging;
create or replace trigger
rhn_server_info_mod_trig
before insert or update on rhnServerInfo
for each row
begin
	if :new.checkin is NULL
	then
	        :new.checkin := sysdate;
	end if;
end;
/
show errors

select 'rhnsat/tables/rhnServerInstallInfo.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerInstallInfo.sql
create table
rhnServerInstallInfo
(
	id		number
			constraint rhn_server_install_info_id_nn not null
			constraint rhn_server_install_info_id_pk primary key
				using index tablespace [[2m_tbs]],
        server_id       number
                        constraint rhn_server_install_info_sid_nn not null
                        constraint rhn_server_install_info_sid_fk
                                references rhnServer(id),
	install_method	varchar2(32)
			constraint rhn_server_install_info_im_nn not null,
	iso_status	number,
	mediasum	varchar2(64),
	created		date default(sysdate)
			constraint rhn_server_install_info_cr_nn not null,
	modified	date default(sysdate)
			constraint rhn_server_install_info_md_nn not null
)
	enable row movement
  ;
create sequence rhn_server_install_info_id_seq;
create index rhn_s_inst_info_sid_im_idx
	on rhnServerInstallInfo(server_id, install_method)
	tablespace [[2m_tbs]]
  ;
create unique index rhn_server_install_info_sid_uq
	on rhnServerInstallInfo( server_id )
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_s_inst_info_mod_trig
before insert or update on rhnServerInstallInfo
for each row
begin
	:new.modified := sysdate;
end;
/

select 'rhnsat/tables/rhnServerLocation.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerLocation.sql
create table
rhnServerLocation
(
        id              number
			constraint rhn_serverlocation_id_nn not null
                        constraint rhn_serverlocation_id_pk primary key
				using index tablespace [[64k_tbs]],
        server_id       number
			constraint rhn_serverlocation_sid_nn  not null
                        constraint rhn_serverlocation_sid_fk
                                references rhnServer(id),
        machine         varchar2(64),
        rack            varchar2(64),
        room            varchar2(32),
        building        varchar2(128),
        address1        varchar2(128),
        address2        varchar2(128),
        city            varchar2(128),
        state           varchar2(60),
        country         char(2),
        created         date default (sysdate)
			constraint rhn_serverlocation_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_serverlocation_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_server_loc_id_seq;
create unique index rhn_serverlocation_sid_uq
	on rhnServerLocation ( server_id )
	tablespace [[2m_tbs]]
  ;
create or replace trigger
rhn_serverlocation_mod_trig
before insert or update on rhnServerLocation
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerLock.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerLock.sql
create table
rhnServerLock
(
        server_id       number
			constraint rhn_server_lock_sid_nn not null
                        constraint rhn_server_lock_sid_fk
				references rhnServer(id),
        locker_id       number
                        constraint rhn_server_lock_lid_fk
				references web_contact(id) on delete set null,
	reason          varchar2(4000),
        created         date default (sysdate)
			constraint rhn_server_lock_created_nn not null
)
	enable row movement
  ;
create unique index rhn_server_lock_sid_unq on
        rhnServerLock(server_id)
	tablespace [[4m_tbs]]
  ;
create index rhn_server_lock_lid_unq on
        rhnServerLock(locker_id)
	tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnServerMessage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerMessage.sql
create table
rhnServerMessage
(
	server_id	number
			constraint rhn_sm_server_id_nn not null
			constraint rhn_sm_server_id_fk
				references rhnServer(id),
	message_id	number
			constraint rhn_sm_message_id_nn not null
			constraint rhn_sm_message_id_fk
				references rhnMessage(id)
				on delete cascade,
	server_event	number
			constraint rhn_sm_se_fk
				references rhnServerEvent(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_sm_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_sm_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_sm_uq
	on rhnServerMessage(server_id, message_id)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_sm_mi_sid_uq
	on rhnServerMessage(message_id, server_id)
	tablespace [[64k_tbs]]
  ;
create index RHN_SRVR_MSSG_SRVR_EVNT_IDX
on rhnServerMessage ( server_event )
        tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_sm_mod_trig
before insert or update on rhnServerMessage
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerNeededErrataCache.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerNeededErrataCache.sql
create table rhnServerNeededErrataCache
(
	org_id
			number
			constraint rhn_snec_oid_nn not null
			constraint rhn_snec_oid_fk
				references web_customer(id)
				on delete cascade,
	server_id	number
			constraint rhn_snec_sid_nn not null
			constraint rhn_snec_sid_fk
				references rhnServer(id)
				on delete cascade,
	errata_id	number
			constraint rhn_snec_eid_fk
				references rhnErrata(id)
				on delete cascade
)
	enable row movement
  ;
alter table rhnServerNeededErrataCache nologging;
create index rhn_snec_eid_sid_idx
	on rhnServerNeededErrataCache(errata_id, server_id)
	parallel 6
	tablespace [[128m_tbs]]
	nologging;
create index rhn_snec_sid_eid_idx
	on rhnServerNeededErrataCache(server_id, errata_id) 
	parallel 6
	tablespace [[128m_tbs]]
	nologging;
create index rhn_snec_oid_eid_sid_idx
	on rhnServerNeededErrataCache(org_id, errata_id, server_id)
	parallel 6
	tablespace [[128m_tbs]]
	nologging;

select 'rhnsat/tables/rhnServerNeededPackageCache.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerNeededPackageCache.sql
create table rhnServerNeededPackageCache
(
	org_id
			number
			constraint rhn_sncp_oid_nn not null
			constraint rhn_sncp_oid_fk
				references web_customer(id),
	server_id	number
			constraint rhn_sncp_sid_nn not null
			constraint rhn_sncp_sid_fk
				references rhnServer(id)
				on delete cascade,
	errata_id	number
			constraint rhn_sncp_eid_fk
				references rhnErrata(id)
				on delete cascade,
	package_id	number
			constraint rhn_sncp_pid_nn not null
			constraint rhn_sncp_pid_fk
				references rhnPackage(id)
				on delete cascade
)
	enable row movement
	nologging;
create index rhn_snpc_pid_idx
	on rhnServerNeededPackageCache(package_id)
	parallel
	tablespace [[128m_tbs]]
	nologging;
create index rhn_snpc_sid_idx
	on rhnServerNeededPackageCache(server_id)
	parallel
	tablespace [[128m_tbs]]
	nologging;
create index rhn_snpc_eid_idx
	on rhnServerNeededPackageCache(errata_id)
	parallel
	tablespace [[128m_tbs]]
	nologging;
create index rhn_snpc_oid_idx
	on rhnServerNeededPackageCache(org_id)
	parallel
	tablespace [[128m_tbs]]
	nologging;

select 'rhnsat/tables/rhnServerNetwork.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerNetwork.sql
create table
rhnServerNetwork
(
        id              number
			constraint rhn_servernetwork_id_nn not null
                        constraint rhn_servernetwork_id_pk primary key
                        using index tablespace [[4m_tbs]],
        server_id       number
			constraint rhn_servernetwork_sid_nn not null
                        constraint rhn_servernetwork_sid_fk
                                references rhnServer(id),
        hostname        varchar2(128),
        ipaddr          char(16),
        created         date default (sysdate)
			constraint rhn_servernetwork_created_nn not null,
        modified        date default (sysdate)
			constraint rhn_servernetwork_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_server_net_id_seq;
create index rhn_servernetwork_sid_id_idx
	on rhnServerNetwork(server_id,id)
	tablespace [[4m_tbs]]
	nologging;
create or replace trigger
rhn_servernetwork_mod_trig
before insert or update on rhnServerNetwork
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerNotes.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerNotes.sql
create table
rhnServerNotes
(
        id              number
                        constraint rhn_servernotes_id_nn not null
                        constraint rhn_servernotes_id_pk primary key
                                using index tablespace [[64k_tbs]],
        creator         number
                        constraint rhn_servernotes_creator_fk
                                   references web_contact(id)
				   on delete set null,
        server_id       number
                        constraint rhn_servernotes_sid_nn not null
                        constraint rhn_servernotes_sid_fk
                                   references rhnServer(id),
        subject         varchar2(80)
                        constraint rhn_servernotes_subject_nn not null,
        note            varchar2(4000),
        created         date default(sysdate)
                        constraint rhn_servernotes_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_servernotes_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_server_note_id_seq;
create index rhn_servernotes_sid_idx
	on rhnServerNotes(server_id)
	tablespace [[64k_tbs]]
	nologging;
create index rhn_servernotes_creator_idx
	on rhnServerNotes ( creator )
	tablespace [[64k_tbs]]
	nologging;
create or replace trigger
rhn_servernotes_mod_trig
before insert or update on rhnServerNotes
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerPackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerPackage.sql
create table
rhnServerPackage
(
        server_id       number,
        name_id         number,
        evr_id          number ,
        package_arch_id number
)
	tablespace [[server_package_tablespace]]
	enable row movement
  ;
create sequence rhn_server_package_id_seq;

select 'rhnsat/tables/rhnServerPackageArchCompat.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerPackageArchCompat.sql
create table
rhnServerPackageArchCompat
(
        server_arch_id	number
                        constraint rhn_sp_ac_said_nn not null
                        constraint rhn_sp_ac_said_fk 
				references rhnServerArch(id),
	package_arch_id	number
			constraint rhn_sp_ac_paid_nn not null
			constraint rhn_sp_ac_paid_fk
				references rhnPackageArch(id),
        preference      number
                        constraint rhn_sp_ac_pref_nn not null,
	created		date default(sysdate)
			constraint rhn_sp_ac_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_sp_ac_modified_nn not null
)
	enable row movement
  ;
create index rhn_sp_ac_said_paid_pref
	on rhnServerPackageArchCompat(
		server_arch_id, package_arch_id, preference)
	tablespace [[64k_tbs]]
  ;
alter table rhnServerPackageArchCompat add constraint rhn_sp_ac_said_paid_uq
	unique ( server_arch_id, package_arch_id );
create index rhn_sp_ac_paid_said_pref
	on rhnServerPackageArchCompat(
	 	package_arch_id, server_arch_id, preference)
	tablespace [[64k_tbs]]
  ;
alter table rhnServerPackageArchCompat add constraint rhn_sp_ac_pref_said_uq
	unique ( preference, server_arch_id )
	using index tablespace [[64k_tbs]];
create or replace trigger
rhn_sp_ac_mod_trig
before insert or update on rhnServerPackageArchCompat
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerPackageArchCompat_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerPackageArchCompat_data.sql
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i386-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i386-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i486-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i486-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i486-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i586-redhat-linux'), LOOKUP_PACKAGE_ARCH('i586'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i586-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i586-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i586-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i686-redhat-linux'), LOOKUP_PACKAGE_ARCH('i686'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i686-redhat-linux'), LOOKUP_PACKAGE_ARCH('i586'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i686-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i686-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 30);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i686-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_PACKAGE_ARCH('athlon'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_PACKAGE_ARCH('i686'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_PACKAGE_ARCH('i586'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 30);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 40);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('athlon-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('alpha-redhat-linux'), LOOKUP_PACKAGE_ARCH('alpha'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('alpha-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('alphaev6-redhat-linux'), LOOKUP_PACKAGE_ARCH('alphaev6'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('alphaev6-redhat-linux'), LOOKUP_PACKAGE_ARCH('alpha'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('alphaev6-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_PACKAGE_ARCH('ia64'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 100);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 200);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i586'), 300);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i686'), 400);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia64-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-redhat-linux'), LOOKUP_PACKAGE_ARCH('sparc'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparcv9-redhat-linux'), LOOKUP_PACKAGE_ARCH('sparcv9'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparcv9-redhat-linux'), LOOKUP_PACKAGE_ARCH('sparc'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparcv9-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('sparc64'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('sparcv9'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('sparc'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('s390-redhat-linux'), LOOKUP_PACKAGE_ARCH('s390'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('s390-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('s390x-redhat-linux'), LOOKUP_PACKAGE_ARCH('s390x'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('s390x-redhat-linux'), LOOKUP_PACKAGE_ARCH('s390'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('s390x-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('pSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('pSeries'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('pSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('pSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('pSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('iSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('iSeries'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('iSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('iSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('iSeries-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('x86_64'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('athlon'), 100);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i686'), 110);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i586'), 120);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 130);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 140);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('x86_64-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('amd64-redhat-linux'), LOOKUP_PACKAGE_ARCH('amd64'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('amd64-redhat-linux'), LOOKUP_PACKAGE_ARCH('x86_64'), 50);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('amd64-redhat-linux'), LOOKUP_PACKAGE_ARCH('athlon'), 100);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('amd64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i686'), 110);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('amd64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i586'), 120);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('amd64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 130);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('amd64-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 140);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('amd64-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia32e-redhat-linux'), LOOKUP_PACKAGE_ARCH('ia32e'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia32e-redhat-linux'), LOOKUP_PACKAGE_ARCH('x86_64'), 50);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia32e-redhat-linux'), LOOKUP_PACKAGE_ARCH('athlon'), 100);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia32e-redhat-linux'), LOOKUP_PACKAGE_ARCH('i686'), 110);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia32e-redhat-linux'), LOOKUP_PACKAGE_ARCH('i586'), 120);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia32e-redhat-linux'), LOOKUP_PACKAGE_ARCH('i486'), 130);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia32e-redhat-linux'), LOOKUP_PACKAGE_ARCH('i386'), 140);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ia32e-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64iseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64iseries'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64iseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64iseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64iseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64pseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64pseries'), 0);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64pseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc64'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64pseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('ppc'), 20);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('ppc64pseries-redhat-linux'), LOOKUP_PACKAGE_ARCH('noarch'), 1000);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4m-solaris'), LOOKUP_PACKAGE_ARCH('sparc.sun4u-solaris'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4m-solaris'), LOOKUP_PACKAGE_ARCH('sparc.sun4v-solaris'), 100);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4m-solaris'), LOOKUP_PACKAGE_ARCH('sparc-solaris'), 210);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4m-solaris'), LOOKUP_PACKAGE_ARCH('sparc-solaris-patch'), 310);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4m-solaris'), LOOKUP_PACKAGE_ARCH('sparc-solaris-patch-cluster'), 410);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4m-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris'), 510);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4m-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris-patch'), 610);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4m-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris-patch-cluster'), 710); 
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4u-solaris'), LOOKUP_PACKAGE_ARCH('sparc.sun4u-solaris'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4u-solaris'), LOOKUP_PACKAGE_ARCH('sparc-solaris'), 100);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4u-solaris'), LOOKUP_PACKAGE_ARCH('sparc-solaris-patch'), 210);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4u-solaris'), LOOKUP_PACKAGE_ARCH('sparc-solaris-patch-cluster'), 310);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4u-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris'), 410);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4u-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris-patch'), 510);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4u-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris-patch-cluster'), 610); 
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4v-solaris'), LOOKUP_PACKAGE_ARCH('sparc.sun4v-solaris'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4v-solaris'), LOOKUP_PACKAGE_ARCH('sparc-solaris'), 100);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4v-solaris'), LOOKUP_PACKAGE_ARCH('sparc-solaris-patch'), 210);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4v-solaris'), LOOKUP_PACKAGE_ARCH('sparc-solaris-patch-cluster'), 310);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4v-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris'), 410);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4v-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris-patch'), 510);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('sparc-sun4v-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris-patch-cluster'), 610);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i386-i86pc-solaris'), LOOKUP_PACKAGE_ARCH('i386-solaris'), 10);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i386-i86pc-solaris'), LOOKUP_PACKAGE_ARCH('i386-solaris-patch'), 200);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i386-i86pc-solaris'), LOOKUP_PACKAGE_ARCH('i386-solaris-patch-cluster'), 300);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i386-i86pc-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris'), 410);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i386-i86pc-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris-patch'), 510);
insert into rhnServerPackageArchCompat
(server_arch_id, package_arch_id, preference) values
(LOOKUP_SERVER_ARCH('i386-i86pc-solaris'), LOOKUP_PACKAGE_ARCH('noarch-solaris-patch-cluster'), 610);
commit;

select 'rhnsat/tables/rhnServerPackage_constraints.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerPackage_constraints.sql
alter table rhnServerPackage modify server_id
	constraint rhn_serverpackage_sid_nn not null;
alter table rhnServerPackage modify name_id
	constraint rhn_serverpackage_nid_nn not null;
alter table rhnServerPackage modify evr_id
	constraint rhn_serverpackage_eid_nn not null;
alter table rhnServerPackage
	add constraint rhn_serverpackage_sid_fk
	foreign key (server_id) references rhnServer(id) on delete cascade;
alter table rhnServerPackage
	add constraint rhn_serverpackage_nid_fk
	foreign key (name_id) references rhnPackageName(id);
alter table rhnServerPackage
	add constraint rhn_serverpackage_eid_fk
	foreign key (evr_id) references rhnPackageEVR(id);
alter table rhnServerPackage
   add constraint rhn_serverpackage_paid_fk
   foreign key (package_arch_id) references rhnPackageArch(id);

select 'rhnsat/tables/rhnServerPackage_indexes.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerPackage_indexes.sql
create index rhn_sp_snep_idx on
        rhnServerPackage(server_id, name_id, evr_id, package_arch_id)
	parallel 6
        tablespace [[128m_tbs]]
	nologging;

select 'rhnsat/tables/rhnServerPath.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerPath.sql
create table
rhnServerPath
(
	server_id		number
				constraint rhn_serverpath_sid_nn not null
				constraint rhn_serverpath_sid_fk
					references rhnServer(id),
	proxy_server_id		number
				constraint rhn_serverpath_psid_nn not null
				constraint rhn_serverpath_psid_fk
					references rhnServer(id),
	position		number
				constraint rhn_serverpath_pos_nn not null,
	hostname		varchar2(256)
				constraint rhn_serverpath_hostname_nn not null,
	created			date default(sysdate)
				constraint rhn_serverpath_creat_nn not null,
	modified		date default(sysdate)
				constraint rhn_serverpath_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_serverpath_sid_pos_uq
	on rhnServerPath( server_id, position )
	tablespace [[2m_tbs]]
  ;
create unique index rhn_serverpath_psid_sid_uq
	on rhnServerPath( proxy_server_id, server_id )
	tablespace [[2m_tbs]]
  ;
create or replace trigger rhn_serverpath_mod_trig
before insert or update on rhnServerPath
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerPreserveFileList.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerPreserveFileList.sql
create table
rhnServerPreserveFileList
(
	server_id	number
			constraint rhn_serverpfl_ksid_nn not null
			constraint rhn_serverpfl_ksid_fk
				references rhnServer(id),
	file_list_id	number
			constraint rhn_serverpfl_flid_nn not null
			constraint rhn_serverpfl_flid_fk
				references rhnFileList(id)
				on delete cascade,
	created		date default (sysdate)
			constraint rhn_serverpfl_creat_nn not null,
	modified	date default (sysdate)
			constraint rhn_serverpfl_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_serverpfl_ksid_flid_uq
	on rhnServerPreserveFileList( server_id, file_list_id )
	tablespace [[8m_tbs]]
  ;
create index rhn_serverpfl_flid_ksid_idx
	on rhnServerPreserveFileList( file_list_id, server_id )
	tablespace [[4m_tbs]]
  ;
create or replace trigger
rhn_serverpfl_mod_trig
before insert or update on rhnServerPreserveFileList
for each row
begin
	:new.modified := sysdate;
end rhn_serverpfl_mod_trig;
/
show errors

select 'rhnsat/tables/rhnServerProfilePackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerProfilePackage.sql
create table
rhnServerProfilePackage
(
        server_profile_id       number
	    	    	    	constraint rhn_sprofile_spid_nn not null
	    	    	    	constraint rhn_sprofile_spid_fk
				    	references rhnServerProfile(id)
					on delete cascade,
        name_id                 number
	    	    	    	constraint rhn_sprofile_nid_nn not null
	    	    	    	constraint rhn_sprofile_nid_fk
				    	references rhnPackageName(id),
        evr_id                  number 
	    	    	    	constraint rhn_sprofile_evrid_nn not null
	    	    	    	constraint rhn_sprofile_evrid_fk
					references rhnPackageEvr(id),
        package_arch_id         number
                                constraint rhn_sprofile_package_fk
                                        references rhnPackageArch(id)
)
	enable row movement
  ;
create index rhn_sprof_sp_sne_idx on
        rhnServerProfilePackage(server_profile_id, name_id, evr_id)
	tablespace [[64k_tbs]]
	nologging;

select 'rhnsat/tables/rhnServerProfileType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerProfileType_data.sql
insert into rhnServerProfileType(id, label, name) values (
	rhn_sproftype_id_seq.nextval, 'normal',
	'A normal server profile');
insert into rhnServerProfileType(id, label, name) values (
	rhn_sproftype_id_seq.nextval, 'sync_profile',
	'A server profile associated with a package sync');
commit;

select 'rhnsat/tables/rhnServerServerGroupArchCompat.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerServerGroupArchCompat.sql
create table
rhnServerServerGroupArchCompat
(
        server_arch_id	number
                        constraint rhn_ssg_ac_said_nn not null
                        constraint rhn_ssg_ac_said_fk 
				references rhnServerArch(id),
	server_group_type number
			constraint rhn_ssg_ac_sgt_nn not null
			constraint rhn_ssg_ac_sgt_fk
				references rhnServerGroupType(id),
	created		date default(sysdate)
			constraint rhn_ssg_ac_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_ssg_ac_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_ssg_ac_said_sgt_uq
	on rhnServerServerGroupArchCompat(server_arch_id, server_group_type)
	tablespace [[64k_tbs]]
  ;
create index rhn_ssg_ac_sgt_said_idx
	on rhnServerServerGroupArchCompat(server_group_type, server_arch_id)
	tablespace [[64k_tbs]]
	nologging;
create or replace trigger
rhn_ssg_ac_mod_trig
before insert or update on rhnServerServerGroupArchCompat
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnServerServerGroupArchCompat_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerServerGroupArchCompat_data.sql
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i386-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i486-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i586-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i686-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('athlon-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('alpha-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('alphaev6-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ia64-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('sparc-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('sparcv9-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('sparc64-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('s390-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('s390x-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc64-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('pSeries-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('iSeries-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('x86_64-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ia32e-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('amd64-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc64iseries-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc64pseries-redhat-linux'), 
            lookup_sg_type('sw_mgr_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i386-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i486-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i586-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i686-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('athlon-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('alpha-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('alphaev6-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ia64-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('sparc-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('sparcv9-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('sparc64-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('s390-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('s390x-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc64-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('pSeries-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('iSeries-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('x86_64-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ia32e-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('amd64-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc64iseries-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc64pseries-redhat-linux'), 
            lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
   values (lookup_server_arch('sparc-sun4m-solaris'), 
           lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
   values (lookup_server_arch('sparc-sun4u-solaris'), 
           lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
   values (lookup_server_arch('sparc-sun4v-solaris'), 
           lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
   values (lookup_server_arch('i386-i86pc-solaris'), 
           lookup_sg_type('enterprise_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i386-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i486-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i586-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i686-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('athlon-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('alpha-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('alphaev6-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ia64-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('sparc-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('sparcv9-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('sparc64-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('s390-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('s390x-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc64-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('pSeries-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('iSeries-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('x86_64-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
   values (lookup_server_arch('ia32e-redhat-linux'), 
           lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
   values (lookup_server_arch('amd64-redhat-linux'), 
           lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc64iseries-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc64pseries-redhat-linux'), 
            lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
   values (lookup_server_arch('sparc-sun4m-solaris'), 
           lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
   values (lookup_server_arch('sparc-sun4u-solaris'), 
           lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
   values (lookup_server_arch('sparc-sun4v-solaris'), 
           lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
   values (lookup_server_arch('i386-i86pc-solaris'), 
           lookup_sg_type('provisioning_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i386-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i486-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i586-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('i686-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('athlon-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('alpha-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('alphaev6-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ia64-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('s390-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('s390x-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc64-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('pSeries-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('iSeries-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('x86_64-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
   values (lookup_server_arch('ia32e-redhat-linux'), 
           lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
   values (lookup_server_arch('amd64-redhat-linux'), 
           lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc64iseries-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type )
	values (lookup_server_arch('ppc64pseries-redhat-linux'), 
            lookup_sg_type('monitoring_entitled'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('i386-redhat-linux'),
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('i486-redhat-linux'), 
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('i586-redhat-linux'), 
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('i686-redhat-linux'), 
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('athlon-redhat-linux'),
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('amd64-redhat-linux'),
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('ia64-redhat-linux'),
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('ia32e-redhat-linux'),
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('s390-redhat-linux'),
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('s390x-redhat-linux'),
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('ppc-redhat-linux'),
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('ppc64-redhat-linux'),
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('x86_64-redhat-linux'),
            lookup_sg_type('virtualization_host'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('i386-redhat-linux'),
            lookup_sg_type('virtualization_host_platform'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('i486-redhat-linux'), 
            lookup_sg_type('virtualization_host_platform'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('i586-redhat-linux'), 
            lookup_sg_type('virtualization_host_platform'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('i686-redhat-linux'), 
            lookup_sg_type('virtualization_host_platform'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('athlon-redhat-linux'),
            lookup_sg_type('virtualization_host_platform'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('amd64-redhat-linux'),
            lookup_sg_type('virtualization_host_platform'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('ia64-redhat-linux'),
            lookup_sg_type('virtualization_host_platform'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('ia32e-redhat-linux'),
            lookup_sg_type('virtualization_host_platform'));
insert into rhnServerServerGroupArchCompat ( server_arch_id, server_group_type)
    values (lookup_server_arch('x86_64-redhat-linux'),
            lookup_sg_type('virtualization_host_platform'));
commit;

select 'rhnsat/tables/rhnServerTokenRegs.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerTokenRegs.sql
create table
rhnServerTokenRegs
(
	token_id	number
			constraint rhn_srv_reg_tok_tid_nn not null
			constraint rhn_srv_reg_tok_tid_fk
				references rhnRegToken(id)
				on delete cascade,
	server_id	number
			constraint rhn_srv_reg_tok_sid_nn not null
			constraint rhn_srv_reg_tok_sid_fk
				references rhnServer(id)
)
	enable row movement
  ;
create index rhn_srv_reg_tok_ts_idx
	on rhnServerTokenRegs(token_id, server_id)
   tablespace [[64k_tbs]]
	nologging;
create index RHN_SRVR_TKN_RGS_SID_TID_IDX
on rhnServerTokenRegs ( server_id, token_id )
        tablespace [[64k_tbs]]
        nologging;

select 'rhnsat/tables/rhnServerUuid.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnServerUuid.sql
create table
rhnServerUuid
(
        server_id       number
			constraint rhn_server_uuid_sid_nn not null
                        constraint rhn_server_uuid_sid_fk
				references rhnServer(id),
	uuid            varchar2(36)
	                constraint rhn_server_uuid_uuid_nn not null
)
	enable row movement
  ;
create unique index rhn_server_uuid_sid_unq on
        rhnServerUuid(server_id)
	tablespace [[4m_tbs]]
  ;
create unique index rhn_serveruuid_uuid_sid_unq on
    rhnServerUUID ( uuid, server_id )
    tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnSnapshotInvalidReason_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSnapshotInvalidReason_data.sql
insert into rhnSnapshotInvalidReason (id, label, name)
	values (rhn_ssinvalid_id_seq.nextval, 'channel_removed',
		'A channel this snapshot was associated with no longer exists');
insert into rhnSnapshotInvalidReason (id, label, name)
	values (rhn_ssinvalid_id_seq.nextval, 'channel_modified',
		'A channel this snapshot is associated with has been modified');
insert into rhnSnapshotInvalidReason (id, label, name)
	values (rhn_ssinvalid_id_seq.nextval, 'sg_removed',
		'A server group this snapshot was associated with no longer exists');
insert into rhnSnapshotInvalidReason (id, label, name)
	values (rhn_ssinvalid_id_seq.nextval, 'ns_removed',
		'A namespace this snapshot was associated with no longer exists');
insert into rhnSnapshotInvalidReason (id, label, name)
	values (rhn_ssinvalid_id_seq.nextval, 'cr_removed',
		'A config revision this snapshot was associated with no longer exists');
insert into rhnSnapshotInvalidReason (id, label, name)
	values (rhn_ssinvalid_id_seq.nextval, 'cc_removed',
		'A config channel this snapshot was associated with no longer exists');
commit;

select 'rhnsat/tables/rhnSnapshotPackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSnapshotPackage.sql
create table
rhnSnapshotPackage
(
	snapshot_id		number
				constraint rhn_snapshotpkg_sid_fk
					references rhnSnapshot(id)
					on delete cascade
				constraint rhn_snapshotpkg_sid_nn not null,
	nevra_id		number
				constraint rhn_snapshotpkg_nid_fk
					references rhnPackageNevra(id)
				constraint rhn_snapshotpkg_nid_nn not null
)
	enable row movement
  ;
create index rhn_snapshotpkg_sid
    	on rhnSnapshotPackage( snapshot_id )
	tablespace [[8m_tbs]]
  ;
create unique index rhn_snapshotpkg_sid_nid_uq
	on rhnSnapshotPackage( snapshot_id, nevra_id )
	tablespace [[32m_tbs]]
  ;
create or replace trigger
rhn_snapshotpkg_mod_trig
before insert or update on rhnSnapshotPackage
for each row
begin
	update rhnSnapshot set modified = sysdate where id = :new.snapshot_id;
end;
/
show errors

select 'rhnsat/tables/rhnSnapshotTag.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSnapshotTag.sql
create table
rhnSnapshotTag
(
	snapshot_id	number
			constraint rhn_st_ssid_nn not null
			constraint rhn_st_ssid_fk
				references rhnSnapshot(id)
				on delete cascade,
	tag_id          number
			constraint rhn_st_tid_nn not null
			constraint rhn_st_tid_fk
				references rhnTag(id),
	server_id	number
			constraint rhn_st_sid_fk
				references rhnServer(id),
	created		date default (sysdate)
			constraint rhn_st_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_st_modified_nn not null
)
	enable row movement
	;
create unique index rhn_ss_tag_ssid_tid_uq
    	on rhnSnapshotTag(snapshot_id, tag_id);
create unique index rhn_ss_tag_sid_tid_uq
    	on rhnSnapshotTag(server_id, tag_id);
create index rhn_ss_tag_tid_ssid_idx
    	on rhnSnapshotTag(tag_id, snapshot_id);
create index rhn_ss_tag_tid_sid_idx
    	on rhnSnapshotTag(tag_id, server_id);
create or replace trigger
rhn_ss_tag_mod_trig
before insert or update on rhnSnapshotTag
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnSolarisPackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSolarisPackage.sql
create table rhnSolarisPackage (
   package_id              number
                           constraint rhn_solaris_pkg_pid_pk primary key
                           constraint rhn_solaris_pkg_pid_fk references rhnPackage(id)
                           on delete cascade,
   category                varchar2(2048)
                           constraint rhn_solaris_pkg_cat_nn not null,
   pkginfo                 varchar2(4000),
   pkgmap                  blob,
   intonly                 char(1) default 'N'
                           constraint rhn_solaris_pkg_io_ck check ( intonly in ('Y','N'))
)
	tablespace [[8m_data_tbs]]
	enable row movement
  ;

select 'rhnsat/tables/rhnSolarisPatchType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSolarisPatchType.sql
create table rhnSolarisPatchType (
   id          number
               constraint rhn_solaris_pt_pk primary key,
   name        varchar2(32)
               constraint rhn_solaris_pt_name_nn not null,
   label       varchar2(32)
               constraint rhn_solaris_pt_label_nn not null
)
tablespace [[8m_data_tbs]]
enable row movement
  ;
create sequence rhn_solaris_pt_seq;

select 'rhnsat/tables/rhnSolarisPatch.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSolarisPatch.sql
create table rhnSolarisPatch (
   package_id        number
                     constraint rhn_solaris_p_pk primary key
                     constraint rhn_solaris_p_fk references rhnPackage(id)
                     on delete cascade,
   solaris_release   varchar2(64),
   sunos_release     varchar2(64),
   patch_type        number
                     constraint rhn_solaris_p_pt_nn not null
                     constraint rhn_solaris_p_pt_fk references rhnSolarisPatchType (id)
                     on delete set null,
   created           date default(sysdate)
                     constraint rhn_solaris_p_created_nn not null,
   modified          date default(sysdate)
                     constraint rhn_solaris_p_modified_nn not null,
   readme            blob
                     constraint rhn_solaris_p_rdme_nn not null,
   patchinfo         varchar2(4000)
)
	tablespace [[8m_data_tbs]]
	enable row movement
  ;
create trigger
rhn_solaris_p_mod_trig
before update on rhnSolarisPatch
for each row
begin
   :new.modified := sysdate;
end;
/
show errors;

select 'rhnsat/tables/rhnSolarisPatchPackages.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSolarisPatchPackages.sql
create table rhnSolarisPatchPackages (
   patch_id             number
                        constraint rhn_solaris_pp_nn not null
                        constraint rhn_solaris_pp_fk references rhnPackage(id)
                        on delete cascade,
   package_nevra_id     number
                        constraint rhn_solaris_pnid_nn not null
                        constraint rhn_solaris_pnid_fk references rhnPackageNEVRA(id)
                        on delete cascade
)
tablespace [[8m_data_tbs]]
enable row movement
  ;
create index rhn_solaris_pp_pid_pnid_idx
on rhnSolarisPatchPackages (patch_id, package_nevra_id)
  ;
create index rhn_solaris_pp_pnid_pid_idx
on rhnSolarisPatchPackages (package_nevra_id, patch_id)
  ;

select 'rhnsat/tables/rhnSolarisPatchSet.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSolarisPatchSet.sql
create table rhnSolarisPatchSet (
   package_id        number
                     constraint rhn_solaris_ps_pid_pk primary key
                     constraint rhn_solaris_ps_pid_fk references rhnPackage(id)
                     on delete cascade,
   readme            blob,
   set_date          date default(sysdate)
                     constraint rhn_solaris_ps_sd_nn not null,
   created           date default(sysdate)
                     constraint rhn_solaris_ps_created_nn not null,
   modified          date default(sysdate)
                     constraint rhn_solaris_ps_modified_nn not null
)
tablespace [[8m_data_tbs]]
enable row movement
  ;
create sequence rhn_solaris_ps_seq;
create or replace trigger
rhn_solaris_ps_mod_trig
before insert or update on rhnSolarisPatchSet
for each row
begin
   :new.modified := sysdate;
end;
/
show errors;

select 'rhnsat/tables/rhnSolarisPatchSetMembers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSolarisPatchSetMembers.sql
create table rhnSolarisPatchSetMembers (
   patch_id          number
                     constraint rhn_solaris_psm_pid_nn not null
                     constraint rhn_solaris_psm_pid_fk references rhnPackage(id)
                     on delete cascade,
   patch_set_id      number
                     constraint rhn_solaris_psm_psid_nn not null
                     constraint rhn_solaris_psm_psid_fk references rhnPackage(id)
                     on delete cascade,
   patch_order       number,
   created           date default(sysdate)
                     constraint rhn_solaris_psm_created_nn not null,
   modified          date default(sysdate)
                     constraint rhn_solaris_psm_modified_nn not null
)
tablespace [[8m_data_tbs]]
enable row movement
  ;
create index rhn_solaris_psm_pid_psid_idx
on rhnSolarisPatchSetMembers (patch_id, patch_set_id)
tablespace [[4m_tbs]]
  ;
create index rhn_solaris_psm_psid_pid_idx
on rhnSolarisPatchSetMembers (patch_set_id, patch_id)
tablespace [[4m_tbs]]
  ;
create trigger
rhn_solaris_psm_mod_trig
before update on rhnSolarisPatchSetMembers
for each row
begin
   :new.modified := sysdate;
end;
/
show errors;

select 'rhnsat/tables/rhnSolarisPatchType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSolarisPatchType_data.sql
insert into rhnSolarisPatchType (id, name, label)
   values (rhn_solaris_pt_seq.nextval, 'Generic Patch', 'generic');
insert into rhnSolarisPatchType (id, name, label)
   values (rhn_solaris_pt_seq.nextval, 'Kernel Update Patch', 'kernel');
insert into rhnSolarisPatchType (id, name, label)
   values (rhn_solaris_pt_seq.nextval, 'Restricted Patch', 'restricted');
insert into rhnSolarisPatchType (id, name, label)
   values (rhn_solaris_pt_seq.nextval, 'Point Patch', 'point');
insert into rhnSolarisPatchType (id, name, label)
   values (rhn_solaris_pt_seq.nextval, 'Temporary Patch', 'temporary');
insert into rhnSolarisPatchType (id, name, label)
   values (rhn_solaris_pt_seq.nextval, 'Nonstandard Patch', 'nonstandard');

select 'rhnsat/tables/rhnSolarisPatchedPackage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSolarisPatchedPackage.sql
create table rhnSolarisPatchedPackage (
   server_id            number
                        constraint rhn_solaris_patchedp_sid_nn not null
                        constraint rhn_solaris_patchedp_sid_fk references rhnServer(id)
                        on delete cascade,
   patch_id             number
                        constraint rhn_solaris_patchedp_pid_nn not null
                        constraint rhn_solaris_patchedp_pid_fk references rhnPackage(id)
                        on delete cascade,
   package_nevra_id     number
                        constraint rhn_solaris_patchedp_pnid_nn not null
                        constraint rhn_solaris_patchedp_pnid_fk references rhnPackageNEVRA(id)
                        on delete cascade
)
tablespace [[8m_data_tbs]]
enable row movement
  ;
create index rhn_solaris_patchedp_sid_idx
on rhnSolarisPatchedPackage ( server_id )
   tablespace [[8m_tbs]]
   nologging;

select 'rhnsat/tables/rhnSystemMigrations.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnSystemMigrations.sql
create table
rhnSystemMigrations
(
        org_id_to       number
                        constraint rhn_sys_mig_oidto_nn not null
                        constraint rhn_sys_mig_oidto_fk
                                references web_customer(id),
        org_id_from     number
                        constraint rhn_sys_mig_oidfrm_nn not null
                        constraint rhn_sys_mig_oidfrm_fk
                                references web_customer(id),
        server_id       number
                        constraint rhn_sys_mig_sid_nn not null
                        constraint rhn_sys_mig_sid_fk
                                references rhnServer(id)
                                 on delete cascade,
        migrated        date default (sysdate)
                        constraint rhn_sys_mig_migrated_nn not null
)
        enable row movement
  ;
create index rsm_org_id_to_idx
        on rhnSystemMigrations ( org_id_to )
  ;
create index rsm_org_id_from_idx
        on rhnSystemMigrations ( org_id_from )
  ;

select 'rhnsat/tables/rhnTaskQueue.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTaskQueue.sql
create table 
rhnTaskQueue
(
	org_id		number
			constraint rhn_task_queue_org_id_nn not null
			constraint rhn_task_queue_org_id_fk
				references web_customer(id)
				on delete cascade,
	task_name	VARCHAR2(64)
			constraint rhn_task_queue_task_name_nn not null,
	task_data	number,
	priority	number default 0,
	earliest	date default sysdate
			constraint rhn_task_queue_earliest_nn not null
)
	enable row movement
	nologging;
create index rhn_task_queue_org_task_idx
	on rhnTaskQueue(org_id, task_name)
	tablespace [[64k_tbs]]
	nologging;
create index rhn_task_queue_earliest
	on rhnTaskQueue(earliest)
        tablespace [[64k_tbs]]
        nologging;

select 'rhnsat/tables/rhnTemplateCategory.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTemplateCategory.sql
create sequence rhn_template_cat_id_seq;
create table
rhnTemplateCategory
(
	id		number
			constraint rhn_template_cat_id_nn not null,
	label		varchar2(64)
			constraint rhn_template_cat_label_nn not null,
	description	varchar2(512)
			constraint rhn_template_cat_desc_nn not null,
	created		date default(sysdate)
			constraint rhn_template_cat_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_template_cat_modified_nn not null
)
	enable row movement
  ;
create index rhn_template_cat_id_idx
	on rhnTemplateCategory ( id )
	tablespace [[64k_tbs]]
  ;
alter table rhnTemplateCategory add constraint rhn_template_cat_id_pk
	primary key ( id );
create index rhn_template_cat_label_id_idx
	on rhnTemplateCategory ( label, id )
	tablespace [[64k_tbs]]
  ;
alter table rhnTemplateCategory add constraint rhn_template_cat_label_uq
	unique ( label );
create or replace trigger
rhn_template_cat_mod_trig
before insert or update on rhnTemplateCategory
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnTemplateCategory_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTemplateCategory_data.sql
INSERT INTO rhnTemplateCategory (id, label, description) 
     VALUES (rhn_template_cat_id_seq.nextval, 'org_strings', 'Organization specific strings.');
INSERT INTO rhnTemplateCategory (id, label, description)
     VALUES (rhn_template_cat_id_seq.nextval, 'email_strings', 'Strings appearing in e-mail sent to users.');

select 'rhnsat/tables/rhnTemplateString.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTemplateString.sql
create sequence rhn_template_str_id_seq;
create table
rhnTemplateString
(
	id		number
			constraint rhn_template_str_id_nn not null,
	category_id	number
			constraint rhn_template_str_cid_nn not null
			constraint rhn_template_str_cid_fk
				references rhnTemplateCategory(id),
	label		varchar2(64)
			constraint rhn_template_str_key_nn not null,
	value		varchar2(4000),
	description	varchar2(512)
			constraint rhn_template_str_desc_nn not null,
	created		date default(sysdate)
			constraint rhn_template_str_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_template_str_modified_nn not null
)
	enable row movement
  ;
create index rhn_template_str_icl_idx
	on rhnTemplateString ( id, category_id, label )
	tablespace [[4m_tbs]]
  ;
alter table rhnTemplateString add constraint rhn_template_str_id_pk
	primary key ( id );
create index rhn_template_str_cid_label_idx
	on rhnTemplateString ( category_id, label )
	tablespace [[2m_tbs]]
  ;
alter table rhnTemplateString add constraint rhn_template_str_cid_label_uq
	unique ( category_id, label );
create or replace trigger
rhn_template_str_mod_trig
before insert or update on rhnTemplateString
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnTemplateString_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTemplateString_data.sql
SET SQLBLANKLINES ON
SET SCAN OFF
INSERT INTO rhnTemplateString (id, category_id, label, value, description) 
     VALUES (rhn_template_str_id_seq.nextval,
             (SELECT TC.id 
                FROM rhnTemplateCategory TC
	       WHERE TC.label = 'email_strings'),
	     'email_footer', '-' || '-the Spacewalk Team', 'Footer for Spacewalk e-mail');
INSERT INTO rhnTemplateString (id, category_id, label, value, description) 
     VALUES (rhn_template_str_id_seq.nextval,
             (SELECT TC.id 
                FROM rhnTemplateCategory TC
	       WHERE TC.label = 'email_strings'),
	     'email_account_info', '
Account Information:
  Your Spacewalk login:         <login />
  Your Spacewalk email address: <email-address />', 'Account info lines for Spacewalk e-mail');

select 'rhnsat/tables/rhnTextMessage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTextMessage.sql
create table
rhnTextMessage
(
	message_id	number
			constraint rhn_tm_message_id_nn not null
			constraint rhn_tm_message_id_fk
				references rhnMessage(id)
				on delete cascade,
	message_body	varchar2(4000) -- the contents of the message
			constraint rhn_tm_message_body_nn not null,
	created		date default (sysdate)
			constraint rhn_tm_created_nn not null,
	modified	date default (sysdate)
			constraint rhn_tm_modified_nn not null
)
	enable row movement
  ;
create or replace trigger
rhn_tm_mod_trig
before insert or update on rhnTextMessage
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnTimezone_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTimezone_data.sql
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Australia/Sydney', 'Australia (Eastern)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Asia/Tokyo', 'Japan');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Asia/Hong_Kong', 'Australia (Western)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Europe/Moscow', 'Russia (Moscow)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Europe/Bucharest', 'Europe (Eastern)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Europe/Paris', 'Europe (Central)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'GMT', 'Greenwich Mean Time');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'America/St_Johns', 'Canada (Newfoundland)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'America/Halifax', 'Canada (Atlantic)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'America/New_York', 'United States (Eastern)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'America/Indianapolis', 'United States (Indiana)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'America/Chicago', 'United States (Central)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'America/Denver', 'United States (Mountain)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'America/Phoenix', 'United States (Arizona)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'America/Los_Angeles', 'United States (Pacific)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'America/Anchorage', 'United States (Alaska)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Pacific/Honolulu', 'United States (Hawaii)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Pacific/Enderbury', 'Tonga');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Pacific/Wallis', 'New Zealand');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Pacific/Norfolk', 'Norfolk Island');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Pacific/Guadalcanal', 'Micronesia');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Australia/Darwin', 'Australia (Central/Darwin)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Asia/Jakarta', 'Thailand');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Indian/Cocos', 'Burma');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Indian/Chagos', 'Bangladesh');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Asia/Katmandu', 'Nepal');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Asia/Calcutta', 'India (Calcutta)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Indian/Maldives', 'Pakistan');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Asia/Kabul', 'Afghanistan');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Asia/Tehran', 'Iran');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Indian/Mauritius', 'Russia (Samara)');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Atlantic/Azores', 'Azores');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Atlantic/South_Georgia', 'Sandwich Islands');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'Pacific/Midway', 'Midway');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'America/Sao_Paulo', 'Brazil');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'GB', 'Great Britain');
insert into rhnTimezone
  (id, olson_name, display_name)
values
  (rhn_timezone_id_seq.nextval,
   'GB-Eire', 'Ireland');
commit;

select 'rhnsat/tables/rhnTinyURL.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTinyURL.sql
CREATE TABLE
rhnTinyURL
(
        token           varchar2(64)
                        constraint rhn_tu_token_nn not null,
        url             varchar2(512)
                        constraint rhn_tu_url_nn not null,
        enabled         varchar2(1)
                        constraint rhn_tu_enabled_nn not null
                        constraint rhn_tu_enabled_ck
                                check (enabled in ('Y','N')),
        created         date default (sysdate)
                        constraint rhn_tu_created_nn not null,
        expires         date default (sysdate)
                        constraint rhn_tu_expires_nn not null
)
	enable row movement
  ;
create unique index rhn_tu_token_uq
        on rhnTinyURL(token)
        tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnTransactionElement.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTransactionElement.sql
create table
rhnTransactionElement
(
	transaction_id		number
				constraint rhn_transelem_tid_nn not null
				constraint rhn_transelem_tid_fk
					references rhnTransaction(id)
					on delete cascade,
	transaction_package_id	number
				constraint rhn_transelem_tpid_nn not null
				constraint rhn_transelem_tpid_fk
					references rhnTransactionPackage(id)
)
	enable row movement
  ;
create unique index rhn_transelem_tid_tpid_uq
	on rhnTransactionElement(transaction_id,transaction_package_id)
	tablespace [[8m_tbs]]
  ;

select 'rhnsat/tables/rhnTransactionOperation_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTransactionOperation_data.sql
insert into rhnTransactionOperation (id, label) values (1,'insert');
insert into rhnTransactionOperation (id, label) values (2,'delete');
insert into rhnTransactionOperation (id, label) values (3,'upgrade');

select 'rhnsat/tables/rhnTransactionOperation_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTransactionOperation_triggers.sql
create or replace trigger
rhn_transop_mod_trig
before insert or update on rhnTransactionOperation
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnTransaction_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTransaction_triggers.sql
create or replace trigger
rhn_trans_mod_trig
before insert or update on rhnTransaction
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnTrustedOrgs.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnTrustedOrgs.sql
create table
rhnTrustedOrgs
(
	org_id		number
			constraint rhn_trusted_orgs_oid_nn not null
			constraint rhn_trusted_orgs_oid_fk
				references web_customer(id)
                                on delete cascade,
	org_trust_id	number
			constraint rhn_trusted_orgs_otid_nn not null
			constraint rhn_trusted_orgs_otid_fk
				references web_customer(id)
                                on delete cascade,
        created         date default (sysdate)
                        constraint rhn_trusted_orgs_created_nn not null,
        modified        date default (sysdate)
                        constraint rhn_trusted_orgs_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_trusted_orgs_oid_uq
	on rhnTrustedOrgs(org_id,org_trust_id)
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnUserDefaultSystemGroups.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserDefaultSystemGroups.sql
create table
rhnUserDefaultSystemGroups
(
	user_id		number
			constraint rhn_udsg_uid_nn not null
			constraint rhn_udsg_uid_fk
				references web_contact(id)
				on delete cascade,
	system_group_id	number
			constraint rhn_udsg_cid_nn not null
			constraint rhn_udsg_cidffk
				references rhnServerGroup(id)
				on delete cascade
)
	enable row movement
  ;
create unique index rhn_udsg_uid_sgid_idx
	on rhnUserDefaultSystemGroups(user_id, system_group_id)
	tablespace [[2m_tbs]]
  ;
create index rhn_udsg_sgid_uid_idx
	on rhnUserDefaultSystemGroups(system_group_id, user_id)
	tablespace [[2m_tbs]]
  ;

select 'rhnsat/tables/rhnUserGroupMembers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserGroupMembers.sql
create table
rhnUserGroupMembers
(
	user_id		number
			constraint rhn_ugmembers_uid_nn not null
			constraint rhn_ugmembers_uid_fk
				references web_contact(id)
				on delete cascade,
	user_group_id	number
			constraint rhn_ugmembers_ugid_nn not null
			constraint rhn_ugmembers_ugid_fk
				references rhnUserGroup(id),
	created		date default(sysdate)
			constraint rhn_ugmembers_created_nn not null,
	modified	date default(sysdate)
			constraint rhn_ugmembers_modified_nn not null
)
	enable row movement
  ;

select 'rhnsat/tables/rhnUserGroupMembers_indexes.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserGroupMembers_indexes.sql
create unique index rhn_ugmembers_uid_ugid_uq
	on rhnUserGroupMembers(user_id, user_group_id)
	parallel 6
	tablespace [[8m_tbs]]
  ;
create index rhn_ugmembers_ugid_uid_idx
	on rhnUserGroupMembers(user_group_id, user_id)
	parallel 6
	tablespace [[8m_tbs]]
	nologging;

select 'rhnsat/tables/rhnUserGroupMembers_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserGroupMembers_triggers.sql
create or replace trigger
rhn_ug_member_mod_trig
before insert or update on rhnUserGroupMembers
for each row
declare
        ug              rhnUserGroup%ROWTYPE;
begin
        :new.modified := sysdate;
        if inserting then
                select
                        * into ug
                from
                        rhnUserGroup
                where
                        id = :new.user_group_id;
                if ug.max_members is not null and
                ug.current_members+1 > ug.max_members then
                        rhn_exception.raise_exception('usergroup_max_members');
                end if;
                update rhnUserGroup
                set current_members = current_members + 1
                where id = :new.user_group_id;
        end if;
end;
/
show errors
CREATE OR REPLACE TRIGGER
rhn_user_group_org_mapping
BEFORE INSERT OR UPDATE ON rhnUserGroupMembers
FOR EACH ROW
DECLARE
        same_org        NUMBER;
BEGIN
        same_org := 0;
        SELECT 1 INTO same_org
          FROM web_contact U, rhnUserGroup UG
         WHERE UG.org_id = U.org_id
           AND U.id = :new.user_id
           AND UG.id = :new.user_group_id;
        IF same_org = 0 THEN
          rhn_exception.raise_exception('ugm_different_orgs');
        END IF;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
          rhn_exception.raise_exception('ugm_different_orgs');
END;
/
SHOW ERRORS
create or replace trigger
rhn_ug_member_del_trig
before delete on rhnUserGroupMembers
for each row
begin
        update rhnUserGroup
        set current_members = current_members - 1
        where id = :old.user_group_id;
end;
/
show errors
create or replace trigger
rhn_ugm_applicant_fix
after delete on rhnUserGroupMembers
for each row
declare
    	group_type_val    NUMBER;
    	group_label_val   rhnUserGroupType.label%TYPE;	
begin
    	SELECT group_type INTO group_type_val
	  FROM rhnUserGroup
	 WHERE id = :old.user_group_id;
	IF group_type_val IS NOT NULL
	THEN
	    SELECT label INTO group_label_val
	      FROM rhnUserGroupType
	     WHERE id = group_type_val;
	    IF group_label_val = 'org_applicant'
	    THEN
	    	UPDATE web_contact SET password = old_password WHERE id = :old.user_id;
	    END IF;
	END IF;
end;
/
show errors

select 'rhnsat/tables/rhnUserGroupType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserGroupType_data.sql
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'satellite_admin',
	'Satellite Administrator'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'org_admin',
	'Organization Administrator'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'org_applicant',
	'Organization Applicant'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'channel_admin',
	'Channel Administrator'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'rhn_support',
	'Spacewalk Support Administrator'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'rhn_superuser',
	'Spacewalk Superuser'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'coma_admin',
	'Coma CMS Administrator'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'coma_author',
	'Coma CMS Author'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'coma_publisher',
	'Coma CMS Publisher'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'config_admin',
	'Configuration Administrator'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'monitoring_admin',
	'Monitoring Administrator'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'system_group_admin',
	'System Group Administrator'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'activation_key_admin',
	'Activation Key Administrator'
);
insert into rhnUserGroupType (id, label, name) values (
	rhn_usergroup_type_seq.nextval,
	'cert_admin',
	'Certificate Administrator'
);
commit;

select 'rhnsat/tables/rhnUserGroup_indexes.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserGroup_indexes.sql
create unique index rhn_ug_oid_name_uq
	on rhnUserGroup(org_id, name)
	tablespace [[32m_tbs]]
  ;
create index rhn_ug_id_name_org
	on rhnUserGroup(id, name, org_id)
	parallel 6
	tablespace [[32m_tbs]]
	nologging;
create index rhn_ug_org_id_name_idx
	on rhnUserGroup(org_id, id, name)
	parallel 6
	tablespace [[32m_tbs]]
	nologging;
create index rhn_ug_org_id_type_idx
	on rhnUserGroup(group_type, id)
	parallel 6
	tablespace [[8m_tbs]]
	nologging;
create index rhn_ug_org_id_gtype_idx
	on rhnUserGroup(org_id, group_type, id)
	parallel 6
	tablespace [[8m_tbs]]
  ;
alter table rhnUserGroup add constraint rhn_ug_oid_gt_uq
	unique ( org_id, group_type );

select 'rhnsat/tables/rhnUserGroup_sequences.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserGroup_sequences.sql
create sequence rhn_user_group_id_seq;

select 'rhnsat/tables/rhnUserGroup_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserGroup_triggers.sql
create or replace trigger
rhn_user_group_mod_trig
before insert or update on rhnUserGroup
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnUserInfoPane.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserInfoPane.sql
create table rhnUserInfoPane (
    user_id number 
            constraint rhn_usr_info_pane_uid_nn not null
            constraint rhn_usr_info_pane_uid_fk 
                references web_contact(id)
                on delete cascade,
    pane_id number
            constraint rhn_usr_info_pane_pid_nn not null
            constraint rhn_usr_info_pane_pid_fk 
                references rhnInfoPane(id)
                on delete cascade
)
    enable row movement
  ;
create unique index rhnusrinfopane_uid_pid_uq
    on rhnUserInfoPane ( user_id, pane_id )
    tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnUserInfo_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserInfo_triggers.sql
create or replace trigger
rhn_user_info_mod_trig
before insert or update on rhnUserInfo
for each row
begin
	:new.modified := sysdate;
end rhn_user_info_mod_trig;
/
show errors

select 'rhnsat/tables/rhnUserMessageStatus.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserMessageStatus.sql
create table
rhnUserMessageStatus
(
	id		number
			constraint rhn_um_status_id_nn not null
			constraint rhn_um_status_id_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(48)
			constraint rhn_um_status_label_nn not null
)
	enable row movement
  ;
create sequence rhn_um_status_id_seq;
create unique index rhn_um_status_label_uq
	on rhnUserMessageStatus(label)
	tablespace [[64k_tbs]]
  ;
create index rhn_um_status_label_id_idx
	on rhnUserMessageStatus(label,id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnUserMessage.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserMessage.sql
create table
rhnUserMessage
(
	user_id		number
			constraint rhn_um_user_id_nn not null
			constraint rhn_um_user_id_fk
				references web_contact(id),
	message_id	number
			constraint rhn_um_message_id_nn not null
			constraint rhn_um_message_id_fk
				references rhnMessage(id)
				on delete cascade,
	status		number
			constraint rhn_um_status_nn not null
			constraint rhn_um_status_fk
				references rhnUserMessageStatus(id)
)
	enable row movement
  ;
create unique index rhn_um_uid_mid_uq
	on rhnUserMessage(user_id, message_id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnUserMessageStatus_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserMessageStatus_data.sql
insert into rhnUserMessageStatus values (
	rhn_um_status_id_seq.nextval, 'New'
);
insert into rhnUserMessageStatus values (
	rhn_um_status_id_seq.nextval, 'Viewed'
);
insert into rhnUserMessageStatus values (
	rhn_um_status_id_seq.nextval, 'Archived'
);
commit;

select 'rhnsat/tables/rhnUserMessageType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserMessageType.sql
create table
rhnUserMessageType
(
	id		number
			constraint rhn_um_type_id_nn not null
			constraint rhn_um_type_pk primary key
				using index tablespace [[64k_tbs]],
	label		varchar2(48)
			constraint rhn_um_type_label_nn not null,
	name		varchar2(96)
			constraint rhn_um_type_name_nn not null
)
	enable row movement
  ;
create unique index rhn_um_type_label_uq
	on rhnUserMessageType(label)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_um_type_name_uq
	on rhnUserMessageType(name)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnUserReserved.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserReserved.sql
create table
rhnUserReserved
(
	login		varchar2(64)
			constraint rhn_user_res_login_nn not null,
	login_uc	varchar2(64)
			constraint rhn_user_res_login_uc_nn not null,
	password	varchar2(38)
			constraint rhn_user_res_pwd_nn not null,
        created         date default(sysdate)
			constraint rhn_user_res_created_nn not null,
        modified        date default(sysdate)
			constraint rhn_user_res_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_user_res_login_uc_uq
	on rhnUserReserved(login_uc)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_user_res_mod_trig
before insert or update on rhnUserreserved
for each row
begin
	:new.login_uc := upper(:new.login);
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnUserServerGroupPerms.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserServerGroupPerms.sql
create table
rhnUserServerGroupPerms
(
        user_id         number
                        constraint rhn_usgp_user_nn not null
                        constraint rhn_usgp_user_fk
                                references web_contact(id) on delete cascade,
        server_group_id number
                        constraint rhn_usgp_server_nn not null
                        constraint rhn_usgp_server_fk
                                references rhnServerGroup(id) on delete cascade,
        created         date default(sysdate)
                        constraint rhn_usgp_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_usgp_modified_nn not null
)
	enable row movement
  ;
create UNIQUE index rhn_usgp_u_sg_p_uq
	on rhnUserServerGroupPerms(user_id, server_group_id)
        tablespace [[4m_tbs]]
  ;
create index rhn_usgp_sg_u_p_idx
        on rhnUserServerGroupPerms(server_group_id, user_id)
        tablespace [[4m_tbs]]
	nologging;

select 'rhnsat/tables/rhnUserServerPerms.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserServerPerms.sql
create table
rhnUserServerPerms
(
	user_id		number
			constraint rhn_usperms_uid_nn not null
			constraint rhn_usperms_uid_fk
				references web_contact(id),
	server_id	number
			constraint rhn_usperms_sid_nn not null
			constraint rhn_usperms_sid_fk
				references rhnServer(id)
)
	enable row movement
  ;
create unique index rhn_usperms_uid_sid_uq
	on rhnUserServerPerms( user_id, server_id )
	tablespace [[8m_tbs]]
  ;
create index rhn_usperms_sid_idx
	on rhnUserServerPerms( server_id )
	tablespace [[4m_tbs]]
  ;

select 'rhnsat/tables/rhnUserServerPrefs.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnUserServerPrefs.sql
create table
rhnUserServerPrefs
(
        user_id		number
                        constraint rhn_userServerPrefs_uid_nn not null
                        constraint rhn_userServerPrefs_uid_fk
                                references web_contact(id)
				on delete cascade,
        server_id	number
                        constraint rhn_userServerPrefs_sid_nn not null
                        constraint rhn_userServerPrefs_sid_fk
                                references rhnServer(id),
        name            varchar2(64)
                        constraint rhn_userServerPrefs_name_nn not null,
        value           varchar2(1)
                        constraint rhn_userServerPrefs_value_nn not null,
        created         date default(sysdate)
                        constraint rhn_userServerPrefs_created_nn not null,
        modified        date default(sysdate)
                        constraint rhn_userServerPrefs_mod_nn not null
)
	enable row movement
  ;
create unique index rhn_usprefs_uid_sid_n_uq
	on rhnUserServerPrefs(user_id, server_id, name)
	tablespace [[2m_tbs]]
  ;
create index rhn_usprefs_n_sid_uid_idx
	on rhnUserServerPrefs(name, server_id, user_id)
	tablespace [[2m_tbs]]
	nologging;
create index rhn_usprefs_sid_uid_n_idx
	on rhnUserServerPrefs(server_id, user_id, name)
	tablespace [[2m_tbs]]
	nologging;
create or replace trigger
rhn_u_s_prefs_mod_trig
before insert or update on rhnUserServerPrefs
for each row
begin
        :new.modified := sysdate;
        :new.value := upper(:new.value);
end;
/
show errors

select 'rhnsat/tables/rhnVersionInfo.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVersionInfo.sql
create table
rhnVersionInfo
(
	label		varchar2(64)
			constraint rhn_versioninfo_label_nn not null,
	name_id		number
			constraint rhn_versioninfo_nid_nn not null
			constraint rhn_versioninfo_nid_fk
				references rhnPackageName(id),
	evr_id		number
			constraint rhn_versioninfo_eid_nn not null
			constraint rhn_versioninfo_eid_fk
				references rhnPackageEVR(id),
	created		date default(sysdate)
			constraint rhn_versioninfo_created_nn not null,
	modified		date default(sysdate)
			constraint rhn_versioninfo_modified_nn not null
)
	enable row movement
  ;
create unique index rhn_versioninfo_label_uq
	on rhnVersionInfo(label)
	tablespace [[64k_tbs]]
  ;
create index rhn_vinfo_label_eid_nid_idx
	on rhnVersionInfo(label, name_id, evr_id)
	tablespace [[64k_tbs]]
  ;
create unique index rhn_versioninfo_nid_eid_uq
	on rhnVersionInfo(name_id,evr_id)
	tablespace [[64k_tbs]]
  ;
create or replace trigger
rhn_versioninfo_mod_trig
before insert or update on rhnVersionInfo
for each row
begin
	:new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/rhnVirtualInstance.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtualInstance.sql
create table
rhnVirtualInstance
(
	id			number
				constraint rhn_vi_id_nn not null
				constraint rhn_vi_id_pk primary key
					using index tablespace [[64k_tbs]],
	host_system_id		number
				constraint rhn_vi_hsi_fk
					references rhnServer(id),
	virtual_system_id	number
				constraint rhn_vi_vsi_fk
					references rhnServer(id),
	uuid			varchar2(128),
        confirmed               number(1) default 1
                                constraint rhn_vi_c_nn not null,
	created			date default (sysdate)
				constraint rhn_vi_created_nn not null,
	modified		date default (sysdate)
				constraint rhn_vi_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_vi_id_seq;
create index rhn_vi_hsid_vsid_idx
	on rhnVirtualInstance(host_system_id, virtual_system_id)
	tablespace [[64k_tbs]]
  ;
create index rhn_vi_vsid_hsid_idx
	on rhnVirtualInstance(virtual_system_id, host_system_id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnVirtualInstanceEventType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtualInstanceEventType.sql
create table
rhnVirtualInstanceEventType
(
	id			number
				constraint rhn_viet_id_nn not null
				constraint rhn_viet_id_pk primary key
					using index tablespace [[64k_tbs]],
	name			varchar2(128)
				constraint rhn_viet_name_nn not null,
	label			varchar2(128)
				constraint rhn_viet_label_nn not null,
	created			date default (sysdate)
				constraint rhn_viet_created_nn not null,
	modified		date default (sysdate)
				constraint rhn_viet_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_viet_id_seq;

select 'rhnsat/tables/rhnVirtualInstanceState.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtualInstanceState.sql
create table
rhnVirtualInstanceState
(
	id			number
				constraint rhn_vis_id_nn not null
				constraint rhn_vis_id_pk primary key
					using index tablespace [[64k_tbs]],
	name			varchar2(128)
				constraint rhn_vis_name_nn not null,
	label			varchar2(128)
				constraint rhn_vis_label_nn not null,
	created			date default (sysdate)
				constraint rhn_vis_created_nn not null,
	modified		date default (sysdate)
				constraint rhn_vis_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_vis_id_seq;
create unique index rhn_vis_lbl_id_idx on
    rhnVirtualInstanceState(label, id)
  ;

select 'rhnsat/tables/rhnVirtualInstanceEventLog.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtualInstanceEventLog.sql
create table
rhnVirtualInstanceEventLog
(
	id			number
				constraint rhn_viel_id_nn not null
				constraint rhn_viel_id_pk primary key
					using index tablespace [[64k_tbs]],
	virtual_instance_id	number
				constraint rhn_viel_vii_fk
					references rhnVirtualInstance(id)
					on delete cascade,
	event_type		number
				constraint rhn_viel_et_nn not null
				constraint rhn_viel_et_fk
					references
					rhnVirtualInstanceEventType(id),
	event_metadata		varchar2(4000),
	old_state		number
				constraint rhn_viel_old_state_nn not null
				constraint rhn_viel_old_state_fk
					   references rhnVirtualInstanceState(id),
	new_state               number
				constraint rhn_viel_new_state_nn not null
				constraint rhn_viel_new_state_fk
					   references rhnVirtualInstanceState(id),
	old_memory_size_k	number,
	new_memory_size_k	number,
	old_vcpus		number,
	new_vcpus		number,
	old_host_system_id	number,
	new_host_system_id	number,
	old_host_system_name	varchar2(128),
	new_host_system_name	varchar2(128),
	local_timestamp		date
				constraint rhn_viel_lt_nn not null,
	created			date default (sysdate)
				constraint rhn_viel_created_nn not null,
	modified		date default (sysdate)
				constraint rhn_viel_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_viel_id_seq;
create index rhn_viel_vii_idx
	on rhnVirtualInstanceEventLog(virtual_instance_id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnVirtualInstanceEventType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtualInstanceEventType_data.sql
insert into rhnVirtualInstanceEventType (id, name, label) values (rhn_viet_id_seq.nextval, 'Create', 'create');
insert into rhnVirtualInstanceEventType (id, name, label) values (rhn_viet_id_seq.nextval, 'Destroy', 'destroy');
insert into rhnVirtualInstanceEventType (id, name, label) values (rhn_viet_id_seq.nextval, 'Shutdown', 'shutdown');
insert into rhnVirtualInstanceEventType (id, name, label) values (rhn_viet_id_seq.nextval, 'Pause', 'pause');
insert into rhnVirtualInstanceEventType (id, name, label) values (rhn_viet_id_seq.nextval, 'Unpause', 'unpause');
insert into rhnVirtualInstanceEventType (id, name, label) values (rhn_viet_id_seq.nextval, 'Migrate', 'migrate');
insert into rhnVirtualInstanceEventType (id, name, label) values (rhn_viet_id_seq.nextval, 'Vcpu-Set', 'vcpu-set');
insert into rhnVirtualInstanceEventType (id, name, label) values (rhn_viet_id_seq.nextval, 'Mem-Set', 'mem-set');

select 'rhnsat/tables/rhnVirtualInstanceType.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtualInstanceType.sql
create table
rhnVirtualInstanceType
(
	id			number
				constraint rhn_vit_id_nn not null
				constraint rhn_vit_id_pk primary key
					using index tablespace [[64k_tbs]],
	name			varchar2(128)
				constraint rhn_vit_name_nn not null,
	label			varchar2(128)
				constraint rhn_vit_label_nn not null,
	created			date default (sysdate)
				constraint rhn_vit_created_nn not null,
	modified		date default (sysdate)
				constraint rhn_vit_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_vit_id_seq;
create unique index rhn_vit_lbl_id_uq on
    rhnVirtualInstanceType(label, id)
  ;

select 'rhnsat/tables/rhnVirtualInstanceInfo.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtualInstanceInfo.sql
create table
rhnVirtualInstanceInfo
(
	name                    varchar2(128),
	instance_id		number
				constraint rhn_vii_viid_nn not null
				constraint rhn_vii_viid_fk
					references rhnVirtualInstance(id)
					on delete cascade,
	instance_type		number
				constraint rhn_vii_it_nn not null
				constraint rhn_vii_it_fk
					references rhnVirtualInstanceType(id),
	memory_size_k		number,
	vcpus			number,
	state			number
				constraint rhn_vii_state_nn not null
				constraint rhn_vii_state_fk
					   references rhnVirtualInstanceState(id),
	created			date default (sysdate)
				constraint rhn_vii_created_nn not null,
	modified		date default (sysdate)
				constraint rhn_vii_modified_nn not null
)
	enable row movement
  ;
create sequence rhn_vii_id_seq;
create unique index rhn_vii_viid_uq
	on rhnVirtualInstanceInfo(instance_id)
	tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/rhnVirtualInstanceInstallLog.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtualInstanceInstallLog.sql
create table
rhnVirtualInstanceInstallLog
(
    id                 number
                           constraint rhn_viil_id_nn not null
                           constraint rhn_viil_id_pk primary key
                           using index tablespace [[64k_tbs]],
    log_message        varchar2(4000)
                           constraint rhn_viil_lm_nn not null,
    ks_session_id      number
                           constraint rhn_viil_ks_sid_fk
                               references rhnKickstartSession(id)
                               on delete cascade,
    created            date default (sysdate)
                           constraint rhn_viil_created_nn not null,
    modified           date default (sysdate)
                           constraint rhn_viil_modified_nn not null
)
    enable row movement
  ;
create sequence rhn_viil_id_seq;

select 'rhnsat/tables/rhnVirtualInstanceState_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtualInstanceState_data.sql
insert into rhnVirtualInstanceState (id, name, label) values (rhn_vis_id_seq.nextval, 'Unknown', 'unknown');
insert into rhnVirtualInstanceState (id, name, label) values (rhn_vis_id_seq.nextval, 'Running', 'running');
insert into rhnVirtualInstanceState (id, name, label) values (rhn_vis_id_seq.nextval, 'Stopped', 'stopped');
insert into rhnVirtualInstanceState (id, name, label) values (rhn_vis_id_seq.nextval, 'Crashed', 'crashed');
insert into rhnVirtualInstanceState (id, name, label) values (rhn_vis_id_seq.nextval, 'Paused', 'paused');

select 'rhnsat/tables/rhnVirtualInstanceType_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtualInstanceType_data.sql
insert into rhnVirtualInstanceType (id, name, label)
     values (rhn_vit_id_seq.nextval, 'Fully Virtualized', 'fully_virtualized');
insert into rhnVirtualInstanceType (id, name, label)
     values (rhn_vit_id_seq.nextval, 'Para-Virtualized', 'para_virtualized');

select 'rhnsat/tables/rhnVirtualInstance_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVirtualInstance_triggers.sql
create or replace trigger
rhn_virtinst_mod_trig
before insert or update on rhnVirtualInstance
for each row
begin
        :new.modified := sysdate;
end;
/
show errors;

select 'rhnsat/tables/rhnVisibleObjects.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVisibleObjects.sql
create table rhnVisibleObjects(
  pxt_session_id number not null,
  object_id number not null,
  object_type varchar2(40) not null,
  constraint rhn_vis_objs_sess_fk
    foreign key (pxt_session_id)
    references PXTSessions(id)
    on delete cascade
)
	enable row movement
	;
create unique index rhn_vis_objs_sess_obj_type_idx
        on rhnVisibleObjects(pxt_session_id, object_id, object_type);

select 'rhnsat/tables/rhnWebContactChangeState.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnWebContactChangeState.sql
create table rhnWebContactChangeState (
    id                     number
                           constraint rhn_cont_change_state_id_pk primary key,
    label                  varchar2(32)
                           constraint rhn_cont_change_state_nn not null
)
tablespace [[32m_tbs]]
enable row movement
  ;
create sequence rhn_wcon_change_state_seq;

select 'rhnsat/tables/rhnWebContactChangeLog.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnWebContactChangeLog.sql
create table rhnWebContactChangeLog (
    id                     number
                           constraint rhn_wcon_cl_id_pk primary key,
    web_contact_id         number
                           constraint rhn_wcon_cl_wcon_id_nn not null
                           constraint rhn_wcon_cl_wcon_id_fk references web_contact(id)
                           on delete cascade,
    web_contact_from_id    number
                           constraint rhn_wcon_cl_wcon_from_id_fk references web_contact(id)
                           on delete set null,
    change_state_id        number
                           constraint rhn_wcon_cl_change_sid_nn not null
                           constraint rhn_wcon_cl_csid_fk references rhnWebContactChangeState(id),
    date_completed         date default(sysdate)
                           constraint rhn_wcon_cl_modified_nn not null
)
enable row movement
  ;
create sequence rhn_wcon_disabled_seq;
create index rhn_wcon_disabled_wcon_id_idx
       on rhnWebContactChangeLog(web_contact_id)
       nologging;

select 'rhnsat/tables/rhnWebContactChangeState_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnWebContactChangeState_data.sql
insert into rhnWebContactChangeState (id, label) values (rhn_wcon_change_state_seq.nextval, 'enabled');
insert into rhnWebContactChangeState (id, label) values (rhn_wcon_change_state_seq.nextval, 'disabled');

select 'rhnsat/tables/rhn_command_class_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_class_data.sql
insert into rhn_command_class(class_name) 
    values ( 'Apache::Processes');
insert into rhn_command_class(class_name) 
    values ( 'Apache::Traffic');
insert into rhn_command_class(class_name) 
    values ( 'Apache::Uptime');
insert into rhn_command_class(class_name) 
    values ( 'Unix::CPU');
insert into rhn_command_class(class_name) 
    values ( 'Unix::Dig');
insert into rhn_command_class(class_name) 
    values ( 'Unix::Disk');
insert into rhn_command_class(class_name) 
    values ( 'Unix::DiskIOThroughput');
insert into rhn_command_class(class_name) 
    values ( 'NetworkService::FTP');
insert into rhn_command_class(class_name) 
    values ( 'NetworkService::HTTP');
insert into rhn_command_class(class_name) 
    values ( 'NetworkService::HTTPS');
insert into rhn_command_class(class_name) 
    values ( 'NetworkService::IMAP');
insert into rhn_command_class(class_name) 
    values ( 'Unix::Process');
insert into rhn_command_class(class_name) 
    values ( 'Unix::Inodes');
insert into rhn_command_class(class_name) 
    values ( 'Unix::Load');
insert into rhn_command_class(class_name) 
    values ( 'LogAgent::PatternMatch');
insert into rhn_command_class(class_name) 
    values ( 'LogAgent::Size');
insert into rhn_command_class(class_name) 
    values ( 'Satellite::LongLegs');
insert into rhn_command_class(class_name) 
    values ( 'Unix::MemoryFree');
insert into rhn_command_class(class_name) 
    values ( 'MySQL::Accessibility');
insert into rhn_command_class(class_name) 
    values ( 'MySQL::Open');
insert into rhn_command_class(class_name) 
    values ( 'MySQL::Opened');
insert into rhn_command_class(class_name) 
    values ( 'MySQL::Queries');
insert into rhn_command_class(class_name) 
    values ( 'MySQL::Threads');
insert into rhn_command_class(class_name) 
    values ( 'General::SNMPCheck');
insert into rhn_command_class(class_name) 
    values ( 'General::UptimeSNMP');
insert into rhn_command_class(class_name) 
    values ( 'Unix::InterfaceTraffic');
insert into rhn_command_class(class_name) 
    values ( 'General::SNMPTrapParser');
insert into rhn_command_class(class_name) 
    values ( 'Satellite::ProbeCount');
insert into rhn_command_class(class_name) 
    values ( 'Satellite::ProbeExecTime');
insert into rhn_command_class(class_name) 
    values ( 'Satellite::ProbeLatency');
insert into rhn_command_class(class_name) 
    values ( 'General::CheckNothing');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::TablespaceUsage');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::BlockingSessions');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::IndexExtents');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::TableExtents');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::IdleSessions');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::Availability');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::Locks');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::ActiveSessions');
insert into rhn_command_class(class_name) 
    values ( 'NetworkService::POP');
insert into rhn_command_class(class_name) 
    values ( 'NetworkService::Ping');
insert into rhn_command_class(class_name) 
    values ( 'Unix::ProcessStateCounts');
insert into rhn_command_class(class_name) 
    values ( 'Unix::ProcessCountTotal');
insert into rhn_command_class(class_name) 
    values ( 'Satellite::CurrentStatePush');
insert into rhn_command_class(class_name) 
    values ( 'NetworkService::RPC');
insert into rhn_command_class(class_name) 
    values ( 'NetworkService::SMTP');
insert into rhn_command_class(class_name) 
    values ( 'NetworkService::SSH');
insert into rhn_command_class(class_name) 
    values ( 'Unix::Swap');
insert into rhn_command_class(class_name) 
    values ( 'General::TCP');
insert into rhn_command_class(class_name) 
    values ( 'Unix::TCPConnectionsByState');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::TNSping');
insert into rhn_command_class(class_name) 
    values ( 'General::RemoteProgram');
insert into rhn_command_class(class_name) 
    values ( 'Unix::Users');
insert into rhn_command_class(class_name) 
    values ( 'Unix::VirtualMemory');
insert into rhn_command_class(class_name) 
    values ( 'General::RemoteProgramWithData');
insert into rhn_command_class(class_name) 
    values ( 'Weblogic::State');
insert into rhn_command_class(class_name) 
    values ( 'Weblogic::HeapFree');
insert into rhn_command_class(class_name) 
    values ( 'Windows::LoadAverage');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::BufferCache');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::DataDictionaryCache');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::LibraryCache');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::RedoLog');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::DiskSort');
insert into rhn_command_class(class_name) 
    values ( 'Weblogic::JDBCConnectionPool');
insert into rhn_command_class(class_name) 
    values ( 'Weblogic::ExecuteQueue');
insert into rhn_command_class(class_name) 
    values ( 'Weblogic::Servlet');
insert into rhn_command_class(class_name) 
    values ( 'Oracle::ClientConnectivity');
insert into rhn_command_class(class_name) 
    values ( 'Unix::ProcessRunning');
commit;

select 'rhnsat/tables/rhn_command_groups_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_groups_data.sql
insert into rhn_command_groups(group_name,description) 
    values ( 'bea_61','BEA Weblogic');
insert into rhn_command_groups(group_name,description) 
    values ( 'oracle','Oracle');
insert into rhn_command_groups(group_name,description) 
    values ( 'mysql','MySQL');
insert into rhn_command_groups(group_name,description) 
    values ( 'netservice','Network Services');
insert into rhn_command_groups(group_name,description) 
    values ( 'satellite','Satellite');
insert into rhn_command_groups(group_name,description) 
    values ( 'logagent','Log Agent');
insert into rhn_command_groups(group_name,description) 
    values ( 'all','All');
insert into rhn_command_groups(group_name,description) 
    values ( 'apache','Apache');
insert into rhn_command_groups(group_name,description) 
    values ( 'linux','Linux');
insert into rhn_command_groups(group_name,description) 
    values ( 'tools','General');
commit;

select 'rhnsat/tables/rhn_command_requirements_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_requirements_data.sql
insert into rhn_command_requirements(name,description) 
    values (
'npunix','RHNMD must be running on the monitored host to perform this check.');
insert into rhn_command_requirements(name,description) 
    values (
'oracle','Oracle checks require the configuration of the database and public associations made by running $ORACLE_HOME/rdbms/admin/catalog.sql. In addition, in any instance of Oracle, the Oracle user configured in the check must have minimum privileges of CONNECT and SELECT_CATALOG_ROLE.');
insert into rhn_command_requirements(name,description) 
    values (
'snmp','SNMP must be running on the monitored host to perform this check.');
insert into rhn_command_requirements(name,description) 
    values (
'bea61_snmp','This check may be configured against a BEA Managed Server if the IP address of the Domain Admin Server is given.SNMP must also be enabled on the Domain Admin Server which can be done via the Weblogic Console.');
insert into rhn_command_requirements(name,description) 
    values (
'npunix_oracle','RHNMD must be running on the monitored host to perform this check. Oracle checks require the configuration of the database and public associations made by running $ORACLE_HOME/rdbms/admin/catalog.sql. In addition, in any instance of Oracle, the Oracle user configured in the check must have minimum privileges of CONNECT and SELECT_CATALOG_ROLE.');
insert into rhn_command_requirements(name,description) 
    values (
'apache1_3','The ExtendedStatus directive in the httpd.conf file of this webserver must be set to On for this check to function properly.');
commit;

select 'rhnsat/tables/rhn_command_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_data.sql
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
2,'LongLegs','LongLegs',NULL,'0','Satellite::LongLegs','0','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
6,'check_tcp','TCP Check','tools','1','General::TCP','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/toolsCheck.html#TCPCheck');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
7,'check_udp','UDP Check','tools','1','General::TCP','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/toolsCheck.html#UDPCheck');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
8,'check_smtp','Mail Transfer (SMTP)','netservice','1','NetworkService::SMTP','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/NetworkServiceCheck.html#MailTransfer(SMTP)');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
9,'check_pop','POP Mail','netservice','1','NetworkService::POP','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/NetworkServiceCheck.html#POPMail');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
10,'check_ftp','FTP','netservice','1','NetworkService::FTP','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/NetworkServiceCheck.html#FTP');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
11,'check_http','Web server (HTTP)','netservice','1','NetworkService::HTTP','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/NetworkServiceCheck.html#WebServer(HTTP)');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
13,'check_ping','Ping','netservice','1','NetworkService::Ping','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/NetworkServiceCheck.html#Ping');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
14,'check_dns_resolution','DNS Lookup','netservice','1','Unix::Dig','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/NetworkServiceCheck.html#DNSLookup');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
15,'check_ssh','SSH','netservice','1','NetworkService::SSH','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/NetworkServiceCheck.html#SSH');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
16,'check_snmp_value','SNMP Check','tools','1','General::SNMPCheck','1','0','system',sysdate,'snmp',NULL,'/help/userguides/user_guide_v2/Output/toolsCheck.html#SNMPCheck');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
17,'satellite_disk_space','Disk Space','satellite','0','Unix::Disk','1','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
18,'satellite_check_users','Users','satellite','0','Unix::Users','1','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
19,'satellite_check_procs','Processes','satellite','0','Unix::ProcessCountTotal','1','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
20,'satellite_check_load','Load','satellite','0','Unix::Load','1','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
22,'satellite_check_swap','Swap','satellite','0','Unix::Swap','1','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
23,'check_tnsping','TNS Ping','oracle','1','Oracle::TNSping','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#TNSPing');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
24,'satellite_probe_latency','Latency','satellite','0','Satellite::ProbeLatency','1','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
25,'remote_check_memory','Memory Usage','linux','1','Unix::MemoryFree','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#MemoryUsage');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
26,'remote_check_cpu','CPU Usage','linux','1','Unix::CPU','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#CPUUsage');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
27,'remote_check_load','Load','linux','1','Unix::Load','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#UnixLoad');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
28,'remote_check_swap','Swap Usage','linux','1','Unix::Swap','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#SwapUsage');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
29,'remote_check_disk','Disk Usage','linux','1','Unix::Disk','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#DiskUsage');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
30,'remote_check_users','Users','linux','1','Unix::Users','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#Users');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
31,'remote_check_procs','Process Count Total','linux','1','Unix::ProcessCountTotal','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#Processes');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
32,'check_host_alive','Host Availability',NULL,'0','NetworkService::Ping','1','1','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
41,'check_nothing','Check Nothing','tools','1','General::CheckNothing','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/toolsCheck.html#CheckNothing');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
42,'check_imap','IMAP Mail','netservice','1','NetworkService::IMAP','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/NetworkServiceCheck.html#IMAPMail');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
48,'check_rpc','RPC Service','netservice','1','NetworkService::RPC','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/NetworkServiceCheck.html#RPCService');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
56,'check_https','Secure Web server (HTTPS)','netservice','1','NetworkService::HTTPS','1','0','system',sysdate,NULL,NULL,'/help/userguides/user_guide_v2/Output/NetworkServiceCheck.html#SecureWebServer(HTTPS)');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
58,'icmp_blocked','ICMP Blocked',NULL,'0','General::CheckNothing','1','1','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
60,'satellite_probe_exec_time','Execution Time','satellite','0','Satellite::ProbeExecTime','1','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
61,'satellite_probe_count','Probe Count','satellite','0','Satellite::ProbeCount','1','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
85,'check_ora_blocking_sessions','Blocking Sessions','oracle','1','Oracle::BlockingSessions','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#BlockingSessions');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
86,'check_ora_locks','Locks','oracle','1','Oracle::Locks','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#Locks');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
87,'check_ora_all_extents','Tablespace Usage','oracle','1','Oracle::TablespaceUsage','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#AllExtents');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
88,'check_ora_table_extents','Table Extents','oracle','1','Oracle::TableExtents','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#TableExtents');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
89,'check_ora_index_extents','Index Extents','oracle','1','Oracle::IndexExtents','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#IndexExtents');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
90,'check_ora_idle_sessions','Idle Sessions','oracle','1','Oracle::IdleSessions','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#IdleSessions');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
91,'check_ora_up','Availability','oracle','1','Oracle::Availability','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#Availability');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
92,'check_ora_sessions','Active Sessions','oracle','1','Oracle::ActiveSessions','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#ActiveSessions');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
93,'check_mysql_open_tables','Open Tables','mysql','1','MySQL::Open','1','0','system',sysdate,NULL,'Version 3.23/3.33','/help/userguides/user_guide_v2/Output/MySQLCheck.html#OpenTables');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
94,'check_mysql_opened_tables','Opened Tables','mysql','1','MySQL::Opened','1','0','system',sysdate,NULL,'Version 3.23/3.33','/help/userguides/user_guide_v2/Output/MySQLCheck.html#OpenedTables');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
95,'check_mysql_threads_running','Threads Running','mysql','1','MySQL::Threads','1','0','system',sysdate,NULL,'Version 3.23/3.33','/help/userguides/user_guide_v2/Output/MySQLCheck.html#ThreadsRunning');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
96,'check_mysql_queries_per_second','Query Rate','mysql','1','MySQL::Queries','1','0','system',sysdate,NULL,'Version 3.23/3.33','/help/userguides/user_guide_v2/Output/MySQLCheck.html#QueryRate');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
97,'check_mysql','Database Accessibility','mysql','1','MySQL::Accessibility','1','0','system',sysdate,NULL,'Version 3.23/3.33','/help/userguides/user_guide_v2/Output/MySQLCheck.html#DatabaseAccessibility');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
99,'remote_check_program','Remote Program','tools','1','General::RemoteProgram','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/toolsCheck.html#RemoteProgram');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
105,'remote_check_interface_traffic','Interface Traffic','linux','1','Unix::InterfaceTraffic','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#UnixInterfaceTraffic');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
106,'check_log_size','Log Size','logagent','1','LogAgent::Size','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/LogAgentCheck.html#LogSize');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
107,'check_log_regex','Log Pattern Match','logagent','1','LogAgent::PatternMatch','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/LogAgentCheck.html#LogRegex');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
109,'remote_check_ora_up','Client Connectivity','oracle','1','Oracle::ClientConnectivity','1','0','system',sysdate,'npunix_oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#RemoteAvailability');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
113,'check_snmp_uptime','Uptime (SNMP)','tools','1','General::UptimeSNMP','1','0','system',sysdate,'snmp',NULL,'/help/userguides/user_guide_v2/Output/toolsCheck.html#Uptime(SNMP)');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
117,'remote_check_inodes','Inodes','linux','1','Unix::Inodes','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#Inodes');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
118,'remote_check_disk_io','Disk I/O Throughput','linux','1','Unix::DiskIOThroughput','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#DiskIOThroughput');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
120,'check_apache_uptime','Uptime','apache','1','Apache::Uptime','1','0','system',sysdate,NULL,'Apache versions 1.3.x and 2.0.x','/help/userguides/user_guide_v2/Output/ApacheCheck.html#Uptime');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
121,'check_apache_traffic','Requests','apache','1','Apache::Traffic','1','0','system',sysdate,'apache1_3','Apache versions 1.3.x and 2.0.x','/help/userguides/user_guide_v2/Output/ApacheCheck.html#Requests');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
122,'check_apache_procs','Processes','apache','1','Apache::Processes','1','0','system',sysdate,'apache1_3','Apache versions 1.3.x and 2.0.x','/help/userguides/user_guide_v2/Output/ApacheCheck.html#Processes');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
123,'check_virtual_memory','Virtual Memory','linux','1','Unix::VirtualMemory','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#VirtualMemory');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
226,'remote_process_running','Process Running','linux','1','Unix::ProcessRunning','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#ProcessRunning');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
227,'satellite_process_running','Process Running','satellite','0','Unix::ProcessRunning','1','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
228,'remote_process_health','Process Health','linux','1','Unix::Process','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#ProcessHealth');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
229,'satellite_process_health','Process Health','satellite','0','Unix::Process','1','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
230,'remote_process_counts','Process Counts by State','linux','1','Unix::ProcessStateCounts','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#ProcessCounts');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
231,'satellite_process_counts','Process Counts','satellite','0','Unix::ProcessStateCounts','1','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
249,'remote_check_tcp_connections_state','TCP Connections by State','linux','1','Unix::TCPConnectionsByState','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/UnixCheck.html#TCPConnections State');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
254,'satellite_check_traffic','Interface Traffic','satellite','0','Unix::InterfaceTraffic','1','0','system',sysdate,NULL,NULL,NULL);
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
274,'remote_check_program_ts','Remote Program with Data','tools','1','General::RemoteProgramWithData','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/toolsCheck.html#RemoteProgramData');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
275,'check_bea_61_state','Server State','bea_61','1','Weblogic::State','1','0','system',sysdate,'bea61_snmp','Version 6.1 or higher','/help/userguides/user_guide_v2/Output/BEAWebLogic61.html#ServerState61');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
276,'check_bea_61_heap_free','Heap Free','bea_61','1','Weblogic::HeapFree','1','0','system',sysdate,'bea61_snmp','Version 6.1 or higher','/help/userguides/user_guide_v2/Output/BEAWebLogic61.html#HeapFree');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
278,'check_ora_buffer_cache','Buffer Cache','oracle','1','Oracle::BufferCache','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#BufferCache');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
279,'check_ora_data_dictionary_cache','Data Dictionary Cache','oracle','1','Oracle::DataDictionaryCache','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#DataDictionaryCache');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
280,'check_ora_library_cache','Library Cache','oracle','1','Oracle::LibraryCache','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#LibraryCache');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
284,'check_ora_redo_log','Redo Log','oracle','1','Oracle::RedoLog','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#RedoLog');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
283,'check_ora_disk_sort','Disk Sort Ratio','oracle','1','Oracle::DiskSort','1','0','system',sysdate,'oracle',NULL,'/help/userguides/user_guide_v2/Output/OracleCheck.html#DiskSortRatio');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
282,'check_bea_61_jdbc_conn_pool','JDBC Connection Pool','bea_61','1','Weblogic::JDBCConnectionPool','1','0','system',sysdate,'bea61_snmp','Version 6.1 or higher','/help/userguides/user_guide_v2/Output/BEAWebLogic61.html#JDBCConnectionPool');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
281,'check_bea_61_execute_queue','Execute Queue','bea_61','1','Weblogic::ExecuteQueue','1','0','system',sysdate,'bea61_snmp','Version 6.1 or higher','/help/userguides/user_guide_v2/Output/BEAWebLogic61.html#ExecuteQueue');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
288,'check_bea_61_servlet','Servlet','bea_61','1','Weblogic::Servlet','1','0','system',sysdate,'bea61_snmp','Version 6.1 or higher','/help/userguides/user_guide_v2/Output/BEAWebLogic61.html#Servlet');
insert into rhn_command(recid,name,description,group_name,allowed_in_suite,
command_class,enabled,for_host_probe,last_update_user,last_update_date,system_requirements,version_support,help_url) 
    values (
304,'remote_check_ping','Remote Ping','netservice','1','NetworkService::Ping','1','0','system',sysdate,'npunix',NULL,'/help/userguides/user_guide_v2/Output/NetworkServiceCheck.html#RemotePing');
commit;

select 'rhnsat/tables/rhn_command_param_threshold.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_param_threshold.sql
create table 
rhn_command_param_threshold
(
    command_id              number   (12)
        constraint rhn_coptr_command_id_nn not null,
    param_name              varchar2 (40)
        constraint rhn_coptr_param_name_nn not null,
    param_type              varchar2 (10)
        constraint rhn_coptr_param_type_nn  not null
        constraint rhn_coptr_param_type_ck check (param_type='threshold'),
    threshold_type_name     varchar2 (10)
        constraint rhn_coptr_thres_name_nn not null,
    threshold_metric_id     varchar2 (40)
        constraint rhn_coptr_thres_met_id_nn not null,
    last_update_user        varchar2 (40),
    last_update_date        date,
    command_class           varchar2 (255)
        constraint rhn_coptr_command_class_nn not null
)
    enable row movement
  ;
comment on table rhn_command_param_threshold 
    is 'coptr  a parameter for a particular command';
create unique index rhn_coptr_id_p_name_p_type_pk 
    on rhn_command_param_threshold ( command_id, param_name, param_type )
    tablespace [[2m_tbs]]
  ;
alter table rhn_command_param_threshold 
    add constraint rhn_coptr_id_p_name_p_type_pk 
        primary key ( command_id, param_name, param_type );
alter table rhn_command_param_threshold
    add constraint rhn_coptr_cmd_id_cmd_cl_fk
    foreign key ( command_id, command_class )
    references rhn_command( recid, command_class )
    on delete cascade;
alter table rhn_command_param_threshold
    add constraint rhn_coptr_m_thr_m_cmd_cl_fk
    foreign key ( command_class, threshold_metric_id )
    references rhn_metrics( command_class, metric_id )
    on delete cascade;
alter table rhn_command_param_threshold
    add constraint rhn_coptr_thrtp_thres_type_fk
    foreign key ( threshold_type_name )
    references rhn_threshold_type( name );

select 'rhnsat/tables/rhn_quanta_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_quanta_data.sql
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'none','-','No physical quantity',
    'system',sysdate);
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'time','secs','Measure of time',
    'system',sysdate);
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'data','bytes','Measure of information',
    'system',sysdate);
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'datarate','Bps','Measure of information flow',
    'system',sysdate);
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'frequency','hertz','Measure of freqency',
    'system',sysdate);
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'temp','kelvins','Measure of temperature',
    'system',sysdate);
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'length','metres','Measure of length',
    'system',sysdate);
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'mass','kilograms','Measure of mass',
    'system',sysdate);
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'current','amperes','Measure of electric current',
    'system',sysdate);
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'force','newtons','Measure of force/weight',
    'system',sysdate);
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'power','watts','Measure of power',
    'system',sysdate);
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'charge','coulombs','Measure of charge',
    'system',sysdate);
insert into rhn_quanta(quantum_id,basic_unit_id,description,last_update_user,
last_update_date) 
    values ( 'voltage','volts','Measure of electric potential difference',
    'system',sysdate);
commit;

select 'rhnsat/tables/rhn_units_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_units_data.sql
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('secs','time','sec','Seconds',
    'x','x','is_number(x)','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('percent','none','%','Percentage',
    'x','x','is_number(x)  and 0 <= x <= 100','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('bits','data','B','Bits',
    'x/8','x*8','is_integer(x) and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('count','none',NULL,'Number',
    'x','x','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('astring','none',NULL,'ASCII string',
    'x','x','is_ascii(x)','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('Bps','datarate','bits/sec','Bits per second',
    'x','x','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('hertz','frequency','hz','Cycles per second',
    'x','x','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('kelvins','temp','K','Degrees Kelvin',
    'x','x','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('kilograms','mass','kg','Kilograms',
    'x','x','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('amperes','current','A','Amperes',
    'x','x','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('newtons','force','N','Newtons',
    'x','x','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('watts','power','W','Watts',
    'x','x','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('coulombs','charge','C','Coulombs',
    'x','x','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('volts','voltage','V','Volts',
    'x','x','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('rpm','frequency','rpm','Revolutions per minute',
    'x*60','x/60','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('MHz','frequency','MHz','Megahertz',
    'x*1024*1024','x/1024/1024','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('bps','datarate','bytes/sec','Bytes per second',
    'x*8','x/8','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('kBps','datarate','Kbits/sec','Kilobits per second',
    'x*1024','x/1024','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('MBps','datarate','Mbits/sec','Megabits per second',
    'x*1024*1024','x/1024/1024','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('bytes','data','bytes','Bytes',
    'x','x','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('kb','data','Kbytes','Kilobytes',
    'x*1024','x/1024','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('Mb','data','MB','Megabytes',
    'x*1024*1024','x/1024/1024','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('Gb','data','GB','Gigabytes',
    'x*1024*1024*1024','x/1024/1024/1024','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('kW','power','kW','Kilowatts',
    'x*1024','x/1024','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('millisecs','time','ms','Milliseconds',
    'x*1000','x/1000','is_number(x)','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('boolean','none',NULL,'Boolean',
    'x','x','is_boolean(x)','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('eps','frequency','/sec','Events per second',
    NULL,NULL,NULL,'system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('celsius','temp','C','Degrees Celsius',
    'x+273','x-273','is_number(x) and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('metres','length','m','Metres',
    'x','x','is_number(x) and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('epm','frequency','/min','Events per minute',
    'x/60','x*60','is_number(x) and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('Kbps','datarate','Kbytes/sec','Kilobytes per second',
    'x*8*1024','x/8/1024','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('bpm','datarate','bytes/min','Bytes per minute',
    'x*8','x/8','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('lpm','datarate','lines/min','Lines per minute',
    NULL,NULL,'is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('pounds','mass','lb','Pounds',
    'x * 0.4535924','x / 0.4535924','is_number(x)  and x >= 0','system',sysdate);
insert into rhn_units(unit_id,quantum_id,unit_label,description,
to_base_unit_fn,from_base_unit_fn,validate_fn,last_update_user,last_update_date)
    values ('msps','datarate','millisec/sec','Milliseconds per second',
    'x','x','is_number(x) and x >= 0','system',sysdate);
commit;

select 'rhnsat/tables/rhn_metrics_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_metrics_data.sql
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'accesses','eps','Request Rate','system',sysdate,'Request rate','Apache::Traffic');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'traffic','Kbps','Traffic','system',sysdate,'Traffic','Apache::Traffic');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'load1','count','CPU Load 1-Minute Average','system',sysdate,'CPU load 1-min ave','Unix::Load');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'open','count','Open Objects','system',sysdate,'Open objects','MySQL::Open');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'pingtime','millisecs','Round-trip Average','system',sysdate,'Round-trip avg','NetworkService::Ping');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'nusers','count','Users','system',sysdate,'Users','Unix::Users');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'nprocs','count','Processes','system',sysdate,'Processes','Unix::ProcessCountTotal');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'probes','count','Probes','system',sysdate,'Probes','Satellite::ProbeCount');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'probelatnc','secs','Probe Latency Average','system',sysdate,'Probe latency ave','Satellite::ProbeLatency');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'free','Mb','RAM Free','system',sysdate,'RAM free','Unix::MemoryFree');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'load5','count','CPU Load 5-Minute Average','system',sysdate,'CPU load 5-min ave','Unix::Load');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'load15','count','CPU Load 15-Minute Average','system',sysdate,'CPU load 15-min ave','Unix::Load');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'opened','count','Opened Objects','system',sysdate,'Opened objects','MySQL::Opened');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'probextm','secs','Probe Execution Time Average','system',sysdate,'Probe exec time ave','Satellite::ProbeExecTime');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'regmatches','count','Regular Expression Matches','system',sysdate,'Pattern matches','LogAgent::PatternMatch');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'regrate','epm','Regular Expression Match Rate','system',sysdate,'Pattern match rate','LogAgent::PatternMatch');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'bytes','bytes','Size','system',sysdate,'Size','LogAgent::Size');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'byterate','bpm','Output Rate','system',sysdate,'Output rate','LogAgent::Size');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'lines','count','Lines','system',sysdate,'Lines','LogAgent::Size');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'linerate','lpm','Line Rate','system',sysdate,'Line rate','LogAgent::Size');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'reqs','count','Current Requests','system',sysdate,'Current requests','Apache::Traffic');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'nblocked','count','Blocked Processes','system',sysdate,'Blocked processes','Unix::ProcessStateCounts');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'nchildren','count','Child Process Groups','system',sysdate,'Child process groups','Unix::Process');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'ndefunct','count','Defunct Processes','system',sysdate,'Defunct processes','Unix::ProcessStateCounts');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'nstopped','count','Stopped Processes','system',sysdate,'Stopped processes','Unix::ProcessStateCounts');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'nswapped','count','Sleeping Processes','system',sysdate,'Sleeping processes','Unix::ProcessStateCounts');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'nthreads','count','Threads','system',sysdate,'Threads','Unix::Process');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'vsz','count','Virtual Memory Used','system',sysdate,'Virtual memory used','Unix::Process');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'kbrps','Kbps','Read Rate','system',sysdate,'Read rate','Unix::DiskIOThroughput');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'kbwps','Kbps','Write Rate','system',sysdate,'Write rate','Unix::DiskIOThroughput');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'pctused','percent','Filesystem Used','system',sysdate,'Filesystem pct used','Unix::Disk');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'pctfree','percent','Virtual Memory Free','system',sysdate,'Virtual mem pct free','Unix::VirtualMemory');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'pctfree','percent','Swap Space Free','system',sysdate,'Swap pct free','Unix::Swap');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'pctused','percent','CPU Used','system',sysdate,'CPU pct used','Unix::CPU');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'pctlost','percent','Packet Loss','system',sysdate,'Packet loss pct','NetworkService::Ping');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'pctiused','percent','Inodes Used','system',sysdate,'Inodes pct used','Unix::Inodes');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'childmb','Mb','Max Data Transferred Per Child','system',sysdate,'Max transferred per child','Apache::Processes');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'slotmb','Mb','Max Data Transferred Per Slot','system',sysdate,'Max transferred per slot','Apache::Processes');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'actsession','count','Active Sessions','system',sysdate,'Active sessions','Oracle::ActiveSessions');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'blksession','count','Blocking Sessions','system',sysdate,'Blocking sessions','Oracle::BlockingSessions');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'idlsession','count','Idle Sessions','system',sysdate,'Idle sessions','Oracle::IdleSessions');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'latency','secs','Remote Service Latency','system',sysdate,'Latency','NetworkService::FTP');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'latency','secs','Remote Service Latency','system',sysdate,'Latency','NetworkService::HTTP');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'latency','secs','Remote Service Latency','system',sysdate,'Latency','NetworkService::HTTPS');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'latency','secs','Remote Service Latency','system',sysdate,'Latency','NetworkService::IMAP');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'qps','eps','Query Rate','system',sysdate,'Query rate','MySQL::Queries');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'threads','count','Threads Running','system',sysdate,'Threads running','MySQL::Threads');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'value','count','Value','system',sysdate,'Value','General::SNMPCheck');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'latency','secs','Remote Service Latency','system',sysdate,'Latency','NetworkService::POP');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'latency','secs','Remote Service Latency','system',sysdate,'Latency','NetworkService::RPC');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'latency','secs','Remote Service Latency','system',sysdate,'Latency','NetworkService::SMTP');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'latency','secs','Remote Service Latency','system',sysdate,'Latency','NetworkService::SSH');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'latency','secs','Remote Service Latency','system',sysdate,'Latency','General::TCP');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'nconns','count','Total Connections','system',sysdate,'Total conns','Unix::TCPConnectionsByState');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'latency','secs','Remote Service Latency','system',sysdate,'Latency','Oracle::TNSping');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'value','count','Value','system',sysdate,'value','General::RemoteProgramWithData');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'value','bytes','Value','system',sysdate,'Value','Weblogic::HeapFree');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'hit_ratio','percent','Buffer Cache Hit Ratio','system',sysdate,'Buffer cache hit ratio','Oracle::BufferCache');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'db_block_gets','epm','DB Block Get Rate','system',sysdate,'DB block get rate','Oracle::BufferCache');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'consistent_gets','epm','Consistent Get Rate','system',sysdate,'Consistent get rate','Oracle::BufferCache');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'physical_reads','epm','Physical Read Rate','system',sysdate,'Physical read rate','Oracle::BufferCache');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'hit_ratio','percent','Data Dictionary Hit Ratio','system',sysdate,'Data dict hit ratio','Oracle::DataDictionaryCache');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'gets','epm','Get Rate','system',sysdate,'Get rate','Oracle::DataDictionaryCache');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'get_misses','epm','Cache Miss Rate','system',sysdate,'Cache miss rate','Oracle::DataDictionaryCache');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'miss_ratio','percent','Library Cache Miss Ratio','system',sysdate,'Library cache miss ratio','Oracle::LibraryCache');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'executions','epm','Execution Rate','system',sysdate,'Execution rate','Oracle::LibraryCache');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'misses','epm','Cache Miss Rate','system',sysdate,'Cache miss rate','Oracle::LibraryCache');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'usedsesspct','percent','Used Sessions','system',sysdate,'Used Sessions','Oracle::ActiveSessions');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'locks','count','Active Locks','system',sysdate,'Active locks','Oracle::Locks');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'requests','epm','Redo Log Space Request Rate','system',sysdate,'Redo log space request rate','Oracle::RedoLog');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'retries','epm','Redo Buffer Allocation Retry Rate','system',sysdate,'Redo buffer allocation retry rate','Oracle::RedoLog');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'ratio','percent','Disk Sort Ratio','system',sysdate,'Disk sort ratio','Oracle::DiskSort');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'dsk_sorts','epm','Disk Sort Rate','system',sysdate,'Disk sort rate','Oracle::DiskSort');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'mem_sorts','epm','Memory Sort Rate','system',sysdate,'Memory sort rate','Oracle::DiskSort');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'connections','count','Connections','system',sysdate,'Connections','Weblogic::JDBCConnectionPool');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'waiters','count','Waiters','system',sysdate,'Waiters','Weblogic::JDBCConnectionPool');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'conn_rate','eps','Connection Rate','system',sysdate,'Conn rate','Weblogic::JDBCConnectionPool');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'idle_threads','count','Idle Execute Threads','system',sysdate,'Idle threads','Weblogic::ExecuteQueue');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'queue_length','count','Queue Length','system',sysdate,'Queue length','Weblogic::ExecuteQueue');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'request_rate','eps','Request Rate','system',sysdate,'Request rate','Weblogic::ExecuteQueue');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'exec_move_ave','count','Execution Time Moving Average','system',sysdate,'Exec time moving ave','Weblogic::Servlet');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'avg_exec_time','count','Execution Time Ave','system',sysdate,'Execution time ave','Weblogic::Servlet');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'reload_rate','epm','Reload Rate','system',sysdate,'Reload rate','Weblogic::Servlet');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'invocation_rate','epm','Invocation Rate','system',sysdate,'Invocation rate','Weblogic::Servlet');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'high_exec_time','count','High Execution Time','system',sysdate,'High exec time','Weblogic::Servlet');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'low_exec_time','count','Low Execution Time','system',sysdate,'Low exec time','Weblogic::Servlet');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'space_used','Mb','Space Used','system',sysdate,'Space used','Unix::Disk');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'space_avail','Mb','Space Available','system',sysdate,'Space available','Unix::Disk');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'out_byte_rt','bps','Output Rate','system',sysdate,'Output rate','Unix::InterfaceTraffic');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'in_byte_rt','bps','Input Rate','system',sysdate,'Input rate','Unix::InterfaceTraffic');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'load1','percent','CPU Load 1-Minute Average','system',sysdate,'CPU load 1-min avg','Windows::LoadAverage');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'load5','percent','CPU Load 5-Minute Average','system',sysdate,'CPU load 5-min avg','Windows::LoadAverage');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'load15','percent','CPU Load 15-Minute Average','system',sysdate,'CPU load 15-min avg','Windows::LoadAverage');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'physical_mem_used','count','Physical Memory Used','system',sysdate,'Physical memory used','Unix::Process');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'cpu_time_rt','msps','CPU Usage','system',sysdate,'CPU usage','Unix::Process');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'time_wait_conn','count','TIME_WAIT Connections','system',sysdate,'TIME_WAIT conns','Unix::TCPConnectionsByState');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'close_wait_conn','count','CLOSE_WAIT Connections','system',sysdate,'CLOSE_WAIT conns','Unix::TCPConnectionsByState');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'fin_wait_conn','count','FIN_WAIT Connections','system',sysdate,'FIN_WAIT conns','Unix::TCPConnectionsByState');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'established_conn','count','ESTABLISHED Connections','system',sysdate,'ESTABLISHED conns','Unix::TCPConnectionsByState');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'syn_rcvd_conn','count','SYN_RCVD Connections','system',sysdate,'SYN_RCVD conns','Unix::TCPConnectionsByState');
insert into rhn_metrics(metric_id,storage_unit_id,description,last_update_user,last_update_date,label,command_class)     values ( 'query_time','millisecs','Query Time','system',sysdate,'Query time','Unix::Dig');
commit;

select 'rhnsat/tables/rhn_threshold_type_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_threshold_type_data.sql
insert into rhn_threshold_type(name,description,ordinal,last_update_user,
last_update_date) 
    values ( 'warn_min','Minimum',10,'system',sysdate);
insert into rhn_threshold_type(name,description,ordinal,last_update_user,
last_update_date) 
    values ( 'warn_max','Maximum',20,'system',sysdate);
insert into rhn_threshold_type(name,description,ordinal,last_update_user,
last_update_date) 
    values ( 'crit_min','Minimum',0,'system',sysdate);
insert into rhn_threshold_type(name,description,ordinal,last_update_user,
last_update_date) 
    values ( 'crit_max','Maximum',30,'system',sysdate);
commit;

select 'rhnsat/tables/rhn_command_param_threshold_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_param_threshold_data.sql
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 122,'criticalchild','threshold','crit_max','childmb','system',
    sysdate,'Apache::Processes');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 122,'warnchild','threshold','warn_max','childmb','system',
    sysdate,'Apache::Processes');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 122,'criticalslot','threshold','crit_max','slotmb','system',
    sysdate,'Apache::Processes');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 122,'warnslot','threshold','warn_max','slotmb','system',
    sysdate,'Apache::Processes');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 121,'criticalaccess','threshold','crit_max','accesses','system',
    sysdate,'Apache::Traffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 121,'warnaccess','threshold','warn_max','accesses','system',
    sysdate,'Apache::Traffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 121,'criticalreqs','threshold','crit_max','reqs','system',
    sysdate,'Apache::Traffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 121,'warnreqs','threshold','warn_max','reqs','system',
    sysdate,'Apache::Traffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 121,'criticaltraffic','threshold','crit_max','traffic','system',
    sysdate,'Apache::Traffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 121,'warntraffic','threshold','warn_max','traffic','system',
    sysdate,'Apache::Traffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 10,'warning','threshold','warn_max','latency','system',
    sysdate,'NetworkService::FTP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 10,'critical','threshold','crit_max','latency','system',
    sysdate,'NetworkService::FTP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 42,'warning','threshold','warn_max','latency','system',
    sysdate,'NetworkService::IMAP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 42,'critical','threshold','crit_max','latency','system',
    sysdate,'NetworkService::IMAP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 8,'warning','threshold','warn_max','latency','system',
    sysdate,'NetworkService::SMTP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 8,'critical','threshold','crit_max','latency','system',
    sysdate,'NetworkService::SMTP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 9,'warning','threshold','warn_max','latency','system',
    sysdate,'NetworkService::POP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 9,'critical','threshold','crit_max','latency','system',
    sysdate,'NetworkService::POP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 13,'warn_loss','threshold','warn_max','pctlost','system',
    sysdate,'NetworkService::Ping');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 13,'critical_loss','threshold','crit_max','pctlost','system',
    sysdate,'NetworkService::Ping');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 13,'warn_time','threshold','warn_max','pingtime','system',
    sysdate,'NetworkService::Ping');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 13,'critical_time','threshold','crit_max','pingtime','system',
    sysdate,'NetworkService::Ping');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 48,'warning','threshold','warn_max','latency','system',
    sysdate,'NetworkService::RPC');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 48,'critical','threshold','crit_max','latency','system',
    sysdate,'NetworkService::RPC');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 56,'warning','threshold','warn_max','latency','system',
    sysdate,'NetworkService::HTTPS');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 56,'critical','threshold','crit_max','latency','system',
    sysdate,'NetworkService::HTTPS');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 11,'warning','threshold','warn_max','latency','system',
    sysdate,'NetworkService::HTTP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 11,'critical','threshold','crit_max','latency','system',
    sysdate,'NetworkService::HTTP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 6,'critical','threshold','crit_max','latency','system',
    sysdate,'General::TCP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 6,'warning','threshold','warn_max','latency','system',
    sysdate,'General::TCP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 7,'critical','threshold','crit_max','latency','system',
    sysdate,'General::TCP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 7,'warning','threshold','warn_max','latency','system',
    sysdate,'General::TCP');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 26,'critical','threshold','crit_max','pctused','system',
    sysdate,'Unix::CPU');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 26,'warn','threshold','warn_max','pctused','system',
    sysdate,'Unix::CPU');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 118,'critical_read_above','threshold','crit_max','kbrps','system',
    sysdate,'Unix::DiskIOThroughput');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 118,'warn_read_above','threshold','warn_max','kbrps','system',
    sysdate,'Unix::DiskIOThroughput');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 118,'critical_read_below','threshold','crit_min','kbrps','system',
    sysdate,'Unix::DiskIOThroughput');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 118,'warn_read_below','threshold','warn_min','kbrps','system',
    sysdate,'Unix::DiskIOThroughput');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 118,'critical_write_above','threshold','crit_max','kbwps','system',
    sysdate,'Unix::DiskIOThroughput');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 118,'warn_write_above','threshold','warn_max','kbwps','system',
    sysdate,'Unix::DiskIOThroughput');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 118,'critical_write_below','threshold','crit_min','kbwps','system',
    sysdate,'Unix::DiskIOThroughput');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 118,'warn_write_below','threshold','warn_min','kbwps','system',
    sysdate,'Unix::DiskIOThroughput');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 29,'critical','threshold','crit_max','pctused','system',
    sysdate,'Unix::Disk');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 29,'warn','threshold','warn_max','pctused','system',
    sysdate,'Unix::Disk');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 117,'critical','threshold','crit_max','pctiused','system',
    sysdate,'Unix::Inodes');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 117,'warn','threshold','warn_max','pctiused','system',
    sysdate,'Unix::Inodes');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 25,'critical','threshold','crit_min','free','system',
    sysdate,'Unix::MemoryFree');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 25,'warn','threshold','warn_min','free','system',
    sysdate,'Unix::MemoryFree');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 31,'critical','threshold','crit_max','nprocs','system',
    sysdate,'Unix::ProcessCountTotal');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 31,'warn','threshold','warn_max','nprocs','system',
    sysdate,'Unix::ProcessCountTotal');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 19,'critical','threshold','crit_max','nprocs','system',
    sysdate,'Unix::ProcessCountTotal');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 19,'warn','threshold','warn_max','nprocs','system',
    sysdate,'Unix::ProcessCountTotal');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 230,'nblocked_critical','threshold','crit_max','nblocked','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 230,'nblocked_warn','threshold','warn_max','nblocked','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 230,'ndefunct_critical','threshold','crit_max','ndefunct','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 230,'ndefunct_warn','threshold','warn_max','ndefunct','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 230,'nstopped_critical','threshold','crit_max','nstopped','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 230,'nstopped_warn','threshold','warn_max','nstopped','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 230,'nswapped_critical','threshold','crit_max','nswapped','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 230,'nswapped_warn','threshold','warn_max','nswapped','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 228,'nchildren_critical','threshold','crit_max','nchildren','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 228,'nchildren_warn','threshold','warn_max','nchildren','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 228,'nthreads_critical','threshold','crit_max','nthreads','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 228,'nthreads_warn','threshold','warn_max','nthreads','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 228,'vsz_critical','threshold','crit_max','vsz','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 228,'vsz_warn','threshold','warn_max','vsz','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 28,'critical','threshold','crit_min','pctfree','system',
    sysdate,'Unix::Swap');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 28,'warn','threshold','warn_min','pctfree','system',
    sysdate,'Unix::Swap');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 249,'critical','threshold','crit_max','nconns','system',
    sysdate,'Unix::TCPConnectionsByState');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 249,'warn','threshold','warn_max','nconns','system',
    sysdate,'Unix::TCPConnectionsByState');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 27,'critical5','threshold','crit_max','load5','system',
    sysdate,'Unix::Load');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 27,'warn5','threshold','warn_max','load5','system',
    sysdate,'Unix::Load');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 123,'warn','threshold','warn_min','pctfree','system',
    sysdate,'Unix::VirtualMemory');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 123,'critical','threshold','crit_min','pctfree','system',
    sysdate,'Unix::VirtualMemory');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 30,'warn','threshold','warn_max','nusers','system',
    sysdate,'Unix::Users');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 30,'critical','threshold','crit_max','nusers','system',
    sysdate,'Unix::Users');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 18,'warn','threshold','warn_max','nusers','system',
    sysdate,'Unix::Users');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 18,'critical','threshold','crit_max','nusers','system',
    sysdate,'Unix::Users');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 16,'genericGTcritical','threshold','crit_max','value','system',
    sysdate,'General::SNMPCheck');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 16,'genericGTwarning','threshold','warn_max','value','system',
    sysdate,'General::SNMPCheck');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 16,'genericLTcritical','threshold','crit_min','value','system',
    sysdate,'General::SNMPCheck');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 16,'genericLTwarning','threshold','warn_min','value','system',
    sysdate,'General::SNMPCheck');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 276,'heapfreeLTwarning','threshold','warn_min','value','system',
    sysdate,'Weblogic::HeapFree');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 276,'heapfreeLTcritical','threshold','crit_min','value','system',
    sysdate,'Weblogic::HeapFree');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 276,'heapfreeGTwarning','threshold','warn_max','value','system',
    sysdate,'Weblogic::HeapFree');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 276,'heapfreeGTcritical','threshold','crit_max','value','system',
    sysdate,'Weblogic::HeapFree');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 278,'warn_min','threshold','warn_min','hit_ratio','system',
    sysdate,'Oracle::BufferCache');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 278,'crit_min','threshold','crit_min','hit_ratio','system',
    sysdate,'Oracle::BufferCache');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 279,'warn_min','threshold','warn_min','hit_ratio','system',
    sysdate,'Oracle::DataDictionaryCache');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 279,'crit_min','threshold','crit_min','hit_ratio','system',
    sysdate,'Oracle::DataDictionaryCache');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 280,'warn_max','threshold','warn_max','miss_ratio','system',
    sysdate,'Oracle::LibraryCache');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 280,'crit_max','threshold','crit_max','miss_ratio','system',
    sysdate,'Oracle::LibraryCache');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 92,'warnpct','threshold','warn_max','usedsesspct','system',
    sysdate,'Oracle::ActiveSessions');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 92,'critpct','threshold','crit_max','usedsesspct','system',
    sysdate,'Oracle::ActiveSessions');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 92,'warn','threshold','warn_max','actsession','system',
    sysdate,'Oracle::ActiveSessions');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 92,'critical','threshold','crit_max','actsession','system',
    sysdate,'Oracle::ActiveSessions');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 86,'warn','threshold','warn_max','locks','system',
    sysdate,'Oracle::Locks');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 86,'critical','threshold','crit_max','locks','system',
    sysdate,'Oracle::Locks');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 107,'critical_num_above','threshold','crit_max','regmatches','system',
    sysdate,'LogAgent::PatternMatch');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 107,'warn_num_above','threshold','warn_max','regmatches','system',
    sysdate,'LogAgent::PatternMatch');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 107,'critical_num_below','threshold','crit_min','regmatches','system',
    sysdate,'LogAgent::PatternMatch');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 107,'warn_num_below','threshold','warn_min','regmatches','system',
    sysdate,'LogAgent::PatternMatch');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 107,'critical_rate_above','threshold','crit_max','regrate','system',
    sysdate,'LogAgent::PatternMatch');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 107,'warn_rate_above','threshold','warn_max','regrate','system',
    sysdate,'LogAgent::PatternMatch');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 107,'critical_rate_below','threshold','crit_min','regrate','system',
    sysdate,'LogAgent::PatternMatch');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 107,'warn_rate_below','threshold','warn_min','regrate','system',
    sysdate,'LogAgent::PatternMatch');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'critical_byte_rate_above','threshold','crit_max','byterate','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'warn_byte_rate_above','threshold','warn_max','byterate','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'critical_byte_rate_below','threshold','crit_min','byterate','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'warn_byte_rate_below','threshold','warn_min','byterate','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'critical_bytes_above','threshold','crit_max','bytes','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'warn_bytes_above','threshold','warn_max','bytes','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'critical_bytes_below','threshold','crit_min','bytes','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'warn_bytes_below','threshold','warn_min','bytes','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'critical_line_rate_above','threshold','crit_max','linerate','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'warn_line_rate_above','threshold','warn_max','linerate','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'critical_line_rate_below','threshold','crit_min','linerate','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'warn_line_rate_below','threshold','warn_min','linerate','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'critical_lines_above','threshold','crit_max','lines','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'warn_lines_above','threshold','warn_max','lines','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'critical_lines_below','threshold','crit_min','lines','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 106,'warn_lines_below','threshold','warn_min','lines','system',
    sysdate,'LogAgent::Size');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 93,'criticalabove','threshold','crit_max','open','system',
    sysdate,'MySQL::Open');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 93,'warnabove','threshold','warn_max','open','system',
    sysdate,'MySQL::Open');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 93,'criticalbelow','threshold','crit_min','open','system',
    sysdate,'MySQL::Open');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 93,'warnbelow','threshold','warn_min','open','system',
    sysdate,'MySQL::Open');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 94,'criticalabove','threshold','crit_max','opened','system',
    sysdate,'MySQL::Opened');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 94,'warnabove','threshold','warn_max','opened','system',
    sysdate,'MySQL::Opened');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 94,'criticalbelow','threshold','crit_min','opened','system',
    sysdate,'MySQL::Opened');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 94,'warnbelow','threshold','warn_min','opened','system',
    sysdate,'MySQL::Opened');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 95,'criticalabove','threshold','crit_max','threads','system',
    sysdate,'MySQL::Threads');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 95,'warnabove','threshold','warn_max','threads','system',
    sysdate,'MySQL::Threads');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 95,'criticalbelow','threshold','crit_min','threads','system',
    sysdate,'MySQL::Threads');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 95,'warnbelow','threshold','warn_min','threads','system',
    sysdate,'MySQL::Threads');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 96,'criticalabove','threshold','crit_max','qps','system',
    sysdate,'MySQL::Queries');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 96,'warnabove','threshold','warn_max','qps','system',
    sysdate,'MySQL::Queries');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 96,'criticalbelow','threshold','crit_min','qps','system',
    sysdate,'MySQL::Queries');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 96,'warnbelow','threshold','warn_min','qps','system',
    sysdate,'MySQL::Queries');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 23,'warn_latency','threshold','warn_max','latency','system',
    sysdate,'Oracle::TNSping');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 23,'critical_latency','threshold','crit_max','latency','system',
    sysdate,'Oracle::TNSping');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 284,'req_warn_max','threshold','warn_max','requests','system',
    sysdate,'Oracle::RedoLog');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 284,'req_crit_max','threshold','crit_max','requests','system',
    sysdate,'Oracle::RedoLog');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 284,'retry_warn_max','threshold','warn_max','retries','system',
    sysdate,'Oracle::RedoLog');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 284,'retry_crit_max','threshold','crit_max','retries','system',
    sysdate,'Oracle::RedoLog');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 85,'critical','threshold','crit_max','blksession','system',
    sysdate,'Oracle::BlockingSessions');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 85,'warn','threshold','warn_max','blksession','system',
    sysdate,'Oracle::BlockingSessions');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 90,'critical','threshold','crit_max','idlsession','system',
    sysdate,'Oracle::IdleSessions');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 90,'warn','threshold','warn_max','idlsession','system',
    sysdate,'Oracle::IdleSessions');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 283,'warn_max','threshold','warn_max','ratio','system',
    sysdate,'Oracle::DiskSort');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 283,'crit_max','threshold','crit_max','ratio','system',
    sysdate,'Oracle::DiskSort');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 282,'connectionsGTwarning','threshold','warn_max','connections','system',
    sysdate,'Weblogic::JDBCConnectionPool');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 282,'connectionsGTcritical','threshold','crit_max','connections','system',
    sysdate,'Weblogic::JDBCConnectionPool');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 282,'connrateGTwarning','threshold','warn_max','conn_rate','system',
    sysdate,'Weblogic::JDBCConnectionPool');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 282,'connrateGTcritical','threshold','crit_max','conn_rate','system',
    sysdate,'Weblogic::JDBCConnectionPool');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 282,'waitersGTwarning','threshold','warn_max','waiters','system',
    sysdate,'Weblogic::JDBCConnectionPool');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 282,'waitersGTcritical','threshold','crit_max','waiters','system',
    sysdate,'Weblogic::JDBCConnectionPool');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 281,'idlethreadsGTwarning','threshold','warn_max','idle_threads','system',
    sysdate,'Weblogic::ExecuteQueue');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 281,'idlethreadsGTcritical','threshold','crit_max','idle_threads','system',
    sysdate,'Weblogic::ExecuteQueue');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 281,'queuelengthGTwarning','threshold','warn_max','queue_length','system',
    sysdate,'Weblogic::ExecuteQueue');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 281,'queuelengthGTcritical','threshold','crit_max','queue_length','system',
    sysdate,'Weblogic::ExecuteQueue');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 281,'requestrateGTwarning','threshold','warn_max','request_rate','system',
    sysdate,'Weblogic::ExecuteQueue');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 281,'requestrateGTcritical','threshold','crit_max','request_rate','system',
    sysdate,'Weblogic::ExecuteQueue');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 288,'exectimemvaveGTwarning','threshold','warn_max','exec_move_ave','system',
    sysdate,'Weblogic::Servlet');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 288,'exectimemvaveGTcritical','threshold','crit_max','exec_move_ave','system',
    sysdate,'Weblogic::Servlet');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 288,'highexectimeGTwarning','threshold','warn_max','high_exec_time','system',
    sysdate,'Weblogic::Servlet');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 288,'highexectimeGTcritical','threshold','crit_max','high_exec_time','system',
    sysdate,'Weblogic::Servlet');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 29,'warn_used','threshold','warn_max','space_used','system',
    sysdate,'Unix::Disk');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 29,'critical_used','threshold','crit_max','space_used','system',
    sysdate,'Unix::Disk');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 29,'warn_avail','threshold','warn_min','space_avail','system',
    sysdate,'Unix::Disk');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 29,'critical_avail','threshold','crit_min','space_avail','system',
    sysdate,'Unix::Disk');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 228,'cpu_time_rt_warn','threshold','warn_max','cpu_time_rt','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 228,'cpu_time_rt_critical','threshold','crit_max','cpu_time_rt','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 228,'physical_mem_used_warn','threshold','warn_max','physical_mem_used','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 228,'physical_mem_used_critical','threshold','crit_max','physical_mem_used','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 229,'cpu_time_rt_warn','threshold','warn_max','cpu_time_rt','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 229,'cpu_time_rt_critical','threshold','crit_max','cpu_time_rt','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 229,'physical_mem_used_warn','threshold','warn_max','physical_mem_used','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 229,'physical_mem_used_critical','threshold','crit_max','physical_mem_used','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 229,'nchildren_warn','threshold','warn_max','nchildren','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 229,'nchildren_critical','threshold','crit_max','nchildren','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 229,'nthreads_warn','threshold','warn_max','nthreads','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 229,'nthreads_critical','threshold','crit_max','nthreads','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 229,'vsz_warn','threshold','warn_max','vsz','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 229,'vsz_critical','threshold','crit_max','vsz','system',
    sysdate,'Unix::Process');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 17,'warn','threshold','warn_max','pctused','system',
    sysdate,'Unix::Disk');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 17,'critical','threshold','crit_max','pctused','system',
    sysdate,'Unix::Disk');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 17,'warn_used','threshold','warn_max','space_used','system',
    sysdate,'Unix::Disk');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 17,'critical_used','threshold','crit_max','space_used','system',
    sysdate,'Unix::Disk');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 17,'warn_avail','threshold','warn_min','space_avail','system',
    sysdate,'Unix::Disk');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 17,'critical_avail','threshold','crit_min','space_avail','system',
    sysdate,'Unix::Disk');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 249,'critical_TIME_WAIT','threshold','crit_max','time_wait_conn','system',
    sysdate,'Unix::TCPConnectionsByState');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 249,'warn_TIME_WAIT','threshold','warn_max','time_wait_conn','system',
    sysdate,'Unix::TCPConnectionsByState');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 249,'critical_CLOSE_WAIT','threshold','crit_max','close_wait_conn','system',
    sysdate,'Unix::TCPConnectionsByState');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 249,'warn_CLOSE_WAIT','threshold','warn_max','close_wait_conn','system',
    sysdate,'Unix::TCPConnectionsByState');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 249,'critical_FIN_WAIT','threshold','crit_max','fin_wait_conn','system',
    sysdate,'Unix::TCPConnectionsByState');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 249,'warn_FIN_WAIT','threshold','warn_max','fin_wait_conn','system',
    sysdate,'Unix::TCPConnectionsByState');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 249,'critical_ESTABLISHED','threshold','crit_max','established_conn','system',
    sysdate,'Unix::TCPConnectionsByState');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 249,'warn_ESTABLISHED','threshold','warn_max','established_conn','system',
    sysdate,'Unix::TCPConnectionsByState');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 249,'critical_SYN_RCVD','threshold','crit_max','syn_rcvd_conn','system',
    sysdate,'Unix::TCPConnectionsByState');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 249,'warn_SYN_RCVD','threshold','warn_max','syn_rcvd_conn','system',
    sysdate,'Unix::TCPConnectionsByState');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 22,'warn','threshold','warn_min','pctfree','system',
    sysdate,'Unix::Swap');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 22,'critical','threshold','crit_min','pctfree','system',
    sysdate,'Unix::Swap');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 105,'InTrafficLTwarning','threshold','warn_min','in_byte_rt','system',
    sysdate,'Unix::InterfaceTraffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 105,'InTrafficLTcritical','threshold','crit_min','in_byte_rt','system',
    sysdate,'Unix::InterfaceTraffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 105,'InTrafficGTwarning','threshold','warn_max','in_byte_rt','system',
    sysdate,'Unix::InterfaceTraffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 105,'InTrafficGTcritical','threshold','crit_max','in_byte_rt','system',
    sysdate,'Unix::InterfaceTraffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 105,'OutTrafficLTwarning','threshold','warn_min','out_byte_rt','system',
    sysdate,'Unix::InterfaceTraffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 105,'OutTrafficLTcritical','threshold','crit_min','out_byte_rt','system',
    sysdate,'Unix::InterfaceTraffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 105,'OutTrafficGTwarning','threshold','warn_max','out_byte_rt','system',
    sysdate,'Unix::InterfaceTraffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 105,'OutTrafficGTcritical','threshold','crit_max','out_byte_rt','system',
    sysdate,'Unix::InterfaceTraffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 254,'intrafficGTcritical','threshold','crit_max','in_byte_rt','system',
    sysdate,'Unix::InterfaceTraffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 254,'outtrafficGTcritical','threshold','crit_max','out_byte_rt','system',
    sysdate,'Unix::InterfaceTraffic');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 20,'critical1','threshold','crit_max','load1','system',
    sysdate,'Unix::Load');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 20,'warn1','threshold','warn_max','load1','system',
    sysdate,'Unix::Load');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 20,'critical15','threshold','crit_max','load15','system',
    sysdate,'Unix::Load');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 20,'warn15','threshold','warn_max','load15','system',
    sysdate,'Unix::Load');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 20,'critical5','threshold','crit_max','load5','system',
    sysdate,'Unix::Load');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 20,'warn5','threshold','warn_max','load5','system',
    sysdate,'Unix::Load');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 27,'critical1','threshold','crit_max','load1','system',
    sysdate,'Unix::Load');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 27,'warn1','threshold','warn_max','load1','system',
    sysdate,'Unix::Load');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 27,'critical15','threshold','crit_max','load15','system',
    sysdate,'Unix::Load');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 27,'warn15','threshold','warn_max','load15','system',
    sysdate,'Unix::Load');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 14,'critical_time','threshold','crit_max','query_time','system',
    sysdate,'Unix::Dig');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 14,'warning_time','threshold','warn_max','query_time','system',
    sysdate,'Unix::Dig');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 61,'warning','threshold','warn_max','probes','system',
    sysdate,'Satellite::ProbeCount');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 61,'critical','threshold','crit_max','probes','system',
    sysdate,'Satellite::ProbeCount');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 60,'warning','threshold','warn_max','probextm','system',
    sysdate,'Satellite::ProbeExecTime');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 60,'critical','threshold','crit_max','probextm','system',
    sysdate,'Satellite::ProbeExecTime');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 24,'w_latency','threshold','warn_max','probelatnc','system',
    sysdate,'Satellite::ProbeLatency');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 24,'c_latency','threshold','crit_max','probelatnc','system',
    sysdate,'Satellite::ProbeLatency');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 304,'critical_time','threshold','crit_max','pingtime','system',
    sysdate,'NetworkService::Ping');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 304,'warn_time','threshold','warn_max','pingtime','system',
    sysdate,'NetworkService::Ping');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 304,'critical_loss','threshold','crit_max','pctlost','system',
    sysdate,'NetworkService::Ping');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 304,'warn_loss','threshold','warn_max','pctlost','system',
    sysdate,'NetworkService::Ping');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 231,'nblocked_critical','threshold','crit_max','nblocked','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 231,'nblocked_warn','threshold','warn_max','nblocked','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 231,'ndefunct_critical','threshold','crit_max','ndefunct','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 231,'ndefunct_warn','threshold','warn_max','ndefunct','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 231,'nstopped_critical','threshold','crit_max','nstopped','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 231,'nstopped_warn','threshold','warn_max','nstopped','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 231,'nswapped_critical','threshold','crit_max','nswapped','system',
    sysdate,'Unix::ProcessStateCounts');
insert into rhn_command_param_threshold(command_id,param_name,param_type,
threshold_type_name,threshold_metric_id,last_update_user,last_update_date,
command_class) 
    values ( 231,'nswapped_warn','threshold','warn_max','nswapped','system',
    sysdate,'Unix::ProcessStateCounts');
commit;

select 'rhnsat/tables/rhn_widget_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_widget_data.sql
insert into rhn_widget(name,description,last_update_user,last_update_date) 
    values ( 'text','Text','system',sysdate);
insert into rhn_widget(name,description,last_update_user,last_update_date) 
    values ( 'password','Password','system',sysdate);
insert into rhn_widget(name,description,last_update_user,last_update_date) 
    values ( 'checkbox','Checkbox','system',sysdate);
commit;

select 'rhnsat/tables/rhn_semantic_data_type_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_semantic_data_type_data.sql
insert into rhn_semantic_data_type(name,description,label_name,converter_name,
help_file,last_update_user,last_update_date) 
    values ( 'generic','Generic data type','Generic label',NULL,
    NULL,'system',sysdate);
insert into rhn_semantic_data_type(name,description,label_name,converter_name,
help_file,last_update_user,last_update_date) 
    values ( 'float','Floating-point number',NULL,'npnumber nptype=float',
    NULL,'system',sysdate);
insert into rhn_semantic_data_type(name,description,label_name,converter_name,
help_file,last_update_user,last_update_date) 
    values ( 'password','Password',NULL,NULL,
    NULL,'system',sysdate);
insert into rhn_semantic_data_type(name,description,label_name,converter_name,
help_file,last_update_user,last_update_date) 
    values ( 'string','Character string',NULL,NULL,
    NULL,'system',sysdate);
insert into rhn_semantic_data_type(name,description,label_name,converter_name,
help_file,last_update_user,last_update_date) 
    values ( 'integer','Integer',NULL,'npnumber nptype=int',
    NULL,'system',sysdate);
insert into rhn_semantic_data_type(name,description,label_name,converter_name,
help_file,last_update_user,last_update_date) 
    values ( 'checkbox','Checkbox',NULL,NULL,
    NULL,'system',sysdate);
insert into rhn_semantic_data_type(name,description,label_name,converter_name,
help_file,last_update_user,last_update_date) 
    values ( 'probestate','Probe state',NULL,'probestate',
    NULL,'system',sysdate);
commit;

select 'rhnsat/tables/rhn_command_parameter_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_parameter_data.sql
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 6,'r_tproto_0','config','string','r_tproto_0','1','tcp',NULL,NULL,30,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 6,'r_ip_0','config','string','r_ip_0','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 6,'r_svc_0','config','string','r_svc_0','1','BAD_FIXME',NULL,NULL,20,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 6,'r_port_0','config','integer','Port','1','1',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 6,'send','config','string','Send','0',NULL,NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 6,'expect','config','string','Expect','0',NULL,NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 6,'warning','threshold','integer','Warning Latency','0','3',NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 6,'critical','threshold','integer','Critical Latency','0','5',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 6,'timeout','config','integer','Timeout (seconds)','1','10',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 7,'cust_0','config','string','cust_0','1','$CUST$',NULL,NULL,1,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 7,'sat_0','config','string','sat_0','1','$SAT$',NULL,NULL,2,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 7,'r_tproto_0','config','string','r_tproto_0','1','udp',NULL,NULL,3,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 7,'r_ip_0','config','string','r_ip_0','1','$HOSTADDRESS$',NULL,NULL,4,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 7,'r_svc_0','config','string','r_svc_0','1','BAD_FIXME',NULL,NULL,5,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 7,'r_port_0','config','integer','Port','1','1',NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 7,'send','config','string','Send','0',NULL,NULL,NULL,7,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 7,'expect','config','string','Expect','0',NULL,NULL,NULL,8,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 7,'warning','threshold','integer','Warning Latency','0','3',NULL,NULL,9,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 7,'critical','threshold','integer','Critical Latency','0','5',NULL,NULL,10,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 7,'timeout','config','integer','Timeout (seconds)','0','10',NULL,NULL,11,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 8,'r_ip_0','config','string','r_ip_0','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 8,'r_port_0','config','integer','SMTP Port','1','25',NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 8,'warning','threshold','integer','Warning Latency','0','3',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 8,'critical','threshold','integer','Critical Latency','0','5',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 8,'timeout','config','integer','Timeout (seconds)','1','10',NULL,NULL,30,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 9,'r_ip_0','config','string','hostaddress','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 9,'r_port_0','config','integer','Port','1','110',NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 9,'warning','threshold','integer','Warning Latency','0','3',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 9,'critical','threshold','integer','Critical Latency','0','5',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 9,'timeout','config','integer','Timeout (seconds)','1','10',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 9,'expect','config','generic','Expect','1','+OK',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 10,'r_ip_0','config','string','r_ip_0','1','$HOSTADDRESS$',NULL,NULL,80,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 10,'r_port_0','config','integer','FTP Port','1','21',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 10,'warning','threshold','integer','Warning Latency','0','3',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 10,'critical','threshold','integer','Critical Latency','0','5',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 10,'timeout','config','integer','Timeout (seconds)','1','10',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 10,'expect_content','config','generic','Expect','0','FTP',NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 10,'username','config','string','Username','0',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 10,'password','config','password','Password','0',NULL,NULL,NULL,30,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 11,'r_ip_0','config','string','r_ip_0','1','$HOSTADDRESS$',NULL,NULL,120,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 11,'r_port_0','config','integer','HTTP Port','1','80',NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 11,'warning','threshold','integer','Warning Latency','0','3',NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 11,'critical','threshold','integer','Critical Latency','0','5',NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 11,'timeout','config','integer','Timeout (seconds)','1','10',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 11,'expect_header','config','string','Expect Header','0','HTTP/1',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 11,'url','config','string','URL Path','0','/',NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 11,'expect_content','config','string','Expect Content','0',NULL,NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 11,'virtual_host','config','string','Virtual Host','0',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 11,'useragent','config','string','UserAgent','1','NOCpulse-check_http/1.0',NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 11,'username','config','string','Username','0',NULL,NULL,NULL,60,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 11,'password','config','password','Password','0',NULL,NULL,NULL,70,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 13,'r_ip_0','config','string','r_ip_0','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 13,'ip','config','generic','IP Address (optional; defaults to host IP)','0',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 13,'warn_time','threshold','integer','Warning Round-trip Ave','0','10',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 13,'warn_loss','threshold','integer','Warning Packet Loss Pct','0','10',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 13,'critical_time','threshold','integer','Critical Round-trip Ave','0','15',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 13,'critical_loss','threshold','integer','Critical Packet Loss Pct','0','15',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 13,'packets','config','integer','Packets to send','1','20',1,NULL,30,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 13,'timeout','config','integer','Timeout (seconds)','1','10',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 14,'ip_0','config','string','ip_0','1','$HOSTADDRESS$',NULL,NULL,4,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 14,'lookuphost','config','string','Host or Address to Look Up','1','www.redhat.com',NULL,NULL,5,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 14,'timeout','config','integer','Timeout (seconds)','1','10',NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 15,'r_ip_0','config','string','r_ip_0','1','$HOSTADDRESS$',NULL,NULL,30,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 15,'timeout','config','integer','Timeout (seconds)','1','5',NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 15,'r_port_0','config','integer','SSH Port','1','22',NULL,NULL,10,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 16,'ip_0','config','string','ip_0','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 16,'port_0','config','integer','SNMP Port','1','161',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 16,'oid_0','config','string','SNMP OID','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 16,'version','config','string','SNMP Version','1','2',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 16,'community','config','password','SNMP Community String','1','public',NULL,NULL,30,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 16,'genericGTwarning','threshold','integer','Warning Value','0',NULL,NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 16,'genericGTcritical','threshold','integer','Critical Value','0',NULL,NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 16,'genericLTwarning','threshold','integer','Warning Value','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 16,'genericLTcritical','threshold','integer','Critical Value','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 17,'cust_0','config','string','cust_0','1','$CUST$',NULL,NULL,1,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 17,'asset_0','config','string','asset_0','1','$ASSET$',NULL,NULL,2,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 17,'warn','threshold','float','Warn Percent','0','85',NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 17,'critical','threshold','float','Critical Percent','0','95',NULL,NULL,5,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 17,'fs_0','config','string','Device','1','/dev/hda1',NULL,NULL,3,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 18,'cust_0','config','string','cust_0','1','$CUST$',NULL,NULL,1,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 18,'asset_0','config','string','asset_0','1','$ASSET$',NULL,NULL,2,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 18,'warn','threshold','integer','Warn Users','0','1',NULL,NULL,3,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 18,'critical','threshold','integer','Critical Users','0','2',NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 19,'cust_0','config','string','cust_0','1','$CUST$',NULL,NULL,1,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 19,'asset_0','config','string','asset_0','1','$ASSET$',NULL,NULL,2,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 19,'warn','threshold','integer','Warn Processes','0','500',NULL,NULL,3,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 19,'critical','threshold','integer','Critical Processes','0','900',NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 20,'warn1','threshold','float','Warn 1 min','0','4',NULL,NULL,3,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 20,'warn5','threshold','float','Warn 5 min','0','4',NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 20,'warn15','threshold','float','Warn 15 min','0','3',NULL,NULL,5,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 20,'critical1','threshold','float','Critical 1 min','0','8',NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 20,'critical5','threshold','float','Critical 5 min','0','6',NULL,NULL,7,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 20,'critical15','threshold','float','Critical 15 min','0','5',NULL,NULL,8,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 22,'cust_0','config','string','cust_0','1','$CUST$',NULL,NULL,1,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 22,'asset_0','config','string','asset_0','1','$ASSET$',NULL,NULL,2,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 22,'swap_0','config','string','swap_0','1','swap',NULL,NULL,3,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 22,'warn','threshold','integer','Warning Swap Pct Free','0',NULL,NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 22,'critical','threshold','integer','Critical Swap Pct Free','0',NULL,NULL,NULL,5,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 23,'ip','config','string','IP Address','1','$HOSTADDRESS$',NULL,NULL,60,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 23,'ORACLE_HOME','config','string','ORACLE_HOME variable','1','/opt/oracle',NULL,NULL,50,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 23,'port','config','integer','TNS Listener Port','1','1521',NULL,NULL,10,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 23,'timeout','config','integer','Timeout (seconds)','1','15',NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 23,'warn_latency','threshold','float','Warning Latency','0',NULL,NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 23,'critical_latency','threshold','float','Critical Latency','0',NULL,NULL,NULL,30,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 24,'w_latency','threshold','integer','Warning Seconds','0','6',NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 24,'c_latency','threshold','integer','Critical Seconds','0','10',NULL,NULL,10,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 25,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,30,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 25,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 25,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (25, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 25, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (25, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 32, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 25,'warn','threshold','float','Warning RAM Free','0',NULL,NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 25,'critical','threshold','float','Critical RAM Free','0',NULL,NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 25,'reclaim','config','checkbox','Include reclaimable memory','0','0',NULL,NULL,40,'checkbox',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 26,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,30,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 26,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 26,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (26, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 25, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (26, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 32, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 26,'warn','threshold','integer','Warning CPU Pct Used','0','70',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 26,'critical','threshold','integer','Critical CPU Pct Used','0','90',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 27,'warn1','threshold','float','Warning CPU Load 1-Min Ave','0',NULL,NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 27,'critical1','threshold','float','Critical CPU Load 1-Min Ave','0',NULL,NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 27,'warn15','threshold','float','Warning CPU Load 15-Min Ave','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 27,'critical15','threshold','float','Critical CPU Load 15-Min Ave','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 27,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 27,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,20,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 27,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (27, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 31, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (27, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 32, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 27,'warn5','threshold','float','Warning CPU Load 5-Min Ave','0',NULL,NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 27,'critical5','threshold','float','Critical CPU Load 5-Min Ave','0',NULL,NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 28,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 28,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,20,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 28,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (28, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 35, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (28, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 45, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 28,'timeout','config','integer','Timeout (seconds)','1','20',0,300,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 28,'warn','threshold','integer','Warning Swap Pct Free','0','20',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 28,'critical','threshold','integer','Critical Swap Pct Free','0','10',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 29,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 29,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (29, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 35, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 29,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,20,'text',40,80,'0','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (29, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 32, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 29,'warn','threshold','float','Warning Filesystem Pct Used','0','75',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 29,'critical','threshold','float','Critical Filesystem Pct Used','0','90',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 29,'fs_0','config','string','Filesystem','1','/dev/hda1',NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 30,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,30,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 30,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 30,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (30, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 25, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (30, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 32, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 30,'warn','threshold','integer','Warning Users','0','10',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 30,'critical','threshold','integer','Critical Users','0','50',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 31,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,30,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 31,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 31,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (31, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 25, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (31, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 32, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 31,'warn','threshold','integer','Warning Process Count','0','400',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 31,'critical','threshold','integer','Critical Process Count','0','700',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 32,'r_ip_0','config','string','r_ip_0','1','$HOSTADDRESS$',NULL,NULL,1,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 32,'critical_time','config','integer','critical_time','0','500',NULL,NULL,2,'text',8,20,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 32,'critical_loss','config','integer','critical_loss','0','80',NULL,NULL,3,'text',8,20,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 32,'packets','config','integer','packets','0','20',NULL,NULL,4,'text',8,20,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 32,'timeout','config','integer','Timeout (seconds)','0','10',NULL,NULL,5,'text',8,20,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 32,'sat_0','config','string','sat_0','1','$SAT$',NULL,NULL,6,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 32,'cust_0','config','string','cust_0','1','$CUST$',NULL,NULL,7,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 32,'host_check','config','integer','host_check','0','1',NULL,NULL,8,'text',8,20,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 41,'state','config','probestate','Status (OK/WARNING/CRITICAL/UNKNOWN)','1','OK',NULL,NULL,1,'text',10,10,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 42,'r_ip_0','config','string','r_ip_0','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 42,'r_port_0','config','integer','IMAP Port','1','143',NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 42,'expect','config','generic','Expect','1','OK',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 42,'warning','threshold','integer','Warning Latency','0','2',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 42,'critical','threshold','integer','Critical Latency','0','3',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 42,'timeout','config','integer','Timeout (seconds)','1','5',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 48,'ip','config','string','hostaddress','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 48,'proto','config','string','Protocol (TCP/UDP)','1','udp',NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 48,'service','config','string','Service Name','1','nfs',NULL,NULL,30,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 48,'warning','threshold','integer','Warning Latency','0','2',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 48,'critical','threshold','integer','Critical Latency','0','5',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 48,'timeout','config','integer','Timeout (seconds)','1','10',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 56,'r_ip_0','config','string','r_ip_0','1','$HOSTADDRESS$',NULL,NULL,120,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 56,'r_port_0','config','integer','HTTPS Port','1','443',NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 56,'warning','threshold','integer','Warning Latency','0','3',NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 56,'critical','threshold','integer','Critical Latency','0','5',NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 56,'timeout','config','integer','Timeout (seconds)','1','10',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 56,'expect_header','config','string','Expect Header','0','HTTP/1',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 56,'url','config','string','URL Path','0','/',NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 56,'expect_content','config','string','Expect Content','0',NULL,NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 56,'useragent','config','string','UserAgent','1','NOCpulse-check_http/1.0',NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 56,'username','config','string','Username','0',NULL,NULL,NULL,60,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 56,'password','config','password','Password','0',NULL,NULL,NULL,70,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 58,'state','config','string','state','1','OK',NULL,NULL,1,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 58,'message','config','string','message','0','(ICMP blocked -- host assumed up)',NULL,NULL,2,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 60,'warning','threshold','integer','Warning Seconds','0','5',NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 60,'critical','threshold','integer','Critical Seconds','0','10',NULL,NULL,10,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 61,'warning','threshold','integer','Warning Count','0',NULL,NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 61,'critical','threshold','integer','Critical Count','0',NULL,NULL,NULL,10,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 85,'ip_0','config','string','ora_host','0','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 85,'ORACLE_HOME','config','string','ORACLE_HOME','0','/opt/oracle',NULL,NULL,80,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 85,'sid_0','config','string','Oracle SID','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 85,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 85,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,40,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 85,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 85,'warn','threshold','integer','Warning Blocking Sessions','0','10',NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 85,'critical','threshold','integer','Critical Blocking Sessions','0','20',NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 85,'blocktime','config','integer','Time Blocking (seconds)','1','20',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 85,'port_0','config','integer','Oracle Port','1','1521',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 86,'ora_host','config','string','ora_host','0','$HOSTADDRESS$',NULL,NULL,90,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 86,'ORACLE_HOME','config','string','ORACLE_HOME','0','/opt/oracle',NULL,NULL,80,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 86,'ora_sid','config','string','Oracle SID','1',NULL,NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 86,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 86,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,30,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 86,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 86,'warn','threshold','integer','Warning Active Locks','0','50',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 86,'critical','threshold','integer','Critical Active Locks','0','100',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 86,'ora_port','config','integer','Oracle Port','1','1521',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 87,'ora_host','config','string','ora_host','0','$HOSTADDRESS$',NULL,NULL,1,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 87,'ORACLE_HOME','config','string','ORACLE_HOME','0','/opt/oracle',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 87,'ora_sid','config','string','Oracle SID','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 87,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 87,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,40,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 87,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 87,'warnpct','threshold','float','Available Space Percent Used Warn if Above','0','60',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 87,'critpct','threshold','float','Available Space Percent Used Critical if Above','0','90',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 87,'ora_port','config','integer','Oracle Port','1','1521',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'ora_host','config','string','ora_host','0','$HOSTADDRESS$',NULL,NULL,130,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'ORACLE_HOME','config','string','ORACLE_HOME','0','/opt/oracle',NULL,NULL,120,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'ora_sid','config','string','Oracle SID','1',NULL,NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,30,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'owner','config','string','Table Owner','1','%',NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'warn','threshold','integer','Number of Allocated Extents Warn if Above','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'critical','threshold','integer','Number of Allocated Extents Critical if Above','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'warnpct','threshold','float','Percent of Available Extents Warn if Above','0','50',NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'critpct','threshold','float','Percent of Available Extents Critical if Above','0','90',NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'ora_port','config','integer','Oracle Port','1','1521',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'ora_host','config','string','ora_host','0','$HOSTADDRESS$',NULL,NULL,130,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'ORACLE_HOME','config','string','ORACLE_HOME','0','/opt/oracle',NULL,NULL,120,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'ora_sid','config','string','Oracle SID','1',NULL,NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,30,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'owner','config','string','Index Owner','1','%',NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'warn','threshold','integer','Number of Allocated Extents Warn if Above','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'critical','threshold','integer','Number of Allocated Extents Critical if Above','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'warnpct','threshold','integer','Percent of Available Extents Warn if Above','0','50',NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'critpct','threshold','integer','Percent of Available Extents Critical if Above','0','90',NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'ora_port','config','integer','Oracle Port','1','1521',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 90,'ip_0','config','string','ora_host','0','$HOSTADDRESS$',NULL,NULL,100,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 90,'ORACLE_HOME','config','string','ORACLE_HOME','0','/opt/oracle',NULL,NULL,90,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 90,'sid_0','config','string','Oracle SID','1',NULL,NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 90,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 90,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,30,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 90,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 90,'warn','threshold','integer','Warning Idle Sessions','0','10',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 90,'critical','threshold','integer','Critical Idle Sessions','0','20',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 90,'idletime','config','integer','Time Idle (seconds)','1','36000',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 90,'port_0','config','integer','Oracle Port','1','1521',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 91,'ora_host','config','string','ora_host','0','$HOSTADDRESS$',NULL,NULL,70,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 91,'ORACLE_HOME','config','string','ORACLE_HOME','0','/opt/oracle',NULL,NULL,60,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 91,'ora_sid','config','string','Oracle SID','1',NULL,NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 91,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 91,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,30,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 91,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 91,'ora_port','config','integer','Oracle Port','1','1521',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 92,'ip_0','config','string','ora_host','0','$HOSTADDRESS$',NULL,NULL,110,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 92,'ORACLE_HOME','config','string','ORACLE_HOME','0','/opt/oracle',NULL,NULL,100,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 92,'sid_0','config','string','Oracle SID','1',NULL,NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 92,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 92,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,30,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 92,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 92,'warn','threshold','integer','Warning Active Sessions','0',NULL,NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 92,'critical','threshold','integer','Critical Active Sessions','0',NULL,NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 92,'warnpct','threshold','integer','Warning Avail Sessions Used Pct','0','60',NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 92,'critpct','threshold','integer','Critical Avail Sessions Used Pct','0','90',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 92,'port_0','config','integer','Oracle Port','1','1521',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 93,'ip_0','config','string','ip_0','1','$HOSTADDRESS$',NULL,NULL,8,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 93,'cust_0','config','string','cust_0','1','$CUST$',NULL,NULL,9,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 93,'asset_0','config','string','asset_0','1','$ASSET$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 93,'user','config','string','Username','0',NULL,NULL,NULL,1,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 93,'pass','config','password','Password','0',NULL,NULL,NULL,2,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 93,'warnabove','threshold','float','Warning Open Tables','0','75',NULL,NULL,3,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 93,'criticalabove','threshold','float','Critical Open Tables','0','100',NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 93,'warnbelow','threshold','float','Warning Open Tables','0','10',NULL,NULL,5,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 93,'criticalbelow','threshold','float','Critical Open Tables','0','1',NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 93,'port_0','config','integer','MySQL Port','1','3306',NULL,NULL,7,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 93,'timeout','config','integer','Timeout (seconds)','0','15',NULL,NULL,11,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 94,'ip_0','config','string','ip_0','1','$HOSTADDRESS$',NULL,NULL,8,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 94,'cust_0','config','string','cust_0','1','$CUST$',NULL,NULL,9,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 94,'asset_0','config','string','asset_0','1','$ASSET$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 94,'user','config','string','Username','0',NULL,NULL,NULL,1,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 94,'pass','config','password','Password','0',NULL,NULL,NULL,2,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 94,'warnabove','threshold','float','Warning Opened Tables','0','1750',NULL,NULL,3,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 94,'criticalabove','threshold','float','Critical Opened Tables','0','2000',NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 94,'warnbelow','threshold','float','Warning Opened Tables','0','100',NULL,NULL,5,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 94,'criticalbelow','threshold','float','Critical Opened Tables','0','1',NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 94,'port_0','config','integer','MySQL Port','1','3306',NULL,NULL,7,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 94,'timeout','config','integer','Timeout (seconds)','0','15',NULL,NULL,11,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 95,'ip_0','config','string','ip_0','1','$HOSTADDRESS$',NULL,NULL,8,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 95,'cust_0','config','string','cust_0','1','$CUST$',NULL,NULL,9,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 95,'asset_0','config','string','asset_0','1','$ASSET$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 95,'user','config','string','Username','0',NULL,NULL,NULL,1,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 95,'pass','config','password','Password','0',NULL,NULL,NULL,2,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 95,'warnabove','threshold','float','Warning Threads Running','0',NULL,NULL,NULL,3,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 95,'criticalabove','threshold','float','Critical Threads Running','0',NULL,NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 95,'warnbelow','threshold','float','Warning Threads Running','0',NULL,NULL,NULL,5,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 95,'criticalbelow','threshold','float','Critical Threads Running','0',NULL,NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 95,'port_0','config','integer','MySQL Port','1','3306',NULL,NULL,7,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 95,'timeout','config','integer','Timeout (seconds)','0','15',NULL,NULL,11,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 96,'ip_0','config','string','ip_0','1','$HOSTADDRESS$',NULL,NULL,8,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 96,'cust_0','config','string','cust_0','1','$CUST$',NULL,NULL,9,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 96,'asset_0','config','string','asset_0','1','$ASSET$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 96,'user','config','string','Username','0',NULL,NULL,NULL,1,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 96,'pass','config','password','Password','0',NULL,NULL,NULL,2,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 96,'warnabove','threshold','float','Warning Query Rate','0','1',NULL,NULL,3,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 96,'criticalabove','threshold','float','Critical Query Rate','0','3',NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 96,'warnbelow','threshold','float','Warning Query Rate','0','0.1',NULL,NULL,5,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 96,'criticalbelow','threshold','float','Critical Query Rate','0','0.05',NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 96,'port_0','config','integer','MySQL Port','1','3306',NULL,NULL,7,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 96,'timeout','config','integer','Timeout (seconds)','0','15',NULL,NULL,11,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 97,'host','config','string','host','1','$HOSTADDRESS$',NULL,NULL,1,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 97,'user','config','string','Username','1',NULL,NULL,NULL,2,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 97,'pass','config','password','Password','0',NULL,NULL,NULL,3,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 97,'port','config','integer','MySQL Port','0','3306',NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 97,'db','config','string','Database','1','mysql',NULL,NULL,5,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 97,'timeout','config','integer','Timeout (seconds)','0','15',NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 99,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 99,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,20,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 99,'command','config','string','Command','1',NULL,NULL,NULL,30,'text',40,1023,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 99,'ok','config','integer','OK Exit Status','1','0',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 99,'warn','config','integer','Warning Exit Status','1','1',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 99,'critical','config','integer','Critical Exit Status','1','2',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 99,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,70,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (99, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 80, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (99, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 85, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 99,'timeout','config','integer','Timeout (seconds)','1','15',NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,110,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,120,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,130,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (105, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 135, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (105, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 140, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'interface_0','config','string','Interface','1',NULL,NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'InTrafficLTwarning','threshold','float','Warning Input Rate','0',NULL,NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'InTrafficLTcritical','threshold','float','Critical Input Rate','0',NULL,NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'InTrafficGTwarning','threshold','float','Warning Input Rate','0',NULL,NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'InTrafficGTcritical','threshold','float','Critical Input Rate','0',NULL,NULL,NULL,30,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'OutTrafficLTwarning','threshold','float','Warning Output Rate','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'OutTrafficLTcritical','threshold','float','Critical Output Rate','0',NULL,NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'OutTrafficGTwarning','threshold','float','Warning Output Rate','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'OutTrafficGTcritical','threshold','float','Critical Output Rate','0',NULL,NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,20,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'log','config','string','Log file','1','/var/log/messages',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (106, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 50, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (106, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 55, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'timeout','config','integer','Timeout (seconds)','1','20',0,300,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'critical_bytes_above','threshold','integer','Critical Size','0',NULL,NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'warn_bytes_above','threshold','integer','Warning Size','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'warn_bytes_below','threshold','integer','Warning Size','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'critical_bytes_below','threshold','integer','Critical Size','0',NULL,NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'critical_byte_rate_above','threshold','float','Critical Output Rate','0',NULL,NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'warn_byte_rate_above','threshold','float','Warning Output Rate','0',NULL,NULL,NULL,120,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'warn_byte_rate_below','threshold','float','Warning Output Rate','0',NULL,NULL,NULL,130,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'critical_byte_rate_below','threshold','float','Critical Output Rate','0',NULL,NULL,NULL,140,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'critical_lines_above','threshold','integer','Critical Lines','0',NULL,NULL,NULL,150,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'warn_lines_above','threshold','integer','Warning Lines','0',NULL,NULL,NULL,160,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'warn_lines_below','threshold','integer','Warning Lines','0',NULL,NULL,NULL,170,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'critical_lines_below','threshold','integer','Critical Lines','0',NULL,NULL,NULL,180,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'critical_line_rate_above','threshold','float','Critical Line Rate','0',NULL,NULL,NULL,190,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'warn_line_rate_above','threshold','float','Warning Line Rate','0',NULL,NULL,NULL,200,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'warn_line_rate_below','threshold','float','Warning Line Rate','0',NULL,NULL,NULL,210,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 106,'critical_line_rate_below','threshold','float','Critical Line Rate','0',NULL,NULL,NULL,220,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,20,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'log','config','string','Log file','1','/var/log/messages',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'regex','config','string','Basic regular expression','1',NULL,NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values (107, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL,60, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (107, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 65, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'timeout','config','integer','Timeout (seconds)','1','45',0,300,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'critical_num_above','threshold','integer','Critical Matches','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values ( 107,'warn_num_above','threshold','integer','Warning Matches','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'warn_num_below','threshold','integer','Warning Matches','0',NULL,NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'critical_num_below','threshold','integer','Critical Matches','0',NULL,NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'critical_rate_above','threshold','float','Critical Match Rate','0',NULL,NULL,NULL,120,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'warn_rate_above','threshold','float','Warning Match Rate','0',NULL,NULL,NULL,130,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'warn_rate_below','threshold','float','Warning Match Rate','0',NULL,NULL,NULL,140,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 107,'critical_rate_below','threshold','float','Critical Match Rate','0',NULL,NULL,NULL,150,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 109,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,90,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 109,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,100,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 109,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,75,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 109,'sshport','config','integer','RHNMD Port','1','4545',NULL,NULL,76,'text',8,20,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (109, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 32, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 109,'ora_host','config','string','Oracle Hostname or IP','1',NULL,NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 109,'ora_sid','config','string','Oracle SID','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 109,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 109,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,40,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 109,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 109,'ORACLE_HOME','config','string','ORACLE_HOME','1',NULL,NULL,NULL,60,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 109,'dbname','config','string','Expected DB Name (V$DATABASE.NAME)','1',NULL,NULL,NULL,70,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 109,'ora_port','config','integer','Oracle Port','1','1521',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 113,'ip','config','string','ip','1','$HOSTADDRESS$',NULL,NULL,1,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 113,'cust_0','config','generic','cust_0','0','$CUST$',NULL,NULL,2,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 113,'asset_0','config','generic','asset_0','0','$ASSET$',NULL,NULL,3,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 113,'community','config','password','SNMP Community String','1','public',NULL,NULL,4,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 113,'port','config','integer','SNMP Port','1','161',NULL,NULL,5,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 113,'version','config','string','SNMP Version','1','2',NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 117,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,30,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 117,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 117,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (117, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 25, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (117, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 32, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 117,'fs_0','config','string','Filesystem','1','/',NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 117,'warn','threshold','float','Warning Inodes Pct Used','0','75',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 117,'critical','threshold','float','Critical Inodes Pct Used','0','90',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,20,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (118, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 35, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (118, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 37, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'disk_0','config','string','Disk number or disk name (from iostat)','1','hda',NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'warn_read_below','threshold','integer','Warning Read Rate','0','10',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'critical_read_below','threshold','integer','Critical Read Rate','0','5',NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'warn_read_above','threshold','integer','Warning Read Rate','0','50',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'critical_read_above','threshold','integer','Critical Read Rate','0','75',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'warn_write_below','threshold','integer','Warning Write Rate','0','3',NULL,NULL,120,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'critical_write_below','threshold','integer','Critical Write Rate','0','1',NULL,NULL,130,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'warn_write_above','threshold','integer','Warning Write Rate','0','20',NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'critical_write_above','threshold','integer','Critical Write rate','0','30',NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 118,'timeout','config','integer','Timeout (seconds)','1','15',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 120,'ip','config','string','hostaddress','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 120,'port','config','integer','Port','1','80',NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 120,'urlpath','config','string','Pathname','1','/server-status',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 120,'useragent','config','string','UserAgent','1','NOCpulse-ApacheUptime/1.0',NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 120,'username','config','string','Username','0',NULL,NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 120,'password','config','password','Password','0',NULL,NULL,NULL,60,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 120,'timeout','config','integer','Timeout (seconds)','1','15',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'ip','config','string','hostaddress','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'port','config','integer','Port','1','80',NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'urlpath','config','string','Pathname','1','/server-status',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'warnreqs','threshold','integer','Warning Requests','0','5',NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'criticalreqs','threshold','integer','Critical Requests','0','10',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'warnaccess','threshold','integer','Warning Accesses','0','500',NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'criticalaccess','threshold','integer','Critical Accesses','0','5000',NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'warntraffic','threshold','integer','Warning Traffic','0','5000',NULL,NULL,130,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'criticaltraffic','threshold','integer','Critical Traffic','0','25000',NULL,NULL,120,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'useragent','config','string','UserAgent','1','NOCpulse-ApacheUptime/1.0',NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'username','config','string','Username','0',NULL,NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'password','config','password','Password','0',NULL,NULL,NULL,60,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'timeout','config','integer','Timeout (seconds)','1','15',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 122,'ip','config','string','hostaddress','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 122,'port','config','integer','Port','1','80',NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 122,'urlpath','config','string','Pathname','1','/server-status',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 122,'warnchild','threshold','integer','Warning Transferred Per Child','0','5',NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 122,'criticalchild','threshold','integer','Critical Transferred Per Child','0','10',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 122,'warnslot','threshold','integer','Warning Transferred Per Slot','0','5',NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 122,'criticalslot','threshold','integer','Critical Transferred Per Slot','0','10',NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 122,'useragent','config','string','UserAgent','1','NOCpulse-ApacheUptime/1.0',NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 122,'username','config','string','Username','0',NULL,NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 122,'password','config','password','Password','0',NULL,NULL,NULL,60,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 122,'timeout','config','integer','Timeout (seconds)','1','15',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 123,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,30,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 123,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 123,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (123, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 25, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (123, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 32, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 123,'warn','threshold','float','Warning Virtual Mem Pct Free','0','25',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 123,'critical','threshold','float','Critical Virtual Mem Pct Free','0','10',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 123,'timeout','config','integer','Timeout (seconds)','1','15',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 226,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 226,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,20,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 226,'commandName','config','string','Command name','0',NULL,NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 226,'pidFile','config','string','PID file (overrides command name)','0',NULL,NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 226,'running','config','integer','running','0','1',NULL,NULL,50,'text',8,20,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 226,'groups','config','checkbox','Count process groups','0','1',NULL,NULL,60,'checkbox',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 226,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,70,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (226, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 80, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (226, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 85, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 226,'timeout','config','integer','Timeout (seconds)','1','15',0,300,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 226,'number_running_min','threshold','integer','Critical Number Running Minimum','0',NULL,NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 226,'number_running_max','threshold','integer','Critical Number Running Maximum','0',NULL,NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 227,'running','config','integer','running','0','1',NULL,NULL,3,'text',8,20,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 227,'commandName','config','string','Command name','0',NULL,NULL,NULL,1,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 227,'pidFile','config','string','PID file (overrides command name)','0',NULL,NULL,NULL,2,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,30,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (228, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 25, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (228, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 32, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'commandName','config','string','Command name','0',NULL,NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'pidFile','config','string','PID file (overrides command name)','0',NULL,NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'nchildren_warn','threshold','integer','Warning Child Process Groups','0',NULL,NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'nchildren_critical','threshold','integer','Critical Child Process Groups','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'nthreads_warn','threshold','integer','Warning Threads','0',NULL,NULL,NULL,120,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'nthreads_critical','threshold','integer','Critical Threads','0',NULL,NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'vsz_warn','threshold','integer','Warning Virtual Memory Used','0',NULL,NULL,NULL,160,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'vsz_critical','threshold','integer','Critical Virtual Memory Used','0',NULL,NULL,NULL,150,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 229,'commandName','config','string','Command name','0',NULL,NULL,NULL,1,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 229,'pidFile','config','string','PID file (overrides command name)','0',NULL,NULL,NULL,2,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 229,'nchildren_warn','threshold','integer','Warning Child Process Groups','0',NULL,NULL,NULL,5,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 229,'nchildren_critical','threshold','integer','Critical Child Process Groups','0',NULL,NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 229,'nthreads_warn','threshold','integer','Warning Threads','0',NULL,NULL,NULL,7,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 229,'nthreads_critical','threshold','integer','Critical Threads','0',NULL,NULL,NULL,8,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 229,'vsz_warn','threshold','integer','Warning Virtual Memory Used','0',NULL,NULL,NULL,11,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 229,'vsz_critical','threshold','integer','Critical Virtual Memory Used','0',NULL,NULL,NULL,12,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,20,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (230, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 31, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (230, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 32, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'nblocked_warn','threshold','integer','Warning Blocked Process Count','0',NULL,NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'nblocked_critical','threshold','integer','Critical Blocked Process Count','0',NULL,NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'nchildren_warn','threshold','integer','Warning Child Process Count','0',NULL,NULL,NULL,130,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'nchildren_critical','threshold','integer','Critical Child Process Count','0',NULL,NULL,NULL,120,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'ndefunct_warn','threshold','integer','Warning Defunct Process Count','0',NULL,NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'ndefunct_critical','threshold','integer','Critical Defunct Process Count','0',NULL,NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'nstopped_warn','threshold','integer','Warning Stopped Process Count','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'nstopped_critical','threshold','integer','Critical Stopped Process Count','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'nswapped_warn','threshold','integer','Warning Sleeping Process Count','0',NULL,NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'nswapped_critical','threshold','integer','Critical Sleeping Process Count','0',NULL,NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 231,'nblocked_warn','threshold','integer','Warning Blocked Process Count','0',NULL,NULL,NULL,1,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 231,'nblocked_critical','threshold','integer','Critical Blocked Process Count','0',NULL,NULL,NULL,2,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 231,'nchildren_warn','threshold','integer','Warning Child Process Count','0',NULL,NULL,NULL,3,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 231,'nchildren_critical','threshold','integer','Critical Child Process Count','0',NULL,NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 231,'ndefunct_warn','threshold','integer','Warning Defunct Process Count','0',NULL,NULL,NULL,5,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 231,'ndefunct_critical','threshold','integer','Critical Defunct Process Count ','0',NULL,NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 231,'nstopped_warn','threshold','integer','Warning Stopped Process Count','0',NULL,NULL,NULL,7,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 231,'nstopped_critical','threshold','integer','Critical Stopped Process Count','0',NULL,NULL,NULL,8,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 231,'nswapped_warn','threshold','integer','Warning Sleeping Process Count','0',NULL,NULL,NULL,9,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 231,'nswapped_critical','threshold','integer','Critical Sleeping Process Count','0',NULL,NULL,NULL,10,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,10,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,20,'text',40,80,'0','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,30,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (249, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 35, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (249, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 37, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'local_ip','config','string','Local IP address filter pattern list','0',NULL,NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'local_port','config','integer','Local port number filter','0',NULL,NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'remote_ip','config','string','Remote IP address filter pattern list','0',NULL,NULL,NULL,60,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'remote_port','config','integer','Remote port number filter','0',NULL,NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'warn','threshold','integer','Warning Total Connections','0',NULL,NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'critical','threshold','integer','Critical Total Connections','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'warn_TIME_WAIT','threshold','integer','Warning TIME_WAIT Connections','0',NULL,NULL,NULL,120,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'critical_TIME_WAIT','threshold','integer','Critical TIME_WAIT Connections','0',NULL,NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'warn_CLOSE_WAIT','threshold','integer','Warning CLOSE_WAIT Connections','0',NULL,NULL,NULL,140,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'critical_CLOSE_WAIT','threshold','integer','Critical CLOSE_WAIT Connections','0',NULL,NULL,NULL,130,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'warn_FIN_WAIT','threshold','integer','Warning FIN_WAIT Connections','0',NULL,NULL,NULL,160,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'critical_FIN_WAIT','threshold','integer','Critical FIN_WAIT Connections','0',NULL,NULL,NULL,150,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'warn_ESTABLISHED','threshold','integer','Warning ESTABLISHED Connections','0',NULL,NULL,NULL,180,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'critical_ESTABLISHED','threshold','integer','Critical ESTABLISHED Connections','0',NULL,NULL,NULL,170,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'warn_SYN_RCVD','threshold','integer','Warning SYN_RCVD Connections','0',NULL,NULL,NULL,200,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'critical_SYN_RCVD','threshold','integer','Critical SYN_RCVD Connections','0',NULL,NULL,NULL,190,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 249,'timeout','config','integer','Timeout (seconds)','1','15',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 254,'interface_0','config','string','Interface','1','eth0',NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 254,'intrafficGTcritical','threshold','integer','Input Traffic Critical','0',NULL,NULL,NULL,30,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 254,'outtrafficGTcritical','threshold','integer','Output Traffic Critical','0',NULL,NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 274,'shell','config','generic','shell','0','SSHRemoteCommandShell',NULL,NULL,10,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 274,'sshhost','config','generic','sshhost','0','$HOSTADDRESS$',NULL,NULL,20,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 274,'command','config','string','Command','1',NULL,NULL,NULL,30,'text',40,1023,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 274,'ok','config','integer','OK Exit Status','1','0',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 274,'warn','config','integer','Warning Exit Status','1','1',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 274,'critical','config','integer','Critical Exit Status','1','2',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 274,'sshuser','config','generic','RHNMD User','1','nocpulse',NULL,NULL,70,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (274, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL,80, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (274, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 85, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 274,'timeout','config','integer','Timeout (seconds)','0','15',NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 275,'ip','config','string','ip','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 275,'port','config','integer','SNMP Port','1','161',NULL,NULL,30,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 275,'community','config','password','SNMP Community String','1','public',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 275,'server_name','config','string','BEA Server Name','1',NULL,NULL,NULL,60,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 276,'ip','config','string','ip','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 276,'port','config','integer','SNMP Port','1','161',NULL,NULL,30,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 276,'community','config','password','SNMP Community String','1','public',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 276,'server_name','config','string','BEA Server Name','1','myserver',NULL,NULL,60,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 276,'heapfreeLTwarning','threshold','integer','Warning Heap Free','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 276,'heapfreeLTcritical','threshold','integer','Critical Heap Free','0',NULL,NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 276,'heapfreeGTwarning','threshold','integer','Warning Heap Free','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 276,'heapfreeGTcritical','threshold','integer','Critical Heap Free','0',NULL,NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 278,'ora_sid','config','string','Oracle SID','1',NULL,NULL,NULL,1,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 278,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,2,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 278,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,3,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 278,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,9,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 278,'ora_port','config','integer','Oracle Port','0','1521',NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 278,'ORACLE_HOME','config','string','ORA_HOME','0','/opt/oracle',NULL,NULL,5,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 278,'ora_host','config','generic','Oracle Host','0','$HOSTADDRESS$',NULL,NULL,6,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 279,'ora_sid','config','string','Oracle SID','1',NULL,NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 279,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 279,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,30,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 279,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 279,'ora_port','config','integer','Oracle Port','1','1521',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 279,'ORACLE_HOME','config','string','ORA_HOME','0','/opt/oracle',NULL,NULL,70,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 279,'ora_host','config','generic','Oracle Host','0','$HOSTADDRESS$',NULL,NULL,60,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 280,'ora_sid','config','string','Oracle SID','1',NULL,NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 280,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 280,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,30,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 280,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 280,'warn_max','threshold','integer','Warning Library Cache Miss Ratio','0','2',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 280,'crit_max','threshold','integer','Critical Library Cache Miss Ratio','0','3',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 280,'ora_port','config','integer','Oracle Port','1','1521',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 280,'ORACLE_HOME','config','string','ORA_HOME','0','/opt/oracle',NULL,NULL,80,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 280,'ora_host','config','generic','Oracle Host','0','$HOSTADDRESS$',NULL,NULL,90,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 284,'ora_sid','config','string','Oracle SID','1',NULL,NULL,NULL,1,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 284,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,2,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 284,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,3,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 284,'timeout','config','integer','Timeout (seconds)','0','30',NULL,NULL,9,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 284,'req_warn_max','threshold','integer','Warning Redo Log Space Requests','0',NULL,NULL,NULL,5,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 284,'req_crit_max','threshold','integer','Critical Redo Log Space Requests','0',NULL,NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 284,'retry_warn_max','threshold','integer','Warning Redo Buffer Allocation Retries','0',NULL,NULL,NULL,7,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 284,'retry_crit_max','threshold','integer','Critical Redo Buffer Allocation Retries','0',NULL,NULL,NULL,8,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 284,'ora_port','config','integer','Oracle Port','1','1521',NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 284,'ORACLE_HOME','config','string','ORA_HOME','0','/opt/oracle',NULL,NULL,10,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 284,'ora_host','config','generic','Oracle Host','0','$HOSTADDRESS$',NULL,NULL,11,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 93,'mysqlpath','config','string','Path to mysqladmin binary','1','/usr/bin/mysqladmin',NULL,NULL,12,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 94,'mysqlpath','config','string','Path to mysqladmin binary','1','/usr/bin/mysqladmin',NULL,NULL,12,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 95,'mysqlpath','config','string','Path to mysqladmin binary','1','/usr/bin/mysqladmin',NULL,NULL,12,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 96,'mysqlpath','config','string','Path to mysqladmin binary','1','/usr/bin/mysqladmin',NULL,NULL,12,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 97,'mysqlpath','config','string','Path to mysql binary','1','/usr/bin/mysql',NULL,NULL,7,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 283,'ora_sid','config','string','Oracle SID','1',NULL,NULL,NULL,10,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 283,'ora_user','config','string','Oracle Username','1',NULL,NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 283,'ora_password','config','password','Oracle Password','1',NULL,NULL,NULL,30,'password',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 283,'timeout','config','integer','Timeout (seconds)','1','30',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 283,'warn_max','threshold','float','Warning Disk Sort Ratio','0','2',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 283,'crit_max','threshold','float','Critical Disk Sort Ratio','0','10',NULL,NULL,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 283,'ora_port','config','integer','Oracle Port','1','1521',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 283,'ORACLE_HOME','config','string','ORA_HOME','0','/opt/oracle',NULL,NULL,80,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 283,'ora_host','config','generic','Oracle Host','0','$HOSTADDRESS$',NULL,NULL,90,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'ip','config','string','ip','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'port','config','integer','SNMP Port','1','161',NULL,NULL,30,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'community','config','password','SNMP Community String','1','public',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'server_name','config','string','BEA Server Name','1','myserver',NULL,NULL,60,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'pool_name','config','string','JDBC Pool Name','1','MyJDBC Connection Pool',NULL,NULL,70,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'connectionsGTwarning','threshold','integer','Warning Connections','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'connectionsGTcritical','threshold','integer','Critical Connections','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'connrateGTwarning','threshold','float','Warning Connection Rate','0',NULL,NULL,NULL,130,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'connrateGTcritical','threshold','float','Critical Connection Rate','0',NULL,NULL,NULL,120,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'waitersGTwarning','threshold','integer','Warning Waiters','0',NULL,NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'waitersGTcritical','threshold','integer','Critical Waiters','0',NULL,NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'ip','config','string','ip','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'port','config','integer','SNMP Port','1','161',NULL,NULL,30,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'community','config','password','SNMP Community String','1','public',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'server_name','config','string','BEA Server Name','1','myserver',NULL,NULL,60,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'queue_name','config','string','Queue Name','1','default',NULL,NULL,70,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'idlethreadsGTwarning','threshold','integer','Warning Idle Threads','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'idlethreadsGTcritical','threshold','integer','Critical Idle Threads','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'queuelengthGTwarning','threshold','integer','Warning Queue Length','0',NULL,NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'queuelengthGTcritical','threshold','integer','Critical Queue Length','0',NULL,NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'requestrateGTwarning','threshold','float','Warning Request Rate','0',NULL,NULL,NULL,130,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'requestrateGTcritical','threshold','float','Critical Request Rate','0',NULL,NULL,NULL,120,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 288,'ip','config','string','ip','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 288,'port','config','integer','SNMP Port','1','161',NULL,NULL,30,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 288,'community','config','password','SNMP Community String','1','public',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 288,'server_name','config','string','BEA Server Name','1','myserver',NULL,NULL,60,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 288,'servlet_name','config','string','Servlet Name','1',NULL,NULL,NULL,70,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 288,'exectimemvaveGTwarning','threshold','integer','Warning Execution Time Moving Ave','0',NULL,NULL,NULL,110,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 288,'exectimemvaveGTcritical','threshold','integer','Critical Execution Time Moving Ave','0',NULL,NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 288,'highexectimeGTwarning','threshold','integer','Warning High Execution Time','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 288,'highexectimeGTcritical','threshold','integer','Critical High Execution Time','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 29,'warn_used','threshold','integer','Warning Space Used','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 29,'critical_used','threshold','integer','Critical Space Used','0',NULL,NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 29,'warn_avail','threshold','integer','Warning Space Available','0',NULL,NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 29,'critical_avail','threshold','integer','Critical Space Available','0',NULL,NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 278,'warn_min','threshold','integer','Warning Buffer Cache Hit Ratio','0','80',NULL,NULL,7,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 278,'crit_min','threshold','integer','Critical Buffer Cache Hit Ratio','0','75',NULL,NULL,8,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 279,'warn_min','threshold','integer','Warning Data Dictionary Hit Ratio','0','80',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 279,'crit_min','threshold','integer','Critical Data Dictionary Hit Ratio','0','75',NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'cpu_time_rt_warn','threshold','float','Warning CPU Time Rate','0',NULL,NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'cpu_time_rt_critical','threshold','float','Critical CPU Time Rate','0',NULL,NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'physical_mem_used_warn','threshold','integer','Warning Physical Memory Used','0',NULL,NULL,NULL,140,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'physical_mem_used_critical','threshold','integer','Critical Physical Memory Used','0',NULL,NULL,NULL,130,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 229,'cpu_time_rt_warn','threshold','float','Warning CPU Time Rate','0',NULL,NULL,NULL,3,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 229,'cpu_time_rt_critical','threshold','float','Critical CPU Time Rate','0',NULL,NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 229,'physical_mem_used_warn','threshold','integer','Warning Physical Memory Used','0',NULL,NULL,NULL,9,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 229,'physical_mem_used_critical','threshold','integer','Critical Physical Memory Used','0',NULL,NULL,NULL,10,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 227,'number_running_min','threshold','integer','Critical Number Running Minimum','0',NULL,NULL,NULL,4,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 227,'number_running_max','threshold','integer','Critical Number Running Maximum','0',NULL,NULL,NULL,5,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 17,'warn_used','threshold','integer','Warning Space Used','0',NULL,NULL,NULL,6,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 17,'critical_used','threshold','integer','Critical Space Used','0',NULL,NULL,NULL,7,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 17,'warn_avail','threshold','integer','Warning Space Available','0',NULL,NULL,NULL,8,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 17,'critical_avail','threshold','integer','Critical Space Available','0',NULL,NULL,NULL,9,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 2,'url','config','string','URL (placeholder parameter)','0',NULL,NULL,NULL,1,'text',20,40,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 105,'timeout','config','integer','Timeout (seconds)','1','30',NULL,300,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 254,'timeout','config','integer','Timeout (seconds)','1','30',NULL,300,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 88,'match_name','config','string','Table Name','1','%',NULL,NULL,60,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 89,'match_name','config','string','Index Name','1','%',NULL,NULL,60,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 14,'critical_time','threshold','float','Critical Query Time','0',NULL,NULL,NULL,10,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 14,'warning_time','threshold','float','Warning Query Time','0',NULL,NULL,NULL,20,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 27,'timeout','config','integer','Timeout (seconds)','1','15',0,300,35,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 117,'timeout','config','integer','Timeout (seconds)','1','15',0,300,45,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 16,'timeout','config','integer','Timeout (seconds)','1','15',0,300,55,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 29,'timeout','config','integer','Timeout (seconds)','1','15',0,300,45,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 26,'timeout','config','integer','Timeout (seconds)','1','15',0,300,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 228,'timeout','config','integer','Timeout (seconds)','1','15',0,300,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 30,'timeout','config','integer','Timeout (seconds)','1','15',0,300,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 25,'timeout','config','integer','Timeout (seconds)','1','15',0,300,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 31,'timeout','config','integer','Timeout (seconds)','1','15',0,300,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 113,'timeout','config','integer','Timeout (seconds)','1','15',0,300,7,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 230,'timeout','config','integer','Timeout (seconds)','1','15',0,300,35,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 87,'named_tablespace','config','string','Tablespace Name','1','%',NULL,NULL,55,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 120,'protocol','config','string','Application Protocol','1','http',NULL,NULL,15,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 121,'protocol','config','string','Application Protocol','1','http',NULL,NULL,15,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 122,'protocol','config','string','Application Protocol','1','http',NULL,NULL,15,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 227,'groups','config','checkbox','Count process groups','0','1',NULL,NULL,6,'checkbox',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 227,'timeout','config','integer','Timeout (seconds)','1','15',0,300,7,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 275,'version','config','string','SNMP Version','1','1',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 275,'admin_server','config','string','BEA Domain Admin Server','0',NULL,NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'version','config','string','SNMP Version','1','1',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 281,'admin_server','config','string','BEA Domain Admin Server','0',NULL,NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 276,'version','config','string','SNMP Version','1','1',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 276,'admin_server','config','string','BEA Domain Admin Server','0',NULL,NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 288,'version','config','string','SNMP Version','1','1',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 288,'admin_server','config','string','BEA Domain Admin Server','0',NULL,NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 304,'sshhost','config','string','ip address of host to ssh to','1','$HOSTADDRESS$',NULL,NULL,10,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 304,'sshuser','config','string','RHNMD User','1','nocpulse',NULL,NULL,20,'text',40,80,'1','1','system',sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (304, 'sshport', 'config', 'integer', 'RHNMD Port', 1, '4545','1', NULL, 25, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into command_parameter(command_id, param_name, param_type,
data_type_name, description, mandatory, default_value, min_value, max_value,
field_order, field_widget_name, field_visible_length, field_maximum_length,
field_visible, default_value_visible, last_update_user, last_update_date)
    values (304, 'sshbannerignore', 'config', 'integer', 'SSH banner (number of lines)', 0, '',NULL, NULL, 27, 'text', 8, 20, 1, 1, 'system', sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 304,'shell','config','string','shell to use','1','SSHRemoteCommandShell',NULL,NULL,30,'text',40,80,'0','0','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 304,'ip','config','string','Remote IP Address','1',NULL,NULL,NULL,40,'text',40,80,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 304,'packets','config','integer','Packets to send','1','20',NULL,NULL,50,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 304,'timeout','config','integer','Timeout (seconds)','1','15',0,300,60,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 304,'critical_time','threshold','integer','Critical Round-trip Avg','0','15',NULL,NULL,70,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 304,'warn_time','threshold','integer','Warning Round-trip Avg','0','10',NULL,NULL,80,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 304,'critical_loss','threshold','integer','Critical Packet Loss Pct','0','15',NULL,NULL,90,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 304,'warn_loss','threshold','integer','Warning Packet Loss Pct','0','10',NULL,NULL,100,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'version','config','string','SNMP Version','1','1',NULL,NULL,40,'text',8,20,'1','1','system',sysdate);
insert into rhn_command_parameter(command_id,param_name,param_type,
data_type_name,description,mandatory,default_value,min_value,max_value,
field_order,field_widget_name,field_visible_length,field_maximum_length,
field_visible,default_value_visible,last_update_user,last_update_date) 
    values ( 282,'admin_server','config','string','BEA Domain Admin Server','0',NULL,NULL,NULL,50,'text',40,80,'1','1','system',sysdate);
commit;

select 'rhnsat/tables/rhn_command_queue_commands_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_command_queue_commands_data.sql
insert into rhn_command_queue_commands(recid,description,notes,command_line,
permanent,restartable,effective_user,effective_group,last_update_user,
last_update_date) 
    values (
1,'Satellite configuration installation','"Install Changes" on a satellite (i.e. push the monitoring config)','/usr/bin/scheduleEvents','1','0','nocpulse','nocpulse','system',sysdate);
insert into rhn_command_queue_commands(recid,description,notes,command_line,
permanent,restartable,effective_user,effective_group,last_update_user,
last_update_date) 
    values (
rhn_command_q_comm_recid_seq.nextval,'ANY SHELL COMMAND (as root)','Pick your command at execution time!  :)','%s','1','0','root','root','system',sysdate);
insert into rhn_command_queue_commands(recid,description,notes,command_line,
permanent,restartable,effective_user,effective_group,last_update_user,
last_update_date) 
    values (
rhn_command_q_comm_recid_seq.nextval,'ANY command as nocpulse','Enter any command - it will run as the nocpulse user','%s','1','0','nocpulse','nocpulse','system',sysdate);
commit;

select 'rhnsat/tables/rhn_config_group_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_config_group_data.sql
insert into rhn_config_group(name,description) 
    values ( 'general','General configuration parameters');
insert into rhn_config_group(name,description) 
    values ( 'timesync','Satellite time synchronization');
insert into rhn_config_group(name,description) 
    values ( 'oracle','General Oracle database configuration');
insert into rhn_config_group(name,description) 
    values ( 'mail','General mail configuration');
insert into rhn_config_group(name,description) 
    values ( 'innovate','Innovate (trouble ticket DB) configuration');
insert into rhn_config_group(name,description) 
    values ( 'cf_db','Configuration database configuration');
insert into rhn_config_group(name,description) 
    values ( 'cs_db','Current state database configuration');
insert into rhn_config_group(name,description) 
    values ( 'release_db','Release database configuration');
insert into rhn_config_group(name,description) 
    values ( 'notif','Notification system configuration');
insert into rhn_config_group(name,description) 
    values ( 'ts_db','Time series database configuration');
insert into rhn_config_group(name,description) 
    values ( 'TSDBLocalQueue','Time series database local queue configuration');
insert into rhn_config_group(name,description) 
    values ( 'sc_db','State change database configuration');
insert into rhn_config_group(name,description) 
    values ( 'satellite','General satellite configuration');
insert into rhn_config_group(name,description) 
    values ( 'netsaint','Netsaint configuration (mostly defunct)');
insert into rhn_config_group(name,description) 
    values ( 'PlugFrame','Plugin framework configuration');
insert into rhn_config_group(name,description) 
    values ( 'current_state','Current state database configuration');
insert into rhn_config_group(name,description) 
    values ( 'queues','Satellite dequeuer configuration');
insert into rhn_config_group(name,description) 
    values ( 'ConfigPusher','Satellite configurator configuration');
insert into rhn_config_group(name,description) 
    values ( 'CommandQueue','SputLite configuration');
insert into rhn_config_group(name,description) 
    values ( 'gritch','Gritch (throttled OOB notifications) configuration');
insert into rhn_config_group(name,description) 
    values ( 'trapReceiver','SNMP Trap Receiver configuration');
insert into rhn_config_group(name,description) 
    values ( 'ssl_bridge','SSL bridge configuration');
insert into rhn_config_group(name,description) 
    values ( 'SpreadBridge','Spread bridge configuration');
insert into rhn_config_group(name,description) 
    values ( 'SuperSput','SuperSput configuration');
insert into rhn_config_group(name,description) 
    values ( 'Discoverer','Discoverer configuration');
insert into rhn_config_group(name,description) 
    values ( 'notification','Notification system configuration');
insert into rhn_config_group(name,description) 
    values ( 'hosts','Host information');
insert into rhn_config_group(name,description) 
    values ( 'ProbeFramework','Probe framework configuration');
commit;

select 'rhnsat/tables/rhn_environment_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_environment_data.sql
insert into rhn_environment(name,description) 
    values ( 'LICENSE','Licensed Software Model');
insert into rhn_environment(name,description) 
    values ( 'ALL','All environments');
commit;

select 'rhnsat/tables/rhn_config_macro_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_config_macro_data.sql
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'CCS_CRYPTKEY', '**CCS_CRYPTKEY**', 'ClusterConfigSvcs encryption key', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'CFDBHOST', '%{RHN_SAT_HOSTNAME}', 'Configuration database host', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'CFDB_NAME', '%{RHN_DB_NAME}', 'Configuration database name', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'CFDB_NOTIF_PASSWD', '%{RHN_DB_PASSWD}', 'Configuration database notification user password', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'CFDB_PASSWD', '%{RHN_DB_PASSWD}', 'Configuration database password', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'CSDBHOST', '%{CFDBHOST}', 'Current state database host', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'CSDB_NAME', '%{RHN_DB_NAME}', 'Current state database name', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'CSDB_PASSWD', '%{CFDB_PASSWD}', 'Current state database password', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'DOM', '**DOM**', 'Local host domain (e.g. ''redhat.com'')', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'EDOM', '%{DOM}', 'Environment-specific domain (e.g. ''dev.rhn_net'')', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'ENV', 'license', 'Environment (e.g. ''prod'')', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'GRITCH_TARGETCUST', '**GRITCH_TARGETCUST**', 'Administrative destination customer ID', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'GRITCH_TARGETDEST', '%{GRITCH_TARGETCUST}_%{GRITCH_TARGETDESTID}_%{GRITCH_TARGETDESTNAME}', 'Gritch target destination', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'GRITCH_TARGETDESTID', '**GRITCH_TARGETDESTID**', 'Administrative destination recid', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'GRITCH_TARGETDESTNAME', '**GRITCH_TARGETDESTNAME**', 'Administrative destination name', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'INNOVATE_LOGINDIR', 'NULL', 'Innovate login directory', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'INNOVATE_PASSWD', 'NULL', 'Innovate password', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'IPROTO', 'http', 'Internal protocol (e.g. ''http'')', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'MAIL_MX', '**MAIL_MX**', 'Local mail exchanger', '1', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'MDOM', '**MDOM**', 'Mail domain (e.g. ''redhat.com'' for myemail@redhat.com)', '1', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'NOTIFDOWNEMAIL', '%{RHN_ADMIN_EMAIL}', 'Email to notif in case of notif meltdown', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'NOTIFHOST', '%{RHN_SAT_HOSTNAME}', 'Notification host', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'NOTIFURL', '%{IPROTO}://%{NOTIFHOST}/cgi-mod-perl/enqueue.cgi', 'Notification server URL', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'NOTIF_ADMINPORT', '%{RHN_SAT_WEB_PORT}', 'Notification administrative webserver port', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'NOTIF_ADMIN_EMAIL', '%{RHN_ADMIN_EMAIL}', 'Notification administrator email', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'NPBIN', '/usr/bin', 'Production user bin directory', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'NPETC', '/etc/nocpulse', 'Production user etc directory', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'NPHOME', '/var/lib/%{USER}', 'Production user home directory', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'NPVAR', '/var/log/%{USER}', 'Production user var directory', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'NPLIB', '/var/lib/%{USER}', 'Production user data directory', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'PORTALURL', '%{XPROTO}://%{RHN_SAT_HOSTNAME}', 'Portal URL', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'RHN_ADMIN_EMAIL', '**RHN_ADMIN_EMAIL**', 'Spacewalk administrator email', '1', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'RHN_DB_NAME', '**RHN_DB_NAME**', 'Spacewalk database name ', '1', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'RHN_DB_PASSWD', '**RHN_DB_PASSWD**', 'Spacewalk database password', '1', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'RHN_DB_TABLE_OWNER', '**RHN_DB_TABLE_OWNER**', 'Spacewalk Database table owner', '1', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'RHN_DB_USERNAME', '**RHN_DB_USERNAME**', 'Spacewalk database username', '1', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'RHN_SAT_HOSTNAME', '**RHN_SAT_HOSTNAME**', 'Spacewalk hostname (FQDN)', '1', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'RHN_SAT_WEB_PORT', '**RHN_SAT_WEB_PORT**', 'Spacewalk webserver port (80 for http, 443 for https)', '1', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'SATCFGHOST', '%{RHN_SAT_HOSTNAME}', 'Satellite configuration host', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'SATCFGURL', '%{SMONURL}/satconfig', 'Satellite configurator URL', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'SCDBHOST', '%{RHN_SAT_HOSTNAME}', 'State change database host', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'SCDBURL', '%{IPROTO}://%{SCDBHOST}/scdb', 'State change database URL', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'SCDB_NAME', '%{RHN_DB_NAME}', 'State change database name', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'SMONHOST', '%{RHN_SAT_HOSTNAME}', 'SMON host', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'SMONTEST', '%{RHN_SAT_HOSTNAME}', 'SMON-TEST host', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'SMONURL', '%{XPROTO}://%{SMONHOST}', 'SMON URL', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'SMON_ADMIN_EMAIL', '%{RHN_ADMIN_EMAIL}', 'Scout administrator email', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'SPREADBRIDGE_CLIENTPORT', '443', 'Spread bridge client port', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'SSPUT_CRYPTKEY', '**SSPUT_CRYPTKEY**', 'SuperSput crypto key', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'SUPPORTURL', 'https://support.nocpulse.com', 'Support URL', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'TIMESYNC_MAXDELTA', '60', 'Maximum time skew for auto-adjustment (seconds)', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'TIMESYNC_MINDELTA', '0.3', 'Minimum time skew for auto-adjustment (seconds)', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'LICENSE', 'TSDBHOST', '%{RHN_SAT_HOSTNAME}', 'Time-series database host', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'TSDBURL', '%{IPROTO}://%{TSDBHOST}/tsdb', 'Time-series database URL', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'USER', 'nocpulse', 'Production user', '0', 'system',sysdate);
insert into rhn_config_macro(environment,name,definition,description,editable,last_update_user,last_update_date)     values ( 'ALL', 'XPROTO', '**XPROTO**', 'External protocol (''http'' or ''https'')', '1', 'system',sysdate);

select 'rhnsat/tables/rhn_config_security_type_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_config_security_type_data.sql
insert into rhn_config_security_type(name,description) 
    values ( 'INTERNAL','Internal-only configuration parameters');
insert into rhn_config_security_type(name,description) 
    values ( 'EXTERNAL','Exportable configuration parameters');
insert into rhn_config_security_type(name,description) 
    values ( 'ALL','All security levels');
commit;

select 'rhnsat/tables/rhn_config_parameter_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_config_parameter_data.sql
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'CommandQueue', 'dbAuthFile', '/etc/NOCpulse.SputLiteAuth', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'CommandQueue', 'exelog', '%{NPLIB}/commands/execute_commands.log', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'CommandQueue', 'exelogLevel', '3', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'CommandQueue', 'gritchdb', '%{NPLIB}/commands/.gripes.gdbm', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'CommandQueue', 'heartbeatFile', '%{NPLIB}/commands/heartbeat', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'CommandQueue', 'lastCompletedFile', '%{NPLIB}/commands/last_completed', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'CommandQueue', 'lastStartedFile', '%{NPLIB}/commands/last_started', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'CommandQueue', 'pollingInterval', '60', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'CommandQueue', 'queueName', 'commands', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'CommandQueue', 'queueServer', '%{SATCFGURL}/cgi-mod-perl/fetch_commands.cgi', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'CommandQueue', 'url', '%{IPROTO}://%{SATCFGHOST}/cgi-bin/upload_results.cgi', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ConfigPusher', 'dbsynchProgram', '%{NPBIN}/synch.sh', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'Discoverer', 'nmapPath', '/usr/bin/nmap', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'Discoverer', 'url', '%{SATCFGURL}/cgi-bin/upload_autodisc.cgi', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'PlugFrame', 'configFile', '%{NPETC}/PlugFrame.ini', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ProbeFramework', 'databaseDirectory', '%{NPLIB}/ProbeState', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ProbeFramework', 'probeClassLibraryDirectory', '%{NPHOME}/libexec', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SpreadBridge', 'clientCA', '%{NPETC}/nocpulse-sys-proxy-chain.crt', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SpreadBridge', 'clientCert', '%{NPETC}/sat-smon-cert.pem', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SpreadBridge', 'clientHost', '%{SMONTEST}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SpreadBridge', 'clientKey', '%{NPETC}/sat-smon-key.pem', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SpreadBridge', 'clientPort', '%{SPREADBRIDGE_CLIENTPORT}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SpreadBridge', 'clientService', 'SPBR', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SpreadBridge', 'logfile', '%{NPVAR}/spbridge.log', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SpreadBridge', 'loglevel', '1', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SpreadBridge', 'serverIP', '0.0.0.0', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SpreadBridge', 'serverPort', '4547', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SpreadBridge', 'serverQueue', '5', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SuperSput', 'clientHost', '%{SMONHOST}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SuperSput', 'clientPort', '443', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SuperSput', 'cryptkey', '%{SSPUT_CRYPTKEY}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SuperSput', 'logfile', '%{NPVAR}/supersput.log', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SuperSput', 'loglevel', '1', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SuperSput', 'serverCert', '%{NPETC}/spbridge/cert.pem', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SuperSput', 'serverIF', 'eth0', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SuperSput', 'serverKey', '%{NPETC}/spbridge/key.pem', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'SuperSput', 'serverPort', '1284', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'TSDBLocalQueue', 'bdb_dir', '/nocpulse/tsdb/bdb', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'TSDBLocalQueue', 'daemon_log_config', '''local_queue'' => 1', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'TSDBLocalQueue', 'daemon_log_file', '/var/log/nocpulse/TSDBLocalQueue/TSDBLocalQueue.log', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'TSDBLocalQueue', 'handler_log_config', '', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'TSDBLocalQueue', 'handler_log_file', '/var/log/nocpulse/TSDBLocalQueue/TSDBHandler.log', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'TSDBLocalQueue', 'handler_rotate_size_kb', '250', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'TSDBLocalQueue', 'local_queue_dir', '/var/log/nocpulse/TSDBLocalQueue', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'TSDBLocalQueue', 'read_old_file_lines', '250', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'TSDBLocalQueue', 'read_old_file_seconds', '3', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'dbd', 'Oracle', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'name', '%{CFDB_NAME}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'notification_password', '%{CFDB_NOTIF_PASSWD}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'notification_username', '%{RHN_DB_USERNAME}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'password', '%{CFDB_PASSWD}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'portal_password', '%{CFDB_PASSWD}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'portal_username', '%{RHN_DB_USERNAME}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'proxy_password', '%{CFDB_PASSWD}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'proxy_username', '%{RHN_DB_USERNAME}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'tableowner', '%{RHN_DB_TABLE_OWNER}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'ui_password', '%{CFDB_PASSWD}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'ui_username', '%{RHN_DB_USERNAME}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cf_db', 'username', '%{RHN_DB_USERNAME}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cs_db', 'dbd', 'Oracle', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cs_db', 'name', '%{CSDB_NAME}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cs_db', 'password', '%{CSDB_PASSWD}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cs_db', 'tableowner', '%{RHN_DB_TABLE_OWNER}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'cs_db', 'username', '%{RHN_DB_USERNAME}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'current_state', 'acceptor_url', '%{SATCFGURL}/cgi-mod-perl/accept_status_log.cgi', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'current_state', 'last_success', '%{NPLIB}/last_state_push', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'current_state', 'notification_interval', '300', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'general', 'domain', '%{DOM}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'general', 'env', '%{ENV}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'general', 'produser', '%{USER}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'gritch', 'countInterval', '1000', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'gritch', 'targetDest', '%{GRITCH_TARGETDEST}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'gritch', 'targetEmail', '%{SMON_ADMIN_EMAIL}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'gritch', 'targetMX', '%{SMONURL}/cgi-bin/https_mx.cgi', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'gritch', 'targetQueue', 'notif', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'gritch', 'timeInterval', '1800', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'hosts', 'cfdb', '%{CFDBHOST}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'hosts', 'csdb', '%{CSDBHOST}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'hosts', 'notif', '%{NOTIFHOST}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'hosts', 'satconfig', '%{SATCFGHOST}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'hosts', 'scdb', '%{SCDBHOST}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'hosts', 'smon', '%{SMONHOST}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'hosts', 'tsdb', '%{TSDBHOST}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'innovate', 'base_path', '/cgi-bin/up.cgi', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'innovate', 'lastresort', '%{NOTIF_ADMIN_EMAIL}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'innovate', 'logindir', '%{INNOVATE_LOGINDIR}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'innovate', 'password', '%{INNOVATE_PASSWD}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'innovate', 'summarylength', '40', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'innovate', 'url', '%{SUPPORTURL}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'innovate', 'user', '1_telalert', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'mail', 'maildomain', '%{MDOM}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'mail', 'mx', '%{MAIL_MX}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'archiveDir', '/var/lib/nocpulse/archives', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'cHashProgram', '/usr/share/ssl/misc/c_hash', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'caPemCertFile', '/etc/nocpulse/nocpulse-cert.pem', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'commandFile', '/var/lib/nocpulse/rw/netsaint.cmd', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'commandParameterDatabase', '/var/lib/nocpulse/CommandParameter.db', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'configBackupDir', '/etc/nocpulse/backup', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'configDir', '/etc/nocpulse', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'hacf', '/etc/ha.d/ha.cf', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'haresources', '/etc/ha.d/haresources', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'hostsConfigFile', 'hosts.cfg', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'llConfigDir', '/var/lib/nocpulse/llconfig', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'llnetsaintFile', '/etc/nocpulse/llnetsaint', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'netsaintConfigFile', 'netsaint.cfg', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'netsaintIdFile', '/etc/nocpulse/netsaintId', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'pluginDatabase', '/var/lib/nocpulse/Probe.db', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'probeRecordDatabase', '/var/lib/nocpulse/ProbeRecord.db', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'program', '/usr/bin/netsaint', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'satKeyFile', '/var/lib/nocpulse/.ssh/nocpulse-identity.pub', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'satPemCertFile', '/etc/nocpulse/satellite-cert.pem', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'netsaint', 'satPemKeyFile', '/etc/nocpulse/satellite-key.pem', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notif', 'url', '%{NOTIFURL}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'ack_handler_log', '/var/tmp/ack_handler.log', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'ack_queue_dir', '/var/lib/notification/queue/ack_queue', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'ack_queue_item', 'Alert', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'admin_port', '%{NOTIF_ADMINPORT}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'alert_queue_dir', '/var/lib/notification/queue/alert_queue', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'alert_queue_item', 'Acknowledgement', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'archive_params', '--cd=/var/log/nocpulse --dir=/var/log/nocpulse/archive /var/tmp/ack_handler.log enqueue.log generate_config.log notifserver.log.save notifserver-error.log --recreate=ticketlog', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'config_dir', '/etc/notification', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'config_reload_flag_file', '/etc/nocpulse/NOCpulse/tmp/reload_notif_config.please', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'enqueue_log', '/var/tmp/enqueue.log', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'frombase', 'rogerthat', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'fromname', 'Monitoring Satellite Notification', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'home', '/var/lib/nocpulse', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'log_dir', '/var/log/nocpulse', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'max_sends_in_progress', '400', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'notif_emergency_email', '%{NOTIFDOWNEMAIL}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'redirects_reload_flag_file', '/etc/nocpulse/NOCpulse/tmp/reload_redirect_config.please', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'request_queue_dir', '/var/lib/nocpulse/queue/request_queue', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'request_queue_item', 'Request', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'rotate_log_flag_file', '/etc/nocpulse/NOCpulse/tmp/rotate_logs.please', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'snmp_notif_url', '%{PORTALURL}/ocenter/', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'ticket_log_dir', '/var/log/nocpulse/ticketlog', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'notification', 'tmp_dir', '/var/tmp', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'oracle', 'ora_home', '/opt/oracle', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'oracle', 'ora_port', '1521', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'aliases', 'notification,states,trends,command,snmp_direct', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'bugsEmail', '%{SMON_ADMIN_EMAIL}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'commands_dequeueLimit', '0', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'commands_maxsize', '5', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'eventHandler', '%{SMONURL}/cgi-bin/eventHandler.cgi', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'gritchdb', '%{NPLIB}/.gripes.gdbm', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'logfile', '%{NPVAR}/dequeue.log', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'notif_dequeueLimit', '50', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'notif_maxsize', '30', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'polling_interval', '5', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'queuedir', '%{NPLIB}/queue', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'queues', 'notif,sc_db,ts_db,commands,snmp', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'queueuser', 'nocpulse', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'sc_db_dequeueLimit', '1000', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'sc_db_maxsize', '3000', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'snmp_dequeueLimit', '0', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'snmp_download_url', '%{SATCFGURL}/cgi-mod-perl/fetch_snmp_alerts.cgi', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'snmp_maxsize', '30', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'snmplast', '%{NPLIB}/queue/snmp/LAST_SENT', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'snmplog', '%{NPVAR}/dequeue.snmp.log', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'ts_db_batch_size', '300', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'ts_db_dequeueLimit', '600', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'queues', 'ts_db_maxsize', '3000', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'satellite', 'bootstrapUrl', '%{SATCFGURL}/cgi-bin/fetch_netsaintid.cgi', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'satellite', 'configGenTimeout', '90', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'satellite', 'configGrabUrl', '%{SATCFGURL}/cgi-bin/configdata.cgi', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'satellite', 'depotUrl', '%{SMONURL}/depot/', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'satellite', 'eventsFile', '%{NPLIB}/events.frozen', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'satellite', 'gritchdb', '%{NPLIB}/.gripes-probe-code.gdbm', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'satellite', 'schedulerConfigFile', '%{NPLIB}/scheduler.xml', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'satellite', 'schedulerLogFile', '%{NPVAR}/kernel.log', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'satellite', 'schedulerReloadFlagFile', '%{NPLIB}/reload.please', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'sc_db', 'url', '%{SCDBURL}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ssl_bridge', 'cdir', '%{NPETC}/spbridge', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ssl_bridge', 'cert', '%{NPETC}/spbridge/smon-sb.crt', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ssl_bridge', 'cfile', '%{NPETC}/spbridge/nocpulse-sys-satellite-chain.crt', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ssl_bridge', 'ciphers', 'DES-CBC3-SHA', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ssl_bridge', 'key', '%{NPETC}/spbridge/smon-sb.key', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ssl_bridge', 'listenIP', '0.0.0.0', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ssl_bridge', 'listenPort', '4546', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ssl_bridge', 'listenQueue', '5', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ssl_bridge', 'logfile', '%{NPVAR}/ssl_bridge.log', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ssl_bridge', 'remoteIP_SPBR', '%{SATCFGHOST}', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ssl_bridge', 'remotePort_SPBR', '4547', 'INTERNAL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'timesync', 'maxdelta', '%{TIMESYNC_MAXDELTA}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'timesync', 'mindelta', '%{TIMESYNC_MINDELTA}', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'timesync', 'retries', '3', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'timesync', 'samplesize', '5', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'timesync', 'timeserver', '%{SMONURL}/cgi-bin/timeserver.cgi', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'trapReceiver', 'cmd_recid', '250', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'trapReceiver', 'config', '%{NPLIB}/trapReceiver/config', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'trapReceiver', 'cust_mibdir', '%{NPLIB}/trapReceiver/mibs', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'trapReceiver', 'logfile', '%{NPVAR}/trapReceiver.log', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'trapReceiver', 'loglevel', '2', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'trapReceiver', 'std_mibdir', '/usr/local/snmp/share/snmp/mibs', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'trapReceiver', 'trapdir', '%{NPLIB}/trapReceiver/traps', 'ALL', 'system',sysdate);
insert into rhn_config_parameter(group_name,name,value,security_type,last_update_user,last_update_date) values ( 'ts_db', 'url', '%{TSDBURL}', 'INTERNAL', 'system',sysdate);

select 'rhnsat/tables/rhn_db_environment_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_db_environment_data.sql
insert into rhn_db_environment(db_name,environment) values ('WEBDEV','LICENSE');
commit;

select 'rhnsat/tables/rhn_method_types_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_method_types_data.sql
insert into rhn_method_types(recid,method_type_name,notification_format_id) 
    values ( 1,'Pager',5);
insert into rhn_method_types(recid,method_type_name,notification_format_id) 
    values ( 2,'Email',4);
insert into rhn_method_types(recid,method_type_name,notification_format_id) 
    values ( 4,'Group',4);
insert into rhn_method_types(recid,method_type_name,notification_format_id) 
    values ( 5,'SNMP',4);
commit;

select 'rhnsat/tables/rhn_notification_formats_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_notification_formats_data.sql
insert into rhn_notification_formats(recid,customer_id,description,
subject_format,body_format,max_subject_length,max_body_length,reply_format) 
    values ( rhn_ntfmt_recid_seq.nextval,NULL,'Default Format','^[alert id] | ^[timestamp]','^[alert id] | ^[timestamp]',70,1920,NULL);
select rhn_ntfmt_recid_seq.nextval from dual;
insert into rhn_notification_formats(recid,customer_id,description,
subject_format,body_format,max_subject_length,max_body_length,reply_format) 
    values ( rhn_ntfmt_recid_seq.nextval,NULL,'New Default (2.15)','^[probe state]: ^[hostname]: ^[probe description] at ^[timestamp:"%H:%M %Z"]','This is a Spacewalk Monitoring Satellite event notification.\n\nTime:      ^[timestamp:"%a %b %d, %H:%M:%S %Z"]\nState:     ^[probe state]\nHost:      ^[hostname] (^[host IP])\nCheck:     ^[probe description]\nMessage:   ^[probe output]\nRun from:  ^[satellite description]\n\nTo acknowledge, reply to this message with this subject line:\n     ACK ^[alert id]\n\nTo immediately escalate, reply to this message with this subject line:\n     NACK ^[alert id]',150,1920,NULL);
insert into rhn_notification_formats(recid,customer_id,description,
subject_format,body_format,max_subject_length,max_body_length,reply_format) 
    values ( rhn_ntfmt_recid_seq.nextval,NULL,'New Default (2.18)','^[probe state]: ^[hostname]: ^[probe description] at ^[timestamp:"%H:%M %Z"]','This is Spacewalk Monitoring Satellite notification ^[alert id].\n\nTime:      ^[timestamp:"%a %b %d, %H:%M:%S %Z"]\nState:     ^[probe state]\nHost:      ^[hostname] (^[host IP])\nCheck:     ^[probe description]\nMessage:   ^[probe output]\nRun from:  ^[satellite description]',150,1920,'\n\nTo acknowledge, reply to this message within ^[ack wait] minutes with this subject line:\n     ACK ^[alert id]\n\nTo immediately escalate, reply to this message within ^[ack wait] minutes with this subject line:\n     NACK ^[alert id]');
insert into rhn_notification_formats(recid,customer_id,description,
subject_format,body_format,max_subject_length,max_body_length,reply_format) 
    values ( rhn_ntfmt_recid_seq.nextval,NULL,'Pager Default (3.6)',NULL,'^[probe state]: ^[hostname]: ^[probe description] at ^[timestamp:"%H:%M %Z"], notification ^[alert id]',0,200,NULL);
commit;

select 'rhnsat/tables/rhn_os_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_os_data.sql
insert into rhn_os(recid,os_name) 
    values ( 4,'Linux System');
insert into rhn_os(recid,os_name) 
    values ( 14,'Satellite');
commit;

select 'rhnsat/tables/rhn_os_commands_xref_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_os_commands_xref_data.sql
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,6);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,7);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,8);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,9);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,10);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,11);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,13);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,14);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,15);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,16);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,17);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,17);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,18);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,18);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,19);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,19);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,20);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,20);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,22);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,22);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,23);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,24);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,24);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,25);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,25);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,26);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,26);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,27);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,27);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,28);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,28);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,29);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,29);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,30);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,30);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,31);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,31);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,32);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,41);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,42);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,48);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,56);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,58);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,60);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,60);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,61);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,61);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,85);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,86);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,87);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,88);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,89);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,90);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,91);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,92);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,93);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,94);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,95);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,96);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,97);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,99);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,105);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,106);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,107);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,109);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,113);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,117);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,117);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,118);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,118);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,120);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,121);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,122);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,123);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,226);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,226);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,227);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,227);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,228);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,228);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,229);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,229);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,230);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,230);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,231);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,231);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,249);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 14,254);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,254);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,274);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,275);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,276);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,278);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,279);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,280);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,281);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,282);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,283);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,284);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,288);
insert into rhn_os_commands_xref(os_id,commands_id) values ( 4,304);
commit;

select 'rhnsat/tables/rhn_pager_types_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_pager_types_data.sql
insert into rhn_pager_types(recid,pager_type_name)
    values ( rhn_pager_types_recid_seq.nextval,'All pager types');
commit;

select 'rhnsat/tables/rhn_physical_location_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_physical_location_data.sql
insert into rhn_physical_location(recid, location_name, last_update_user, last_update_date)
    values (rhn_physical_loc_recid_seq.nextval, 'Generic All-Encompassing Location','system', sysdate); 
commit;

select 'rhnsat/tables/rhn_probe_types_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_probe_types_data.sql
insert into rhn_probe_types(probe_type,type_description) 
    values ( 'None','None specified');
insert into rhn_probe_types(probe_type,type_description) 
    values ( 'satnode','Satellite Node Probe');
insert into rhn_probe_types(probe_type,type_description) 
    values ( 'satcluster','Satellite Cluster Probe');
insert into rhn_probe_types(probe_type,type_description) 
    values ( 'url','URL Probe');
insert into rhn_probe_types(probe_type,type_description) 
    values ( 'host','Host Probe');
insert into rhn_probe_types(probe_type,type_description) 
    values ( 'check','Check Probe');
insert into rhn_probe_types(probe_type,type_description) 
    values ( 'suite','Check Suite Probe');
commit;

select 'rhnsat/tables/rhn_redirect_match_types_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_redirect_match_types_data.sql
insert into rhn_redirect_match_types(name) 
    values ( 'CASE_SEN_MSG_PATTERN');
insert into rhn_redirect_match_types(name) 
    values ( 'CASE_INSEN_MSG_PATTERN');
insert into rhn_redirect_match_types(name) 
    values ( 'PROBE_ID');
insert into rhn_redirect_match_types(name) 
    values ( 'NETSAINT_ID');
insert into rhn_redirect_match_types(name) 
    values ( 'PROBE_TYPE');
insert into rhn_redirect_match_types(name) 
    values ( 'SERVICE_STATE');
insert into rhn_redirect_match_types(name) 
    values ( 'HOST_STATE');
insert into rhn_redirect_match_types(name) 
    values ( 'CONTACT_GROUP_ID');
insert into rhn_redirect_match_types(name) 
    values ( 'CONTACT_METHOD_ID');
insert into rhn_redirect_match_types(name) 
    values ( 'CUSTOMER_ID');
commit;

select 'rhnsat/tables/rhn_redirect_types_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_redirect_types_data.sql
insert into rhn_redirect_types(name,description,long_name) 
    values ( 'METOO','Specify a destination for matching alerts (appends to default recipient list)','Supplemental Notification');
insert into rhn_redirect_types(name,description,long_name) 
    values ( 'BLACKHOLE','Clear out default recipient list for matching alerts (i.e. send to nobody, unless other redirects are in effect)','Suspend Standard Notifications');
insert into rhn_redirect_types(name,description,long_name) 
    values ( 'ACK','Automatically acknowlege matching alerts','Automatic Acknowledgement');
insert into rhn_redirect_types(name,description,long_name) 
    values ( 'REDIR','Specify a destination for matching alerts (overrides default recipient list)','Redirect Standard Notifications');
commit;

select 'rhnsat/tables/rhn_schedule_types_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_schedule_types_data.sql
insert into rhn_schedule_types(recid,description) 
    values ( 1,'Weekly');
insert into rhn_schedule_types(recid,description) 
    values ( 2,'Rotation of Days');
insert into rhn_schedule_types(recid,description) 
    values ( 3,'Rotation of Weeklies');
commit;

select 'rhnsat/tables/rhn_schedules_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_schedules_data.sql
insert into rhn_schedules(recid,schedule_type_id,description,last_update_user,
last_update_date,customer_id) 
    values ( rhn_schedules_recid_seq.nextval,1,'24x7','system',sysdate,NULL);
commit;

select 'rhnsat/tables/rhn_schedule_days_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_schedule_days_data.sql
insert into rhn_schedule_days(recid,schedule_id,ord,start_1,end_1,start_2,
end_2,start_3,end_3,start_4,end_4,last_update_user,last_update_date) 
    values ( rhn_schedule_days_recid_seq.nextval,1,0,
    to_date('08-SEP-2000 12:00:02 AM','DD-MON-YYYY HH:MI:SS AM'),
    to_date('09-SEP-2000 12:00:00 AM','DD-MON-YYYY HH:MI:SS AM'),
    null,null,null,null,null,null,'system',null);
insert into rhn_schedule_days(recid,schedule_id,ord,start_1,end_1,start_2,
end_2,start_3,end_3,start_4,end_4,last_update_user,last_update_date) 
    values ( rhn_schedule_days_recid_seq.nextval,1,1,
    to_date('08-SEP-2000 12:00:09 AM','DD-MON-YYYY HH:MI:SS AM'),
    to_date('09-SEP-2000 12:00:00 AM','DD-MON-YYYY HH:MI:SS AM'),
    null,null,null,null,null,null,'system',null);
insert into rhn_schedule_days(recid,schedule_id,ord,start_1,end_1,start_2,
end_2,start_3,end_3,start_4,end_4,last_update_user,last_update_date) 
    values ( rhn_schedule_days_recid_seq.nextval,1,2,
    to_date('08-SEP-2000 12:00:14 AM','DD-MON-YYYY HH:MI:SS AM'),
    to_date('09-SEP-2000 12:00:00 AM','DD-MON-YYYY HH:MI:SS AM'),
    null,null,null,null,null,null,'system',null);
insert into rhn_schedule_days(recid,schedule_id,ord,start_1,end_1,start_2,
end_2,start_3,end_3,start_4,end_4,last_update_user,last_update_date) 
    values ( rhn_schedule_days_recid_seq.nextval,1,3,
    to_date('08-SEP-2000 12:00:20 AM','DD-MON-YYYY HH:MI:SS AM'),
    to_date('09-SEP-2000 12:00:00 AM','DD-MON-YYYY HH:MI:SS AM'),
    null,null,null,null,null,null,'system',null);
insert into rhn_schedule_days(recid,schedule_id,ord,start_1,end_1,start_2,
end_2,start_3,end_3,start_4,end_4,last_update_user,last_update_date) 
    values ( rhn_schedule_days_recid_seq.nextval,1,4,
    to_date('08-SEP-2000 12:00:25 AM','DD-MON-YYYY HH:MI:SS AM'),
    to_date('09-SEP-2000 12:00:00 AM','DD-MON-YYYY HH:MI:SS AM'),
    null,null,null,null,null,null,'system',null);
insert into rhn_schedule_days(recid,schedule_id,ord,start_1,end_1,start_2,
end_2,start_3,end_3,start_4,end_4,last_update_user,last_update_date) 
    values ( rhn_schedule_days_recid_seq.nextval,1,5,
    to_date('08-SEP-2000 12:00:31 AM','DD-MON-YYYY HH:MI:SS AM'),
    to_date('09-SEP-2000 12:00:00 AM','DD-MON-YYYY HH:MI:SS AM'),
    null,null,null,null,null,null,'system',null);
insert into rhn_schedule_days(recid,schedule_id,ord,start_1,end_1,start_2,
end_2,start_3,end_3,start_4,end_4,last_update_user,last_update_date) 
    values ( rhn_schedule_days_recid_seq.nextval,1,6,
    to_date('08-SEP-2000 12:00:36 AM','DD-MON-YYYY HH:MI:SS AM'),
    to_date('09-SEP-2000 12:00:00 AM','DD-MON-YYYY HH:MI:SS AM'),
    null,null,null,null,null,null,'system',null);
commit;

select 'rhnsat/tables/rhn_strategies_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_strategies_data.sql
insert into rhn_strategies(recid,name,comp_crit,esc_crit,contact_strategy,
ack_completed) 
    values (rhn_strategies_recid_seq.nextval,'Broadcast-NoAck',
    'Sent=100',NULL,'Broadcast','No');
insert into rhn_strategies(recid,name,comp_crit,esc_crit,contact_strategy,
ack_completed) 
    values (rhn_strategies_recid_seq.nextval,'Escalate-OneAck',
    'Acked>0','Incomplete=0','Escalate','One');
insert into rhn_strategies(recid,name,comp_crit,esc_crit,contact_strategy,
ack_completed) 
    values (rhn_strategies_recid_seq.nextval,'Escalate-AllAck',
    'Acked=100','(Failed>50)|(Incomplete=0)','Escalate','All');
insert into rhn_strategies(recid,name,comp_crit,esc_crit,contact_strategy,
ack_completed) 
    values (rhn_strategies_recid_seq.nextval,'Broadcast-OneAck',
    'Acked>0',NULL,'Broadcast','One');
insert into rhn_strategies(recid,name,comp_crit,esc_crit,contact_strategy,
ack_completed) 
    values (rhn_strategies_recid_seq.nextval,'Broadcast-AllAck',
    'Acked=100',NULL,'Broadcast','All');
select rhn_strategies_recid_seq.nextval from dual; 
select rhn_strategies_recid_seq.nextval from dual;
select rhn_strategies_recid_seq.nextval from dual;
select rhn_strategies_recid_seq.nextval from dual;
select rhn_strategies_recid_seq.nextval from dual;
select rhn_strategies_recid_seq.nextval from dual;
insert into rhn_strategies(recid,name,comp_crit,esc_crit,contact_strategy,
ack_completed) 
    values (rhn_strategies_recid_seq.nextval,'Escalate-NoAck',
    'Sent>0','Failed>0|Incomplete>0','Escalate','No');
commit;

select 'rhnsat/tables/rhn_time_zone_names_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhn_time_zone_names_data.sql
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 10,'America/Anchorage','US/Alaska',-540,'1','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 20,'America/Chicago','US/Central',-360,'1','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 30,'America/Denver','US/Mountain',-420,'1','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 40,'America/Halifax','Canada/Atlantic',-240,'1','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 50,'America/Indianapolis','US/Indiana',-300,'0','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 60,'America/Los_Angeles','US/Pacific',-480,'1','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 70,'America/New_York','US/Eastern',-300,'1','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 80,'America/Phoenix','US/Arizona',-420,'0','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 90,'America/St_Johns','Canada/Newfoundland',-210,'1','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 100,'Europe/Bucharest','Europe/Eastern',120,'1','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 110,'Europe/Paris','Europe/Central',60,'1','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 120,'GMT','Greenwich Mean Time',0,'0','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 130,'Pacific/Honolulu','US/Hawaii',-600,'0','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 150,'America/Puerto_Rico','Puerto Rico',-240,'0','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 160,'Europe/Moscow','Europe/Moscow',180,'0','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 170,'Asia/Hong_Kong','Asia/Hong Kong',480,'0','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 180,'Asia/Shanghai','Asia/Shanghai',480,'0','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 190,'Asia/Singapore','Asia/Singapore',480,'0','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 200,'Asia/Taipei','Asia/Taipei',480,'0','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 210,'Asia/Seoul','Asia/Seoul',540,'0','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 220,'Asia/Tokyo','Asia/Tokyo',540,'0','system',
    sysdate);
insert into rhn_time_zone_names(recid,java_id,display_name,gmt_offset_minutes,
use_daylight_time,last_update_user,last_update_date) 
    values ( 230,'Australia/Sydney','Australia/Sydney',600,'0','system',
    sysdate);
commit;

select 'rhnsat/tables/state_change.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/state_change.sql
create table
state_change
(
    o_id       varchar2(64)
    	       constraint state_change_o_id_nn not null,
    entry_time number
               constraint state_change_etime_nn not null,
    data       varchar2(4000)
)
    enable row movement
  ;
create index state_change_oid_entry_idx
    on state_change(o_id, entry_time)
    tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/time_series.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/time_series.sql
create table
time_series
(
    o_id       varchar2(64)
    	       constraint time_series_o_id_nn not null,
    entry_time number
               constraint time_series_etime_nn not null,
    data       varchar2(1024)
)
    enable row movement
  ;
create index time_series_oid_entry_idx
    on time_series(o_id, entry_time)
    tablespace [[64k_tbs]]
  ;

select 'rhnsat/tables/valid_countries.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/valid_countries.sql
create table valid_countries (
    code       varchar2(2)    NOT NULL
                             CONSTRAINT valid_countries_pk
                             PRIMARY KEY,
    short_name varchar2(80) NOT NULL,
    name       varchar2(240)
)
	enable row movement
	;
insert into valid_countries(code,short_name,name) values ('AD','Andorra','Principality of Andorra');
insert into valid_countries(code,short_name,name) values ('AE','United Arab Emirates','United Arab Emirates');
insert into valid_countries(code,short_name,name) values ('AF','Afghanistan','Islamic State of Afghanistan');
insert into valid_countries(code,short_name,name) values ('AG','Antigua and Barbuda','Antigua and Barbuda (includes Redonda)');
insert into valid_countries(code,short_name,name) values ('AI','Anguilla','Anguilla');
insert into valid_countries(code,short_name,name) values ('AL','Albania','Republic of Albania');
insert into valid_countries(code,short_name,name) values ('AM','Armenia','Republic of Armenia');
insert into valid_countries(code,short_name,name) values ('AN','Netherlands Antilles','Netherlands Antilles (includes Bonaire, Curacao, Saba, St. Eustatius, and Southern St. Martin)');
insert into valid_countries(code,short_name,name) values ('AO','Angola','Republic of Angola');
insert into valid_countries(code,short_name,name) values ('AQ','Antarctica','Territory south of 60 degrees south latitude');
insert into valid_countries(code,short_name,name) values ('AR','Argentina','Argentine Republic');
insert into valid_countries(code,short_name,name) values ('AS','American Samoa','American Samoa');
insert into valid_countries(code,short_name,name) values ('AT','Austria','Republic of Austria');
insert into valid_countries(code,short_name,name) values ('AU','Australia','Australia (includes Lord Howe Island, Macquarie Islands, Ashmore Islands and Cartier Island, and Coral Sea Islands are Australian external territories)');
insert into valid_countries(code,short_name,name) values ('AW','Aruba','Aruba');
insert into valid_countries(code,short_name,name) values ('AZ','Azerbaijan','Azerbaijani Republic');
insert into valid_countries(code,short_name,name) values ('BA','Bosnia and Herzegovina','Republic of Bosnia and Herzegovina');
insert into valid_countries(code,short_name,name) values ('BB','Barbados','Barbados');
insert into valid_countries(code,short_name,name) values ('BD','Bangladesh','Bangladesh');
insert into valid_countries(code,short_name,name) values ('BE','Belgium','Kingdom of Belgium');
insert into valid_countries(code,short_name,name) values ('BF','Burkina Faso','Burma see Myanmar');
insert into valid_countries(code,short_name,name) values ('BG','Bulgaria','Republic of Bulgaria');
insert into valid_countries(code,short_name,name) values ('BH','Bahrain','State of Bahrain');
insert into valid_countries(code,short_name,name) values ('BI','Burundi','Republic of Burundi');
insert into valid_countries(code,short_name,name) values ('BJ','Benin','Republic of Benin');
insert into valid_countries(code,short_name,name) values ('BM','Bermuda','Bermuda');
insert into valid_countries(code,short_name,name) values ('BN','Brunei Darussalam','Brunei Darussalam');
insert into valid_countries(code,short_name,name) values ('BO','Bolivia','Republic of Bolivia');
insert into valid_countries(code,short_name,name) values ('BR','Brazil','Federative Republic of Brazil (includes Rocas, Fernando de Noronha Archipelago, Trindade, Ilhas Martim Vaz, and Sao Pedro e Sao Paulo)');
insert into valid_countries(code,short_name,name) values ('BS','Bahamas','Commonwealth of the Bahamas (Turks and Caicos Islands not included)');
insert into valid_countries(code,short_name,name) values ('BT','Bhutan','Kingdom of Bhutan');
insert into valid_countries(code,short_name,name) values ('BV','Bouvet Island','Bouvet Island (also called Bouvetoya)');
insert into valid_countries(code,short_name,name) values ('BW','Botswana','Republic of Botswana');
insert into valid_countries(code,short_name,name) values ('BY','Belarus','Republic of Belarus');
insert into valid_countries(code,short_name,name) values ('BZ','Belize','Belize');
insert into valid_countries(code,short_name,name) values ('CA','Canada','Canada');
insert into valid_countries(code,short_name,name) values ('CC','Cocos (Keeling) Islands','Cocos (Keeling) Islands');
insert into valid_countries(code,short_name,name) values ('CF','Central African Republic','Central African Republic');
insert into valid_countries(code,short_name,name) values ('CG','Congo','Republic of the Congo');
insert into valid_countries(code,short_name,name) values ('CH','Switzerland','Swiss Confederation');
insert into valid_countries(code,short_name,name) values ('CI','Cote d''Ivoire','Republic of Cote d''Ivoire');
insert into valid_countries(code,short_name,name) values ('CK','Cook Islands','Cook Islands');
insert into valid_countries(code,short_name,name) values ('CL','Chile','Republic of Chile (includes Easter Island, Juan Fernandez Islands, San Felix and Sala y Gomez)');
insert into valid_countries(code,short_name,name) values ('CM','Cameroon','Republic of Cameroon');
insert into valid_countries(code,short_name,name) values ('CN','China','People''s Republic of China');
insert into valid_countries(code,short_name,name) values ('CO','Colombia','Republic of Colombia (includes San Andres y Providencia, Malpelo Island, Roncador Bank, Serrana Bank and Serranilla Bank)');
insert into valid_countries(code,short_name,name) values ('CR','Costa Rica','Republic of Costa Rica (includes Cocos Island)');
insert into valid_countries(code,short_name,name) values ('CU','Cuba','Republic of Cuba');
insert into valid_countries(code,short_name,name) values ('CV','Cape Verde','Republic of Cape Verde (includes Boa Vista, Brava, Fogo, Maio, Sal,  Santo Antao, Sao Nicolau, Sao Tiago and Sao Vicente)');
insert into valid_countries(code,short_name,name) values ('CX','Christmas Island','Australian Christmas Island');
insert into valid_countries(code,short_name,name) values ('CY','Cyprus','Republic of Cyprus');
insert into valid_countries(code,short_name,name) values ('CZ','Czech Republic','Czech Republic');
insert into valid_countries(code,short_name,name) values ('DE','Germany','Federal Republic of Germany');
insert into valid_countries(code,short_name,name) values ('DJ','Djibouti','Republic of Djibouti');
insert into valid_countries(code,short_name,name) values ('DK','Denmark','Kingdom of Denmark');
insert into valid_countries(code,short_name,name) values ('DM','Dominica','Commonwealth of Dominica');
insert into valid_countries(code,short_name,name) values ('DO','Dominican Republic','Dominican Republic');
insert into valid_countries(code,short_name,name) values ('DZ','Algeria','People''s Democratic Republic of Algeria');
insert into valid_countries(code,short_name,name) values ('EC','Ecuador','Republic of Ecuador (includes Galapagos Islands (Archipelago de Colon))');
insert into valid_countries(code,short_name,name) values ('EE','Estonia','Republic of Estonia');
insert into valid_countries(code,short_name,name) values ('EG','Egypt','Arab Republic of Egypt');
insert into valid_countries(code,short_name,name) values ('EH','Western Sahara','Western Sahara');
insert into valid_countries(code,short_name,name) values ('ER','Eritrea','Eritrea');
insert into valid_countries(code,short_name,name) values ('ES','Spain','Kingdom of Spain');
insert into valid_countries(code,short_name,name) values ('ET','Ethiopia','Ethiopia');
insert into valid_countries(code,short_name,name) values ('FI','Finland','Republic of Finland');
insert into valid_countries(code,short_name,name) values ('FJ','Fiji','Fiji');
insert into valid_countries(code,short_name,name) values ('FK','Falkland Islands (Malvinas)','Falkland Islands (Malvinas) (includes West Falkland, and East Falkland)');
insert into valid_countries(code,short_name,name) values ('FM','Micronesia (Federated States of)','Caroline Islands except Palau (includes Yap, Chuuk, Pohnpei, Kosrae)');
insert into valid_countries(code,short_name,name) values ('FO','Faroe Islands','Faroe Islands');
insert into valid_countries(code,short_name,name) values ('FR','France','French Republic');
insert into valid_countries(code,short_name,name) values ('FX','France, Metropolitan','France, Metropolitan');
insert into valid_countries(code,short_name,name) values ('GA','Gabon','Gabonese Republic');
insert into valid_countries(code,short_name,name) values ('GB','United Kingdom','United Kingdom of Great Britain and Northern Ireland (includes Orkney Islands and Shetland Island)');
insert into valid_countries(code,short_name,name) values ('GD','Grenada','Grenada (includes Southern Grenadine Islands)');
insert into valid_countries(code,short_name,name) values ('GE','Georgia','Republic of Georgia');
insert into valid_countries(code,short_name,name) values ('GF','French Guiana','Department of Guiana');
insert into valid_countries(code,short_name,name) values ('GH','Ghana','Republic of Ghana');
insert into valid_countries(code,short_name,name) values ('GI','Gibraltar','Gibraltar');
insert into valid_countries(code,short_name,name) values ('GL','Greenland','Greenland');
insert into valid_countries(code,short_name,name) values ('GM','Gambia','Republic of the Gambia');
insert into valid_countries(code,short_name,name) values ('GN','Guinea','Republic of Guinea');
insert into valid_countries(code,short_name,name) values ('GP','Guadeloupe','Department of Guadeloupe (includes Grande Terre, Basse Terre, Marie Galante, Les Saintes, Iles de la Petite Terre, Desirade, Saint-Barthelemy, and Northern St. Martin)');
insert into valid_countries(code,short_name,name) values ('GQ','Equatorial Guinea','Republic of Equatorial Guinea (includes Rio Muni, Bioko, Annobon, Corisco, Elobey Chico, and Elobey Grande)');
insert into valid_countries(code,short_name,name) values ('GR','Greece','Hellenic Republic (includes Aegean Islands, Ionian Islands, Dodecanese Islands, Crete, and Mount Athos autonomous area)');
insert into valid_countries(code,short_name,name) values ('GS','South Georgia and the South Sandwich Island','South Georgia and the South Sandwich Island');
insert into valid_countries(code,short_name,name) values ('GT','Guatemala','Republic of Guatemala');
insert into valid_countries(code,short_name,name) values ('GU','Guam','Guam');
insert into valid_countries(code,short_name,name) values ('GW','Guinea-Bissau','Republic of Guinea-Bissau');
insert into valid_countries(code,short_name,name) values ('GY','Guyana','Republic of Guyana');
insert into valid_countries(code,short_name,name) values ('HK','Hong Kong','Hong Kong (also called Hisiangkang, or Xianggang)');
insert into valid_countries(code,short_name,name) values ('HM','Heard Island and McDonald Islands','Heard Island and McDonald Islands');
insert into valid_countries(code,short_name,name) values ('HN','Honduras','Republic of Honduras (includes Swan Islands)');
insert into valid_countries(code,short_name,name) values ('HR','Croatia','Republic of Croatia');
insert into valid_countries(code,short_name,name) values ('HT','Haiti','Republic of Haiti');
insert into valid_countries(code,short_name,name) values ('HU','Hungary','Republic of Hungary');
insert into valid_countries(code,short_name,name) values ('ID','Indonesia','Republic of Indonesia');
insert into valid_countries(code,short_name,name) values ('IE','Ireland','Ireland');
insert into valid_countries(code,short_name,name) values ('IL','Israel','State of Israel');
insert into valid_countries(code,short_name,name) values ('IN','India','Republic of India (includes Amindivis, Laccadives, Minicoy, Andaman Islands, Nicobar Islands, and Sikkim)');
insert into valid_countries(code,short_name,name) values ('IO','British Indian Ocean Territory','Chagos Archipelago');
insert into valid_countries(code,short_name,name) values ('IQ','Iraq','Republic of Iraq');
insert into valid_countries(code,short_name,name) values ('IR','Iran (Islamic Republic of)','Islamic Republic of Iran');
insert into valid_countries(code,short_name,name) values ('IS','Iceland','Republic of Iceland');
insert into valid_countries(code,short_name,name) values ('IT','Italy','Italian Republic');
insert into valid_countries(code,short_name,name) values ('JM','Jamaica','Jamaica (includes Morant Cays, and Pedro Cays)');
insert into valid_countries(code,short_name,name) values ('JO','Jordan','Hashemite Kingdom of Jordan');
insert into valid_countries(code,short_name,name) values ('JP','Japan','Japan');
insert into valid_countries(code,short_name,name) values ('KE','Kenya','Republic of Kenya');
insert into valid_countries(code,short_name,name) values ('KG','Kyrgyzstan','Kyrgyz Republic');
insert into valid_countries(code,short_name,name) values ('KH','Cambodia','Kingdom of Cambodia');
insert into valid_countries(code,short_name,name) values ('KI','Kiribati','Kiribati (includes Fanning Island, Washington Island, and Christmas Island (all in the Line Islands), Ocean Island, Phoenix Islands (Birnie, Gardner, Hull, McKean, Phoenix, Sydney, Canton and Enderbury))');
insert into valid_countries(code,short_name,name) values ('KM','Comoros','Islamic Federal Republic of the Comoros (includes Anjouan, Grande Comore, Moheli, and other islands)');
insert into valid_countries(code,short_name,name) values ('KN','Saint Kitts and Nevis','Saint Kitts and Nevis');
insert into valid_countries(code,short_name,name) values ('KP','Korea, Democratic People''s Republic of','Korea, Democratic People''s Republic of');
insert into valid_countries(code,short_name,name) values ('KR','Korea, Republic of','Korea, Republic of');
insert into valid_countries(code,short_name,name) values ('KW','Kuwait','State of Kuwait');
insert into valid_countries(code,short_name,name) values ('KY','Cayman Islands','Cayman Islands (includes Grand Cayman, Cayman Brac and Little Cayman)');
insert into valid_countries(code,short_name,name) values ('KZ','Kazakhstan','Republic of Kazakhstan');
insert into valid_countries(code,short_name,name) values ('LA','Lao People''s Democratic Republic','Lao People''s Democratic Republic');
insert into valid_countries(code,short_name,name) values ('LB','Lebanon','Lebanese Republic');
insert into valid_countries(code,short_name,name) values ('LC','Saint Lucia','Saint Lucia');
insert into valid_countries(code,short_name,name) values ('LI','Liechtenstein','Principality of Liechtenstein');
insert into valid_countries(code,short_name,name) values ('LK','Sri Lanka','Democratic Socialist Republic of Sri Lanka');
insert into valid_countries(code,short_name,name) values ('LR','Liberia','Republic of Liberia');
insert into valid_countries(code,short_name,name) values ('LS','Lesotho','Kingdom of Lesotho');
insert into valid_countries(code,short_name,name) values ('LT','Latin America','Latin America');
insert into valid_countries(code,short_name,name) values ('LU','Luxembourg','Grand Duchy of Luxembourg');
insert into valid_countries(code,short_name,name) values ('LV','Latvia','Republic of Latvia');
insert into valid_countries(code,short_name,name) values ('LX','Lithuania','Republic of Lithuania');
insert into valid_countries(code,short_name,name) values ('LY','Libyan Arab Jamahiriya','Socialist People''s Libyan Arab Jamahiriya');
insert into valid_countries(code,short_name,name) values ('MA','Morocco','Kingdom of Morocco');
insert into valid_countries(code,short_name,name) values ('MC','Monaco','Principality of Monaco');
insert into valid_countries(code,short_name,name) values ('MD','Moldova, Republic of','Republic of Moldova');
insert into valid_countries(code,short_name,name) values ('MG','Madagascar','Republic of Madagascar');
insert into valid_countries(code,short_name,name) values ('MH','Marshall Islands','Republic of the Marshall Islands');
insert into valid_countries(code,short_name,name) values ('MK','Macedonia','Macedonia, the Former Yugoslav Republic of');
insert into valid_countries(code,short_name,name) values ('ML','Mali','Republic of Mali');
insert into valid_countries(code,short_name,name) values ('MM','Myanmar','Union of Myanmar');
insert into valid_countries(code,short_name,name) values ('MN','Mongolia','Mongolia');
insert into valid_countries(code,short_name,name) values ('MO','Macau','Macau (also called Ao-men)');
insert into valid_countries(code,short_name,name) values ('MP','Northern Mariana Islands','Commonwealth of the Northern Mariana Islands except Guam');
insert into valid_countries(code,short_name,name) values ('MQ','Martinique','Department of Martinique');
insert into valid_countries(code,short_name,name) values ('MR','Mauritania','Islamic Republic of Mauritania');
insert into valid_countries(code,short_name,name) values ('MS','Montserrat','Montserrat');
insert into valid_countries(code,short_name,name) values ('MT','Malta','Republic of Malta');
insert into valid_countries(code,short_name,name) values ('MU','Mauritius','Republic of Mauritius (includes Rodrigues, Agalega Islands, and Cargados Carajos)');
insert into valid_countries(code,short_name,name) values ('MV','Maldives','Republic of Maldives');
insert into valid_countries(code,short_name,name) values ('MW','Malawi','Republic of Malawi');
insert into valid_countries(code,short_name,name) values ('MX','Mexico','United Mexican States');
insert into valid_countries(code,short_name,name) values ('MY','Malaysia','Malaysia (includes Peninsular Malaysia, Sabah, and Sarawak)');
insert into valid_countries(code,short_name,name) values ('MZ','Mozambique','Republic of Mozambique');
insert into valid_countries(code,short_name,name) values ('NA','Namibia','Republic of Namibia');
insert into valid_countries(code,short_name,name) values ('NC','New Caledonia','New Caledonia (includes Isle of Pines, Loyalty Islands, Huon Islands,  Belep Archipelago, Chesterfield Islands, and Walpole)');
insert into valid_countries(code,short_name,name) values ('NE','Niger','Republic of the Niger');
insert into valid_countries(code,short_name,name) values ('NF','Norfolk Island','Norfolk Island');
insert into valid_countries(code,short_name,name) values ('NG','Nigeria','Federal Republic of Nigeria');
insert into valid_countries(code,short_name,name) values ('NI','Nicaragua','Republic of Nicaragua');
insert into valid_countries(code,short_name,name) values ('NL','Netherlands','Kingdom of the Netherlands');
insert into valid_countries(code,short_name,name) values ('NO','Norway','Kingdom of Norway');
insert into valid_countries(code,short_name,name) values ('NP','Nepal','Kingdom of Nepal');
insert into valid_countries(code,short_name,name) values ('NR','Nauru','Republic of Nauru');
insert into valid_countries(code,short_name,name) values ('NU','Niue','Niue');
insert into valid_countries(code,short_name,name) values ('NZ','New Zealand','New Zealand (includes Antipodes Islands, Auckland Islands, Bounty Islands, Campbell Islands, Kermadec Islands, Chatham Islands, and Snares Islands)');
insert into valid_countries(code,short_name,name) values ('OM','Oman','Sultanate of Oman');
insert into valid_countries(code,short_name,name) values ('PA','Panama','Republic of Panama');
insert into valid_countries(code,short_name,name) values ('PE','Peru','Republic of Peru');
insert into valid_countries(code,short_name,name) values ('PF','French Polynesia','French Polynesia (includes Society Archipelago, Tuamotu Archipelago, Marquezas Islands, Bambier Islands, Austral Islands, and Clipperton Island)');
insert into valid_countries(code,short_name,name) values ('PG','Papua New Guinea','Papua New Guinea (includes Bismarck and Louisiade Archipelagos, Admiralty Islands, d''Entrecasteaux Islands, Northern Solomon Islands, Trobriand Islands, New Britain, New Ireland, Woodlark, and associated islands)');
insert into valid_countries(code,short_name,name) values ('PH','Philippines','Republic of the Philippines');
insert into valid_countries(code,short_name,name) values ('PK','Pakistan','Islamic Republic of Pakistan');
insert into valid_countries(code,short_name,name) values ('PL','Poland','Republic of Poland');
insert into valid_countries(code,short_name,name) values ('PM','Saint Pierre and Miquelon','Territorial collectivity of St. Pierre and Miquelon');
insert into valid_countries(code,short_name,name) values ('PN','Pitcairn','Pitcairn (includes Henderson, Ducie, and Oeno)');
insert into valid_countries(code,short_name,name) values ('PR','Puerto Rico','Puerto Rico');
insert into valid_countries(code,short_name,name) values ('PT','Portugal','Portuguese Republic');
insert into valid_countries(code,short_name,name) values ('PW','Palau','Republic of Palau');
insert into valid_countries(code,short_name,name) values ('PY','Paraguay','Republic of Paraguay');
insert into valid_countries(code,short_name,name) values ('QA','Qatar','State of Qatar');
insert into valid_countries(code,short_name,name) values ('RE','Reunion','Department of Reunion');
insert into valid_countries(code,short_name,name) values ('RO','Romania','Romania');
insert into valid_countries(code,short_name,name) values ('RU','Russian Federation','Russian Federation');
insert into valid_countries(code,short_name,name) values ('RW','Rwanda','Rwandese Republic');
insert into valid_countries(code,short_name,name) values ('SA','Saudi Arabia','Kingdom of Saudi Arabia');
insert into valid_countries(code,short_name,name) values ('SB','Solomon Islands','Solomon Islands (includes Southern Solomon Islands, primarily Guadalcanal, Malaita, San Cristobal, Santa Isabel, Choiseul)');
insert into valid_countries(code,short_name,name) values ('SC','Seychelles','Republic of Seychelles (includes Alphonse, Bijoutier, St. Francois Islands, St. Pierre Islet, Cosmoledo Islands, Amirantes, Aldabra, Farquhar, and Desroches)');
insert into valid_countries(code,short_name,name) values ('SD','Sudan','Republic of the Sudan');
insert into valid_countries(code,short_name,name) values ('SG','Singapore','Singapore');
insert into valid_countries(code,short_name,name) values ('SH','Saint Helena','Saint Helena (includes Ascension, Gough Island, Inaccessible, Nightingale Islands, and Tristan da Cunha)');
insert into valid_countries(code,short_name,name) values ('SI','Slovenia','Republic of Slovenia');
insert into valid_countries(code,short_name,name) values ('SJ','Svalbard and Jan Mayen Islands','Svalbard and Jan Mayen Islands (includes Bear Island)');
insert into valid_countries(code,short_name,name) values ('SK','Slovakia','Slovak Republic');
insert into valid_countries(code,short_name,name) values ('SL','Sierra Leone','Republic of Sierra Leone');
insert into valid_countries(code,short_name,name) values ('SM','San Marino','Republic of San Marino');
insert into valid_countries(code,short_name,name) values ('SN','Senegal','Republic of Senegal');
insert into valid_countries(code,short_name,name) values ('SO','Somalia','Somali Democratic Republic');
insert into valid_countries(code,short_name,name) values ('SR','Suriname','Republic of Suriname');
insert into valid_countries(code,short_name,name) values ('ST','Sao Tome and Principe','Democratic Republic of Sao Tome and Principe');
insert into valid_countries(code,short_name,name) values ('SV','El Salvador','Republic of El Salvador');
insert into valid_countries(code,short_name,name) values ('SY','Syrian Arab Republic','Syrian Arab Republic');
insert into valid_countries(code,short_name,name) values ('SZ','Swaziland','Kingdom of Swaziland');
insert into valid_countries(code,short_name,name) values ('TC','Turks and Caicos Islands','Turks and Caicos Islands');
insert into valid_countries(code,short_name,name) values ('TD','Chad','Republic of Chad');
insert into valid_countries(code,short_name,name) values ('TF','French Southern Territories','French Southern Territories (includes Kerguelen Islands, Amsterdam, St. Paul, Crozet Islands)');
insert into valid_countries(code,short_name,name) values ('TG','Togo','Togolese Republic');
insert into valid_countries(code,short_name,name) values ('TH','Thailand','Kingdom of Thailand');
insert into valid_countries(code,short_name,name) values ('TJ','Tajikistan','Republic of Tajikistan');
insert into valid_countries(code,short_name,name) values ('TK','Tokelau','Tokelau');
insert into valid_countries(code,short_name,name) values ('TM','Turkmenistan','Turkmenistan');
insert into valid_countries(code,short_name,name) values ('TN','Tunisia','Republic of Tunisia');
insert into valid_countries(code,short_name,name) values ('TO','Tonga','Kingdom of Tonga');
insert into valid_countries(code,short_name,name) values ('TP','East Timor','East Timor (includes the exclave of Oe-Cussi)');
insert into valid_countries(code,short_name,name) values ('TR','Turkey','Republic of Turkey');
insert into valid_countries(code,short_name,name) values ('TT','Trinidad and Tobago','Republic of Trinidad and Tobago');
insert into valid_countries(code,short_name,name) values ('TV','Tuvalu','Tuvalu (includes Funafuti, Nanumanga, Nui, Nanomea, Nurakita, Niutao, Nukufetau, Nukulaelae, and Vaitupu)');
insert into valid_countries(code,short_name,name) values ('TW','Taiwan, Republic of China','Taiwan, Republic of China');
insert into valid_countries(code,short_name,name) values ('TZ','Tanzania, United Republic of','United Republic of Tanzania (includes Zanzibar and Pemba)');
insert into valid_countries(code,short_name,name) values ('UA','Ukraine','Ukraine');
insert into valid_countries(code,short_name,name) values ('UG','Uganda','Republic of Uganda');
insert into valid_countries(code,short_name,name) values ('UM','United States Minor Outlying Islands','United States Minor Outlying Islands (includes i.a. Baker Island, Howland Island, Jarvis Island, Johnston Atoll, Kingman Reef, Midway Islands,  Palmyra Islands, and Wake Island)');
insert into valid_countries(code,short_name,name) values ('US','United States','United States of America');
insert into valid_countries(code,short_name,name) values ('UY','Uruguay','Eastern Republic of Uruguay');
insert into valid_countries(code,short_name,name) values ('UZ','Uzbekistan','Republic of Uzbekistan');
insert into valid_countries(code,short_name,name) values ('VA','Vatican City State (Holy See)','Vatican City State (Holy See)');
insert into valid_countries(code,short_name,name) values ('VC','Saint Vincent and the Grenadines','Saint Vincent and the Grenadines (includes Northern Grenadine Islands)');
insert into valid_countries(code,short_name,name) values ('VE','Venezuela','Republic of Venezuela');
insert into valid_countries(code,short_name,name) values ('VG','Virgin Islands (British)','Virgin Islands (British) (includes Anegada, Jost Van Dyke, Tortola, and Virgin Gorda)');
insert into valid_countries(code,short_name,name) values ('VI','Virgin Islands (U.S.)','Virgin Islands of the United States (includes Saint Croix, Saint John, and Saint Thomas)');
insert into valid_countries(code,short_name,name) values ('VN','Viet Nam','Socialist Republic of Viet Nam');
insert into valid_countries(code,short_name,name) values ('VU','Vanuatu','Republic of Vanuatu');
insert into valid_countries(code,short_name,name) values ('WF','Wallis and Futuna Islands','Wallis and Futuna Islands (includes Iles Wallis (Uvea), and Iles de Hoorn (Futuna and Alofi))');
insert into valid_countries(code,short_name,name) values ('WS','Samoa','Independent State of Western Samoa');
insert into valid_countries(code,short_name,name) values ('YE','Yemen','Republic of Yemen (includes Perim, Kamaran, Socotra, and associated islands)');
insert into valid_countries(code,short_name,name) values ('YT','Mayotte','Territorial collectivity of Mayotte (includes Grande-Terre, and Pamandzi)');
insert into valid_countries(code,short_name,name) values ('YU','Yugoslavia','Federal Republic of Yugoslavia');
insert into valid_countries(code,short_name,name) values ('ZA','South Africa','Republic of South Africa (includes Walvis Bay, Marion Island, and Prince  Edward Island)');
insert into valid_countries(code,short_name,name) values ('ZM','Zambia','Republic of Zambia');
insert into valid_countries(code,short_name,name) values ('ZR','Zaire','Republic of Zaire');
insert into valid_countries(code,short_name,name) values ('ZW','Zimbabwe','Republic of Zimbabwe');
insert into valid_countries(code,short_name,name) values ('SE','Sweden','Kingom of Sweden');
create table valid_countries_tl (
    lang          char(2)     NOT NULL,
    code          varchar2(2)  NOT NULL
			      CONSTRAINT valid_countries_tl_code
                                REFERENCES valid_countries(code),
    short_name_tl varchar2(80) NOT NULL,
                              CONSTRAINT valid_countries_tl_unq
                                UNIQUE (lang, code)
);
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AD','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AE','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AF','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AG','????????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AI','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AL','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AM','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AN','???????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AO','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AQ','Antarctica');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AR','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AS','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AT','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AU','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AW','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','AZ','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BA','????????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BB','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BD','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BE','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BF','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BG','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BH','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BI','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BJ','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BM','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BN','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BO','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BR','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BS','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BT','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BV','Bouvet Island');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BW','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BY','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','BZ','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CA','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CC','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CF','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CG','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CH','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CI','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CK','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CL','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CM','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CN','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CO','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CR','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CU','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CV','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CX','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CY','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','CZ','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','DE','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','DJ','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','DK','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','DM','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','DO','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','DZ','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','EC','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','EE','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','EG','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','EH','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ER','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ES','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ET','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FI','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FJ','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FK','?????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FM','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FO','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FR','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','FX','France, Metropolitan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GA','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GB','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GD','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GE','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GF','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GH','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GI','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GL','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GM','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GN','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GP','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GQ','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GR','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GS','S. Georgia and S. Sandwich Isls.');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GT','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GU','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GW','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','GY','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','HK','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','HM','Heard and McDonald Islands');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','HN','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','HR','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','HT','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','HU','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ID','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IE','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IL','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IN','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IO','British Indian Ocean Territory');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IQ','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IR','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IS','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','IT','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','JM','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','JO','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','JP','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KE','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KG','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KH','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KI','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KM','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KN','Saint Kitts and Nevis');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KP','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KR','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KW','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KY','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','KZ','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LA','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LB','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LC','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LI','?????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LK','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LR','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LS','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LT','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LU','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LV','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','LY','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MA','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MC','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MD','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MG','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MH','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MK','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ML','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MM','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MN','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MO','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MP','Northern Mariana Islands');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MQ','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MR','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MS','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MT','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MU','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MV','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MW','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MX','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MY','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','MZ','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NA','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NC','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NE','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NF','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NG','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NI','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NL','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NO','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NP','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NR','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NU','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','NZ','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','OM','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PA','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PE','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PF','??????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PG','?????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PH','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PK','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PL','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PM','?????????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PN','Pitcairn');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PR','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PT','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PW','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','PY','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','QA','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','RE','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','RO','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','RU','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','RW','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SA','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SB','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SC','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SD','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SE','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SG','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SH','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SI','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SJ','Svalbard and Jan Mayen Islands');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SK','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SL','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SM','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SN','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SO','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SR','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ST','??????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SV','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SY','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','SZ','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TC','?????????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TD','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TF','French Southern Territories');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TG','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TH','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TJ','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TK','Tokelau');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TM','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TN','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TO','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TP','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TR','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TT','??????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TV','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TW','??');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','TZ','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','UA','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','UG','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','UM','US Minor Outlying Islands');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','US','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','UY','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','UZ','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VA','??????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VC','????????????????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VE','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VG','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VI','????????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VN','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','VU','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','WF','Wallis and Futuna Islands');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','WS','???');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','YE','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','YT','Mayotte');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','YU','???????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ZA','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ZM','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ZR','????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('ja','ZW','?????');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AD','Andorra');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AE','Vereinigte Arabische Emirate');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AF','Afghanistan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AG','Antigua und Barbuda');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AI','Anguilla');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AL','Albanien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AM','Armenien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AN','Niederlandische Antillen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AO','Angola');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AQ','Antarktika');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AR','Argentinien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AS','Ostsamoa');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AT','osterreich');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AU','Australien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AW','Aruba');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','AZ','Aserbaidschan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BA','Bosnien-Herzegovina');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BB','Barbados');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BD','Bangladesch');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BE','Belgien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BF','Burkina Faso');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BG','Bulgarien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BH','Bahrain');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BI','Burundi');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BJ','Benin');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BM','Bermuda-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BN','Brunei');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BO','Bolivien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BR','Brazilien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BS','Bahamas');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BT','Bhutan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BV','Bouvet Insel');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BW','Botswana');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BY','Wei?ru?land');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','BZ','Belize');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CA','Kanada');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CC','Kokos-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CF','Zentral Afrikanische Republik');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CG','Kongo');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CH','Schweiz');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CI','Elfenbeinkuste');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CK','Cook-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CL','Chile');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CM','Kamerun');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CN','China');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CO','Kolumbien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CR','Costa Rica');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CU','Kuba');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CV','Kap Verde');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CX','Weihnachtsinsel');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CY','Zypern');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','CZ','Tschechische Republik');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','DE','Deutschland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','DJ','Dschibuti');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','DK','Danemark');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','DM','Dominica');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','DO','Dominikanische Republik');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','DZ','Algerien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','EC','Ecuador');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','EE','Estland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','EG','agypten');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','EH','(West) Sahara');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ER','Eritrea');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ES','Spanien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ET','athiopien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FI','Finnland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FJ','Fidschi');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FK','Falkland-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FM','Mikronesien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FO','Faroer');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FR','Frankreich');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','FX','Frankreich (Europaisches Territorium)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GA','Gabun');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GB','Gro?britannien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GD','Grenada');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GE','Georgien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GF','Franzosisch Guayana');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GH','Ghana');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GI','Gibraltar');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GL','Gronland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GM','Gambia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GN','Guinea Bissau');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GP','Guadeloupe (Franzosisch)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GQ','Guinea');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GR','Griechenland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GS','S. Georgia und S. Sandwich Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GT','Guatemala');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GU','Guam (USA)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GW','Guinea Bissau');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','GY','Guyana');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','HK','Hong Kong');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','HM','Heard und McDonald Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','HN','Honduras');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','HR','Kroatien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','HT','Haiti');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','HU','Ungarn');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ID','Indonesien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IE','Irland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IL','Israel');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IN','Indien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IO','Britisches Indischer Ozean Territorium');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IQ','Irak');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IR','Iran');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IS','Island');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','IT','Italien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','JM','Jamaica');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','JO','Jordanien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','JP','Japan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KE','Kenia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KG','Kirgizstan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KH','Kambodscha');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KI','Kiribati');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KM','Komoren');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KN','Saint Kitts und Nevis Anguilla');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KP','Nordkorea');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KR','Sudkorea');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KW','Kuwait');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KY','Cayman-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','KZ','Kasachstan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LA','Laos');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LB','Libanon');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LC','Saint Lucia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LI','Liechtenstein');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LK','Sri Lanka');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LR','Liberia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LS','Lesotho');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LT','Litauen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LU','Luxemburg');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LV','Lettland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','LY','Libyen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MA','Marokko');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MC','Monaco');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MD','Moldawien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MG','Madagakar');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MH','Marshall-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MK','Mazedonien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ML','Mali');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MM','Myanmar');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MN','Mongolien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MO','Macau');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MP','Nordlichen Mariana-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MQ','Martinique (Franzosisch)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MR','Mauritanien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MS','Montserrat');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MT','Malta');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MU','Mauritius');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MV','Malediven');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MW','Malawi');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MX','Mexico');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MY','Malaysia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','MZ','Mosambik');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NA','Namibia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NC','Neukaledonien (Franzosisch)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NE','Niger');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NF','Norfolk-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NG','Nigeria');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NI','Nicaragua');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NL','Niederlande');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NO','Norwegen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NP','Nepal');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NR','Nauru');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NU','Niue');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','NZ','Neuseeland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','OM','Oman');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PA','Panama');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PE','Peru');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PF','Polynesien (Franzosisch)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PG','Papua Neuguinea');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PH','Philippinen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PK','Pakistan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PL','Polen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PM','Saint Pierre und Miquelon');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PN','Pitcairn-Insel');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PR','Puerto Rico');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PT','Portugal');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PW','Palau');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','PY','Paraguay');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','QA','Qatar');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','RE','Reunion (Franzosisch)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','RO','Rumanien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','RU','Russische Foderation');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','RW','Rwanda');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SA','Saudi-Arabien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SB','Solomon-Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SC','Seychellen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SD','Sudan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SE','Schweden');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SG','Singapur');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SH','St. Helena');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SI','Slowenien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SJ','Svalbard und Jan Mayen Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SK','Slowakische Republik');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SL','Sierra Leone');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SM','San Marino');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SN','Senegal');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SO','Somalia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SR','Surinam');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ST','St. Tome und Principe');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SV','El Salvador');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SY','Syrien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','SZ','Swasiland');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TC','Turks und Caicos Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TD','Tschad');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TF','Franzosische Sud Territorien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TG','Togo');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TH','Thailand');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TJ','Tadschikistan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TK','Tokelau');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TM','Turkmenistan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TN','Tunisien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TO','Tonga');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TP','Osttimor');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TR','Turkei');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TT','Trinidad und Tobago');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TV','Tuvalu');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TW','Taiwan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','TZ','Tansania');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','UA','Ukraine');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','UG','Uganda');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','UM','USA Kleinere Exterritoriale Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','US','Vereinigte Staaten');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','UY','Uruguay');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','UZ','Usbekistan');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VA','Vatikan Staat');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VC','St. Vincent');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VE','Venezuela');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VG','Virgin-Inseln (Britisch)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VI','Virgin-Inseln (USA)');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VN','Vietnam');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','VU','Vanuatu');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','WF','Wallis und Futuna Inseln');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','WS','Westsamoa');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','YE','Jemen');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','YT','Mayotte');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','YU','Jugoslawien');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ZA','Sudafrika');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ZM','Sambia');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ZR','Ehemaliges Zaire');
insert into valid_countries_tl(lang,code,short_name_tl) values ('de','ZW','Simbabwe');
commit;

select 'rhnsat/tables/web_contact_indexes.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/web_contact_indexes.sql
create index web_contact_oid_id
	on web_contact(org_id, id)
	parallel 6
	tablespace [[web_index_tablespace_2]]
  ;
create index web_contact_id_oid_cust_luc on
	web_contact(id,oracle_contact_id,org_id,login_uc)
	parallel 6
	tablespace [[web_index_tablespace_2]]
  ;

select 'rhnsat/tables/web_contact_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/web_contact_triggers.sql
create or replace trigger
web_contact_mod_trig
before insert or update on web_contact
for each row
begin
        :new.modified := sysdate;
        :new.login_uc := UPPER(:new.login);
        IF :new.password <> :old.password THEN
                :new.old_password := :old.password;
        END IF;
end;
/
show errors

select 'rhnsat/tables/web_customer_notification.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/web_customer_notification.sql
create sequence web_cust_notif_seq start with 1000000;
create table
web_customer_notification
(
	id			number
				constraint web_cust_not_id_nn not null
				constraint web_cust_not_id_pk primary key
					using index tablespace [[64k_tbs]],
	org_id			number
				constraint web_cust_not_oid_nn not null
				constraint web_cust_not_oid_fk
					references web_customer(id)
					on delete cascade,
	contact_email_address	varchar2(150)
				constraint web_cust_not_ea_nn not null,
	creation_date		date
				constraint web_cust_not_creat_nn not null
)
	enable row movement
	 ;

select 'rhnsat/tables/web_customer_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/web_customer_triggers.sql
create or replace trigger
web_customer_mod_trig
before insert or update on web_customer
for each row
begin
        :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/tables/web_user_contact_permission.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/web_user_contact_permission.sql
create table
web_user_contact_permission
(
	web_user_id		number
				constraint wucp_wuid_nn not null
				constraint contperm_wbuserid_fk
					references web_contact(id)
					on delete cascade,
	email			char(1) default('N')
				constraint wucp_email_ck
					check (email in ('Y','N')),
	mail			char(1) default('N')
				constraint wucp_mail_ck
					check (mail in ('Y','N')),
	call			char(1) default('N')
				constraint wucp_call_ck
					check (call in ('Y','N')),
	fax			char(1) default('N')
				constraint wucp_fax_ck
					check (fax in ('Y','N')),
	created			date default(sysdate)
				constraint wucp_created_nn not null,
	modified		date default(sysdate)
				constraint wucp_modified_nn not null
)
	enable row movement
	;
create or replace trigger
web_user_cp_timestamp
BEFORE INSERT OR UPDATE ON web_user_contact_permission
FOR EACH ROW
BEGIN
  :new.modified := sysdate;
END;
/
show errors

select 'rhnsat/tables/web_user_contact_permission_triggers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/web_user_contact_permission_triggers.sql
create or replace trigger
web_user_pi_timestamp
BEFORE INSERT OR UPDATE ON web_user_personal_info
FOR EACH ROW
BEGIN
  :new.modified := sysdate;
END;
/
show errors

select 'rhnsat/tables/web_user_site_type.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/web_user_site_type.sql
create table
web_user_site_type
(
	type			char(1)
				constraint wust_type_nn not null
				constraint wust_type_pk primary key,
	description		varchar2(64)
				constraint wust_desc_nn not null
)
	enable row movement
	;
insert into WEB_USER_SITE_TYPE VALUES('M', 'MARKET');
insert into WEB_USER_SITE_TYPE VALUES('B', 'BILL_TO');
insert into WEB_USER_SITE_TYPE VALUES('S', 'SHIP_TO');
insert into WEB_USER_SITE_TYPE VALUES('R', 'SERVICE');

select 'rhnsat/tables/web_user_site_info.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/web_user_site_info.sql
create table
web_user_site_info
(
	id			number
				constraint wusi_id_nn not null
				constraint wusi_id_pk primary key,
	web_user_id		number
				constraint wusi_wuid_fk
					references web_contact(id)
					on delete cascade,
	email			varchar2(128),
	email_uc		varchar2(128),
	alt_first_names		varchar2(128),
	alt_last_name		varchar2(128),
	address1		varchar2(128)
				constraint wusi_addr1_nn not null,
	address2		varchar2(128),
	address3		varchar2(128),
	address4		varchar2(128),
	city			varchar2(128)
				constraint wusi_city_nn not null,
	state			varchar2(64),
	zip			varchar2(64),
	country			char(2)
				constraint wusi_country_nn not null,
	phone			varchar2(32),
	fax			varchar2(32),
	url			varchar2(128),
	is_po_box		char(1) default '0'
				constraint wusi_ipb_ck
					check (is_po_box in ('1','0')),
	type			char(1)
				constraint wusi_type_fk
					references web_user_site_type(type),
	oracle_site_id		varchar2(32),
	notes			varchar2(2000),
	created			date default(sysdate),
	modified		date default(sysdate),
	alt_first_names_ol	varchar2(128),
	alt_last_name_ol	varchar2(128),
	address1_ol		varchar2(128),
	address2_ol		varchar2(128),
	address3_ol		varchar2(128),
	city_ol			varchar2(128),
	state_ol		varchar2(32),
	zip_ol			varchar2(32)
)
	enable row movement
	;
create sequence web_user_site_info_id_seq;
create index web_user_site_info_wuid 
    on web_user_site_info(web_user_id)
    parallel 6;
create index wusi_email_uc_idx
    on web_user_site_info ( email_uc );
create or replace trigger
web_user_si_timestamp
before insert or update on web_user_site_info
for each row
begin
  :new.email_uc := upper(:new.email);
  :new.modified := sysdate;
end;
/
show errors

select 'rhnsat/views/rhnActionOverview.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnActionOverview.sql
CREATE OR REPLACE VIEW
rhnActionOverview
(
	org_id,
	action_id,
	type_id,
	type_name,
	name,
    	scheduler,
	scheduler_login,
	earliest_action,
	total_count,
	successful_count,
	failed_count,
	in_progress_count,
	archived
)
AS
SELECT    A.org_id,
	  A.id,
	  AT.id,
	  AT.name,
	  A.name,
	  A.scheduler,
	  U.login,
	  A.earliest_action,
	  (SELECT COUNT(*) FROM rhnServerAction WHERE action_id = A.id),
	  (SELECT COUNT(*) FROM rhnServerAction WHERE action_id = A.id AND status = 2), -- XXX: don''t hard code status here :)
	  (SELECT COUNT(*) FROM rhnServerAction WHERE action_id = A.id AND status = 3),
	  (SELECT COUNT(*) FROM rhnServerAction WHERE action_id = A.id AND status NOT IN (2, 3)),
	  A.archived
FROM
	  web_contact U,
	  rhnActionType AT,
	  rhnAction A
WHERE	  A.scheduler = U.id(+)
AND	  A.action_type = AT.id
ORDER BY  A.earliest_action;

select 'rhnsat/views/rhnOrgChannelTreeView.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnOrgChannelTreeView.sql
CREATE OR REPLACE VIEW rhnOrgChannelTreeView
(
	org_id,
        id,
        depth,
	name,
        padded_name,
	channel_arch_id,
        last_modified,
        label,
	parent_or_self_label,
	parent_or_self_id,
	end_of_life
)
AS
select * from (
	select	cfp.org_id		org_id,
		c.id			id,
		1			depth,
		c.name			name,
		'  ' || c.name		padded_name,
		c.channel_arch_id	channel_arch_id,
		c.last_modified		last_modified,
		c.label			label,
		c.label			parent_or_self_label,
		c.id			parent_or_self_id,
		c.end_of_life		end_of_life
	from	rhnChannel		c,
		rhnChannelFamilyMembers cfm,
		rhnOrgChannelFamilyPermissions cfp
	where	cfp.channel_family_id = cfm.channel_family_id
		and cfm.channel_id = c.id
		and c.parent_channel is null
	union
	select	cfp.org_id		org_id,
		c.id			id,
		2			depth,
		c.name			name,
		'' || c.name		padded_name,
		c.channel_arch_id 	channel_arch_id,
		c.last_modified		last_modified,
		c.label			label,
		pc.label		parent_or_self_label,
		pc.id			parent_or_self_id,
		c.end_of_life		end_of_life
	from	rhnChannel		pc,
		rhnChannel		c,
		rhnChannelFamilyMembers	cfm,
		rhnOrgChannelFamilyPermissions cfp
	where	cfp.channel_family_id = cfm.channel_family_id
		and cfm.channel_id = c.id
		and c.parent_channel = pc.id
) order by parent_or_self_label, parent_or_self_id;

select 'rhnsat/views/rhnSharedChannelView.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnSharedChannelView.sql
CREATE OR REPLACE VIEW RHNSHAREDCHANNELVIEW
AS
SELECT 
   CH.ID,
   CH.PARENT_CHANNEL,
   CH.ORG_ID,
   CH.CHANNEL_ARCH_ID,
   CH.LABEL,
   CH.BASEDIR,
   CH.NAME,
   CH.SUMMARY,
   CH.DESCRIPTION,
   CH.PRODUCT_NAME_ID,
   CH.GPG_KEY_URL,
   CH.GPG_KEY_ID,
   CH.GPG_KEY_FP,
   CH.END_OF_LIFE,
   CH.RECEIVING_UPDATES,
   CH.LAST_MODIFIED,
   CH.CHANNEL_PRODUCT_ID,
   CH.CREATED,
   CH.MODIFIED,
   CH.CHANNEL_ACCESS,
   TR.ORG_TRUST_ID
FROM RHNCHANNEL CH,
     RHNTRUSTEDORGS TR
WHERE CH.ORG_ID = TR.ORG_ID AND
      CH.CHANNEL_ACCESS = 'public'
UNION
SELECT
   CH.ID,
   CH.PARENT_CHANNEL,
   CH.ORG_ID,
   CH.CHANNEL_ARCH_ID,
   CH.LABEL,
   CH.BASEDIR,
   CH.NAME,
   CH.SUMMARY,
   CH.DESCRIPTION,
   CH.PRODUCT_NAME_ID,
   CH.GPG_KEY_URL,
   CH.GPG_KEY_ID,
   CH.GPG_KEY_FP,
   CH.END_OF_LIFE,
   CH.RECEIVING_UPDATES,
   CH.LAST_MODIFIED,
   CH.CHANNEL_PRODUCT_ID,
   CH.CREATED,
   CH.MODIFIED,
   CH.CHANNEL_ACCESS,
   TR.ORG_TRUST_ID
FROM RHNCHANNEL CH,
     RHNCHANNELTRUST TR
WHERE CH.ID = TR.CHANNEL_ID
/

select 'rhnsat/views/rhnSharedChannelTreeView.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnSharedChannelTreeView.sql
CREATE OR REPLACE VIEW RHNSHAREDCHANNELTREEVIEW
(
  ORG_ID,
  ID,
  DEPTH,
  NAME,
  PADDED_NAME,
  CHANNEL_ARCH_ID,
  LAST_MODIFIED,
  LABEL,
  PARENT_OR_SELF_LABEL,
  PARENT_OR_SELF_ID,
  END_OF_LIFE
)
AS
SELECT * FROM (
  SELECT
    C.ORG_TRUST_ID AS ORG_ID,
    C.ID,
    1 AS DEPTH,
    C.NAME,
    '  '||C.NAME AS PADDED_NAME,
    C.CHANNEL_ARCH_ID,
    C.LAST_MODIFIED,
    C.LABEL,
    C.LABEL AS PARENT_OR_SELF_LABEL,
    C.ID AS PARENT_OR_SELF_ID,
    C.END_OF_LIFE
  FROM RHNSHAREDCHANNELVIEW C
  WHERE C.PARENT_CHANNEL IS NULL
  UNION
  SELECT
    C.ORG_TRUST_ID AS ORG_ID,
    C.ID,
    2 AS DEPTH,
    c.name,
    ''||C.NAME AS PADDED_NAME,
    C.CHANNEL_ARCH_ID,
    C.LAST_MODIFIED,
    C.LABEL,
    C.LABEL AS PARENT_OR_SELF_LABEL,
    C.ID AS PARENT_OR_SELF_ID,
    C.END_OF_LIFE
  FROM RHNSHAREDCHANNELVIEW PC,
       RHNSHAREDCHANNELVIEW C
  WHERE C.PARENT_CHANNEL = PC.ID
) ORDER BY PARENT_OR_SELF_LABEL, PARENT_OR_SELF_ID;

select 'rhnsat/views/rhnAvailableChannels.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnAvailableChannels.sql
create or replace view
rhnAvailableChannels
(
    	org_id,
	channel_id,
	channel_depth,
	channel_name,
	channel_arch_id,
	padded_name,
	current_members,
	available_members,
        last_modified,
        channel_label,
	parent_or_self_label,
	parent_or_self_id 
)
as
select
     ct.org_id,
     ct.id, 
     CT.depth, 
     CT.name, 
     CT.channel_arch_id, 
     CT.padded_name,
     (SELECT COUNT(1) 
        FROM rhnServer S 
       WHERE S.org_id = ct.org_id 
         AND EXISTS (SELECT 1 FROM rhnServerChannel WHERE channel_id = ct.id AND server_id = S.id)),
     rhn_channel.available_chan_subscriptions(ct.id, ct.org_id),
     CT.last_modified,
     CT.label,
     CT.parent_or_self_label,
     CT.parent_or_self_id
from
     rhnOrgChannelTreeView CT
UNION
select
     ct.org_id,
     ct.id,
     CT.depth,
     CT.name,
     CT.channel_arch_id,
     CT.padded_name,
     (SELECT COUNT(1) 
        FROM rhnServer S 
       WHERE S.org_id = ct.org_id 
         AND EXISTS (SELECT 1 FROM rhnServerChannel WHERE channel_id = ct.id AND server_id = S.id)),
     NULL,
     CT.last_modified,
     CT.label,
     CT.parent_or_self_label,
     CT.parent_or_self_id
from
     rhnSharedChannelTreeView CT
/

select 'rhnsat/views/rhnCDDevice.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnCDDevice.sql
create or replace view 
rhnCDDevice
(id, server_Id, class, bus, detached, device, driver, 
description, dev_host, dev_id, dev_channel, dev_lun, pcitype)
as select 
	d.id,
	d.server_Id,
	d.class,
	d.bus,
	d.detached,
	d.device,
	d.driver,
	d.description,
	d.prop1,
	d.prop2,
	d.prop3,
	d.prop4,
	d.pcitype
from rhndevice d
where d.class = 'CDROM';

select 'rhnsat/views/rhnChannelFamilyOverview.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnChannelFamilyOverview.sql
create or replace view rhnChannelFamilyOverview as
select	pcf.org_id				org_id,
	f.id					id,
	f.name					name,
	f.product_url				url,
	f.label					label,
	NVL(pcf.current_members,0)		current_members,
	pcf.max_members				max_members,
	1					has_subscription
from	rhnChannelFamily			f,
	rhnPrivateChannelFamily			pcf
where	pcf.channel_family_id = f.id;

select 'rhnsat/views/rhnChannelFamilyPermissions.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnChannelFamilyPermissions.sql
create or replace view rhnChannelFamilyPermissions as
	select	channel_family_id,
		to_number(null) org_id,
		to_number(null) max_members,
		0 current_members,
		created,
		modified
	from	rhnPublicChannelFamily
	union
	select	channel_family_id,
		org_id,
		max_members,
		current_members,
		created,
		modified
	from	rhnPrivateChannelFamily;

select 'rhnsat/views/rhnServerEntitlementView.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnServerEntitlementView.sql
create or replace view
rhnServerEntitlementView
(
   server_id,
   server_group_type_id,
   label,
   permanent,
   is_base
)
as
select
   distinct
   sgm.server_id,
   sgt.id,
   sgt.label,
   sgt.permanent,
   sgt.is_base
from
   rhnServerGroupType sgt,
   rhnServerGroup sg,
   rhnServerGroupMembers sgm
where
   sg.id = sgm.server_group_id
   and sg.group_type = sgt.id;
show errors;

select 'rhnsat/views/rhnChannelFamilyServerPhysical.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnChannelFamilyServerPhysical.sql
create or replace view rhnChannelFamilyServerPhysical as
	select	rs.org_id			customer_id,
		rcfm.channel_family_id		channel_family_id,
		rsc.server_id			server_id,
		rsc.created			created,
		rsc.modified			modified
	from	rhnChannelFamilyMembers		rcfm,
		rhnChannelFamily		rcf,
		rhnServerChannel		rsc,
		rhnServer			rs
	where
		rcfm.channel_id = rsc.channel_id
		and rcfm.channel_family_id = rcf.id
		and rsc.server_id = rs.id
        and not exists (
                select 1
                from 
                    rhnChannelFamilyVirtSubLevel cfvsl, 
                    rhnSGTypeVirtSubLevel sgtvsl,
                    rhnServerEntitlementView sev,
                    rhnVirtualInstance vi
                where 
                    vi.virtual_system_id = rs.id
                    and vi.host_system_id = sev.server_id
                    and sev.label in ('virtualization_host',
                                      'virtualization_host_platform')
                    and sev.server_group_type_id = sgtvsl.server_group_type_id
                    and sgtvsl.virt_sub_level_id = cfvsl.virt_sub_level_id
                    and cfvsl.channel_family_id = rcf.id
                );
show errors;                

select 'rhnsat/views/rhnChannelFamilyServerVirtual.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnChannelFamilyServerVirtual.sql
create or replace view rhnChannelFamilyServerVirtual as
	select	rs.org_id			customer_id,
		rcfm.channel_family_id		channel_family_id,
		rsc.server_id			server_id,
		rsc.created			created,
		rsc.modified			modified
	from	rhnChannelFamilyMembers		rcfm,
		rhnChannelFamily		rcf,
		rhnServerChannel		rsc,
		rhnServer			rs
	where
		rcfm.channel_id = rsc.channel_id
		and rcfm.channel_family_id = rcf.id
		and rsc.server_id = rs.id
        and exists (
                select 1
                from 
                    rhnChannelFamilyVirtSubLevel cfvsl, 
                    rhnSGTypeVirtSubLevel sgtvsl,
                    rhnServerEntitlementView sev,
                    rhnVirtualInstance vi
                where 
                    vi.virtual_system_id = rs.id
                    and vi.host_system_id = sev.server_id
                    and sev.label in ('virtualization_host',
                                      'virtualization_host_platform')
                    and sev.server_group_type_id = sgtvsl.server_group_type_id
                    and sgtvsl.virt_sub_level_id = cfvsl.virt_sub_level_id
                    and cfvsl.channel_family_id = rcf.id
                );
show errors;                

select 'rhnsat/views/rhnChannelFamilyServers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnChannelFamilyServers.sql
create or replace view rhnChannelFamilyServers as
	select	rs.org_id			customer_id,
		rcfm.channel_family_id		channel_family_id,
		rsc.server_id			server_id,
		rsc.created			created,
		rsc.modified			modified
	from	rhnChannelFamilyMembers		rcfm,
		rhnChannelFamily		rcf,
		rhnServerChannel		rsc,
		rhnServer			rs
	where
		rcfm.channel_id = rsc.channel_id
		and rcfm.channel_family_id = rcf.id
		and rsc.server_id = rs.id;

select 'rhnsat/views/rhnChannelNewestPackageView.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnChannelNewestPackageView.sql
create or replace view
rhnChannelNewestPackageView
as
select  cp.channel_id		channel_id,
		p.name_id			name_id,
		p.evr_id			evr_id,
		p.package_arch_id	package_arch_id,
		p.id				package_id
from	rhnPackageEVR		pe,
		rhnPackage			p,
		rhnChannelPackage	cp
where	cp.package_id = p.id
		and p.evr_id = pe.id
		and pe.evr = (
			select	max(sq_pe.evr)
			from	rhnChannelPackage sq_cp,
					rhnPackage sq_p,
					rhnPackageEVR sq_pe
			where	1=1
				and sq_cp.channel_id = cp.channel_id
				and sq_cp.package_id = sq_p.id
				and sq_p.name_id = p.name_id
				and sq_pe.id = sq_p.evr_id
		)
/

select 'rhnsat/views/rhnChannelPackageOverview.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnChannelPackageOverview.sql
create or replace view
rhnChannelPackageOverview
(
    	channel_id,
	name_id,
	evr
)
as
select  cp.channel_id,
	p.name_id,
	max(p_evr.evr)
from
	rhnPackageEVR p_evr,
	rhnPackage p,
	rhnChannelPackage cp
where
    	cp.package_id = p.id
    and p.evr_id = p_evr.id
group by cp.channel_id, p.name_id
/

select 'rhnsat/views/rhnChannelPermissions.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnChannelPermissions.sql
create or replace view
rhnChannelPermissions
(
    org_id, channel_id
)
as
select distinct org_id, channel_id from (
select	privcf.org_id, cfm.channel_id
from	rhnChannelFamilyMembers cfm,
	rhnPrivateChannelFamily privcf
where	privcf.channel_family_id = cfm.channel_family_id
union all
select	u.org_id, cfm.channel_id
from	web_contact u,
	rhnChannelFamilyMembers cfm,
	rhnPublicChannelFamily pubcf
where	pubcf.channel_family_id = cfm.channel_family_id
);

select 'rhnsat/views/rhnChannelTreeView.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnChannelTreeView.sql
CREATE OR REPLACE VIEW rhnChannelTreeView
(
        id,
        depth,
	name,
        padded_name,
	channel_arch_id,
        last_modified,
        label,
	parent_or_self_label,
	parent_or_self_id,
	end_of_life
)
AS
select * from (
	select	c.id			id,
		1			depth,
		c.name			name,
		'  ' || c.name		padded_name,
		c.channel_arch_id	channel_arch_id,
		c.last_modified		last_modified,
		c.label			label,
		c.label			parent_or_self_label,
		c.id			parent_or_self_id,
		c.end_of_life		end_of_life
	from	rhnChannel		c
	where	c.parent_channel is null
	union
	select	c.id			id,
		2			depth,
		c.name			name,
		'' || c.name		padded_name,
		c.channel_arch_id 	channel_arch_id,
		c.last_modified		last_modified,
		c.label			label,
		pc.label		parent_or_self_label,
		pc.id			parent_or_self_id,
		c.end_of_life		end_of_life
	from	rhnChannel		pc,
		rhnChannel		c
	where	c.parent_channel = pc.id
) order by parent_or_self_label, parent_or_self_id;

select 'rhnsat/views/rhnDemoOrgs.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnDemoOrgs.sql
create or replace view rhnDemoOrgs
as
(
    select org_id 
    from demo_log
    where server_id = 0
)
/
show errors;

select 'rhnsat/views/rhnEntitledServers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnEntitledServers.sql
create or replace view
rhnEntitledServers
as
select distinct
    S.id,
    S.org_id,
    S.digital_server_id,
    S.server_arch_id,
    S.os,
    S.release,
    S.name,
    S.description,
    S.info,
    S.secret
from
    rhnServerGroup SG,
    rhnServerGroupType SGT,
    rhnServerGroupMembers SGM,
    rhnServer S
where
    S.id = SGM.server_id
and SG.id = SGM.server_group_id
and SGT.label IN ('sw_mgr_entitled', 'enterprise_entitled', 'provisioning_entitled')
and SG.group_type = SGT.id
and SG.org_id = S.org_id
/

select 'rhnsat/views/rhnHWDevice.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnHWDevice.sql
create or replace view 
rhnHWDevice
(id, server_Id, class, bus, detached, device, driver, 
description, vendor_id, device_id, subvendor_Id, subdevice_Id, pcitype)
as
select 
	d.id,
	d.server_Id,
	d.class,
	d.bus,
	d.detached,
	d.device,
	d.driver,
	d.description,
	d.prop1,
	d.prop2,
	d.prop3,
	d.prop4,
	d.pcitype
from rhnDevice d
where d.class in ('AUDIO', 'MODEM', 'MOUSE', 'NETWORK', 
	        'SCSI', 'OTHER', 'USB', 'VIDEO', 'CAPTURE',
		'SCANNER', 'TAPE', 'RAID', 'SOCKET');

select 'rhnsat/views/rhnHistoryView.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnHistoryView.sql
create or replace function 
rhnHistoryView_pkglist(action_id IN NUMBER, separator IN VARCHAR2 DEFAULT chr(10))
return VARCHAR2
is
    store_var  VARCHAR2(4000);
    store_tmp  VARCHAR2(4000);
    select_sql VARCHAR2(4000);
    trimmed NUMBER;
    cursor pkg_cursor(action_id_in IN NUMBER)
    is
       select
           pn.name||'-'||pevr.version||'-'||pevr.release||'.'||pa.name
       from
           rhnPackageName pn, rhnPackageEVR pevr, rhnPackageArch pa,
	   rhnActionPackage ap
       where
               ap.name_id = pn.id
	   and ap.evr_id = pevr.id
	   and ap.package_arch_id = pa.id(+)
	   and ap.action_id = action_id_in;
begin
    store_var := NULL;
    trimmed := 0;
    open pkg_cursor(action_id);
    loop
	fetch pkg_cursor into store_tmp;
	exit when pkg_cursor%NOTFOUND;
	if store_var is NULL then
	   store_var := store_tmp;
	else
	   trimmed := 1;
	   exit when length(store_var) + length(separator) + length(store_tmp) > 3700;
	   store_var := store_var || separator || store_tmp;
	   trimmed := 0;
	end if;
    end loop;
    close pkg_cursor;
    if trimmed <> 0 then
        store_var := store_var || separator || '...';
    end if;
    return store_var;
end;
/
show errors
create or replace function 
rhnHistoryView_erratalist(action_id IN NUMBER, separator IN VARCHAR2 DEFAULT chr(10))
return VARCHAR2
is
    store_var  VARCHAR2(4000);
    store_tmp  VARCHAR2(4000);
    select_sql VARCHAR2(4000);
    trimmed NUMBER;
    cursor errata_cursor(action_id_in IN NUMBER, separator IN VARCHAR2 DEFAULT chr(10))
    is
       select
           'Errata Advisory: ' || e.advisory || separator ||
	   'Errata Synopsis: ' || e.synopsis || separator
       from
           rhnActionErrataUpdate ae, rhnErrata e
       where
           e.id = ae.errata_id
       and ae.action_id = action_id_in;
begin
    store_var := NULL;
    trimmed := 0;
    open errata_cursor(action_id);
    loop
	fetch errata_cursor into store_tmp;
	exit when errata_cursor%NOTFOUND;
	if store_var is NULL then
	   store_var := store_tmp;
	else
	   trimmed := 1;
	   exit when length(store_var) + length(separator) + length(store_tmp) > 3700;
	   store_var := store_var || separator || store_tmp;
	   trimmed := 0;
	end if;
    end loop;
    close errata_cursor;
    if trimmed <> 0 then
        store_var := store_var || separator || '...';
    end if;
    return store_var;
end;
/
show errors
create or replace view 
rhnHistoryView_refresh
as
select 
    sa.action_id event_id, 
    sa.server_id, 
    at.name || ' scheduled by ' || contact.login || ' (' || astat.name || ')' summary,
    'This action will be executed after ' || 
        to_char(a.earliest_action, 'YYYY-MM-DD HH24:MI:SS') || ' EST' || chr(10) || chr(10) ||
	'The current action status is: ' || astat.name || chr(10) ||
	nvl2(sa.pickup_time, 
	    'The client picked up this action on ' || 
	        to_char(sa.pickup_time, 'YYYY-MM-DD HH24:MI:SS') || ' EST',
	    'This action has not been picked up') || chr(10) ||
	nvl2(sa.completion_time,
	    'The client reported completion on execution on ' ||
	        to_char(sa.completion_time, 'YYYY-MM-DD HH24:MI:SS') || ' EST',
	    'This action has not been fully executed') || chr(10) ||
	nvl2(sa.result_code,
	    'Client execution returned code '||to_char(sa.result_code)||
	        ' ('||nvl(sa.result_msg, 'SUCCESS')||')',
	    '') || 
	chr(10) ||
	'' details,
    a.created, 
    sa.modified
from
    rhnAction a, rhnServerAction sa, 
    rhnActionType at, rhnActionStatus astat,
    web_contact contact
where
    sa.action_id = a.id
and a.action_type = at.id
and a.scheduler = contact.id
and sa.status = astat.id
and at.label in ('packages.refresh_list', 'hardware.refresh_list', 'reboot.reboot', 'rollback.rollback')
with
    read only;
create or replace view
rhnHistoryView_packages
as
select 
    sa.action_id event_id, 
    sa.server_id, 
    at.name || ( select ' (' || count(name_id) || 
                        decode(count(name_id), 1, ' package) ',  ' packages) ')
                 from rhnActionPackage ap where ap.action_id = sa.action_id ) ||
    ' scheduled by ' || contact.login || ' (' || astat.name || ')' summary,
    'This action will be executed after ' || 
        to_char(a.earliest_action, 'YYYY-MM-DD HH24:MI:SS') || ' EST' || chr(10) || chr(10) ||
	'The current action status is: ' || astat.name || chr(10) || 
	nvl2(sa.pickup_time, 
	    'The client picked up this action on ' || 
	        to_char(sa.pickup_time, 'YYYY-MM-DD HH24:MI:SS') || ' EST',
	    'This action has not been picked up') || chr(10) ||
	nvl2(sa.completion_time,
	    'The client reported completion on execution on ' ||
	        to_char(sa.completion_time, 'YYYY-MM-DD HH24:MI:SS') || ' EST',
	    'This action has not been fully executed') || chr(10) ||
	nvl2(sa.result_code,
	    'Client execution returned code '||to_char(sa.result_code)||
	        ' ('||nvl(sa.result_msg, 'SUCCESS')||')',
	    '') || 
	chr(10) || chr(10) ||
	'Package list:' || chr(10) || rhnHistoryView_pkglist(sa.action_id) ||
	'' details,
    a.created, 
    sa.modified
from
    rhnAction a, rhnServerAction sa,
    rhnActionType at, rhnActionStatus astat,
    web_contact contact
where
    sa.action_id = a.id
and a.action_type = at.id
and a.scheduler = contact.id
and sa.status = astat.id
and at.label in ('packages.update', 'packages.remove')
with
    read only;
create or replace view
rhnHistoryView_errata
as
select 
    sa.action_id event_id, 
    sa.server_id, 
    at.name || ( select ' (' || count(errata_id) || 
                        decode(count(errata_id), 1, ' erratum) ', ' errata) ')
                 from rhnActionErrataUpdate aeu where aeu.action_id = sa.action_id ) ||
    ' scheduled by ' || contact.login || ' (' || astat.name || ')' summary,   
    'This action will be executed after ' || 
        to_char(a.earliest_action, 'YYYY-MM-DD HH24:MI:SS') || ' EST' || chr(10) || chr(10) ||
	'The current action status is: ' || astat.name || chr(10) ||
	nvl2(sa.pickup_time, 
	    'The client picked up this action on ' || 
	        to_char(sa.pickup_time, 'YYYY-MM-DD HH24:MI:SS') || ' EST',
	    'This action has not been picked up') || chr(10) ||
	nvl2(sa.completion_time,
	    'The client reported completion on execution on ' ||
	        to_char(sa.completion_time, 'YYYY-MM-DD HH24:MI:SS') || ' EST',
	    'This action has not been fully executed') || chr(10) ||
	nvl2(sa.result_code,
	    'Client execution returned code '||to_char(sa.result_code)||
	        ' ('||nvl(sa.result_msg, 'SUCCESS')||')',
	    '') || 
	chr(10) || chr(10) ||
	'Errata list:' || chr(10) || rhnHistoryView_erratalist(sa.action_id) ||
	'' details,
    a.created, 
    sa.modified
from
    rhnAction a, rhnServerAction sa,
    rhnActionType at, rhnActionStatus astat,
    web_contact contact
where
    sa.action_id = a.id
and a.action_type = at.id
and a.scheduler = contact.id
and sa.status = astat.id
and at.label = 'errata.update'
with 
    read only;
create or replace view
rhnHistoryView
as
select 
    id event_id, server_id, summary, details, created, modified
from
    rhnServerHistory
UNION
select * from rhnHistoryView_refresh
UNION
select * from rhnHistoryView_packages
UNION
select * from rhnHistoryView_errata
with
    read only;

select 'rhnsat/views/rhnOrgErrata.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnOrgErrata.sql
create or replace view
rhnOrgErrata
(
    	org_id,
	errata_id,
	channel_id
)
as
select
    ac.org_id,
    ce.errata_id,
    ac.channel_id
from
    rhnChannelErrata ce,
    rhnAvailableChannels ac
where
    ce.channel_id = ac.channel_id
/

select 'rhnsat/packages/rhn_package.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_package.pkb
CREATE OR REPLACE
PACKAGE BODY rhn_package
IS
    FUNCTION canonical_name(name_in IN VARCHAR2, evr_in IN EVR_T, 
    	                    arch_in IN VARCHAR2)
    RETURN VARCHAR2
    IS
    	name_out     VARCHAR2(256);
    BEGIN
    	name_out := name_in || '-' || evr_in.as_vre_simple();
	IF arch_in IS NOT NULL
	THEN
	    name_out := name_out || '-' || arch_in;
	END IF;
        RETURN name_out;
    END canonical_name;
    FUNCTION channel_occupancy_string(package_id_in IN NUMBER, separator_in VARCHAR2 := ', ') 
    RETURN VARCHAR2
    IS
    	list_out    VARCHAR2(4000);
    BEGIN
    	FOR channel IN channel_occupancy_cursor(package_id_in)
	LOOP
	    IF list_out IS NULL
	    THEN
	    	list_out := channel.channel_name;
	    ELSE
	        list_out := channel.channel_name || separator_in || list_out;
	    END IF;
	END LOOP;
	RETURN list_out;
    END channel_occupancy_string;
END rhn_package;
/
SHOW ERRORS

select 'rhnsat/views/rhnOrgPackageOverview.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnOrgPackageOverview.sql
create or replace view
rhnOrgPackageOverview
as
select
    p.org_id org_id,
    cpac.channel_arch_id,
    p.id package_id,
    rhn_package.canonical_name(p_name.name, p_evr.evr, pa.name) package_nvrea
from
    rhnPackageName p_name,
    rhnPackageEVR p_evr,
    rhnPackageArch pa,
    rhnChannelPackageArchCompat cpac,
    rhnPackage p
where
        p_name.id = p.name_id
    and p_evr.id = p.evr_id
    and cpac.package_arch_id = p.package_arch_id
    and p.package_arch_id = pa.id
order by package_nvrea, p.created
/

select 'rhnsat/views/rhnPaidOrgs.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnPaidOrgs.sql
create or replace view
rhnPaidOrgs
as
select	org_id
from	rhnServerGroup
where	group_type = lookup_sg_type('enterprise_entitled')
	and NVL(max_members,1) > 0
union all
select	sg.org_id
from	rhnServerGroup sg
where	sg.group_type = lookup_sg_type('sw_mgr_entitled')
	and NVL(sg.max_members,1) > 0
    and not exists (
        select 1
        from
            rhnDemoOrgs do
        where
            do.org_id = sg.org_id
            and sg.max_members = 1
    )
union all
select	sg.org_id
from	rhnServerGroup sg
where	group_type = lookup_sg_type('provisioning_entitled')
	and NVL(sg.max_members,2) > 1;
show errors;

select 'rhnsat/views/rhnWebContactDisabled.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnWebContactDisabled.sql
create or replace view
rhnWebContactDisabled
as
select
   wcon.id,
   wcon.org_id,
   wcon.login,
   wcon.login_uc,
   wcon.password,
   wcon.old_password,
   wcon.oracle_contact_id,
   wcon.created,
   wcon.modified,
   wcon.ignore_flag
from
   rhnWebContactChangeLog   wccl,
   rhnWebContactChangeState wccs,
   web_contact              wcon
where 1=1
   and wccl.change_state_id = wccs.id
   and wccs.label = 'disabled'
   and wccl.web_contact_id = wcon.id
   and wccl.date_completed =
              (select max(wccl_exists.date_completed)
                 from rhnWebContactChangeLog   wccl_exists
                where wccl.web_contact_id = wccl_exists.web_contact_id);

select 'rhnsat/views/rhnPrivateErrataMail.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnPrivateErrataMail.sql
create or replace view
rhnPrivateErrataMail
as
with rhnSPmaxEVR as (
   select   sq2_sp.server_id, sq2_sp.name_id, max(sq2_pe.evr) max_evr
            from  rhnServerPackage  sq2_sp,
               rhnPackageEVR     sq2_pe
            where sq2_sp.evr_id = sq2_pe.id
	    group by sq2_sp.server_id, sq2_sp.name_id)
select
   w.login, 
   w.login_uc,
   wpi.email,  
   w.id user_id,
   s.id server_id,  
   w.org_id org_id, 
   s.name server_name,  
   sa.name server_arch,  
   s.release server_release,  
   ce.errata_id errata_id,
   e.advisory
from
   rhnServer s,
   web_user_personal_info wpi,
   rhnUserInfo ui,
   rhnErrata e,
   rhnServerArch sa,
   rhnChannelErrata ce,
   web_contact w, 
   rhnServerChannel sc,
   rhnServerGroupMembers sgm,
   rhnServerGroup sg
where 1=1
   and sg.id = sgm.server_group_id
   and sgm.server_id = sc.server_id
   and sg.org_id = w.org_id
   and not exists (
      select   usprefs.server_id 
               from  rhnUserServerPrefs usprefs
         where 1=1
         and w.id = usprefs.user_id 
               and sc.server_id = usprefs.server_id 
               and usprefs.name = 'receive_notifications'
   )
   and w.id = wpi.web_user_id
   and wpi.email is not null
   and w.id = ui.user_id
      and ui.email_notify = 1
   and exists (
      select   1
      from  
         rhnUserGroupType  ugt,
         rhnUserGroup      ug,
         rhnUserGroupMembers  ugm
      where 1=1
         and ugt.label = 'org_admin'
         and ugt.id = ug.group_type
         and ug.id = ugm.user_group_id
         and ugm.user_id = w.id
      union all
      select   1
      from
         rhnServerGroupMembers   sq_sgm,
         rhnUserServerGroupPerms usg
      where sc.server_id = sq_sgm.server_id
         and sq_sgm.server_group_id = usg.server_group_id
         and usg.user_id = w.id
   )
   and sc.channel_id = ce.channel_id
   and sc.server_id = s.id
      and exists (
         select 1
      from
            rhnPackageEVR        p_evr,
            rhnPackageEVR        sp_evr,
            rhnServerPackage     sp,
            rhnChannelPackage    cp,
            rhnPackage        p,
            rhnErrataPackage     ep,
            rhnServerPackageArchCompat spac
      where 1=1
         and sc.channel_id = cp.channel_id
         and cp.package_id = p.id
         and ce.errata_id = ep.errata_id
         and ep.package_id = p.id
         and sc.channel_id = ce.channel_id
         and ce.errata_id = ep.errata_id
         and sc.server_id = sp.server_id
         and sp.name_id = p.name_id
         and sp.evr_id = sp_evr.id
         and p.evr_id = p_evr.id
         and sp.evr_id != p.evr_id
         and sp_evr.evr < p_evr.evr
         and sp_evr.evr = (
            select max_evr from rhnSPmaxEVR rsme
	    where sp.server_id = rsme.server_id
               and sp.name_id = rsme.name_id
         )
         and p.package_arch_id = spac.package_arch_id
         and s.server_arch_id = spac.server_arch_id
   )
   and s.server_arch_id = sa.id
   and ce.errata_id = e.id
   and not exists ( select 1
                      from rhnWebContactDisabled wcd
                     where wcd.id = w.id )
/

select 'rhnsat/views/rhnServerEntitlementPhysical.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnServerEntitlementPhysical.sql
create or replace view
rhnServerEntitlementPhysical
(
   server_id,
   server_group_id,
   server_group_type_id,
   label,
   permanent,
   is_base,
   modified
)
as
select
   distinct
   sgm.server_id,
   sg.id,
   sgt.id,
   sgt.label,
   sgt.permanent,
   sgt.is_base,
   sgm.modified
from
   rhnServerGroupType sgt,
   rhnServerGroup sg,
   rhnServerGroupMembers sgm
where
   sg.id = sgm.server_group_id
   and sg.group_type = sgt.id
   and not exists (
        select 1
        from
            rhnServerGroup sg2,
            rhnServerGroupMembers sgm2,
            rhnVirtualInstance vi
        where
            vi.virtual_system_id = sgm.server_id
            and vi.host_system_id = sgm2.server_id
            and sgm2.server_group_id = sg2.id
            and sg2.group_type = sg.group_type
            and exists (
                select 1
                from
                    rhnServerGroupType sgt3,
                    rhnServerGroup sg3,
                    rhnServerGroupMembers sgm3
                where
                    sgm3.server_id = sgm2.server_id
                    and sgm3.server_group_id = sg3.id
                    and sg3.group_type = sgt3.id
                    and sgt3.label in ('virtualization_host',
                                       'virtualization_host_platform')
                )
        );
show errors;

select 'rhnsat/views/rhnServerEntitlementVirtual.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnServerEntitlementVirtual.sql
create or replace view
rhnServerEntitlementVirtual
(
   server_id,
   server_group_id,
   server_group_type_id,
   label,
   permanent,
   is_base
)
as
select
   distinct
   sgm.server_id,
   sg.id,
   sgt.id,
   sgt.label,
   sgt.permanent,
   sgt.is_base
from
   rhnServerGroupType sgt,
   rhnServerGroup sg,
   rhnServerGroupMembers sgm
where
   sg.id = sgm.server_group_id
   and sg.group_type = sgt.id
   and exists (
        select 1
        from
            rhnServerGroup sg2,
            rhnServerGroupMembers sgm2,
            rhnVirtualInstance vi
        where
            vi.virtual_system_id = sgm.server_id
            and vi.host_system_id = sgm2.server_id
            and sgm2.server_group_id = sg2.id
            and sg2.group_type = sg.group_type
            and exists (
                select 1
                from
                    rhnServerGroupType sgt3,
                    rhnServerGroup sg3,
                    rhnServerGroupMembers sgm3
                where
                    sgm3.server_id = sgm2.server_id
                    and sgm3.server_group_id = sg3.id
                    and sg3.group_type = sgt3.id
                    and sgt3.label in ('virtualization_host',
                                       'virtualization_host_platform')
                )
        );
show errors;

select 'rhnsat/views/rhnServerErrataTypeView.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnServerErrataTypeView.sql
CREATE OR REPLACE VIEW rhnServerErrataTypeView
(
    	server_id,
	errata_id,
	errata_type,
	package_count
)
AS
SELECT
    	SNPC.server_id,
	SNPC.errata_id,
	E.advisory_type,
	COUNT(SNPC.package_id)
FROM    rhnErrata E,
    	rhnServerNeededPackageCache SNPC
WHERE   E.id = SNPC.errata_id
GROUP BY SNPC.server_id, SNPC.errata_id, E.advisory_type
/

select 'rhnsat/views/rhnServerFeaturesView.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnServerFeaturesView.sql
create or replace view
rhnServerFeaturesView
(
   server_id,
   label
)
as
select
   distinct
   sgm.server_id,
   f.label
from
   rhnFeature f,
   rhnServerGroupTypeFeature sgtf,
   rhnServerGroupMembers sgm,
   rhnServerGroup sg
where
   sg.id = sgm.server_group_id
   and sgtf.feature_id = f.id
   and sg.group_type = sgtf.server_group_type_id
/
show errors;

select 'rhnsat/views/rhnServerGroupMembership.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnServerGroupMembership.sql
CREATE OR REPLACE VIEW rhnServerGroupMembership (
         ORG_ID, SERVER_ID, GROUP_ID, GROUP_NAME, GROUP_TYPE, CURRENT_MEMBERS, MAX_MEMBERS
)
AS
SELECT   SG.org_id, SGM.server_id, SG.id, SG.name, SGT.label, SG.current_members, SG.max_members
  FROM   rhnServerGroupType SGT, 
	 rhnServerGroupMembers SGM,
    	 rhnServerGroup SG
 WHERE   SG.id = SGM.server_group_id(+)
   AND   SG.group_type = SGT.id(+)
/

select 'rhnsat/views/rhnServerGroupOVLiteHelper.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnServerGroupOVLiteHelper.sql
create or replace view
rhnServerGroupOVLiteHelper as
select	sgm.server_group_id						server_group_id,
		e.advisory_type							advisory_type
from	rhnErrata								e,
		rhnServerNeededPackageCache				snpc,
		rhnServerGroupMembers					sgm
where   1=1
	and sgm.server_id = snpc.server_id
	and snpc.errata_id = e.id
/

select 'rhnsat/views/rhnUserManagedServerGroups.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUserManagedServerGroups.sql
create or replace view
rhnUserManagedServerGroups (
    user_id, server_group_id
)
as
select user_id, server_group_id from rhnUserServerGroupPerms
union
select wc.id, sg.id
  from rhnServerGroup sg,
       rhnUserGroup ug,
       rhnUserGroupMembers ugm,
       web_contact wc
 where wc.org_id = sg.org_id
   and wc.id = ugm.user_id
   and ugm.user_group_id = ug.id
   and ug.group_type = (select id from rhnUserGroupType where label = 'org_admin')
/

select 'rhnsat/views/rhnServerGroupOverview.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnServerGroupOverview.sql
CREATE OR REPLACE VIEW rhnServerGroupOverview (
         ORG_ID, SECURITY_ERRATA, BUG_ERRATA, ENHANCEMENT_ERRATA, GROUP_ID, GROUP_NAME, GROUP_ADMINS, SERVER_COUNT, NOTE_COUNT, MODIFIED, MAX_MEMBERS
)
AS
  SELECT SG.org_id,
         (SELECT COUNT(distinct E.id)
            FROM rhnErrata E,
                 rhnServerNeededPackageCache SNPC,
                 rhnServerGroupMembers SGM
           WHERE E.advisory_type = 'Security Advisory'
                 and snpc.errata_id = e.id
                 and snpc.server_id = sgm.server_id
                 and sgm.server_group_id = sg.id
                 AND EXISTS ( SELECT 1
                              FROM rhnServerFeaturesView SFV
                              WHERE SFV.server_id = SGM.server_id
                                    AND SFV.label = 'ftr_system_grouping')),
         (SELECT COUNT(distinct E.id)
            FROM rhnErrata E,
                 rhnServerNeededPackageCache SNPC,
                 rhnServerGroupMembers SGM
           WHERE E.advisory_type = 'Bug Fix Advisory'
                 and snpc.errata_id = e.id
                 and snpc.server_id = sgm.server_id
                 and sgm.server_group_id = sg.id
                 AND EXISTS ( SELECT 1
                              FROM rhnServerFeaturesView SFV
                              WHERE SFV.server_id = SGM.server_id
                                    AND SFV.label = 'ftr_system_grouping')),
         (SELECT COUNT(distinct E.id)
            FROM rhnErrata E,
                 rhnServerNeededPackageCache SNPC,
                 rhnServerGroupMembers SGM
           WHERE E.advisory_type = 'Product Enhancement Advisory'
                 and snpc.errata_id = e.id
                 and snpc.server_id = sgm.server_id
                 and sgm.server_group_id = sg.id
                 AND EXISTS ( SELECT 1
                              FROM rhnServerFeaturesView SFV
                              WHERE SFV.server_id = SGM.server_id
                                    AND SFV.label = 'ftr_system_grouping')),
         SG.id, SG.name,
         (SELECT COUNT(*) FROM rhnUserManagedServerGroups UMSG WHERE UMSG.server_group_id = SG.id),
         (SELECT COUNT(*) FROM rhnServerGroupMembers SGM WHERE SGM.server_group_id = SG.id
                 AND EXISTS ( SELECT 1
                              FROM rhnServerFeaturesView SFV
                              WHERE SFV.server_id = SGM.server_id
                                    AND SFV.label = 'ftr_system_grouping')),
         0, SYSDATE, MAX_MEMBERS
    FROM rhnServerGroup SG;
show errors;

select 'rhnsat/views/rhnServerNeededPackageView.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnServerNeededPackageView.sql
CREATE OR REPLACE VIEW
rhnServerNeededPackageView
(
    org_id,
    server_id,
    errata_id,
    package_id,
    package_name_id
)
AS
SELECT   S.org_id,
         S.id,
	  (SELECT EP.errata_id
	     FROM rhnErrataPackage EP,
	          rhnChannelErrata CE,
		  rhnServerChannel SC
	    WHERE SC.server_id = S.id
	      AND SC.channel_id = CE.channel_id
	      AND CE.errata_id = EP.errata_id
	      AND EP.package_id = P.id
	      AND ROWNUM = 1),
	 P.id,
	 P.name_id
FROM
	 rhnPackage P,
	 rhnServerPackageArchCompat SPAC,
	 rhnPackageEVR P_EVR,
	 rhnPackageEVR SP_EVR,
	 rhnServerPackage SP,
	 rhnChannelPackage CP,
	 rhnServerChannel SC,
         rhnServer S
WHERE
    	 SC.server_id = S.id
  AND  	 SC.channel_id = CP.channel_id
  AND    CP.package_id = P.id
  AND    p.package_arch_id = spac.package_arch_id
  AND    spac.server_arch_id = s.server_arch_id
  AND    SP_EVR.id = SP.evr_id
  AND    P_EVR.id = P.evr_id
  AND    SP.server_id = S.id
  AND    SP.name_id = P.name_id
  AND    SP.evr_id != P.evr_id
  AND    SP_EVR.evr < P_EVR.evr
  AND    SP_EVR.evr = (SELECT MAX(PE.evr) FROM rhnServerPackage SP2, rhnPackageEvr PE WHERE PE.id = SP2.evr_id AND SP2.server_id = SP.server_id AND SP2.name_id = SP.name_id)
/

select 'rhnsat/views/rhnServerOutdatedPackages.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnServerOutdatedPackages.sql
CREATE OR REPLACE VIEW
rhnServerOutdatedPackages
(
    server_id,
    package_name_id,
    package_evr_id,    
    package_nvre,
    errata_id,
    errata_advisory
)
AS
SELECT DISTINCT SNPC.server_id,
       P.name_id, 
       P.evr_id, 
       PN.name || '-' || PE.evr.as_vre_simple(),
       E.id,
       E.advisory
  FROM rhnErrata E,
       rhnPackageName PN,
       rhnPackageEVR PE,
       rhnPackage P,
       rhnServerNeededPackageCache SNPC
 WHERE SNPC.package_id = P.id
   AND P.name_id = PN.id
   AND P.evr_id = PE.id
   AND SNPC.errata_id = E.id(+)
/

select 'rhnsat/views/rhnVisibleServerGroupMembers.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnVisibleServerGroupMembers.sql
CREATE OR REPLACE VIEW
rhnVisibleServerGroupMembers
AS
  SELECT SGM.*
    FROM rhnServerGroup SG,
         rhnServerGroupMembers SGM
   WHERE SGM.server_group_id = SG.id
     AND SG.group_type IS NULL;

select 'rhnsat/packages/rhn_entitlements.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_entitlements.pkb
create or replace
package body rhn_entitlements
is
	body_version varchar2(100) := '';
    procedure remove_org_entitlements(
        org_id_in in number
    )
    is
        cursor system_ents is
        select sg.id, sg.max_members, sg.group_type
        from rhnServerGroup sg
        where group_type is not null
          and org_id = org_id_in;
        cursor channel_subs is
        select pcf.channel_family_id, pcf.max_members
        from rhnChannelFamily cf,
             rhnPrivateChannelFamily pcf
        where pcf.org_id = org_id_in
          and pcf.channel_family_id = cf.id
          and cf.org_id is null;
    begin
        for system_ent in system_ents loop
            update rhnServerGroup
            set max_members = max_members + system_ent.max_members
            where org_id = 1
              and group_type = system_ent.group_type;
        end loop;
        update rhnServerGroup
        set max_members = 0
        where org_id = org_id_in;
        for channel_sub in channel_subs loop
            update rhnPrivateChannelFamily
            set max_members = max_members + channel_sub.max_members
            where org_id = 1
              and channel_family_id = channel_sub.channel_family_id;
        end loop;
        update rhnPrivateChannelFamily
        set max_members = 0
        where org_id = org_id_in;
    end remove_org_entitlements;
	function entitlement_grants_service (
	    entitlement_in in varchar2,
	    service_level_in in varchar2
	) return number	is
	begin
		if service_level_in = 'provisioning' then
			if entitlement_in = 'provisioning_entitled' then
				return 1;
			else
				return 0;
			end if;
		elsif service_level_in = 'management' then
			if entitlement_in = 'enterprise_entitled' then
				return 1;
			else
				return 0;
			end if;
		elsif service_level_in = 'monitoring' then
			if entitlement_in = 'monitoring_entitled' then
				return 1;
			end if;
		elsif service_level_in = 'updates' then
			return 1;			
		else
			return 0;
		end if;
	end entitlement_grants_service;
	function lookup_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number is
		cursor server_groups is
			select	sg.id				server_group_id
			from	rhnServerGroup		sg,
					rhnServerGroupType	sgt
			where	sgt.label = type_label_in
				and sgt.id = sg.group_type
				and sg.org_id = org_id_in;
	begin
		for sg in server_groups loop
			return sg.server_group_id;
		end loop;
		return rhn_entitlements.create_entitlement_group(
				org_id_in, 
				type_label_in
			);
	end lookup_entitlement_group;
	function create_entitlement_group (
		org_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) return number is
		sg_id_val number;
	begin
		select	rhn_server_group_id_seq.nextval
		into	sg_id_val
		from	dual;
		insert into rhnServerGroup (
				id, name, description, max_members, current_members,
				group_type, org_id
			) (
				select	sg_id_val, sgt.label, sgt.label,
						0, 0, sgt.id, org_id_in
				from	rhnServerGroupType sgt
				where	sgt.label = type_label_in
			);
		return sg_id_val;
	end create_entitlement_group;
   function can_entitle_server ( 
        server_id_in in number, 
        type_label_in in varchar2 ) 
   return number is
      cursor addon_servergroups (base_label_in in varchar2, 
                                 addon_label_in in varchar2) is
         select
            addon_id
         from
            rhnSGTypeBaseAddonCompat
         where base_id = lookup_sg_type (base_label_in)
           and addon_id = lookup_sg_type (addon_label_in);
      previous_ent        rhn_entitlements.ents_array;
      is_base_in          char   := 'N';
      is_base_current     char   := 'N';
      i                   number := 0;
      sgid                number := 0;
   begin
      previous_ent := rhn_entitlements.ents_array();
      previous_ent := rhn_entitlements.get_server_entitlement(server_id_in);
      select distinct is_base
      into is_base_in
      from rhnServerGroupType
      where label = type_label_in;
      if previous_ent.count = 0 then
         if (is_base_in = 'Y' and rhn_entitlements.find_compatible_sg (server_id_in, type_label_in, sgid)) then
            return 1;
         else
            return 0;
         end if;
      elsif is_base_in = 'Y' then
         return 0;
      else
         is_base_current := 'N';
         i := 0;
         while is_base_current = 'N' and i <= previous_ent.count
         loop
            i := i + 1;
            select is_base
            into is_base_current
            from rhnServerGroupType
            where label = previous_ent(i);
         end loop;
         if is_base_current  = 'N' then
            return 0;
         end if;
         for addon_servergroup in addon_servergroups  (previous_ent(i), type_label_in) loop
            if rhn_entitlements.find_compatible_sg (server_id_in, type_label_in, sgid) then
               return 1;
            else
               return 0;
            end if;
         end loop;
      end if;
      return 0;
   end can_entitle_server;
   function can_switch_base (
      server_id_in   in    integer,
      type_label_in  in    varchar2
   ) return number is
      type_label_in_is_base   char(1);
      sgid                    number;
   begin
      begin
         select is_base into type_label_in_is_base
         from rhnServerGroupType
         where label = type_label_in;
      exception
         when no_data_found then
            rhn_exception.raise_exception ( 'invalid_entitlement' );
      end;
      if type_label_in_is_base = 'N' then
         rhn_exception.raise_exception ( 'invalid_entitlement' );
      elsif rhn_entitlements.find_compatible_sg ( server_id_in, 
                                                  type_label_in, sgid ) then
         return 1;
      else
         return 0;
      end if;
   end can_switch_base;
   function find_compatible_sg (
      server_id_in    in   number,
      type_label_in   in   varchar2,
      sgid_out        out  number
   ) return boolean is
      cursor servergroups is
         select sg.id            id
           from rhnServerGroupType             sgt,
                rhnServerGroup                 sg,
                rhnServer                     s,
                rhnServerServerGroupArchCompat ssgac
          where s.id = server_id_in
            and s.org_id = sg.org_id
            and sgt.label = type_label_in
            and sg.group_type = sgt.id
            and ssgac.server_group_type = sgt.id
            and ssgac.server_arch_id = s.server_arch_id
            and not exists ( 
                     select 1
                      from rhnServerGroupMembers sgm
                     where sgm.server_group_id = sg.id 
                       and sgm.server_id = s.id);
   begin
      for servergroup in servergroups loop
         sgid_out := servergroup.id;
         return true;      
      end loop;
      sgid_out := 0;
      return false;
   end find_compatible_sg;
	procedure entitle_server (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled'
	) is
      sgid  number := 0;
      is_virt number := 0;
	begin
          begin
          select 1 into is_virt
            from rhnServerEntitlementView
           where server_id = server_id_in
             and label in ('virtualization_host', 'virtualization_host_platform');
	  exception
            when no_data_found then
              is_virt := 0;
          end;
      if is_virt = 0 and (type_label_in = 'virtualization_host' or
                          type_label_in = 'virtualization_host_platform') then
        is_virt := 1;
      end if;
      if rhn_entitlements.can_entitle_server(server_id_in, 
                                             type_label_in) = 1 then
         if rhn_entitlements.find_compatible_sg (server_id_in, 
                                                 type_label_in, sgid) then
            insert into rhnServerHistory ( id, server_id, summary, details )
            values ( rhn_event_id_seq.nextval, server_id_in,
                     'added system entitlement ',
                      case type_label_in
                       when 'enterprise_entitled' then 'Management'
                       when 'sw_mgr_entitled' then 'Update'
                       when 'provisioning_entitled' then 'Provisioning'
                       when 'monitoring_entitled' then 'Monitoring'  
                       when 'virtualization_host' then 'Virtualization'
                       when 'virtualization_host_platform' then 
                            'Virtualization Platform' end  );
            rhn_server.insert_into_servergroup (server_id_in, sgid);
            if is_virt = 1 then
              rhn_entitlements.repoll_virt_guest_entitlements(server_id_in);
            end if;
         else
            rhn_exception.raise_exception ('no_available_server_group');
         end if;
      else
         rhn_exception.raise_exception ('invalid_entitlement');
      end if;
   end entitle_server;
	procedure remove_server_entitlement (
		server_id_in in number,
		type_label_in in varchar2 := 'sw_mgr_entitled',
        repoll_virt_guests in number := 1
	) is
		group_id number;
      type_is_base char;
      is_virt number := 0;
	begin
      begin
        begin
          select 1 into is_virt
            from rhnServerEntitlementView
           where server_id = server_id_in
             and label in ('virtualization_host', 'virtualization_host_platform');
        exception
          when no_data_found then
            is_virt := 0;
        end;
		select	sg.id, sgt.is_base
  		into	group_id, type_is_base
  		from	rhnServerGroupType sgt,
   			rhnServerGroup sg,
  				rhnServerGroupMembers sgm,
  				rhnServer s
  		where	s.id = server_id_in
  			and s.id = sgm.server_id
  			and sgm.server_group_id = sg.id
  			and sg.org_id = s.org_id
  			and sgt.label = type_label_in
  			and sgt.id = sg.group_type;
      if ( type_is_base = 'Y' ) then
         unentitle_server ( server_id_in );
      else
         insert into rhnServerHistory ( id, server_id, summary, details )
         values ( rhn_event_id_seq.nextval, server_id_in,
                  'removed system entitlement ',
                   case type_label_in
                    when 'enterprise_entitled' then 'Management'
                    when 'sw_mgr_entitled' then 'Update'
                    when 'provisioning_entitled' then 'Provisioning'
                    when 'monitoring_entitled' then 'Monitoring'
                    when 'virtualization_host' then 'Virtualization'
                    when 'virtualization_host_platform' then 
                         'Virtualization Platforrm' end  );
         rhn_server.delete_from_servergroup(server_id_in, group_id);
         if type_label_in = 'monitoring_entitled' then
           DELETE
             FROM state_change
            WHERE o_id IN (SELECT probe_id
                             FROM rhn_check_probe
                            WHERE host_id = server_id_in);
           DELETE
             FROM time_series
            WHERE SUBSTR(o_id, INSTR(o_id, '-') + 1, 
                        (INSTR(o_id, '-', INSTR(o_id, '-') + 1) - INSTR(o_id, '-')) - 1)
              IN (SELECT probe_id
                    FROM rhn_check_probe
                   WHERE host_id = server_id_in);
           DELETE
             FROM rhn_probe
            WHERE recid IN (SELECT probe_id
                              FROM rhn_check_probe
                             WHERE host_id = server_id_in);
         end if;
         if is_virt = 1 and repoll_virt_guests = 1 then
           rhn_entitlements.repoll_virt_guest_entitlements(server_id_in);
         end if;
      end if;
  		exception
  		when no_data_found then
  				rhn_exception.raise_exception('invalid_server_group_member');	
      end;
 	end remove_server_entitlement;
   procedure unentitle_server (server_id_in in number) is
      cursor servergroups is
         select distinct sgt.label, sg.id server_group_id
         from  rhnServerGroupType sgt,
               rhnServerGroup sg,
               rhnServer s,
               rhnServerGroupMembers sgm
         where s.id = server_id_in
            and s.org_id = sg.org_id
            and sg.group_type = sgt.id
            and sgm.server_group_id = sg.id
            and sgm.server_id = s.id;
     is_virt number := 0;
   begin
      begin
        select 1 into is_virt
          from rhnServerEntitlementView
         where server_id = server_id_in
           and label in ('virtualization_host', 'virtualization_host_platform');
      exception
        when no_data_found then
          is_virt := 0;
      end;
      for servergroup in servergroups loop
         insert into rhnServerHistory ( id, server_id, summary, details )
         values ( rhn_event_id_seq.nextval, server_id_in,
                  'removed system entitlement ',
                   case servergroup.label
                    when 'enterprise_entitled' then 'Management'
                    when 'sw_mgr_entitled' then 'Update'
                    when 'provisioning_entitled' then 'Provisioning'
                    when 'monitoring_entitled' then 'Monitoring'
                    when 'virtualization_host' then 'Virtualization'
                    when 'virtualization_host_platform' then 
                         'Virtualization Platform' end  );
         rhn_server.delete_from_servergroup(server_id_in, 
                                            servergroup.server_group_id );
      end loop;
      if is_virt = 1 then
        rhn_entitlements.repoll_virt_guest_entitlements(server_id_in);
      end if;
   end unentitle_server;
    procedure repoll_virt_guest_entitlements(server_id_in in number)
    is
        cursor families is 
            select distinct cfs.channel_family_id
            from
                rhnChannelFamilyServers cfs,
                rhnVirtualInstance vi
            where
                vi.host_system_id = server_id_in
                and vi.virtual_system_id = cfs.server_id;
        cursor group_types is
            select distinct sg.group_type, sgt.label
            from
                rhnServerGroupType sgt,
                rhnServerGroup sg,
                rhnServerGroupMembers sgm,
                rhnVirtualInstance vi
            where
                vi.host_system_id = server_id_in
                and vi.virtual_system_id = sgm.server_id
                and sgm.server_group_id = sg.id
                and sg.group_type = sgt.id;
        cursor virt_servers_cfam(family_id_in in number, quantity_in in number)  is
            select virtual_system_id
            from (
                select rownum, vi.virtual_system_id
                from
                    rhnChannelFamilyMembers cfm,
                    rhnServerChannel sc,
                    rhnVirtualInstance vi
                where
                    vi.host_system_id = server_id_in
                    and vi.virtual_system_id = sc.server_id
                    and sc.channel_id = cfm.channel_id
                    and cfm.channel_family_id = family_id_in
                order by sc.modified desc
                )
            where rownum <= quantity_in;                
        cursor virt_servers_sgt(group_type_in in number, quantity_in in number)  is
            select virtual_system_id
            from (
                select rownum, vi.virtual_system_id
                from
                    rhnServerGroup sg,
                    rhnServerGroupMembers sgm,
                    rhnVirtualInstance vi
                where
                    vi.host_system_id = server_id_in
                    and vi.virtual_system_id = sgm.server_id
                    and sgm.server_group_id = sg.id
                    and sg.group_type = group_type_in
                order by sgm.modified desc
                )
            where rownum <= quantity_in;                
        org_id_val number;
        max_members_val number;
        current_members_calc number;
        sg_id number;
    begin
        select org_id
        into org_id_val
        from rhnServer
        where id = server_id_in;
        for family in families loop
            current_members_calc := 
                rhn_channel.channel_family_current_members(family.channel_family_id,
                                                           org_id_val); -- fixed transposed args
            select max_members
            into max_members_val
            from rhnPrivateChannelFamily
            where channel_family_id = family.channel_family_id
            and org_id = org_id_val;
            if current_members_calc > max_members_val then
                for virt_server in virt_servers_cfam(family.channel_family_id,
                                current_members_calc - max_members_val) loop 
                    rhn_channel.unsubscribe_server_from_family(
                                virt_server.virtual_system_id,
                                family.channel_family_id);
                end loop;                               
                if current_members_calc > max_members_val then
                    set_family_count(org_id_val,
                                     family.channel_family_id,
                                     max_members_val);
                end if; 
           end if;
            rhn_channel.update_family_counts(family.channel_family_id,
                                             org_id_val);
        end loop;
        for a_group_type in group_types loop
          select max_members, id
            into max_members_val, sg_id
            from rhnServerGroup
            where group_type = a_group_type.group_type
            and org_id = org_id_val;
	  select count(sep.server_id) into current_members_calc
            from rhnServerEntitlementPhysical sep
           where sep.server_group_id = sg_id
             and sep.server_group_type_id = a_group_type.group_type;
          if current_members_calc > max_members_val then
            for virt_server in virt_servers_sgt(a_group_type.group_type,
                                                current_members_calc - max_members_val) loop
              rhn_entitlements.remove_server_entitlement(virt_server.virtual_system_id, a_group_type.label);
              current_members_calc := current_members_calc - 1;
            end loop;
          end if;
          update rhnServerGroup set current_members = current_members_calc
           where org_id = org_id_val
             and group_type = a_group_type.group_type;
        end loop;
    end repoll_virt_guest_entitlements;
	function get_server_entitlement (
		server_id_in in number
	) return ents_array is
		cursor server_groups is
			select	sgt.label
			from	rhnServerGroupType		sgt,
					rhnServerGroup			sg,
					rhnServerGroupMembers	sgm
			where	1=1
				and sgm.server_id = server_id_in
				and sg.id = sgm.server_group_id
				and sgt.id = sg.group_type
				and sgt.label in (
					'sw_mgr_entitled','enterprise_entitled',
					'provisioning_entitled', 'nonlinux_entitled',
					'monitoring_entitled', 'virtualization_host',
                                        'virtualization_host_platform'
					);
         ent_array ents_array;
	begin
      ent_array := ents_array();
		for sg in server_groups loop
         ent_array.extend;
         ent_array(ent_array.count) := sg.label;
		end loop;
		return ent_array;
	end get_server_entitlement;
	procedure modify_org_service (
		org_id_in in number,
		service_label_in in varchar2,
		enable_in in char
	) is
		type roles_v is varray(10) of rhnUserGroupType.label%TYPE;
		roles_to_process roles_v;
		cursor roles(role_label_in in varchar2) is
			select	label, id
			from	rhnUserGroupType
			where	label = role_label_in;
		cursor org_roles(role_label_in in varchar2) is
			select	1
			from	rhnUserGroup ug,
					rhnUserGroupType ugt
			where	ugt.label = role_label_in
				and ug.org_id = org_id_in
				and ugt.id = ug.group_type;
		type ents_v is varray(10) of rhnOrgEntitlementType.label%TYPE;
		ents_to_process ents_v;
		cursor ents(ent_label_in in varchar2) is
			select	label, id
			from	rhnOrgEntitlementType
			where	label = ent_label_in;
		cursor org_ents(ent_label_in in varchar2) is
			select	1
			from	rhnOrgEntitlements oe,
					rhnOrgEntitlementType oet
			where	oet.label = ent_label_in
				and oe.org_id = org_id_in
				and oet.id = oe.entitlement_id;
		create_row char(1);
	begin
		ents_to_process := ents_v();
		roles_to_process := roles_v();
		if service_label_in = 'enterprise' or 
           service_label_in = 'management' then
			ents_to_process.extend;
			ents_to_process(ents_to_process.count) := 'sw_mgr_enterprise';
			roles_to_process.extend;
			roles_to_process(roles_to_process.count) := 'org_admin';
			roles_to_process.extend;
			roles_to_process(roles_to_process.count) := 'system_group_admin';
			roles_to_process.extend;
			roles_to_process(roles_to_process.count) := 'activation_key_admin';
			roles_to_process.extend;
			roles_to_process(roles_to_process.count) := 'org_applicant';
		elsif service_label_in = 'provisioning' then
			ents_to_process.extend;
			ents_to_process(ents_to_process.count) := 'rhn_provisioning';
			roles_to_process.extend;
			roles_to_process(roles_to_process.count) := 'system_group_admin';
			roles_to_process.extend;
			roles_to_process(roles_to_process.count) := 'activation_key_admin';
			roles_to_process.extend;
			roles_to_process(roles_to_process.count) := 'config_admin';
			if enable_in = 'Y' then
				ents_to_process.extend;
				ents_to_process(ents_to_process.count) := 'sw_mgr_enterprise';
			end if;
		elsif service_label_in = 'monitoring' then
			ents_to_process.extend;
			ents_to_process(ents_to_process.count) := 'rhn_monitor';
			roles_to_process.extend;
			roles_to_process(roles_to_process.count) := 'monitoring_admin';
		elsif service_label_in = 'virtualization' then
			ents_to_process.extend;
			ents_to_process(ents_to_process.count) := 'rhn_virtualization';
			roles_to_process.extend;
			roles_to_process(roles_to_process.count) := 'config_admin';
        elsif service_label_in = 'virtualization_platform' then
			ents_to_process.extend;
			ents_to_process(ents_to_process.count) := 'rhn_virtualization_platform'; 
			roles_to_process.extend;
			roles_to_process(roles_to_process.count) := 'config_admin';
	elsif service_label_in = 'nonlinux' then
			ents_to_process.extend;
			ents_to_process(ents_to_process.count) := 'rhn_nonlinux';
			roles_to_process.extend;
			roles_to_process(roles_to_process.count) := 'config_admin';
		end if;
		if enable_in = 'Y' then
			for i in 1..ents_to_process.count loop
				for ent in ents(ents_to_process(i)) loop
					create_row := 'Y';
					for oe in org_ents(ent.label) loop
						create_row := 'N';
					end loop;
					if create_row = 'Y' then
						insert into rhnOrgEntitlements(org_id, entitlement_id)
							values (org_id_in, ent.id);
					end if;
				end loop;
			end loop;
			for i in 1..roles_to_process.count loop
				for role in roles(roles_to_process(i)) loop
					create_row := 'Y';
					for o_r in org_roles(role.label) loop
						create_row := 'N';
					end loop;
					if create_row = 'Y' then
						insert into rhnUserGroup(
								id, name, description, current_members,
								group_type, org_id
							) (
								select	rhn_user_group_id_seq.nextval,
										ugt.name || 's',
										ugt.name || 's for Org ' ||
											o.name || ' ('|| o.id ||')',
										0, ugt.id, o.id
								from	rhnUserGroupType ugt,
										web_customer o
								where	o.id = org_id_in
									and ugt.id = role.id
							);
					end if;
				end loop;
			end loop;
		else
			for i in 1..ents_to_process.count loop
				for ent in ents(ents_to_process(i)) loop
					delete from rhnOrgEntitlements
					 where org_id = org_id_in
					   and entitlement_id = ent.id;
				end loop;
			end loop;
		end if;
	end modify_org_service;
	procedure set_customer_enterprise (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'enterprise', 'Y');
	end set_customer_enterprise;
	procedure set_customer_provisioning (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'provisioning', 'Y');
	end set_customer_provisioning;
	procedure set_customer_monitoring (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'monitoring', 'Y');
	end set_customer_monitoring;
	procedure set_customer_nonlinux (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'nonlinux', 'Y');
	end set_customer_nonlinux;
	procedure unset_customer_enterprise (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'enterprise', 'N');
	end unset_customer_enterprise;
	procedure unset_customer_provisioning (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'provisioning', 'N');
	end unset_customer_provisioning;
	procedure unset_customer_monitoring (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'monitoring', 'N');
	end unset_customer_monitoring;
	procedure unset_customer_nonlinux (
		customer_id_in in number
	) is
	begin
		modify_org_service(customer_id_in, 'nonlinux', 'N');
	end unset_customer_nonlinux;
	procedure prune_group (
		group_id_in in number,
		type_in in char,
		quantity_in in number
	) is
		cursor usergroups is
			select	user_id, user_group_id, ugt.label
			from	rhnUserGroupType	ugt,
					rhnUserGroup		ug,
					rhnUserGroupMembers	ugm
			where	1=1
				and ugm.user_group_id = group_id_in
				and ugm.user_id in (
					select	user_id
					from	(
						select	rownum row_number,
								user_id,
								time
						from	(
							select	user_id,
									modified time
							from	rhnUserGroupMembers
							where	user_group_id = group_id_in
							order by time asc
						)
					)
					where	row_number > quantity_in
				)
				and ugm.user_group_id = ug.id
				and ug.group_type = ugt.id;
        cursor servergroups is
           select  server_id, server_group_id, sgt.id group_type_id, sgt.label
            from    rhnServerGroupType              sgt,
                            rhnServerGroup                  sg,
                            rhnServerGroupMembers   sgm
            where   1=1
                    and sgm.server_group_id = group_id_in
                    and sgm.server_id in (
                            select  server_id
                            from    (
                                    select  rownum row_number,
                                                    server_id,
                                                    time
                                    from    (
                                            select  sep.server_id,
                                                    sep.modified time
                                            from
                                                rhnServerEntitlementPhysical sep
                                            where
                                                sep.server_group_id = group_id_in
                                            order by time asc
                                    )
                            )
                            where   row_number > quantity_in
                    )
                    and sgm.server_group_id = sg.id
                    and sg.group_type = sgt.id;
      type_is_base char;
	begin
		if type_in = 'U' then
			update		rhnUserGroup
				set		max_members = quantity_in
				where	id = group_id_in;
			for ug in usergroups loop
				rhn_user.remove_from_usergroup(ug.user_id, ug.user_group_id);
			end loop;
		elsif type_in = 'S' then
			update		rhnServerGroup
				set		max_members = quantity_in
				where	id = group_id_in;
			for sg in servergroups loop
				remove_server_entitlement(sg.server_id, sg.label);
            select is_base 
            into type_is_base
            from rhnServerGroupType sgt
            where sgt.id = sg.group_type_id;
            if ( type_is_base = 'Y' ) then
				   rhn_channel.clear_subscriptions(sg.server_id);
            end if;
			end loop;
		end if;
	end prune_group;
    procedure assign_system_entitlement(
        group_label_in in varchar2,
        from_org_id_in in number,
        to_org_id_in in number,
        quantity_in in number
    )
    is
        prev_ent_count number;
	to_org_prev_ent_count number;
        new_ent_count number;
	new_quantity number;
        group_type number;
    begin
        begin
            select max_members
            into prev_ent_count
            from rhnServerGroupType sgt,
                 rhnServerGroup sg
            where sg.org_id = from_org_id_in
              and sg.group_type = sgt.id
              and sgt.label = group_label_in;
        exception
            when NO_DATA_FOUND then
                rhn_exception.raise_exception(
                              'not_enough_entitlements_in_base_org');
        end;
        begin
            select max_members
            into to_org_prev_ent_count
            from rhnServerGroupType sgt,
                 rhnServerGroup sg
            where sg.org_id = to_org_id_in
              and sg.group_type = sgt.id
              and sgt.label = group_label_in;
        exception
            when NO_DATA_FOUND then
                to_org_prev_ent_count := 0;
        end;
        begin
            select id
            into group_type
            from rhnServerGroupType
            where label = group_label_in;
        exception
            when NO_DATA_FOUND then
                rhn_exception.raise_exception(
                              'invalid_server_group');
        end;
        new_ent_count := prev_ent_count - quantity_in;
        if prev_ent_count > new_ent_count then
            new_quantity := to_org_prev_ent_count + quantity_in;
        end if;
        if new_ent_count < 0 then
            rhn_exception.raise_exception(
                          'not_enough_entitlements_in_base_org');
        end if;
        rhn_entitlements.set_group_count(from_org_id_in,
                                         'S',
                                         group_type,
                                         new_ent_count);
        rhn_entitlements.set_group_count(to_org_id_in,
                                         'S',
                                         group_type,
                                         new_quantity);
        if group_label_in = 'enterprise_entitled' then 
            if new_quantity > 0 then
                set_customer_enterprise(to_org_id_in);
            else
                unset_customer_enterprise(to_org_id_in);
            end if;
        end if;
        if group_label_in = 'provisioning_entitled' then
            if new_quantity > 0 then
                set_customer_provisioning(to_org_id_in);
            else
                unset_customer_provisioning(to_org_id_in);
            end if;
        end if;
        if group_label_in = 'monitoring_entitled' then
            if new_quantity > 0 then
                set_customer_monitoring(to_org_id_in);
            else
                unset_customer_monitoring(to_org_id_in);
            end if;
        end if;
    end assign_system_entitlement;
    procedure assign_channel_entitlement(
        channel_family_label_in in varchar2,
        from_org_id_in in number,
        to_org_id_in in number,
        quantity_in in number
    )
    is
        prev_ent_count number;
        new_ent_count number;
	to_org_prev_ent_count number;
	new_quantity number;
        cfam_id       number;
    begin
        begin
            select max_members
            into prev_ent_count
            from rhnChannelFamily cf,
                 rhnPrivateChannelFamily pcf
            where pcf.org_id = from_org_id_in
              and pcf.channel_family_id = cf.id
              and cf.label = channel_family_label_in;
        exception
            when NO_DATA_FOUND then
                rhn_exception.raise_exception(
                              'not_enough_entitlements_in_base_org');
        end;
        begin
            select max_members
            into to_org_prev_ent_count
            from rhnChannelFamily cf,
                 rhnPrivateChannelFamily pcf
            where pcf.org_id = to_org_id_in
              and pcf.channel_family_id = cf.id
              and cf.label = channel_family_label_in;
        exception
            when NO_DATA_FOUND then
                to_org_prev_ent_count := 0;
        end;
        begin
            select id
            into cfam_id
            from rhnChannelFamily
            where label = channel_family_label_in;
        exception
            when NO_DATA_FOUND then
                rhn_exception.raise_exception(
                              'invalid_channel_family');
        end;                              
        new_ent_count := prev_ent_count - quantity_in;
	if prev_ent_count > new_ent_count then
            new_quantity := to_org_prev_ent_count + quantity_in;
	end if;
        if new_ent_count < 0 then
            rhn_exception.raise_exception(
                          'not_enough_entitlements_in_base_org');
        end if;
        rhn_entitlements.set_family_count(from_org_id_in,
                                          cfam_id,
                                          new_ent_count);
        rhn_entitlements.set_family_count(to_org_id_in,
                                          cfam_id,
                                          new_quantity);
    end assign_channel_entitlement;
    procedure activate_system_entitlement(
        org_id_in in number,
        group_label_in in varchar2,
        quantity_in in number
    )
    is
        prev_ent_count number; 
        prev_ent_count_sum number; 
        group_type number;
    begin
        begin
            select current_members
            into prev_ent_count
            from rhnServerGroupType sgt,
                 rhnServerGroup sg
            where sg.group_type = sgt.id
              and sgt.label = group_label_in
              and sg.org_id = org_id_in;
        exception
            when NO_DATA_FOUND then
                prev_ent_count := 0;
        end;
        begin
            select id
            into group_type
            from rhnServerGroupType
            where label = group_label_in;
        exception
            when NO_DATA_FOUND then
                rhn_exception.raise_exception(
                              'invalid_server_group');
        end;
        if quantity_in < prev_ent_count then
            rhn_exception.raise_exception(
                          'not_enough_entitlements_in_base_org');
        else
            rhn_entitlements.set_group_count(org_id_in,
                                             'S',
                                             group_type,
                                             quantity_in);
        end if;
    end activate_system_entitlement;
    procedure activate_channel_entitlement(
        org_id_in in number,
        channel_family_label_in in varchar2,
        quantity_in in number
    )
    is
        prev_ent_count number; 
        prev_ent_count_sum number; 
        cfam_id number;
    begin
        begin
            select current_members
            into prev_ent_count
            from rhnChannelFamily cf,
                 rhnPrivateChannelFamily pcf
            where pcf.org_id = org_id_in
              and pcf.channel_family_id = cf.id
              and cf.label = channel_family_label_in;
        exception
            when NO_DATA_FOUND then
                prev_ent_count := 0;
        end;
        begin
            select id
            into cfam_id
            from rhnChannelFamily
            where label = channel_family_label_in;
        exception
            when NO_DATA_FOUND then
                rhn_exception.raise_exception(
                              'invalid_channel_family');
        end;                              
        if quantity_in < prev_ent_count then
            rhn_exception.raise_exception(
                          'not_enough_entitlements_in_base_org');
        else
            rhn_entitlements.set_family_count(org_id_in,
                                              cfam_id,
                                              quantity_in);
        end if;
    end activate_channel_entitlement;
	procedure set_group_count (
		customer_id_in in number,
		type_in in char,
		group_type_in in number,
		quantity_in in number
	) is
		group_id number;
		quantity number;
	begin
		quantity := quantity_in;
		if quantity is not null and quantity < 0 then
			quantity := 0;
		end if;
		if type_in = 'U' then
			select	rug.id
			into	group_id
			from	rhnUserGroup rug
			where	1=1
				and rug.org_id = customer_id_in
				and rug.group_type = group_type_in;
		elsif type_in = 'S' then
			select	rsg.id
			into	group_id
			from	rhnServerGroup rsg
			where	1=1
				and rsg.org_id = customer_id_in
				and rsg.group_type = group_type_in;
		end if;
		rhn_entitlements.prune_group(
			group_id,
			type_in,
			quantity
		);
	exception
		when no_data_found then
			if type_in = 'U' then
				insert into rhnUserGroup (
						id, name, description, max_members, current_members,
						group_type, org_id, created, modified
					) (
						select	rhn_user_group_id_seq.nextval, name, name,
								quantity, 0, id, customer_id_in,
								sysdate, sysdate
						from	rhnUserGroupType
						where	id = group_type_in
				);
			elsif type_in = 'S' then
				insert into rhnServerGroup (
						id, name, description, max_members, current_members,
						group_type, org_id, created, modified
					) (
						select	rhn_server_group_id_seq.nextval, name, name,
								quantity, 0, id, customer_id_in,
								sysdate, sysdate
						from	rhnServerGroupType
						where	id = group_type_in
				);
			end if;
	end set_group_count;
	procedure prune_family (
		customer_id_in in number,
		channel_family_id_in in number,
		quantity_in in number
	) is
		cursor serverchannels is
			select	sc.server_id,
					sc.channel_id
			from	rhnServerChannel sc,
					rhnChannelFamilyMembers cfm
			where	1=1
				and cfm.channel_family_id = channel_family_id_in
				and cfm.channel_id = sc.channel_id
				and server_id in (
					select	server_id
					from	(
						select	server_id,
								time,
								rownum row_number
						from	(
							select	rs.id					server_id,
									rcfm.modified			time
							from	
									rhnServerChannel		rsc,
									rhnChannelFamilyMembers	rcfm,
                                    rhnServer				rs
							where	1=1
								and rs.org_id = customer_id_in
								and rs.id = rsc.server_id
								and rsc.channel_id = rcfm.channel_id
								and rcfm.channel_family_id =
									channel_family_id_in
                                and exists (
                                    select 1
                                    from rhnChannelFamilyServerPhysical cfsp
                                    where cfsp.server_id = rs.id
                                    and cfsp.channel_family_id = 
                                        channel_family_id_in
                                    )
							order by time asc
						)
					)
					where row_number > quantity_in
				);
	begin
		if customer_id_in is null then
			return;
		end if;
		update		rhnPrivateChannelFamily
			set		max_members = quantity_in
			where	1=1
				and org_id = customer_id_in
				and channel_family_id = channel_family_id_in;
		for sc in serverchannels loop
			rhn_channel.unsubscribe_server(sc.server_id, sc.channel_id, 1, 1);
		end loop;
	end prune_family;
	procedure set_family_count (
		customer_id_in in number,
		channel_family_id_in in number,
		quantity_in in number
	) is
		cursor privperms is
			select	1
			from	rhnPrivateChannelFamily
			where	org_id = customer_id_in
				and channel_family_id = channel_family_id_in;
		cursor pubperms is
			select	o.id org_id
			from	web_customer o,
					rhnPublicChannelFamily pcf
			where	pcf.channel_family_id = channel_family_id_in;
		quantity number;
		done number := 0;
	begin
		quantity := quantity_in;
		if quantity is not null and quantity < 0 then
			quantity := 0;
		end if;
		if customer_id_in is not null then
			for perm in privperms loop
				rhn_entitlements.prune_family(
					customer_id_in,
					channel_family_id_in,
					quantity
				);
				update rhnPrivateChannelFamily
					set max_members = quantity
					where org_id = customer_id_in
						and channel_family_id = channel_family_id_in;
				return;
			end loop;
			insert into rhnPrivateChannelFamily (
					channel_family_id, org_id, max_members, current_members
				) values (
					channel_family_id_in, customer_id_in, quantity, 0
				);
			return;
		end if;
		for perm in pubperms loop
			if quantity = 0 then
				rhn_entitlements.prune_family(
					perm.org_id,
					channel_family_id_in,
					quantity
				);
				if done = 0 then
					delete from rhnPublicChannelFamily
						where channel_family_id = channel_family_id_in;
				end if;
			end if;
			done := 1;
		end loop;
		if done != 1 then
			insert into rhnPublicChannelFamily (
					channel_family_id
				) values (
					channel_family_id_in
				);
		end if;
	end set_family_count;
	procedure entitle_last_modified_servers (
		customer_id_in in number,
		type_label_in in varchar2,
		quantity_in in number
	) is
		cursor servers(cid_in in number, quant_in in number) is
			select	server_id
			from	(
						select	rownum row_number,
								server_id
						from	(
									select	rs.id server_iD
									from	rhnServer rs
									where	1=1
										and rs.org_id = cid_in
										and not exists (
											select	1
											from	rhnServerGroup sg,
													rhnServerGroupMembers rsgm
											where	rsgm.server_id = rs.id
												and rsgm.server_group_id = sg.id
												and sg.group_type is not null
										)
                                        and not exists (
                                            select 1
                                            from rhnVirtualInstance vi
                                            where vi.virtual_system_id =
                                                  rs.id
                                        )                                                                           order by modified desc
								)
					)
			where	row_number <= quant_in;
	begin
		for server in servers(customer_id_in, quantity_in) loop
			rhn_entitlements.entitle_server(server.server_id, type_label_in);
		end loop;
	end entitle_last_modified_servers;
	procedure prune_everything (
		customer_id_in in number
	) is
		cursor everything is
			select	sg.id					id,
					'S'						type,
					sg.max_members			quantity
			from	rhnServerGroup			sg
			where	sg.org_id = customer_id_in
			union
			select	ug.id					id,
					'U'						type,
					ug.max_members 			quantity
			from	rhnUserGroup			ug
			where	ug.org_id = customer_id_in
			union ( 
			select	cfp.channel_family_id	id,
					'C'						type,
					cfp.max_members			quantity
			from	rhnOrgChannelFamilyPermissions cfp
			where	cfp.org_id = customer_id_in
			union
			select	cfm.channel_family_id	id,
					'C'						type,
					0						quantity
			from	rhnChannelFamily		cf,
					rhnChannelFamilyMembers	cfm,
					rhnServerChannel		sc,
					rhnServer				s
			where	s.org_id = customer_id_in
				and s.id = sc.server_id
				and sc.channel_id = cfm.channel_id
				and cfm.channel_family_id = cf.id
				and cf.org_id is not null
				and cf.org_id != customer_id_in
				and not exists (
					select	1
					from	rhnOrgChannelFamilyPermissions cfp
					where	cfp.org_id = customer_id_in
						and cfp.channel_family_id = cfm.channel_family_id
					)
			);
	begin
		for one in everything loop
			if one.type in ('U','S') then
				prune_group(one.id, one.type, one.quantity);
			else
				prune_family(customer_id_in, one.id, one.quantity);
			end if;
		end loop;
	end prune_everything;
	procedure subscribe_newest_servers (
		customer_id_in in number
	) is
		cursor servers(cid_in in number) is
			select	s.id
			from	rhnServer			s
			where	1=1
				and s.org_id = cid_in
				and not exists (
						select 1
						from	rhnChannel			c,
								rhnServerChannel	sc
						where	sc.server_id = s.id
							and sc.channel_id = c.id
							and c.parent_channel is null
					)
                and not exists (
                        select 1
                        from rhnVirtualInstance vi
                        where vi.virtual_system_id = s.id
                    )                        
			order by s.modified desc;
		channel_id number;
	begin
		for server in servers(customer_id_in) loop
			channel_id := rhn_channel.guess_server_base(server.id);
			if channel_id is not null then
				begin
					rhn_channel.subscribe_server(server.id, channel_id);
					commit;
				exception
					when others then
						null;
				end;
			end if;
		end loop;
	end subscribe_newest_servers;
end rhn_entitlements;
/
show errors

select 'rhnsat/views/rhnServerOverview.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnServerOverview.sql
create or replace view
rhnServerOverview
(
    org_id, 
    server_id, 
    server_name, 
    note_count, 
    modified, 
    server_admins, 
    group_count, 
    channel_id,
    channel_labels, 
    history_count, 
    security_errata, 
    bug_errata, 
    enhancement_errata,
    outdated_packages,
    last_checkin_days_ago,
    last_checkin,
    pending_updates,
    os,
    release,
    server_arch_name,
    locked
)
as
select
    s.org_id, s.id, s.name, 0, s.modified, 
    ( select count(user_id) from rhnUserServerPerms ap 
      where server_id = s.id ), 
    ( select count(server_group_id) from rhnVisibleServerGroupMembers
      where server_id = s.id ),
    ( select C.id
        from rhnChannel C,
	     rhnServerChannel SC
       where SC.server_id = S.id
         and SC.channel_id = C.id
	 and C.parent_channel IS NULL),
    NVL(( select C.name
        from rhnChannel C,
	     rhnServerChannel SC
       where SC.server_id = S.id
         and SC.channel_id = C.id
	 and C.parent_channel IS NULL), '(none)'),
    ( select count(id) from rhnServerHistory
      where
            server_id = S.id),
    ( select count(*) from rhnServerErrataTypeView setv 
      where
            setv.server_id = s.id
        and setv.errata_type = 'Security Advisory'), 
    ( select count(*) from rhnServerErrataTypeView setv 
      where 
            setv.server_id = s.id
        and setv.errata_type = 'Bug Fix Advisory'),
    ( select count(*) from rhnServerErrataTypeView setv 
      where 
            setv.server_id = s.id
        and setv.errata_type = 'Product Enhancement Advisory'),
    ( select count(distinct p.name_id) from rhnPackage p, rhnServerNeededPackageCache snpc
      where
             snpc.server_id = S.id
	 and p.id = snpc.package_id
	 ),    
    ( select sysdate - checkin from rhnServerInfo where server_id = S.id ),
    ( select TO_CHAR(checkin, 'YYYY-MM-DD HH24:MI:SS') from rhnServerInfo where server_id = S.id ),
    ( select count(1) 
        from rhnServerAction
       where server_id = S.id
         and status in (0, 1)),
    os,
    release,
    ( select name from rhnServerArch where id = s.server_arch_id),
    NVL((select 1 from rhnServerLock SL WHERE SL.server_id = S.id), 0)
from 
    rhnServer S
/

select 'rhnsat/views/rhnStorageDevice.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnStorageDevice.sql
create or replace view 
rhnStorageDevice
(id, server_Id, class, bus, detached, device, driver, 
description, physical, logical, pcitype)
as select 
	d.id,
	d.server_Id,
	d.class,
	d.bus,
	d.detached,
	d.device,
	d.driver,
	d.description,
	d.prop1,
	d.prop2,
	d.pcitype
from rhnDevice d
where d.class in ('HD', 'FLOPPY');

select 'rhnsat/views/rhnUserActionOverview.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUserActionOverview.sql
create or replace view rhnUserActionOverview as
select	ao.org_id                                       org_id,
	usp.user_id                                     user_id,
    	ao.action_id                                    id,
	ao.type_name                                    type_name,
        ao.scheduler                                    scheduler,
	ao.earliest_action                              earliest_action,
	decode(ao.name, null, ao.type_name, ao.name)	action_name,
	sa.status					action_status_id,
	astat.name                                      action_status,
	count(sa.action_id)				tally,
	ao.archived                                     archived
from	rhnActionStatus            astat,
    	rhnUserServerPerms         usp,
	rhnServerAction            sa,
	rhnActionOverview	   ao
where	ao.action_id = sa.action_id
  and   sa.server_id = usp.server_id
  and   sa.status = astat.id
group by ao.org_id,
	 usp.user_id,
	 ao.action_id,
	 ao.type_name,
	 ao.scheduler,
	 ao.earliest_action,
	 decode(ao.name, null, ao.type_name, ao.name),
	 sa.status,
	 astat.name,
	 ao.archived
order by earliest_action;

select 'rhnsat/views/rhnUserAppletOverview.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUserAppletOverview.sql
CREATE OR REPLACE VIEW
rhnUserAppletOverview
(
    	    user_id,
    	    security_count,
	    bug_count,
	    enhancement_count
)
AS
SELECT      USP.user_id,
    	    SUM((SELECT COUNT(*) FROM rhnServerErrataTypeView SEV 
	         WHERE SEV.server_id = USP.server_id
	         AND SEV.errata_type = 'Security Advisory')),
    	    SUM((SELECT COUNT(*) FROM rhnServerErrataTypeView SEV 
	         WHERE SEV.server_id = USP.server_id
	         AND SEV.errata_type = 'Bug Fix Advisory')),
    	    SUM((SELECT COUNT(*) FROM rhnServerErrataTypeView SEV 
	         WHERE SEV.server_id = USP.server_id
	         AND SEV.errata_type = 'Product Enhancement Advisory'))
FROM        rhnUserServerPerms USP
GROUP BY    USP.user_id
/

select 'rhnsat/views/rhnUserChannelFamilyPerms.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUserChannelFamilyPerms.sql
create or replace view rhnUserChannelFamilyPerms as
	select	pcf.channel_family_id,
		u.org_id org_id,
		u.id user_id,
		to_number(null) max_members,
		0 current_members,
		pcf.created,
		pcf.modified
	from	rhnPublicChannelFamily pcf,
		web_contact u
	union
	select	pcf.channel_family_id,
		u.org_id,
		u.id user_id,
		pcf.max_members,
		pcf.current_members,
		pcf.created,
		pcf.modified
	from	rhnPrivateChannelFamily pcf,
		web_contact u
	where	u.org_id = pcf.org_id;

select 'rhnsat/views/rhnUserChannelTreeView.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUserChannelTreeView.sql
CREATE OR REPLACE VIEW rhnUserChannelTreeView
(
	user_id,
	org_id,
        id,
        depth,
	name,
        padded_name,
	channel_arch_id,
        last_modified,
        label,
	parent_or_self_label,
	parent_or_self_id,
	end_of_life
)
AS
select * from (
	select	cfp.user_id		user_id,
		cfp.org_id		org_id,
		c.id			id,
		1			depth,
		c.name			name,
		'  ' || c.name		padded_name,
		c.channel_arch_id	channel_arch_id,
		c.last_modified		last_modified,
		c.label			label,
		c.label			parent_or_self_label,
		c.id			parent_or_self_id,
		c.end_of_life		end_of_life
	from	rhnChannel		c,
		rhnChannelFamilyMembers cfm,
		rhnUserChannelFamilyPerms cfp
	where	1=1
		and cfp.channel_family_id = cfm.channel_family_id
		and cfm.channel_id = c.id
		and c.parent_channel is null
	union
	select	cfp.user_id		user_id,
		cfp.org_id		org_id,
		c.id			id,
		2			depth,
		c.name			name,
		'' || c.name		padded_name,
		c.channel_arch_id 	channel_arch_id,
		c.last_modified		last_modified,
		c.label			label,
		pc.label		parent_or_self_label,
		pc.id			parent_or_self_id,
		c.end_of_life		end_of_life
	from	rhnChannel		pc,
		rhnChannel		c,
		rhnChannelFamilyMembers	cfm,
		rhnUserChannelFamilyPerms cfp
	where	1=1
		and cfp.channel_family_id = cfm.channel_family_id
		and cfm.channel_id = c.id
		and c.parent_channel = pc.id
) order by parent_or_self_label, parent_or_self_id;

select 'rhnsat/views/rhnUserAvailableChannels.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUserAvailableChannels.sql
create or replace view
rhnUserAvailableChannels
(
    	user_id,
	org_id,
	channel_id,
	channel_depth,
	channel_name,
	channel_arch_id,
	padded_name,
	current_members,
	available_members,
        last_modified,
        channel_label,
	parent_or_self_label,
	parent_or_self_id,
	end_of_life
)
as
select
     ct.user_id,
     ct.org_id,
     ct.id, 
     CT.depth, 
     CT.name, 
     CT.channel_arch_id, 
     CT.padded_name,
     (
     SELECT COUNT(1) 
       FROM rhnUserServerPerms USP
      WHERE USP.user_id = ct.user_id
        AND EXISTS (SELECT 1 FROM rhnServerChannel WHERE channel_id = ct.id AND server_id = USP.server_id)
     ),
     rhn_channel.available_chan_subscriptions(ct.id, ct.org_id),
     CT.last_modified,
     CT.label,
     CT.parent_or_self_label,
     CT.parent_or_self_id,
     CT.end_of_life
from
     rhnUserChannelTreeView ct      
where rhn_channel.org_channel_setting(ct.id, ct.org_id ,'not_globally_subscribable') = 0 OR exists (
     						SELECT 1 from rhnChannelPermission per where per.channel_id = ct.id     
     						) 
                            OR (rhn_user.check_role(ct.user_id, 'org_admin') = 1 
                                OR rhn_user.check_role(ct.user_id, 'channel_admin') = 1)
/

select 'rhnsat/views/rhnUserChannel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUserChannel.sql
create or replace view rhnUserChannel
as
select
   cfp.user_id,
   cfp.org_id,
   cfm.channel_id,
   'manage' role
from rhnChannelFamilyMembers cfm,
      rhnUserChannelFamilyPerms cfp
where
   cfp.channel_family_id = cfm.channel_family_id and
   rhn_channel.user_role_check(cfm.channel_id, cfp.user_id, 'manage') = 1
union all
select
   cfp.user_id,
   cfp.org_id,
   cfm.channel_id,
   'subscribe' role
from rhnChannelFamilyMembers cfm,
      rhnUserChannelFamilyPerms cfp
where
   cfp.channel_family_id = cfm.channel_family_id and
   rhn_channel.user_role_check(cfm.channel_id, cfp.user_id, 'subscribe') = 1
union all
select
   w.id as user_id,
   w.org_id,
   s.id as channel_id,
   'subscribe' role
from rhnSharedChannelView s,
      web_contact w
where
   w.org_id = s.org_trust_id and
   rhn_channel.user_role_check(s.id, w.id, 'subscribe') = 1;

select 'rhnsat/views/rhnUserGroupMembership.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUserGroupMembership.sql
CREATE OR REPLACE VIEW rhnUserGroupMembership (
         ORG_ID, USER_ID, GROUP_ID, GROUP_NAME, GROUP_TYPE
)
AS
SELECT   UG.org_id, UGM.user_id, UG.id, UG.name, UGT.label
  FROM   rhnUserGroupType UGT, 
    	 rhnUserGroup UG, 
	 rhnUserGroupMembers UGM
 WHERE   UG.id = UGM.user_group_id(+)
   AND   UG.group_type = UGT.id
/

select 'rhnsat/views/rhnUserServerPermsDupes.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUserServerPermsDupes.sql
create or replace view rhnUserServerPermsDupes as
select	usg.user_id,
	sgm.server_id
from	rhnServerGroupMembers sgm,
	rhnUserServerGroupPerms usg
where	usg.server_group_id = sgm.server_group_id
union all
select	ugm.user_id, s.id
from	rhnServer s,
	rhnUserGroup ug,
	rhnUserGroupMembers ugm,
	rhnUserGroupType ugt
where	ugt.label = 'org_admin'
	and ugm.user_group_id = ug.id
	and ug.group_type = ugt.id
	and ug.org_id = s.org_id
/

select 'rhnsat/views/rhnUserTypeBase.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUserTypeBase.sql
create or replace view rhnUserTypeBase (
       user_id, type_id, type_label, type_name
)
AS
select distinct
    ugm.user_id, ugt.id, ugt.label, ugt.name
from   
    rhnUserGroupMembers ugm, rhnUserGroupType ugt, rhnUserGroup ug
where   
    ugm.user_group_id = ug.id
and ugt.id = ug.group_type;

select 'rhnsat/views/rhnUserTypeArray.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUserTypeArray.sql
create or replace view rhnUserTypeArray (
       user_id, type_id_t, type_label_t, type_name_t
)
as
select
    U.id,
    cast(multiset(select utb.type_id
    	    	  from rhnUserTypeBase utb 
    	    	  where utb.user_id = u.id)
	 as user_group_id_t),
    cast(multiset(select utb.type_label
    	    	  from rhnUserTypeBase utb
    	    	  where utb.user_id = u.id)
	 as user_group_label_t),
    cast(multiset(select utb.type_name
    	    	  from rhnUserTypeBase utb
    	    	  where utb.user_id = u.id)
	 as user_group_name_t)
from 
    web_contact u
/

select 'rhnsat/procs/name_join.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/name_join.sql
CREATE OR REPLACE FUNCTION
NAME_JOIN(sep_in IN VARCHAR2, ugi_in IN user_group_name_t)
RETURN VARCHAR2
deterministic
IS
	ret	VARCHAR2(4000);
	i	BINARY_INTEGER;
BEGIN
	ret := '';
	i := ugi_in.FIRST;
	IF i IS NULL
	THEN
		RETURN ret;
	END IF;
	ret := ugi_in(i);
	i := ugi_in.NEXT(i);
	WHILE i IS NOT NULL
	LOOP
		ret := ret || sep_in || ugi_in(i);
		i := ugi_in.NEXT(i);
	END LOOP;
	RETURN ret;
END;
/
SHOW ERRORS

select 'rhnsat/procs/label_join.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/label_join.sql
CREATE OR REPLACE FUNCTION
LABEL_JOIN(sep_in IN VARCHAR2, ugi_in IN user_group_label_t)
RETURN VARCHAR2
deterministic
IS
	ret	VARCHAR2(4000);
	i	BINARY_INTEGER;
BEGIN
	ret := '';
	i := ugi_in.FIRST;
	IF i IS NULL
	THEN
		RETURN ret;
	END IF;
	ret := ugi_in(i);
	i := ugi_in.NEXT(i);
	WHILE i IS NOT NULL
	LOOP
		ret := ret || sep_in || ugi_in(i);
		i := ugi_in.NEXT(i);
	END LOOP;
	RETURN ret;
END;
/
SHOW ERRORS

select 'rhnsat/procs/id_join.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/id_join.sql
CREATE OR REPLACE FUNCTION
ID_JOIN(sep_in IN VARCHAR2, ugi_in IN user_group_id_t)
RETURN VARCHAR2
deterministic
IS
	ret	VARCHAR2(4000);
	i	BINARY_INTEGER;
BEGIN
	ret := '';
	i := ugi_in.FIRST;
	IF i IS NULL
	THEN
		RETURN ret;
	END IF;
	ret := ugi_in(i);
	i := ugi_in.NEXT(i);
	WHILE i IS NOT NULL
	LOOP
		ret := ret || sep_in || ugi_in(i);
		i := ugi_in.NEXT(i);
	END LOOP;
	RETURN ret;
END;
/
SHOW ERRORS

select 'rhnsat/views/rhnUserTypeCommaView.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUserTypeCommaView.sql
create or replace view rhnUserTypeCommaView (
       user_id, ids, labels, names
)
as
select
    uta.user_id,
    id_join(', ', uta.type_id_t),
    label_join(', ', uta.type_label_t),
    name_join(', ', uta.type_name_t)
from	   
    rhnUserTypeArray uta
/

select 'rhnsat/views/rhnVisibleServerGroup.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnVisibleServerGroup.sql
CREATE OR REPLACE VIEW
rhnVisibleServerGroup
AS
  SELECT *
    FROM rhnServerGroup SG
   WHERE SG.group_type IS NULL;

select 'rhnsat/views/rhnUsersInOrgOverview.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnUsersInOrgOverview.sql
create or replace view rhnUsersInOrgOverview as
select    
	u.org_id					org_id,
	u.id						user_id,
	u.login						user_login,
	pi.first_names					user_first_name,
	pi.last_name					user_last_name,
	u.modified					user_modified, 
    	(	select	count(server_id)
		from	rhnUserServerPerms sp
		where	sp.user_id = u.id)
							server_count, 
	(	select	count(server_group_id)
		from	rhnUserManagedServerGroups umsg
		where	umsg.user_id = u.id and exists (
			select	1
			from	rhnVisibleServerGroup sg
			where	sg.id = umsg.server_group_id))
							server_group_count,
	(	select	nvl(utcv.names, '(normal user)')
		from	rhnUserTypeCommaView utcv
		where	utcv.user_id = u.id)
							role_names
from	web_user_personal_info pi, 
	web_contact u 
where
	u.id = pi.web_user_id;

select 'rhnsat/views/rhnVisServerGroupMembership.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnVisServerGroupMembership.sql
CREATE OR REPLACE VIEW rhnVisServerGroupMembership (
         ORG_ID, SERVER_ID, GROUP_ID, GROUP_NAME, GROUP_TYPE, CURRENT_MEMBERS, MAX_MEMBERS
)
AS
SELECT   SG.org_id, SGM.server_id, SG.id, SG.name, SGT.label, SG.current_members, SG.max_members
  FROM   rhnServerGroupType SGT, 
	 rhnServerGroupMembers SGM,
    	 rhnVisibleServerGroup SG
 WHERE   SG.id = SGM.server_group_id(+)
   AND   SG.group_type = SGT.id(+)
/

select 'rhnsat/views/rhnVisServerGroupOverview.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnVisServerGroupOverview.sql
CREATE OR REPLACE VIEW rhnVisServerGroupOverview (
         ORG_ID, SECURITY_ERRATA, BUG_ERRATA, ENHANCEMENT_ERRATA, GROUP_ID, GROUP_NAME, GROUP_ADMINS, SERVER_COUNT, NOTE_COUNT, MODIFIED, MAX_MEMBERS
)
AS
  SELECT SG.org_id, 
         (SELECT COUNT(E.id)
	    FROM rhnErrata E
	   WHERE E.advisory_type = 'Security Advisory'
	     AND EXISTS (SELECT 1 FROM rhnServerNeededPackageCache SNEC, rhnServerGroupMembers SGM
	                         WHERE SGM.server_id = SNEC.server_id
				   AND SNEC.errata_id = E.id
				   AND SGM.server_group_id = SG.id)),
         (SELECT COUNT(E.id)
	    FROM rhnErrata E
	   WHERE E.advisory_type = 'Bug Fix Advisory'
	     AND EXISTS (SELECT 1 FROM rhnServerNeededPackageCache SNEC, rhnServerGroupMembers SGM
	                         WHERE SGM.server_id = SNEC.server_id
				   AND SNEC.errata_id = E.id
				   AND SGM.server_group_id = SG.id)),
         (SELECT COUNT(E.id)
	    FROM rhnErrata E
	   WHERE E.advisory_type = 'Product Enhancement Advisory'
	     AND EXISTS (SELECT 1 FROM rhnServerNeededPackageCache SNEC, rhnServerGroupMembers SGM
	                         WHERE SGM.server_id = SNEC.server_id
				   AND SNEC.errata_id = E.id
				   AND SGM.server_group_id = SG.id)),
	 SG.id, SG.name, 
	 (SELECT COUNT(*) FROM rhnUserManagedServerGroups UMSG WHERE UMSG.server_group_id = SG.id),
	 (SELECT COUNT(*) FROM rhnServerGroupMembers SGM WHERE SGM.server_group_id = SG.id), 
	 0, SYSDATE, MAX_MEMBERS
    FROM rhnVisibleServerGroup SG;

select 'rhnsat/views/rhnVisServerGroupOverviewLite.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnVisServerGroupOverviewLite.sql
create or replace view
rhnVisServerGroupOverviewLite as
select	sg.org_id					org_id,
		case when exists (
			select	1
			from	rhnServerGroupOVLiteHelper
			where	server_group_id = sg.id
				and advisory_type = 'Security Advisory'
			)
			then 1
			else 0
			end						security_errata,
		case when exists (
			select	1
			from	rhnServerGroupOVLiteHelper
			where	server_group_id = sg.id
				and advisory_type = 'Bug Fix Advisory'
			)
			then 1
			else 0
			end						bug_errata,
		case when exists (
			select	1
			from	rhnServerGroupOVLiteHelper
			where	server_group_id = sg.id
				and advisory_type = 'Product Enhancement Advisory'
			)
			then 1
			else 0
			end						enhancement_errata,
		sg.id						group_id,
		sg.name						group_name,
		(	select	count(*)
			from	rhnUserManagedServerGroups	umsg
			where	umsg.server_group_id = sg.id
		)							group_admins,
		(	select	count(*)
			from	rhnServerGroupMembers		sgm
			where	sgm.server_group_id = sg.id
		)							server_count,
		0							note_count,
		sysdate						modified,
		max_members					max_members
from	rhnVisibleServerGroup		sg
/

select 'rhnsat/views/rhnWebContactEnabled.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/views/rhnWebContactEnabled.sql
create or replace view
rhnWebContactEnabled
as
select
   wcon.id,
   wcon.org_id,
   wcon.login,
   wcon.login_uc,
   wcon.password,
   wcon.old_password,
   wcon.oracle_contact_id,
   wcon.created,
   wcon.modified,
   wcon.ignore_flag
from
   web_contact wcon
minus
select
   wcd.id,
   wcd.org_id,
   wcd.login,
   wcd.login_uc,
   wcd.password,
   wcd.old_password,
   wcd.oracle_contact_id,
   wcd.created,
   wcd.modified,
   wcd.ignore_flag
from
   rhnWebContactDisabled wcd;

select 'rhnsat/procs/channel_name_join.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/channel_name_join.sql
create or replace function
channel_name_join(sep_in in varchar2, ch_in in channel_name_t)
return varchar2
deterministic
is
	ret	varchar2(4000);
	i	binary_integer;
begin
	ret := '';
	i := ch_in.first;
	if i is null
	then
		return ret;
	end if;
	ret := ch_in(i);
	i := ch_in.next(i);
	while i is not null
	loop
		ret := ret || sep_in || ch_in(i);
		i := ch_in.next(i);
	end loop;
	return ret;
end;
/

select 'rhnsat/procs/create_first_org.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/create_first_org.sql
create or replace procedure
create_first_org
(
	name_in in varchar2,
	password_in in varchar2
) is
	ug_type			number;
	group_val		number;
begin
	insert into web_customer (
		id, name,
		oracle_customer_id, oracle_customer_number,
		customer_type
	) values (
		1, name_in,
		1, 1, 'B'
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'org_admin';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Organization Administrators',
		'Organization Administrators for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'org_applicant';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) VALues (
		group_val, 'Organization Applicants',
		'Organization Applicants for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'system_group_admin';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'System Group Administrators',
		'System Group Administrators for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'activation_key_admin';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Activation Key Administrators',
		'Activation Key Administrators for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'channel_admin';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Channel Administrators',
		'Channel Administrators for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'satellite_admin';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Satellite Administrators',
		'Satellite Administrators for Org ' || name_in || ' (1)',
		NULL, ug_type, 1
	);
	insert into rhnOrgQuota(
		org_id, total
	) values (
		1, 1024*1024*1024*16
	);
        insert into rhnServerGroup 
		( id, name, description, max_members, group_type, org_id )
		select rhn_server_group_id_seq.nextval, sgt.name, sgt.name, 
			0, sgt.id, 1
		from rhnServerGroupType sgt
		where sgt.label = 'sw_mgr_entitled';
end create_first_org;
/
show errors;

select 'rhnsat/procs/create_new_org.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/create_new_org.sql
create or replace procedure
create_new_org
(
	name_in      in varchar2,
	password_in  in varchar2,
	org_id_out   out number
) is
	ug_type			number;
	group_val		number;
	new_org_id              number;
begin
        select web_customer_id_seq.nextval into new_org_id from dual;
	insert into web_customer (
		id, name,
		oracle_customer_id, oracle_customer_number,
		customer_type
	) values (
		new_org_id, name_in,
		new_org_id, new_org_id, 'B'
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'org_admin';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Organization Administrators',
		'Organization Administrators for Org ' || name_in,
		NULL, ug_type, new_org_id
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'org_applicant';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) VALues (
		group_val, 'Organization Applicants',
		'Organization Applicants for Org ' || name_in,
		NULL, ug_type, new_org_id
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'system_group_admin';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'System Group Administrators',
		'System Group Administrators for Org ' || name_in,
		NULL, ug_type, new_org_id
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'activation_key_admin';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Activation Key Administrators',
		'Activation Key Administrators for Org ' || name_in,
		NULL, ug_type, new_org_id
	);
	select rhn_user_group_id_seq.nextval into group_val from dual;
	select	id
	into	ug_type
	from	rhnUserGroupType
	where	label = 'channel_admin';
	insert into rhnUserGroup (
		id, name,
		description,
		max_members, group_type, org_id
	) values (
		group_val, 'Channel Administrators',
		'Channel Administrators for Org ' || name_in,
		NULL, ug_type, new_org_id
	);
        insert into rhnServerGroup 
		( id, name, description, max_members, group_type, org_id )
		select rhn_server_group_id_seq.nextval, sgt.name, sgt.name, 
			0, sgt.id, new_org_id
		from rhnServerGroupType sgt
		where sgt.label = 'sw_mgr_entitled';
	org_id_out := new_org_id;
end create_new_org;
/
show errors;

select 'rhnsat/procs/create_new_user.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/create_new_user.sql
create or replace function
create_new_user
(
    org_id_in		in number, 
    login_in		in varchar2,
    password_in		in varchar2,
    oracle_contact_id_in in number,
    prefix_in		in varchar2,
    first_names_in	in varchar2,
    last_name_in	in varchar2,
    genqual_in		in varchar2, 
    parent_company_in	in varchar2,
    company_in		in varchar2,
    title_in		in varchar2,
    phone_in		in varchar2, 
    fax_in		in varchar2,
    email_in		in varchar2,
    pin_in		in varchar2,
    first_names_ol_in	in varchar2,
    last_name_ol_in	in varchar2,
    address1_in		in varchar2, 
    address2_in		in varchar2,
    address3_in		in varchar2,
    city_in		in varchar2, 
    state_in		in varchar2, 
    zip_in		in varchar2, 
    country_in		in varchar2,
    alt_first_names_in  in varchar2,
    alt_last_name_in    in varchar2,
    contact_call_in	varchar2 := 'N', 
    contact_mail_in	varchar2 := 'N',
    contact_email_in	varchar2 := 'N',
    contact_fax_in	varchar2 := 'N'
)
return number
is
    user_id		number;
begin
    select web_contact_id_seq.nextval into user_id from dual;
    insert into web_contact
        (id, org_id, login, login_uc, password, old_password, oracle_contact_id)
    values
        (user_id, org_id_in, login_in, upper(login_in), password_in, null, oracle_contact_id_in);
    insert into web_user_contact_permission
        (web_user_id, call, mail, email, fax)
    values
        (user_id, contact_call_in, contact_mail_in, contact_email_in, contact_fax_in);
    insert into web_user_personal_info 
        (web_user_id, prefix, first_names, last_name, genqual,
	parent_company, company, title, phone, fax, email, pin,
	first_names_ol, last_name_ol)
    values
        (user_id, prefix_in, first_names_in, last_name_in, genqual_in, 
	parent_company_in, company_in, title_in, phone_in, fax_in, email_in, pin_in,
	first_names_ol_in, last_name_ol_in);
    if address1_in != '.' then
        insert into web_user_site_info
	    (id, web_user_id, email,
	    address1, address2, address3, 
	    city, state, zip, country, phone, fax, type,
	    alt_first_names, alt_last_name)
	values
	    (web_user_site_info_id_seq.nextval, user_id, email_in,
	    address1_in, address2_in, address3_in,
	    city_in, state_in, zip_in, country_in, phone_in, fax_in, 'M', 
	    alt_first_names_in, alt_last_name_in);
    end if;
    insert into rhnUserInfo
        (user_id)
    values
        (user_id);
    return user_id;
end;
/
show errors

select 'rhnsat/procs/create_pxt_session.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/create_pxt_session.sql
create or replace function
create_pxt_session(web_user_id in number, expires in number, value in varchar)
return number
is
pragma autonomous_transaction;
	id number;
begin
	select
		pxt_id_seq.nextval into id
	from
		dual;
	insert into PXTSessions (id, value, expires, web_user_id)
	values (id, value, expires, web_user_id);
	commit;
	return id;
end;
/
show errors

select 'rhnsat/procs/delete_channel.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/delete_channel.sql
create or replace
procedure delete_channel (
	channel_id_in in number
) is
begin
        delete from rhnChannelPackage where channel_id = channel_id_in;
        delete from rhnChannelErrata where channel_id = channel_id_in;
        delete from rhnServerChannel where channel_id = channel_id_in;
        delete from rhnRegTokenChannels where channel_id = channel_id_in;
        delete from rhnDistChannelMap where channel_id = channel_id_in;
        delete from rhnChannelFamilyMembers where channel_id = channel_id_in;
        delete from rhnServerProfilePackage where server_profile_id in (
            select id from rhnServerProfile where base_channel = channel_id_in
        );
        delete from rhnServerProfile where base_channel = channel_id_in;
        delete from rhnChannel where id = channel_id_in;
end;
/
show errors

select 'rhnsat/procs/delete_errata.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/delete_errata.sql
create or replace procedure
delete_errata (
	errata_id_in in number
) is
begin
	delete from rhnServerNeededPackageCache where errata_id = errata_id_in;
	delete from rhnPaidErrataTempCache where errata_id = errata_id_in;
	delete from rhnErrataFile where errata_id = errata_id_in;
	delete from rhnErrataPackage where errata_id = errata_id_in;
	delete from rhnErrata where id = errata_id_in;
	delete from rhnErrataTmp where id = errata_id_in;
end delete_errata;
/
show errors

select 'rhnsat/procs/delete_server.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/delete_server.sql
create or replace
procedure delete_server (
	server_id_in in number
) is
	cursor servergroups is
		select	server_id, server_group_id
		from	rhnServerGroupMembers sgm
		where	sgm.server_id = server_id_in;
	cursor configchannels is
		select	cc.id
		from	rhnConfigChannel cc,
			rhnConfigChannelType cct,
			rhnServerConfigChannel scc
		where	1=1
			and scc.server_id = server_id_in
			and scc.config_channel_id = cc.id
			and cct.label in
				('local_override','server_import')
			and cct.id = cc.confchan_type_id;
        type filelistsid_t is table of rhnServerPreserveFileList.file_list_id%type;
        filelistsid_c filelistsid_t;
        type probesid_t is table of rhn_check_probe.probe_id%type;
        probesid_c probesid_t;
    is_virt number := 0;
begin
	rhn_channel.delete_server_channels(server_id_in);
	select	spfl.file_list_id id bulk collect into filelistsid_c
	  from	rhnServerPreserveFileList spfl
	 where	spfl.server_id = server_id_in
			and not exists (
				select	1
				from	rhnServerPreserveFileList
				where	file_list_id = spfl.file_list_id
					and server_id != server_id_in
				union
				select	1
				from	rhnKickstartPreserveFileList
				where	file_list_id = spfl.file_list_id
			);
        if filelistsid_c.first is not null then
            forall i in filelistsid_c.first..filelistsid_c.last
                delete from rhnFileList where id = filelistsid_c(i);
        end if;
	for configchannel in configchannels loop
		rhn_config.delete_channel(configchannel.id);
	end loop;
      select count(1) into is_virt
        from rhnServerEntitlementView
       where server_id = server_id_in
         and label in ('virtualization_host', 'virtualization_host_platform')
         and rownum <= 1;
	for sgm in servergroups loop
		rhn_server.delete_from_servergroup(
			sgm.server_id, sgm.server_group_id);
	end loop;
    if is_virt = 1 then
        rhn_entitlements.repoll_virt_guest_entitlements(server_id_in);
    end if;
	update rhnKickstartSession
		set old_server_id = case when old_server_id = server_id_in then null else old_server_id end,
		    new_server_id = case when new_server_id = server_id_in then null else new_server_id end
		where old_server_id = server_id_in 
		   or new_server_id = server_id_in;
	rhn_channel.clear_subscriptions(server_id_in,1);
        delete from rhnVirtualInstance vi
	      where (host_system_id = server_id_in and virtual_system_id is null)
                 or (virtual_system_id = server_id_in and host_system_id is null)
                 or (vi.virtual_system_id = server_id_in and vi.modified < (select max(vi2.modified)
                    from rhnVirtualInstance vi2 where vi2.uuid = vi.uuid));
        update rhnVirtualInstance
	   set host_system_id = case when host_system_id = server_id_in then null else host_system_id end,
	       virtual_system_id = case when virtual_system_id = server_id_in then null else virtual_system_id end
	 where host_system_id = server_id_in
	    or virtual_system_id = server_id_in;
	update rhnVirtualInstanceEventLog
	   set old_host_system_id = case when old_host_system_id = server_id_in then null else old_host_system_id end,
               new_host_system_id = case when new_host_system_id = server_id_in then null else new_host_system_id end
         where old_host_system_id = server_id_in
            or new_host_system_id = server_id_in;
	delete from rhnActionConfigChannel where server_id = server_id_in;
	delete from rhnActionConfigRevision where server_id = server_id_in;
	delete from rhnActionPackageRemovalFailure where server_id = server_id_in;
	delete from rhnChannelFamilyLicenseConsent where server_id = server_id_in;
	delete from rhnClientCapability where server_id = server_id_in;
	delete from rhnCpu where server_id = server_id_in;
	delete from rhnDevice where server_id = server_id_in;
	delete from rhnProxyInfo where server_id = server_id_in;
	delete from rhnRam where server_id = server_id_in;
	delete from rhnRegToken where server_id = server_id_in;
	delete from rhnSNPServerQueue where server_id = server_id_in;
	delete from rhnSatelliteChannelFamily where server_id = server_id_in;
	delete from rhnSatelliteInfo where server_id = server_id_in;
	delete from rhnServerAction where server_id = server_id_in;
	delete from rhnServerActionPackageResult where server_id = server_id_in;
	delete from rhnServerActionScriptResult where server_id = server_id_in;
	delete from rhnServerActionVerifyResult where server_id = server_id_in;
	delete from rhnServerActionVerifyMissing where server_id = server_id_in;
	delete from rhnServerChannel where server_id = server_id_in;
	delete from rhnServerConfigChannel where server_id = server_id_in;
	delete from rhnServerCustomDataValue where server_id = server_id_in;
	delete from rhnServerDMI where server_id = server_id_in;
	delete from rhnServerMessage where server_id = server_id_in;
	delete from rhnServerEvent where server_id = server_id_in;
	delete from rhnServerHistory where server_id = server_id_in;
	delete from rhnServerInfo where server_id = server_id_in;
	delete from rhnServerInstallInfo where server_id = server_id_in;
	delete from rhnServerLocation where server_id = server_id_in;
	delete from rhnServerLock where server_id = server_id_in;
	delete from rhnServerNeededPackageCache where server_id = server_id_in;
	delete from rhnServerNeededErrataCache where server_id = server_id_in;
	delete from rhnServerNetwork where server_id = server_id_in;
	delete from rhnServerNotes where server_id = server_id_in;
	delete from rhnServerPackage where server_id = server_id_in;
	delete from rhnServerTokenRegs where server_id = server_id_in;
	delete from rhnSnapshotTag where server_id = server_id_in;
	delete from rhnSnapshot where server_id = server_id_in;
	delete from rhnTransaction where server_id = server_id_in;
	delete from rhnUserServerPrefs where server_id = server_id_in;
	delete from rhnServerPath where server_id_in in (server_id, proxy_server_id);
	delete from rhnUserServerPerms where server_id = server_id_in;
	delete from rhn_interface_monitoring where server_id = server_id_in;
	delete from rhnServerNetInterface where server_id = server_id_in;
	delete from rhn_server_monitoring_info where recid = server_id_in;
	delete from rhnAppInstallSession where server_id = server_id_in;
	delete from rhnServerUuid where server_id = server_id_in;
     SELECT CP.probe_id bulk collect into probesid_c
       FROM rhn_check_probe CP  
      WHERE CP.host_id = server_id_in
         OR CP.sat_cluster_id in
    (SELECT SN.sat_cluster_id
       FROM rhn_sat_node SN
      WHERE SN.server_id = server_id_in);
    if probesid_c.first is not null then
        FORALL i IN probesid_c.first..probesid_c.last
            DELETE FROM rhn_probe_state PS WHERE PS.probe_id = probesid_c(i);
        FORALL i IN probesid_c.first..probesid_c.last
            DELETE FROM rhn_probe P  WHERE P.recid = probesid_c(i);
    end if;
	delete from rhn_check_probe where host_id = server_id_in;
	delete from rhn_host_probe where host_id = server_id_in;
    delete from rhn_sat_cluster where recid in
      ( select sat_cluster_id from rhn_sat_node where server_id = server_id_in );
	delete from rhn_sat_node where server_id = server_id_in;
	delete
	from	rhnServer
		where id = server_id_in;
	delete
	from	rhnSet
	where	1=1
		and user_id in (
			select	wc.id
			from	rhnServer rs,
				web_contact wc
			where	rs.id = server_id_in
				and rs.org_id = wc.org_id
		)
		and label = 'system_list'
		and element = server_id_in;
end delete_server;
/
show errors;

select 'rhnsat/procs/delete_server_bulk.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/delete_server_bulk.sql
create or replace
procedure delete_server_bulk (
	user_id_in in number
) is
	cursor systems is
		select	s.element id
		from	rhnSet s
		where	s.user_id = user_id_in
			and s.label = 'system_list';
begin
	for s in systems loop
                delete_server(s.id);
	end loop;
end delete_server_bulk;
/
show errors;

select 'rhnsat/procs/does_user_have_role.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/does_user_have_role.sql
create or replace function
does_user_have_role
(
	user_id_in in number,
	role_in in varchar2
)
return number
is
	org_admin	number;
begin
	select	1
	into	org_admin
	from
		rhnUserGroupType	ugt,
		rhnUserGroup		ug,
		rhnUserGroupMembers	ugm
	where	1=1
		and ugm.user_id = user_id_in
		and ugm.user_group_id = ug.id
		and ugt.label = role_in
		and ugt.id = ug.group_type;
	return org_admin;
exception
	when no_data_found then
		return 0;
end;
/
show errors

select 'rhnsat/procs/is_user_applicant.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/is_user_applicant.sql
create or replace function
is_user_applicant
(
    user_id_in IN number
)
return number
is
    org_id_val		number;
    app_group_val	number;
    applicant           number;
begin
    select org_id into org_id_val
      from web_contact
     where id = user_id_in;
    select id into app_group_val
      from rhnUserGroup
     where org_id = org_id_val
       and group_type = (
		select	id
		from	rhnUserGroupType
		where	label = 'org_applicant'
	   );
    select count(1) into applicant
      from rhnUserGroupMembers
     where user_group_id = app_group_val
       and user_id = user_id_in;
   return applicant;
end;
/
show errors

select 'rhnsat/procs/lookup_cf_state.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_cf_state.sql
create or replace function
lookup_cf_state(
	label_in in varchar2
) return number deterministic
is
	state_id number;
begin
	select	id
	into	state_id
	from	rhnConfigFileState
	where	label = label_in;
	return state_id;
end;
/
show errors

select 'rhnsat/procs/lookup_client_capability.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_client_capability.sql
CREATE OR REPLACE FUNCTION
LOOKUP_CLIENT_CAPABILITY(name_in IN VARCHAR2)
RETURN NUMBER
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	cap_name_id		NUMBER;
BEGIN
	SELECT id
          INTO cap_name_id
          FROM rhnClientCapabilityName
         WHERE name = name_in;
	RETURN cap_name_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            INSERT INTO rhnClientCapabilityName (id, name) 
                VALUES (rhn_client_capname_id_seq.nextval, name_in)
                RETURNING id INTO cap_name_id;
            COMMIT;
	RETURN cap_name_id;
END;
/
SHOW ERRORS

select 'rhnsat/procs/lookup_config_filename.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_config_filename.sql
CREATE OR REPLACE FUNCTION
LOOKUP_CONFIG_FILENAME(name_in IN VARCHAR2)
RETURN NUMBER
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	name_id		NUMBER;
BEGIN
	SELECT id
          INTO name_id
          FROM rhnConfigFileName
         WHERE path = name_in;
	RETURN name_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            INSERT INTO rhnConfigFileName (id, path) 
                VALUES (rhn_cfname_id_seq.nextval, name_in)
                RETURNING id INTO name_id;
            COMMIT;
	RETURN name_id;
END;
/
SHOW ERRORS

select 'rhnsat/procs/lookup_config_info.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_config_info.sql
create or replace function
lookup_config_info (
    username_in     in varchar2,
    groupname_in    in varchar2,
    filemode_in     in varchar2
) return number
deterministic
is
    pragma autonomous_transaction;
    v_id    number;
    cursor lookup_cursor is
        select id
          from rhnConfigInfo
         where 1=1
           and username = username_in
           and groupname = groupname_in
           and filemode = filemode_in;
begin
    for r in lookup_cursor loop
        return r.id;
    end loop;
    select rhn_confinfo_id_seq.nextval
      into v_id
      from dual;
    insert into rhnConfigInfo (id, username, groupname, filemode)
    values (v_id, username_in, groupname_in, filemode_in);
    commit;
    return v_id;
end lookup_config_info;
/
show errors

select 'rhnsat/procs/lookup_cve.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_cve.sql
CREATE OR REPLACE FUNCTION
LOOKUP_CVE(name_in IN VARCHAR2)
RETURN NUMBER
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	name_id		NUMBER;
BEGIN
	SELECT id
          INTO name_id
          FROM rhnCve
         WHERE name = name_in;
	RETURN name_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
            INSERT INTO rhnCve (id, name) 
                VALUES (rhn_cve_id_seq.nextval, name_in)
                RETURNING id INTO name_id;
            COMMIT;
	RETURN name_id;
END LOOKUP_CVE;
/
SHOW ERRORS

select 'rhnsat/procs/lookup_first_matching_cf.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_first_matching_cf.sql
create or replace function
lookup_first_matching_cf (
	server_id_in in number,
	path_in in varchar2
) return number is
	retval number := -1;
begin
	begin
		select	a.cfid
		into	retval
		from	(
			select	b.cfid,
				rownum rn
			from (
				select	cf.id cfid
				from	rhnConfigFile		cf,
					rhnConfigFileName	cfn,
					rhnConfigChannel	cc,
					rhnServerConfigChannel	scc
				where	scc.server_id = server_id_in
					and scc.config_channel_id = cc.id
					and cc.id = cf.config_channel_id
					and cf.state_id != lookup_cf_state('dead')
					and cfn.path = path_in
					and cf.config_file_name_id = cfn.id
				order by scc.position asc
				) b
			) a
		where a.rn = 1;
	exception
		when no_data_found then
			null;
	end;
	return retval;
end lookup_first_matching_cf;
/
show errors

select 'rhnsat/procs/lookup_package_delta.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_package_delta.sql
CREATE OR REPLACE FUNCTION
LOOKUP_PACKAGE_DELTA(n_in IN VARCHAR2)
RETURN NUMBER
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
	name_id         NUMBER;
BEGIN
	SELECT id INTO name_id
	  FROM rhnPackageDelta
	 WHERE label = n_in;
	RETURN name_id;
EXCEPTION
	WHEN NO_DATA_FOUND THEN
	    INSERT INTO rhnPackageDelta (id, label)
	    VALUES (rhn_packagedelta_id_seq.nextval, n_in)
	    RETURNING id INTO name_id;
	COMMIT;
	RETURN name_id;
END;
/
SHOW ERRORS

select 'rhnsat/procs/lookup_transaction_package.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/lookup_transaction_package.sql
CREATE OR REPLACE FUNCTION
LOOKUP_TRANSACTION_PACKAGE(o_in IN VARCHAR2, n_in IN VARCHAR2, 
    e_in IN VARCHAR2, v_in IN VARCHAR2, r_in IN VARCHAR2, a_in IN VARCHAR2)
RETURN NUMBER
IS
	PRAGMA AUTONOMOUS_TRANSACTION;
        o_id        NUMBER;
        n_id        NUMBER;
	e_id	    NUMBER;
        p_arch_id   NUMBER;
        tp_id       NUMBER;
BEGIN
	BEGIN
	    SELECT id
	      INTO o_id
	      FROM rhnTransactionOperation
	     WHERE label = o_in;
	EXCEPTION
	    WHEN NO_DATA_FOUND THEN
		rhn_exception.raise_exception('invalid_transaction_operation');
	END;
	SELECT LOOKUP_PACKAGE_NAME(n_in)
	  INTO n_id
	  FROM dual;
	SELECT LOOKUP_EVR(e_in, v_in, r_in)
	  INTO e_id
	  FROM dual;
	p_arch_id := NULL;
	IF a_in IS NOT NULL
	THEN
		SELECT LOOKUP_PACKAGE_ARCH(a_in)
		  INTO p_arch_id
		  FROM dual;
	END IF;
	SELECT id
	  INTO tp_id
	  FROM rhnTransactionPackage
	 WHERE operation = o_id
	   AND name_id = n_id
	   AND evr_id = e_id
	   AND (package_arch_id = p_arch_id OR (p_arch_id IS NULL AND package_arch_id IS NULL));
	RETURN tp_id;
EXCEPTION
        WHEN NO_DATA_FOUND THEN
	    INSERT INTO rhnTransactionPackage 
		(id, operation, name_id, evr_id, package_arch_id)
	    VALUES (rhn_transpack_id_seq.nextval, o_id, n_id, e_id, p_arch_id)
	    RETURNING id INTO tp_id;
	    COMMIT;
	    RETURN tp_id;
END;
/
SHOW ERRORS

select 'rhnsat/procs/new_user_postop.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/new_user_postop.sql
create or replace procedure
new_user_postop
(
    user_id_in IN number
)
is
    org_id_val		number;
    admin_group_val	number;
begin
    select org_id into org_id_val
      from web_contact
     where id = user_id_in;
    select id into admin_group_val
      from rhnUserGroup
     where org_id = org_id_val
       and group_type = (
		select	id
		from	rhnUserGroupType
		where	label = 'org_admin'
	   );
    insert into rhnUserGroupMembers
        (user_group_id, user_id)
    values
        (admin_group_val, user_id_in);
    insert into rhnUserInfo
        (user_id)
    values
        (user_id_in);
end;
/
show errors
declare
    CURSOR user_cursor
    is
    select wc.id
      from web_contact wc
     where not exists (select 1
                         from rhnUserGroupMembers
		        where user_id = wc.id);
   i NUMBER;
begin
    i := 0;
    for user_rec in user_cursor
    loop
    	new_user_postop(user_rec.id);
	i := i + 1;
	if mod(i, 500) = 0
	then
	    commit;
	end if;
    end loop;
    commit;
end;
/
show errors

select 'rhnsat/procs/pxt_session_cleanup.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/pxt_session_cleanup.sql
create or replace procedure pxt_session_cleanup
   (bound_in in number, commit_interval in number := 100,
batch_size in number := 50000, sessions_deleted in out number)
is
   PRAGMA AUTONOMOUS_TRANSACTION; 
   cursor sessions (bound_val in number) is 
   select rowid from PXTSessions
   where expires < bound_val;
   counter number := 0;
begin
   for session in sessions (bound_in) loop
      delete from PXTSessions where rowid = session.rowid;
       counter := counter + 1;
       if mod(counter, commit_interval) = 0 then
          commit;
       end if;
      if counter >= batch_size then 
         commit;
         sessions_deleted := counter;
         return;
      end if;
   end loop;  
    commit;
   sessions_deleted := counter;
end;
/

select 'rhnsat/procs/queue_errata.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/queue_errata.sql
CREATE OR REPLACE PROCEDURE
queue_errata(errata_id_in IN NUMBER)
IS
BEGIN
	INSERT INTO rhnSNPErrataQueue (errata_id) VALUES (errata_id_in);
EXCEPTION
	WHEN DUP_VAL_ON_INDEX THEN
	     UPDATE rhnSNPErrataQueue SET processed = 0 WHERE errata_id = errata_id_in;
END;
/
SHOW ERRORS

select 'rhnsat/procs/queue_server.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/queue_server.sql
CREATE OR REPLACE PROCEDURE
queue_server(server_id_in IN NUMBER, immediate_in IN NUMBER := 1)
IS
    org_id_tmp NUMBER;
BEGIN
    IF immediate_in > 0
    THEN
        DELETE FROM rhnServerNeededPackageCache WHERE server_id = server_id_in;
        INSERT INTO rhnServerNeededPackageCache
       	    (SELECT org_id, server_id, errata_id, package_id
	       FROM rhnServerNeededPackageView
              WHERE server_id = server_id_in);
	DELETE FROM rhnServerNeededErrataCache snec WHERE server_id = server_id_in;
	insert into rhnServerNeededErrataCache
	    (select distinct org_id, server_id, errata_id
	       from rhnServerNeededPackageCache
	      where server_id = server_id_in
	        and errata_id is not null);
    ELSE
          SELECT org_id INTO org_id_tmp FROM rhnServer WHERE id = server_id_in;
	  INSERT
            INTO rhnTaskQueue
                 (org_id, task_name, task_data)
          VALUES (org_id_tmp, 
                  'update_server_errata_cache',
                  server_id_in);
    END IF;
END queue_server;
/
SHOW ERRORS

select 'rhnsat/procs/rhn_prepare_install.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/rhn_prepare_install.sql
create or replace procedure 
rhn_prepare_install
(
    username            in rhn_command_queue_instances.last_update_user%type,
    command_instance_id in out rhn_command_queue_instances.recid%type,
    install_command     in rhn_command_queue_instances.command_id%type
) 
is
    /* ignore this command if it has not been run after five minutes */
    stale_after_minutes number := 10;
    /* should take no more than five minutes to run the install */
    max_execution_time_seconds number := 10 * 60;
begin
    select rhn_command_q_inst_recid_seq.nextval
    into command_instance_id
    from dual;
    insert into rhn_command_queue_instances (
        recid,
        command_id,
        notes,
        expiration_date,
        notify_email,
        timeout,
        date_submitted,
        last_update_user,
        last_update_date
    )
    values (
        command_instance_id,
        install_command,
        null, /* no notes */
        sysdate + (stale_after_minutes / (60*24)),
        null, /* no notification email */
        max_execution_time_seconds,
        sysdate,
        username,
        sysdate
    );
end rhn_prepare_install;
/
show errors

select 'rhnsat/procs/rhn_install_satellite.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/rhn_install_satellite.sql
create or replace procedure 
rhn_install_satellite
(
    command_instance_id in rhn_command_queue_instances.recid%type,
    satellite_id in rhn_sat_cluster.recid%type
) 
is
begin
    insert into rhn_command_queue_execs (
           instance_id, 
           netsaint_id,
           target_type)
    values (command_instance_id, satellite_id, 'cluster');
end rhn_install_satellite;
/
show errors

select 'rhnsat/procs/rhn_install_org_satellites.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/rhn_install_org_satellites.sql
create or replace procedure 
rhn_install_org_satellites
(
    for_customer_id in web_customer.id%type,
    sat_cluster_id in rhn_sat_cluster.recid%type,
    username in rhn_command_queue_instances.last_update_user%type
) 
is
    cursor satellite_cursor is
        select recid from rhn_sat_cluster
        where customer_id = for_customer_id
        and recid not in (
            select netsaint_id from rhn_ll_netsaint
        )
        minus
        select recid from rhn_sat_cluster
        where customer_id = for_customer_id
        and recid not in (sat_cluster_id);
    command_instance_id rhn_command_queue_instances.recid%type;
begin
    rhn_prepare_install(username, command_instance_id, 1);
    for satellite in satellite_cursor loop
        rhn_install_satellite(command_instance_id, satellite.recid);
    end loop;
end rhn_install_org_satellites;
/
show errors

select 'rhnsat/procs/rhn_synch_probe_state.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/rhn_synch_probe_state.sql
CREATE OR REPLACE PROCEDURE rhn_synch_probe_state
is
begin
    update
        rhn_probe_state
    set state = 'PENDING',
        output = 'Awaiting update'
    where last_check < (
        select (
            sysdate - greatest(15 / 60 / 24,
            ((3 * rhn_deployed_probe.check_interval_minutes) / 60 / 24)))
        from rhn_deployed_probe
        where rhn_deployed_probe.recid = rhn_probe_state.probe_id
    );
    update rhn_multi_scout_threshold t
    set (scout_warning_threshold, scout_critical_threshold)=(
        select
            decode(scout_warning_threshold_is_all,0,
                scout_warning_threshold,count(scout_id)),
            decode(scout_crit_threshold_is_all,0,
                scout_critical_threshold,count(scout_id))
        from rhn_probe_state p
        where t.probe_id=p.probe_id
          and state in ('OK', 'WARNING', 'CRITICAL')
        group by t.probe_id
    );
end rhn_synch_probe_state;
/
show errors;

select 'rhnsat/procs/set_ks_session_history_message.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/set_ks_session_history_message.sql
create or replace procedure
set_ks_session_history_message (
	kickstart_session_id_in in number,
	state_label_in in varchar2,
	message_in in varchar2
) is
	cursor states is
		select	id
		from	rhnKickstartSessionState
		where	label = state_label_in;
	cursor history_items(state_id_in in number) is
		select	id
		from	rhnKickstartSessionHistory
		where	kickstart_session_id = kickstart_session_id_in
			and state_id = state_id_in
		order by time desc;
begin
	for state in states loop
		for item in history_items(state.id) loop
			update rhnKickstartSessionHistory
				set message = message_in
				where id = item.id;
			return;
		end loop;
		insert into rhnKickstartSessionHistory (
				id, kickstart_session_id, state_id, message
			) values (
				rhn_ks_sessionhist_id_seq.nextval,
				kickstart_session_id_in,
				state.id,
				message_in
			);
		return;
	end loop;
end;
/
show errors

select 'rhnsat/procs/truncateCacheQueue.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/procs/truncateCacheQueue.sql
create or replace procedure  truncateCacheQueue as
begin
  execute immediate 'Truncate Table rhnOrgErrataCacheQueue';
end;
/

select 'rhnsat/packages/rhn_bel.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_bel.pkb
create or replace
package body rhn_bel
is
   function is_org_paid (
      org_id_in in number
   ) return number is
      cursor paids is
         select   1
         from  rhnPaidOrgs
         where org_id = org_id_in;
   begin
      for paid in paids loop return 1; end loop;
      return 0;
   end;
        function lookup_email_state (
                state_in in varchar2
        ) return number is
                retval number;
        begin
                select id into retval from rhnEmailAddressState where label = state_in;
                return retval;
        exception
                        when no_data_found then
                                rhn_exception.raise_exception('invalid_state');
        end lookup_email_state;
end;
/
show errors;

select 'rhnsat/packages/rhn_cache.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_cache.pkb
create or replace package body
rhn_cache
is
	body_version varchar2(100) := '';
	procedure update_perms_for_server(
		server_id_in in number
	) is
	begin
		delete from rhnUserServerPerms where server_id = server_id_in;
		insert into rhnUserServerPerms(user_id, server_id) (
				select	distinct user_id, server_id_in
				from	rhnUserServerPermsDupes
				where	server_id = server_id_in
			);
	end update_perms_for_server;
	procedure update_perms_for_user(
		user_id_in in number
	) is
	begin
        delete from rhnUserServerPerms
        where user_id = user_id_in
            and server_id in
            (select server_id
             from rhnUserServerPerms
             where user_id = user_id_in
             minus
             select server_id
             from rhnUserServerPermsDupes uspd
             where uspd.user_id = user_id_in);
        insert into rhnUserServerPerms (user_id, server_id)
        select distinct user_id_in, server_id
        from rhnUserServerPermsDupes uspd
        where uspd.user_id = user_id_in
            and not exists
            (select 1
             from rhnUserServerPerms usp
             where usp.user_id = user_id_in
                 and usp.server_id = uspd.server_id);
	end update_perms_for_user;
	procedure update_perms_for_server_group(
		server_group_id_in in number
	) is
		cursor users is
			select	usgp.user_id id
			from	rhnUserServerGroupPerms usgp
			where	usgp.server_group_id = server_group_id_in
				and not exists (
					select	1
					from	rhnUserGroup ug,
							rhnUserGroupMembers ugm,
							rhnServerGroup sg,
							rhnUserGroupType ugt
					where	ugt.label = 'org_admin'
						and sg.id = server_group_id_in
						and ugm.user_id = usgp.user_id
						and ug.org_id = sg.org_id
						and ugm.user_group_id = ug.id
					);
	begin
		for u in users loop
			update_perms_for_user(u.id);
		end loop;
	end update_perms_for_server_group;
end rhn_cache;
/
show errors

select 'rhnsat/packages/rhn_set.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_set.pkb
CREATE OR REPLACE
PACKAGE BODY rhn_set
IS
END rhn_set;
/
SHOW ERRORS

select 'rhnsat/packages/rhn_channel.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_channel.pkb
CREATE OR REPLACE
PACKAGE BODY rhn_channel
IS
        body_version varchar2(100) := '';
        cursor  base_channel_cursor(
                release_in in varchar2,
                server_arch_id_in in number,
                org_id_in in number
        ) return rhnChannel%ROWTYPE is
                select distinct c.*
                from    rhnDistChannelMap                       dcm,
                                rhnServerChannelArchCompat      scac,
                                rhnChannel                                      c,
                                rhnChannelPermissions           cp
                where   cp.org_id = org_id_in
                        and cp.channel_id = c.id
                        and c.parent_channel is null
                        and c.id = dcm.channel_id
                        and c.channel_arch_id = dcm.channel_arch_id
                        and dcm.release = release_in
                        and scac.server_arch_id = server_arch_id_in
                        and scac.channel_arch_id = c.channel_arch_id;
    FUNCTION get_license_path(channel_id_in IN NUMBER)
    RETURN VARCHAR2
    IS
        license_val VARCHAR2(1000);
    BEGIN
        SELECT CFL.license_path INTO license_val
          FROM rhnChannelFamilyLicense CFL, rhnChannelFamilyMembers CFM
         WHERE CFM.channel_id = channel_id_in
           AND CFM.channel_family_id = CFL.channel_family_id;
        RETURN license_val;
    EXCEPTION
        WHEN NO_DATA_FOUND
            THEN
            RETURN NULL;
    END get_license_path;
    PROCEDURE license_consent(channel_id_in IN NUMBER, user_id_in IN NUMBER, server_id_in IN NUMBER)
    IS
        channel_family_id_val NUMBER;
    BEGIN
        channel_family_id_val := rhn_channel.family_for_channel(channel_id_in);
        IF channel_family_id_val IS NULL
        THEN
            rhn_exception.raise_exception('channel_subscribe_no_family');
        END IF;
        IF rhn_channel.get_license_path(channel_id_in) IS NULL
        THEN
            rhn_exception.raise_exception('channel_consent_no_license');
        END IF;
        INSERT INTO rhnChannelFamilyLicenseConsent (channel_family_id, user_id, server_id)
        VALUES (channel_family_id_val, user_id_in, server_id_in);
    END license_consent;
    PROCEDURE subscribe_server(server_id_in IN NUMBER, channel_id_in NUMBER, immediate_in NUMBER := 1, user_id_in in number := null)
    IS
        channel_parent_val      rhnChannel.parent_channel%TYPE;
        parent_subscribed       BOOLEAN;
        server_has_base_chan    BOOLEAN;
        server_already_in_chan  BOOLEAN;
        channel_family_id_val   NUMBER;
        server_org_id_val       NUMBER;
        available_subscriptions NUMBER;
        consenting_user         NUMBER;
        allowed                 number := 0;
        current_members_val     number;
    BEGIN
        if user_id_in is not null then
            allowed := rhn_channel.user_role_check(channel_id_in, user_id_in, 'subscribe');
        else
            allowed := 1;
        end if;
        if allowed = 0 then
            rhn_exception.raise_exception('no_subscribe_permissions');
        end if;
        SELECT parent_channel INTO channel_parent_val FROM rhnChannel WHERE id = channel_id_in;
        IF channel_parent_val IS NOT NULL
        THEN    
            parent_subscribed := FALSE;    
            FOR check_subscription IN check_server_subscription(server_id_in, channel_parent_val)
            LOOP
                parent_subscribed := TRUE;
            END LOOP check_subscription;
            IF NOT parent_subscribed
            THEN
                RETURN;
            END IF;
        ELSE
            server_has_base_chan := FALSE;
            FOR base IN server_base_subscriptions(server_id_in)
            LOOP
                server_has_base_chan := TRUE;
            END LOOP base;
            IF server_has_base_chan
            THEN
                rhn_exception.raise_exception('channel_server_one_base');
            END IF;
        END IF;
        FOR check_subscription IN check_server_subscription(server_id_in, channel_id_in)
        LOOP
            server_already_in_chan := TRUE;
        END LOOP check_subscription;
        IF server_already_in_chan
        THEN
            RETURN;
        END IF;
        channel_family_id_val := rhn_channel.family_for_channel(channel_id_in);
        IF channel_family_id_val IS NULL
        THEN
            rhn_exception.raise_exception('channel_subscribe_no_family');
        END IF;
        SELECT NVL(org_id, (SELECT org_id FROM rhnServer WHERE id = server_id_in))
          INTO server_org_id_val
          FROM rhnChannel
         WHERE id = channel_id_in;
        select current_members 
        into current_members_val
        from rhnPrivateChannelFamily
        where org_id = server_org_id_val and channel_family_id = channel_family_id_val
        for update of current_members;
        available_subscriptions := rhn_channel.available_family_subscriptions(channel_family_id_val, server_org_id_val);
        IF available_subscriptions IS NULL OR 
           available_subscriptions > 0 or
           can_server_consume_virt_channl(server_id_in, channel_family_id_val) = 1
        THEN
            IF rhn_channel.get_license_path(channel_id_in) IS NOT NULL
            THEN
                BEGIN
                SELECT user_id INTO consenting_user
                  FROM rhnChannelFamilyLicenseConsent
                 WHERE channel_family_id = channel_family_id_val
                   AND server_id = server_id_in;
                EXCEPTION
                    WHEN NO_DATA_FOUND THEN
                        rhn_exception.raise_exception('channel_subscribe_no_consent');
                END;
            END IF;
            insert into rhnServerHistory (id,server_id,summary,details) (
                select  rhn_event_id_seq.nextval,
                        server_id_in,
                        'subscribed to channel ' || SUBSTR(c.label, 0, 106),
                        c.label
                from    rhnChannel c
                where   c.id = channel_id_in
            );
            UPDATE rhnServer SET channels_changed = sysdate WHERE id = server_id_in;
            INSERT INTO rhnServerChannel (server_id, channel_id) VALUES (server_id_in, channel_id_in);
            rhn_channel.update_family_counts(channel_family_id_val, server_org_id_val);
            queue_server(server_id_in, immediate_in);
        ELSE
            rhn_exception.raise_exception('channel_family_no_subscriptions');
        END IF;
    END subscribe_server;
    function can_server_consume_virt_channl(
        server_id_in in number,
        family_id_in in number )
    return number
    is
        cursor server_virt_families is
            select vi.virtual_system_id, cfvsl.channel_family_id
            from
                rhnChannelFamilyVirtSubLevel cfvsl,
                rhnSGTypeVirtSubLevel sgtvsl,
                rhnVirtualInstance vi
            where
                vi.virtual_system_id = server_id_in 
                and sgtvsl.virt_sub_level_id = cfvsl.virt_sub_level_id
                and cfvsl.channel_family_id = family_id_in
                and exists (
                    select 1
                    from rhnServerEntitlementView sev
                    where vi.host_system_id = sev.server_id
                    and sev.server_group_type_id = sgtvsl.server_group_type_id );
    begin
        for server_virt_family in server_virt_families loop
            return 1;
        end loop;
        return 0;
    end;
    PROCEDURE bulk_subscribe_server(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER)
    IS
    BEGIN
        FOR server IN rhn_set.set_iterator(set_label_in, set_uid_in)
        LOOP
            rhn_channel.subscribe_server(server.element, channel_id_in, 0, set_uid_in);
        END LOOP server;
    END bulk_subscribe_server;
    PROCEDURE bulk_server_base_change(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER)
    IS
    BEGIN
        FOR server IN rhn_set.set_iterator(set_label_in, set_uid_in)
        LOOP
            IF rhn_server.can_change_base_channel(server.element) = 1
            THEN
                rhn_channel.clear_subscriptions(TO_NUMBER(server.element));
                rhn_channel.subscribe_server(server.element, channel_id_in, 0, set_uid_in);
            END IF;
        END LOOP server;
    END bulk_server_base_change;
    procedure bulk_server_basechange_from(
        set_label_in in varchar2,
        set_uid_in in number,
        old_channel_id_in in number,
        new_channel_id_in in number
    ) is
    cursor servers is
        select  sc.server_id id
        from    rhnChannel nc,
                rhnServerChannelArchCompat scac,
                rhnServer s,
                rhnChannel oc,
                rhnServerChannel sc,
                rhnSet st
        where   1=1
            and st.label = set_label_in
            and st.user_id = set_uid_in
            and st.element = sc.server_id
            and sc.channel_id = old_channel_id_in
            and sc.channel_id = oc.id
            and oc.parent_channel is null
            and nc.id = new_channel_id_in
            and nc.parent_channel is null
            and sc.server_id = s.id
            and s.server_arch_id = scac.server_arch_id
            and scac.channel_arch_id = nc.channel_arch_id;
    begin
        for s in servers loop
            insert into rhnSet (
                    user_id, label, element
                ) values (
                    set_uid_in,
                    set_label_in || 'basechange', 
                    s.id
                );
        end loop channel;
        bulk_server_base_change(new_channel_id_in,
                                set_label_in || 'basechange',
                                set_uid_in);
        delete from rhnSet
            where   label = set_label_in||'basechange'
                and user_id = set_uid_in;
    end bulk_server_basechange_from;
    procedure bulk_guess_server_base(
        set_label_in in varchar2,
        set_uid_in in number
    ) is
        channel_id number;
    begin
        for server in rhn_set.set_iterator(set_label_in, set_uid_in)
        loop
            begin
                if rhn_server.can_change_base_channel(server.element) = 1
                then
                    channel_id := guess_server_base(TO_NUMBER(server.element));
                    rhn_channel.clear_subscriptions(TO_NUMBER(server.element));
                    rhn_channel.subscribe_server(TO_NUMBER(server.element), channel_id, 0, set_uid_in);
                end if;
            exception when others then
                null;
            end;
        end loop server;
    end;
    function guess_server_base(
        server_id_in in number
    ) RETURN number is
        cursor server_cursor is
            select s.server_arch_id, s.release, s.org_id
              from rhnServer s
             where s.id = server_id_in;
    begin
        for s in server_cursor loop
            for channel in base_channel_cursor(s.release,
                s.server_arch_id, s.org_id) 
            loop
                return channel.id;
            end loop base_channel_cursor;
        end loop server_cursor;
        return null;
    end;
    function normalize_server_arch(server_arch_in in varchar2)
    return varchar2
    deterministic
    is
        suffix VARCHAR2(128) := '-redhat-linux';
        suffix_len NUMBER := length(suffix);
    begin
        if server_arch_in is NULL then
            return NULL;
        end if;
        if instr(server_arch_in, '-') > 0
        then
            return server_arch_in;
        end if;
        return server_arch_in || suffix;
    end normalize_server_arch;
    function base_channel_for_release_arch(
        release_in in varchar2,
        server_arch_in in varchar2,
        org_id_in in number := -1,
        user_id_in in number := null
    ) return number is
        server_arch varchar2(256) := normalize_server_arch(server_arch_in);
        server_arch_id number;
    begin
        begin
            select id
              into server_arch_id
              from rhnServerArch
             where label = server_arch;
        exception
            when no_data_found then
                rhn_exception.raise_exception('server_arch_not_found');
        end;
        return base_channel_rel_archid(release_in, server_arch_id,
            org_id_in, user_id_in);
    end base_channel_for_release_arch;
    function base_channel_rel_archid(
        release_in in varchar2,
        server_arch_id_in in number,
        org_id_in in number := -1,
        user_id_in in number := null
    ) return number is
        denied_channel_id number := null;
        valid_org_id number := org_id_in;
        valid_user_id number := user_id_in;
        channel_subscribable number;
    begin
        if org_id_in = -1 and user_id_in is not null then
            begin
                select org_id
                  into valid_org_id
                  from web_contact
                 where id = user_id_in;
            exception
                when no_data_found then
                    valid_user_id := null;
                    valid_org_id := -1;
            end;
        end if;
        for c in base_channel_cursor(release_in, server_arch_id_in, valid_org_id)
        loop
            if valid_user_id is null then
                return c.id;
            end if;
            select loose_user_role_check(c.id, user_id_in, 'subscribe')
              into channel_subscribable
              from dual;
            if channel_subscribable = 1 then
                return c.id;
            end if;
            denied_channel_id := c.id;
        end loop base_channel_fetch;
        if denied_channel_id is not null then
            rhn_exception.raise_exception('no_subscribe_permissions');
        end if;
        return NULL;
    end base_channel_rel_archid;
    procedure bulk_guess_server_base_from(
        set_label_in in varchar2,
        set_uid_in in number,
        channel_id_in in number
    ) is
        cursor channels(server_id_in in number) is
            select      rsc.channel_id
            from        rhnServerChannel rsc,
                        rhnChannel rc
            where       server_id_in = rsc.server_id
                        and rsc.channel_id = rc.id
                        and rc.parent_channel is null;
    begin
        for server in rhn_set.set_iterator(set_label_in, set_uid_in)
        loop
            for channel in channels(server.element)
            loop
                if channel.channel_id = channel_id_in
                then
                    insert into rhnSet (user_id, label, element) values (set_uid_in, set_label_in || 'baseguess', server.element);
                end if;
            end loop channel;
        end loop server;
        bulk_guess_server_base(set_label_in||'baseguess',set_uid_in);
        delete from rhnSet where label = set_label_in||'baseguess' and user_id = set_uid_in;
    end;
    PROCEDURE clear_subscriptions(server_id_in IN NUMBER, deleting_server IN NUMBER := 0 )
    IS
        cursor server_channels(server_id_in in number) is
                select  s.org_id, sc.channel_id, cfm.channel_family_id
                from    rhnServer s,
                        rhnServerChannel sc,
                        rhnChannelFamilyMembers cfm
                where   s.id = server_id_in
                        and s.id = sc.server_id
                        and sc.channel_id = cfm.channel_id;
    BEGIN
        for channel in server_channels(server_id_in)
        loop
                unsubscribe_server(server_id_in, channel.channel_id, 1, 1, deleting_server);
                rhn_channel.update_family_counts(channel.channel_family_id, channel.org_id);
        end loop channel;
    END clear_subscriptions;
    PROCEDURE unsubscribe_server(server_id_in IN NUMBER, channel_id_in NUMBER, immediate_in NUMBER := 1, unsubscribe_children_in number := 0,
                                 deleting_server IN NUMBER := 0 )
    IS
        channel_family_id_val   NUMBER;
        server_org_id_val       NUMBER;
        available_subscriptions NUMBER; 
        server_already_in_chan  BOOLEAN;
        cursor  channel_family_is_proxy(channel_family_id_in in number) is
                select  1
                from    rhnChannelFamily
                where   id = channel_family_id_in
                    and label = 'rhn-proxy';
        cursor  channel_family_is_satellite(channel_family_id_in in number) is
                select  1
                from    rhnChannelFamily
                where   id = channel_family_id_in
                    and label = 'rhn-satellite';
        cursor local_chk_server_parent_memb (
                        server_id_in number,
                        channel_id_in number ) is
                select  c.id
                from    rhnChannel                      c,
                                rhnServerChannel        sc
                where   1=1
                        and c.parent_channel = channel_id_in
                        and c.id = sc.channel_id
                        and sc.server_id = server_id_in;
    BEGIN
        FOR child IN local_chk_server_parent_memb(server_id_in, channel_id_in)
        LOOP
            if unsubscribe_children_in = 1 then
                unsubscribe_server(server_id_in => server_id_in,
                                                                channel_id_in => child.id,
                                                                immediate_in => immediate_in,
                                                                unsubscribe_children_in => unsubscribe_children_in,
                        deleting_server => deleting_server);
            else
                rhn_exception.raise_exception('channel_unsubscribe_child_exists');
            end if;
        END LOOP child;
        server_already_in_chan := FALSE;
        FOR check_subscription IN check_server_subscription(server_id_in, channel_id_in)
        LOOP
            server_already_in_chan := TRUE;
        END LOOP check_subscription;
        IF NOT server_already_in_chan
        THEN
            RETURN;
        END IF;
   if deleting_server = 0 then 
      insert into rhnServerHistory (id,server_id,summary,details) (
          select  rhn_event_id_seq.nextval,
                server_id_in,
             'unsubscribed from channel ' || SUBSTR(c.label, 0, 106),
             c.label
          from    rhnChannel c
          where   c.id = channel_id_in
      );
        UPDATE rhnServer SET channels_changed = sysdate WHERE id = server_id_in;
   end if;
   DELETE FROM rhnServerChannel WHERE server_id = server_id_in AND channel_id = channel_id_in;
   if deleting_server = 0 then 
        queue_server(server_id_in, immediate_in);
   end if;
        channel_family_id_val := rhn_channel.family_for_channel(channel_id_in);
        IF channel_family_id_val IS NULL
        THEN
            rhn_exception.raise_exception('channel_unsubscribe_no_family');
        END IF;
        for ignore in channel_family_is_satellite(channel_family_id_val) loop
                delete from rhnSatelliteInfo where server_id = server_id_in;
                delete from rhnSatelliteChannelFamily where server_id = server_id_in;
        end loop;
        for ignore in channel_family_is_proxy(channel_family_id_val) loop
                delete from rhnProxyInfo where server_id = server_id_in;
        end loop;
        DELETE FROM rhnChannelFamilyLicenseConsent
         WHERE channel_family_id = channel_family_id_val
           AND server_id = server_id_in;
        SELECT org_id INTO server_org_id_val
          FROM rhnServer
         WHERE id = server_id_in;
        rhn_channel.update_family_counts(channel_family_id_val, server_org_id_val);
    END unsubscribe_server;
    PROCEDURE bulk_unsubscribe_server(channel_id_in IN NUMBER, set_label_in IN VARCHAR2, set_uid_in IN NUMBER)
    IS
    BEGIN
        FOR server IN rhn_set.set_iterator(set_label_in, set_uid_in)
        LOOP
            rhn_channel.unsubscribe_server(server.element, channel_id_in, 0);
        END LOOP server;
    END bulk_unsubscribe_server;
    FUNCTION family_for_channel(channel_id_in IN NUMBER)
    RETURN NUMBER
    IS
        channel_family_id_val NUMBER;
    BEGIN
        SELECT channel_family_id INTO channel_family_id_val
          FROM rhnChannelFamilyMembers
         WHERE channel_id = channel_id_in;
        RETURN channel_family_id_val;
    EXCEPTION
        WHEN NO_DATA_FOUND
        THEN
            RETURN NULL;
    END family_for_channel;
    FUNCTION available_family_subscriptions(channel_family_id_in IN NUMBER, org_id_in IN NUMBER)
    RETURN NUMBER
    IS
        cfp channel_family_perm_cursor%ROWTYPE;
        current_members_val NUMBER;
        max_members_val     NUMBER;
        found               NUMBER;
    BEGIN
        IF NOT channel_family_perm_cursor%ISOPEN
        THEN
            OPEN channel_family_perm_cursor(channel_family_id_in, org_id_in);
        END IF;
        FETCH channel_family_perm_cursor INTO cfp;
        WHILE channel_family_perm_cursor%FOUND
        LOOP
            found := 1;
            current_members_val := cfp.current_members;
            max_members_val := cfp.max_members;
            FETCH channel_family_perm_cursor INTO cfp;
        END LOOP;
        IF channel_family_perm_cursor%ISOPEN
        THEN
            CLOSE channel_family_perm_cursor;
        END IF;
        IF found IS NULL
        THEN
            RETURN 0;
        END IF;
        IF max_members_val IS NULL
        THEN
            RETURN NULL;
        END IF;
        RETURN max_members_val - current_members_val;                   
    END available_family_subscriptions;
    function channel_family_current_members(channel_family_id_in IN NUMBER,
                                            org_id_in IN NUMBER)
    return number
    is
        current_members_count number := 0;
    begin
        select  count(sc.server_id)
        into    current_members_count
        from    rhnChannelFamilyMembers cfm,
                rhnServerChannel sc,
                rhnServer s
        where   s.org_id = org_id_in
            and s.id = sc.server_id
            and cfm.channel_family_id = channel_family_id_in
            and cfm.channel_id = sc.channel_id
            and exists ( 
                select 1
                from rhnChannelFamilyServerPhysical cfsp
                where cfsp.CHANNEL_FAMILY_ID = channel_family_id_in
                    and cfsp.server_id = s.id
                );
        return current_members_count;
    end;        
    PROCEDURE update_family_counts(channel_family_id_in IN NUMBER, 
                                   org_id_in IN NUMBER)
    IS
    BEGIN
                update rhnPrivateChannelFamily
                set current_members = (
                channel_family_current_members(channel_family_id_in, org_id_in)
                )
                        where org_id = org_id_in
                                and channel_family_id = channel_family_id_in;
    END update_family_counts;
    FUNCTION available_chan_subscriptions(channel_id_in IN NUMBER, 
                                          org_id_in IN NUMBER)
    RETURN NUMBER
    IS
            channel_family_id_val NUMBER;
    BEGIN
        SELECT channel_family_id INTO channel_family_id_val
            FROM rhnChannelFamilyMembers
            WHERE channel_id = channel_id_in;
            RETURN rhn_channel.available_family_subscriptions(
                           channel_family_id_val, org_id_in);
    END available_chan_subscriptions;
    procedure entitle_customer(customer_id_in in number, 
                               channel_family_id_in in number, 
                               quantity_in in number)
    is
                cursor permissions is
                        select  1
                        from    rhnPrivateChannelFamily pcf
                        where   pcf.org_id = customer_id_in
                                and     pcf.channel_family_id = channel_family_id_in; 
    begin
                for perm in permissions loop
                        set_family_maxmembers(
                                customer_id_in,
                                channel_family_id_in,
                                quantity_in
                        );
                        rhn_channel.update_family_counts(
                                channel_family_id_in,
                                customer_id_in
                        );
                        return;
                end loop;
                insert into rhnPrivateChannelFamily pcf (
                                channel_family_id, org_id, max_members, current_members
                        ) values (
                                channel_family_id_in, customer_id_in, quantity_in, 0
                        );
    end;
    procedure set_family_maxmembers(customer_id_in in number, 
                                    channel_family_id_in in number, 
                                    quantity_in in number)
    is
        cursor servers is
            select  server_id from (
            select      rownum row_number, server_id, modified from (
                select  rcfsp.server_id,
                        rcfsp.modified
                from    rhnChannelFamilyServerPhysical rcfsp
                where   rcfsp.customer_id = customer_id_in
                    and rcfsp.channel_family_id = channel_family_id_in
                order by modified
            )
            where rownum > quantity_in
            );
    begin
        for server in servers loop
            rhn_channel.unsubscribe_server_from_family(server.server_id, 
                                                       channel_family_id_in);
        end loop;
        update  rhnPrivateChannelFamily pcf
        set     pcf.max_members = quantity_in
        where   pcf.org_id = customer_id_in
            and pcf.channel_family_id = channel_family_id_in;
    end;
    procedure unsubscribe_server_from_family(server_id_in in number, 
                                             channel_family_id_in in number)
    is
    begin
        delete
        from    rhnServerChannel rsc
        where   rsc.server_id = server_id_in
            and channel_id in (
                select  rcfm.channel_id
                from    rhnChannelFamilyMembers rcfm
                where   rcfm.channel_family_id = channel_family_id_in);
    end;
    function get_org_id(channel_id_in in number)
    return number
    is
        org_id_out number;
    begin
        select org_id into org_id_out
            from rhnChannel
            where id = channel_id_in;
            return org_id_out;
    end get_org_id;
    function get_cfam_org_access(cfam_id_in in number, org_id_in in number)
    return number
    is
        cursor  families is
                        select  1
                        from    rhnOrgChannelFamilyPermissions cfp
                        where   cfp.org_id = org_id_in;
    begin
                for family in families loop
                return 1;
                end loop;
                return 0;
    end;
    function get_org_access(channel_id_in in number, org_id_in in number)
    return number
    is
        throwaway number;
    begin
        select distinct 1 into throwaway
          from rhnChannelFamilyMembers CFM,
               rhnOrgChannelFamilyPermissions CFP
         where cfp.org_id = org_id_in
           and CFM.channel_family_id = CFP.channel_family_id
           and CFM.channel_id = channel_id_in
           and (CFP.max_members > 0 or CFP.max_members is null or CFP.org_id = 1);
        return 1;
        exception
            when no_data_found
            then
            return 0;
    end;
    function user_role_check_debug(channel_id_in in number, 
                                   user_id_in in number, 
                                   role_in in varchar2, 
                                   reason_out out varchar2)
    return number
    is
        org_id number;
    begin
        org_id := rhn_user.get_org_id(user_id_in);
        if role_in = 'subscribe' and
           rhn_channel.shared_user_role_check(channel_id_in, user_id_in, role_in) = 1 then
            return 1;
        end if;
        if role_in = 'manage' and 
           NVL(rhn_channel.get_org_id(channel_id_in), -1) <> org_id then
                reason_out := 'channel_not_owned';
               return 0;
            end if;
        if role_in = 'subscribe' and 
           rhn_channel.get_org_access(channel_id_in, org_id) = 0 then
                reason_out := 'channel_not_available';
                return 0;
            end if;
        if rhn_user.check_role_implied(user_id_in, 'channel_admin') = 1 then
            reason_out := 'channel_admin';
            return 1;
            end if;
        if role_in = 'subscribe'
        then
            if rhn_channel.org_channel_setting(channel_id_in, 
                       org_id,
                       'not_globally_subscribable') = 0 then
                reason_out := 'globally_subscribable';
                    return 1;
            end if;
        end if;
        reason_out := 'direct_permission';
        return rhn_channel.direct_user_role_check(channel_id_in, 
                                              user_id_in, role_in);
    end;
    function user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    return number
    is
        throwaway varchar2(256);
    begin
        return rhn_channel.user_role_check_debug(channel_id_in, user_id_in, role_in, throwaway);
    end;
    function shared_user_role_check(channel_id in number, user_id in number, role in varchar2)
    return number
    is
      n number;
      oid number;
    begin
      oid := rhn_user.get_org_id(user_id);
      select 1 into n
      from rhnSharedChannelView s
      where s.id = channel_id and s.org_trust_id = oid;
      return 1;
      exception
        when no_data_found then
          return 0;
    end;
    function loose_user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    return number
    is
    begin
        if user_id_in is null then
            return 1;
        end if;
        return user_role_check(channel_id_in, user_id_in, role_in);
    end loose_user_role_check;
    function direct_user_role_check(channel_id_in in number, user_id_in in number, role_in in varchar2)
    return number
    is
        throwaway number;
    begin
        select 1 into throwaway
          from rhnChannelPermissionRole CPR,
               rhnChannelPermission CP
         where CP.user_id = user_id_in
           and CP.channel_id = channel_id_in
           and CPR.label = role_in
           and CP.role_id = CPR.id;
        return 1;
    exception
        when no_data_found
            then
            return 0;
    end;
    function org_channel_setting(channel_id_in in number, org_id_in in number, setting_in in varchar2)
    return number
    is
        throwaway number;
    begin
        select 1 into throwaway
          from rhnOrgChannelSettingsType OCST,
               rhnOrgChannelSettings OCS
         where OCS.org_id = org_id_in
           and OCS.channel_id = channel_id_in
           and OCST.label = setting_in
           and OCS.setting_id = OCST.id;
        return 1;
    exception
        when no_data_found
            then
            return 0;
    end;
    FUNCTION channel_priority(channel_id_in IN number) 
    RETURN number
    IS
         channel_name varchar2(64);
         priority number;
         end_of_life_val date;
         org_id_val number;
    BEGIN
        select name, end_of_life, org_id
        into channel_name, end_of_life_val, org_id_val
        from rhnChannel
        where id = channel_id_in;
        if end_of_life_val is not null then
          return -400;
        end if;
        if channel_name like 'Red Hat Enterprise Linux%' or channel_name like 'RHEL%' then
          priority := 1000;
          if channel_name not like '%Beta%' then
            priority := priority + 1000;
          end if;
          priority := priority +
            case
              when channel_name like '%v. 5%' then 600
              when channel_name like '%v. 4%' then 500
              when channel_name like '%v. 3%' then 400
              when channel_name like '%v. 2%' then 300
              when channel_name like '%v. 1%' then 200
              else 0
            end;
          priority := priority +
            case
              when channel_name like 'Red Hat Enterprise Linux (v. 5%' then 60
              when (channel_name like '%AS%' and channel_name not like '%Extras%') then 50
              when (channel_name like '%ES%' and channel_name not like '%Extras%') then 40
              when (channel_name like '%WS%' and channel_name not like '%Extras%') then 30
              when (channel_name like '%Desktop%' and channel_name not like '%Extras%') then 20
              when channel_name like '%Extras%' then 10
              else 0
            end; 
          priority := priority +
            case
              when channel_name like '%)' then 5
              else 0
            end;
          priority := priority +
            case
              when channel_name like '%32-bit x86%' then 4
              when channel_name like '%64-bit Intel Itanium%' then 3
              when channel_name like '%64-bit AMD64/Intel EM64T%' then 2
              else 0
            end;
        elsif channel_name like 'Red Hat Desktop%' then
            priority := 900;
            if channel_name not like '%Beta%' then
               priority := priority + 50;
            end if;
          priority := priority +
            case
              when channel_name like '%v. 4%' then 40
              when channel_name like '%v. 3%' then 30
              when channel_name like '%v. 2%' then 20
              when channel_name like '%v. 1%' then 10
              else 0
            end;
          priority := priority +
            case
              when channel_name like '%32-bit x86%' then 4
              when channel_name like '%64-bit Intel Itanium%' then 3
              when channel_name like '%64-bit AMD64/Intel EM64T%' then 2
              else 0
            end;
        elsif org_id_val is not null then
          priority := 600;
        else
          priority := 500;
        end if;
      return -priority;
    end channel_priority;
    procedure delete_server_channels(server_id_in in number)
    is
    begin
        update  rhnPrivateChannelFamily
        set     current_members = current_members -1
        where   org_id in (
                        select  org_id
                        from    rhnServer
                        where   id = server_id_in
                )
                and channel_family_id in (
                        select  rcfm.channel_family_id
                        from    rhnChannelFamilyMembers rcfm,
                                rhnServerChannel rsc
                        where   rsc.server_id = server_id_in
                                and rsc.channel_id = rcfm.channel_id
                and not exists (
                    select 1
                    from
                        rhnChannelFamilyVirtSubLevel cfvsl,
                        rhnSGTypeVirtSubLevel sgtvsl,
                        rhnServerEntitlementView sev,
                        rhnVirtualInstance vi
                    where
                        vi.virtual_system_id = server_id_in
                        and vi.host_system_id = sev.server_id
                        and sev.label in ('virtualization_host',
                                          'virtualization_host_platform')
                        and sev.server_group_type_id = 
                            sgtvsl.server_group_type_id
                        and sgtvsl.virt_sub_level_id = cfvsl.virt_sub_level_id
                        and cfvsl.channel_family_id = rcfm.channel_family_id
                    )
                );
    end;
        procedure refresh_newest_package(channel_id_in in number, caller_in in varchar2 := '(unknown)')
        is
        begin
                delete from rhnChannelNewestPackage where channel_id = channel_id_in;
                insert into rhnChannelNewestPackage
                        ( channel_id, name_id, evr_id, package_id, package_arch_id ) 
                        (       select  channel_id,
                                                name_id, evr_id,
                                                package_id, package_arch_id
                                from    rhnChannelNewestPackageView
                                where   channel_id = channel_id_in
                        );
                insert into rhnChannelNewestPackageAudit (channel_id, caller)
                    values (channel_id_in, caller_in);
                update rhnChannel 
                    set last_modified = greatest(sysdate, last_modified + 1/86400)
                    where id = channel_id_in; 
        end;
   procedure update_channel ( channel_id_in in number, invalidate_ss in number := 0, 
                              date_to_use in date := sysdate )
   is
   channel_last_modified date;
   last_modified_value date;
   cursor snapshots is
   select  snapshot_id id
   from    rhnSnapshotChannel
   where   channel_id = channel_id_in;
   begin
      select last_modified
      into channel_last_modified
      from rhnChannel
      where id = channel_id_in;
      last_modified_value := date_to_use;
      if last_modified_value <= channel_last_modified then
          last_modified_value := last_modified_value + 1/86400;
      end if;
      update rhnChannel set last_modified = last_modified_value
      where id = channel_id_in;
      if invalidate_ss = 1 then 
        for snapshot in snapshots loop
            update rhnSnapshot
            set invalid = lookup_snapshot_invalid_reason('channel_modified')
            where id = snapshot.id;
        end loop;
      end if;
   end update_channel;
   procedure update_channels_by_package ( package_id_in in number, date_to_use in date := sysdate )
   is
   cursor channels is
   select channel_id
   from rhnChannelPackage
   where package_id = package_id_in
   order by channel_id;
   begin
      for channel in channels loop
         rhn_channel.update_channel ( channel.channel_id, 1, date_to_use );
      end loop;
   end update_channels_by_package;
   procedure update_channels_by_errata ( errata_id_in number, date_to_use in date := sysdate )
   is
   cursor channels is
   select channel_id
   from rhnChannelErrata
   where errata_id = errata_id_in
   order by channel_id;
   begin
      for channel in channels loop
         rhn_channel.update_channel ( channel.channel_id, 0, date_to_use );
      end loop;
   end update_channels_by_errata;
END rhn_channel;
/
SHOW ERRORS

select 'rhnsat/packages/rhn_config.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_config.pkb
create or replace package body
rhn_config
is
	procedure prune_org_configs (
		org_id_in in number,
		total_in in number
	) is
	begin
		null;
	end prune_org_configs;
	function insert_revision (
		revision_in in number,
		config_file_id_in in number,
		config_content_id_in in number,
		config_info_id_in in number,
		delim_start_in in varchar2 := '{@',
		delim_end_in in varchar2 := '@}',
      config_file_type_id_in in number := 1
	) return number is
		retval number;
		cursor affected_orgs is
			select	cc.org_id id
			from	rhnConfigChannel cc,
					rhnConfigFile cf
			where	cf.id = config_file_id_in
				and cf.config_channel_id = cc.id;
	begin
		insert into rhnConfigRevision(id, revision, config_file_id,
				config_content_id, config_info_id, delim_start, delim_end, 
            config_file_type_id
			) values (
				rhn_confrevision_id_seq.nextval, revision_in, config_file_id_in,
				config_content_id_in, config_info_id_in, delim_start_in,
				delim_end_in, config_file_type_id_in
			)
			returning id into retval;
		for org in affected_orgs loop
			rhn_quota.update_org_quota(org.id);
		end loop;
		return retval;
	end insert_revision;
	procedure delete_revision (
		config_revision_id_in in number,
		org_id_in in number := -1
	) is
		cfid number;
		ccid number;
		oid number;
		latest_crid number;
		others number := 0;
		cursor snapshots is
			select	scr.snapshot_id id
			from	rhnSnapshot s,
					rhnSnapshotConfigRevision scr
			where	scr.config_revision_id = config_revision_id_in
					and scr.snapshot_id = s.id
					and s.invalid is null;
		cursor other_revisions(config_content_id_in in number) is
			select	1
			from	rhnConfigRevision
			where	config_content_id = config_content_id_in;
	begin
		for snapshot in snapshots loop
			update		rhnSnapshot s
				set		s.invalid =
							lookup_snapshot_invalid_reason('cr_removed')
				where	s.id = snapshot.id;
		end loop;
		if org_id_in < 0 then
			select	cr.config_content_id, cc.org_id
			into	ccid, oid
			from	rhnConfigChannel cc,
					rhnConfigFile cf,
					rhnConfigRevision cr
			where	cr.id = config_revision_id_in
				and cr.config_file_id = cf.id
				and cf.config_channel_id = cc.id;
		else
			select	cr.config_content_id, org_id_in
			into	ccid, oid
			from	rhnConfigRevision cr
			where	cr.id = config_revision_id_in;
		end if;
		delete from rhnConfigRevision where id = config_revision_id_in;
		for other_revision in other_revisions(ccid) loop
			others := 1;
			exit;
		end loop;
		if others = 0 then
			delete from rhnConfigContent where id = ccid;
		end if;
		if org_id_in < 0 then
			select	cf.latest_config_revision_id,
					cf.id
			into	latest_crid,
					cfid
			from	rhnConfigFile cf,
					rhnConfigRevision cr
			where	cr.id = config_revision_id_in
				and cr.config_file_id = cf.id;
			if latest_crid = config_revision_id_in then
				latest_crid := rhn_config.get_latest_revision(cfid);
				if latest_crid is not null then
					update rhnConfigFile set latest_config_revision_id = latest_crid
						where id = cfid;
				else
					delete from rhnConfigFile where id = cfid;
				end if;
			end if;
		end if;
		rhn_quota.update_org_quota(oid);
	end delete_revision;
	function get_latest_revision (
		config_file_id_in in number
	) return number is
		cursor revisions is
			select	cr.id
			from	rhnConfigRevision cr
			where	cr.config_file_id = config_file_id_in
			order by revision desc;
	begin
		for revision in revisions loop
			return revision.id;
		end loop;
		return null;
	end get_latest_revision;
	function insert_file (
		config_channel_id_in in number,
		name_in in varchar2
	) return number is
		retval number;
	begin
		select	rhn_conffile_id_seq.nextval
		into	retval
		from	dual;
		insert into rhnConfigFile(id, config_channel_id, config_file_name_id, 
				state_id
			) (
				select	retval,
						config_channel_id_in,
						lookup_config_filename(name_in),
						id
				from	rhnConfigFileState
				where	label = 'alive'
			);
		return retval;
	end insert_file;
	procedure delete_file (
		config_file_id_in in number
	) is
		cursor revisions is
			select	cr.id, cc.org_id
			from	rhnConfigChannel cc,
					rhnConfigRevision cr,
					rhnConfigFile cf
			where	cf.id = config_file_id_in
				and cf.config_channel_id = cc.id
				and cr.config_file_id = cf.id;
		org_id number;
	begin
		for revision in revisions loop
			rhn_config.delete_revision(revision.id, revision.org_id);
			org_id := revision.org_id;
		end loop;
		rhn_quota.update_org_quota(org_id);
		delete from rhnConfigFile where id = config_file_id_in;
	end delete_file;
	function insert_channel (
		org_id_in in number,
		type_in in varchar2,
		name_in in varchar2,
		label_in in varchar2,
		description_in in varchar2
	) return number is
		retval number;
	begin
		select	rhn_confchan_id_seq.nextval
		into	retval
		from	dual;
		insert into rhnConfigChannel(id, org_id, confchan_type_id,
				name, label, description
			) (
				select	retval,
						org_id_in,
						cct.id,
						name_in,
						label_in,
						description_in
				from	rhnConfigChannelType cct
				where	label = type_in
			);
		return retval;
	end insert_channel;
	procedure delete_channel (
		config_channel_id_in in number
	) is
		cursor config_files is
			select	id
			from	rhnConfigFile
			where	config_channel_id = config_channel_id_in;
	begin
		for config_file in config_files loop
			rhn_config.delete_file(config_file.id);
		end loop;
		delete from rhnConfigChannel where id = config_channel_id_in;
	end delete_channel;
end rhn_config;
/
show errors

select 'rhnsat/packages/rhn_config_channel.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_config_channel.pkb
CREATE OR REPLACE
PACKAGE BODY rhn_config_channel
IS
    FUNCTION action_diff_revision_status(action_config_revision_id_in IN NUMBER)
    RETURN VARCHAR2
    IS
    	failure_reason VARCHAR2(4000);
	result_is_null NUMBER;
	result_exists NUMBER;
    BEGIN
	select extant, is_null, reason
	into   result_exists, result_is_null, failure_reason
	from   (
        	SELECT ACRR.action_config_revision_id extant,
        	       1 is_null, -- NVL2(ACRR.result, 0, 1),
        	       CFF.name reason
        	  FROM rhnConfigFileFailure CFF,
        	       rhnActionConfigRevisionResult ACRR,
        	       rhnActionConfigRevision ACR
        	 WHERE ACR.id = action_config_revision_id_in
        	   AND ACR.id = ACRR.action_config_revision_id (+)
        	   and acrr.result is null
        	   AND ACR.failure_id = CFF.id (+)
        	union all
        	SELECT ACRR.action_config_revision_id extant, 
        	       0 is_null, -- NVL2(ACRR.result, 0, 1),
        	       CFF.name reason
        	  FROM rhnConfigFileFailure CFF,
        	       rhnActionConfigRevisionResult ACRR,
        	       rhnActionConfigRevision ACR
        	 WHERE ACR.id = action_config_revision_id_in
        	   AND ACR.id = ACRR.action_config_revision_id (+)
        	   and acrr.result is not null
        	   AND ACR.failure_id = CFF.id (+)
		);
    	IF failure_reason IS NOT NULL
	THEN
	    RETURN failure_reason;
	END IF;
    	IF result_exists IS NOT NULL
	THEN
	    IF result_is_null = 1
	    THEN
	    	RETURN 'No differences';
	    END IF;
	    RETURN 'Differences exist';
	END IF;
    	RETURN NULL;
    END action_diff_revision_status;
    FUNCTION get_user_chan_access(config_channel_id_in IN NUMBER, user_id_in IN NUMBER)
    RETURN NUMBER
    IS
    	server_id NUMBER;
	org_matches NUMBER;
	global_channel VARCHAR2(30);
	any_visible_servers_subscribed NUMBER;
    BEGIN
    	org_matches := 0;
	BEGIN
    	  SELECT 1 INTO org_matches
	    FROM rhnConfigChannel CC,
	         web_contact WC
	   WHERE WC.id = user_id_in
	     AND CC.id = config_channel_id_in
	     AND WC.org_id = CC.org_id;
	EXCEPTION
	  WHEN NO_DATA_FOUND
	    THEN RETURN 0;
	END;
	global_channel := 'unknown';
 	SELECT CCT.label INTO global_channel
	  FROM rhnConfigChannel CC,
	       rhnConfigChannelType CCT
	 WHERE CC.id = config_channel_id_in
	   AND CCT.id = CC.confchan_type_id;
    	IF (rhn_user.check_role_implied(user_id_in, 'config_admin') = 1) AND (global_channel = 'normal')
	THEN
	    RETURN 1;
	END IF;
    	any_visible_servers_subscribed := 0;
	BEGIN
    	  SELECT 1 INTO any_visible_servers_subscribed
	    FROM DUAL
           WHERE EXISTS (
	     SELECT SCC.server_id
	       FROM rhnServerConfigChannel SCC,
	            rhnUserServerPermsDupes USPD
	      WHERE USPD.user_id = user_id_in
	        AND USPD.server_id = SCC.server_id
	        AND SCC.config_channel_id = config_channel_id_in
	   );
	EXCEPTION
	  WHEN NO_DATA_FOUND
	    THEN RETURN 0;
	END;
	RETURN any_visible_servers_subscribed;
    END get_user_chan_access;
    FUNCTION get_user_revision_access(config_revision_id_in IN NUMBER, user_id_in IN NUMBER)    
    RETURN NUMBER
    IS
    	config_channel_id NUMBER;
    BEGIN
    BEGIN
    	SELECT CF.config_channel_id INTO config_channel_id
	  FROM rhnConfigFile CF,
	       rhnConfigRevision CR
	 WHERE CF.id = CR.config_file_id
	   AND CR.id = config_revision_id_in;
    EXCEPTION
	  WHEN NO_DATA_FOUND
	   THEN RETURN 0;	   
    END;
	RETURN rhn_config_channel.get_user_chan_access(config_channel_id, user_id_in);
    END get_user_revision_access;
    FUNCTION get_user_file_access(config_file_id_in IN NUMBER, user_id_in IN NUMBER)    
    RETURN NUMBER
    IS
    	config_channel_id NUMBER;
    BEGIN
    BEGIN    
        SELECT CF.config_channel_id INTO config_channel_id    	
	  FROM rhnConfigFile CF
	 WHERE CF.id = config_file_id_in;
	EXCEPTION
	  WHEN NO_DATA_FOUND
	    THEN RETURN 0;
    END;
	RETURN rhn_config_channel.get_user_chan_access(config_channel_id, user_id_in);
    END get_user_file_access;
END rhn_config_channel;
/
SHOW ERRORS

select 'rhnsat/packages/rhn_date_manip.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_date_manip.pkb
create or replace
package body rhn_date_manip
is
	function get_reporting_period_start
	return date is
		months_ago	number;
		weeks_ago	number;
		target_date	date;
		day_number	number;
	begin
		months_ago := rhn_date_manip.periods_ago/2;
		weeks_ago := mod(rhn_date_manip.periods_ago,2);
		target_date := trunc(add_months(sysdate,-months_ago)-(7*weeks_ago));
		day_number := to_char(target_date,'DD');
		if day_number > 16 then
			target_date := target_date - (day_number - 16);
		else
			target_date := target_date - (day_number - 1);
		end if;
		return target_date;
	end get_reporting_period_start;
	function get_reporting_period_end
	return date is
		months_ago	number;
		weeks_ago	number;
		target_date	date;
		day_number	number;
	begin
		months_ago := rhn_date_manip.periods_ago/2;
		weeks_ago := mod(rhn_date_manip.periods_ago,2);
		target_date := trunc(add_months(sysdate,-months_ago)-(7*weeks_ago));
		day_number := to_char(target_date,'DD');
		if day_number > 16 then
			target_date := last_day(target_date);
		else
			target_date := target_date + (-day_number + 15) + (1-1/86400);
		end if;
		return target_date;
	end get_reporting_period_end;
end rhn_date_manip;
/
show errors

select 'rhnsat/packages/rhn_org.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_org.pkb
CREATE OR REPLACE
PACKAGE BODY rhn_org
IS
	body_version varchar2(100) := '';
    FUNCTION find_server_group_by_type(org_id_in NUMBER, group_label_in VARCHAR2) 
    RETURN NUMBER
    IS
	server_group       server_group_by_label%ROWTYPE;
    BEGIN
    	OPEN server_group_by_label(org_id_in, group_label_in);
	FETCH server_group_by_label INTO server_group;
	CLOSE server_group_by_label;
	RETURN server_group.id;
    END find_server_group_by_type;
    procedure delete_org (
        org_id_in in number
    )
    is
        cursor users is
        select id
        from web_contact
        where org_id = org_id_in;
		cursor servers(org_id_in in number) is
        select	id
        from	rhnServer
        where	org_id = org_id_in;
        cursor config_channels is
        select id
        from rhnConfigChannel
        where org_id = org_id_in;
    begin
        if org_id_in = 1 then
            rhn_exception.raise_exception('cannot_delete_base_org');
        end if;
        for u in users loop
            rhn_org.delete_user(u.id, 1);
        end loop;
        for s in servers(org_id_in) loop
            delete_server(s.id);
        end loop;
        for c in config_channels loop
            rhn_config.delete_channel(c.id);
        end loop;
        rhn_entitlements.remove_org_entitlements(org_id_in);
        delete from rhnChannel where org_id = org_id_in;
        delete from rhnDailySummaryQueue where org_id = org_id_in;
        delete from rhnOrgQuota where org_id = org_id_in;
        delete from rhnOrgInfo where org_id = org_id_in;
        delete from rhnFileList where org_id = org_id_in;
        delete from rhnServerGroup where org_id = org_id_in;
        delete from rhn_check_suites where customer_id = org_id_in;
        delete from rhn_command_target where customer_id = org_id_in;
        delete from rhn_contact_groups where customer_id = org_id_in;
        delete from rhn_notification_formats where customer_id = org_id_in;
        delete from rhn_probe where customer_id = org_id_in;
        delete from rhn_redirects where customer_id = org_id_in;
        delete from rhn_sat_cluster where customer_id = org_id_in;
        delete from rhn_schedules where customer_id = org_id_in;
        delete from web_customer where id = org_id_in;
    end delete_org;
	procedure delete_user(user_id_in in number, deleting_org in number := 0) is
		cursor is_admin is
			select	1
			from	rhnUserGroupType	ugt,
					rhnUserGroup		ug,
					rhnUserGroupMembers	ugm
			where	ugm.user_id = user_id_in
				and ugm.user_group_id = ug.id
				and ug.group_type = ugt.id
				and ugt.label = 'org_admin';
		cursor servergroups_needing_admins is
			select	usgp.server_group_id	server_group_id
			from	rhnUserServerGroupPerms	usgp
			where	1=1
				and usgp.user_id = user_id_in
				and not exists (
					select	1
					from	rhnUserServerGroupPerms	sq_usgp
					where	1=1
						and sq_usgp.server_group_id = usgp.server_group_id
						and	sq_usgp.user_id != user_id_in
				);
		cursor messages is
			select	message_id id
			from	rhnUserMessage
			where	user_id = user_id_in;
		users			number;
		our_org_id		number;
		other_users		number;
		other_org_admin	number;
        other_user_id  number;
	begin
		select	wc.org_id
		into	our_org_id
		from	web_contact wc
		where	id = user_id_in;
		begin
			select	id, 1
			into	other_user_id, other_users
			from	web_contact
			where	1=1
				and org_id = our_org_id
				and id != user_id_in
				and rownum = 1;
		exception
			when no_data_found then
				other_users := 0;
		end;
		if other_users != 0 then
			for ignore in is_admin loop
				begin 
					select	new_ugm.user_id
					into	other_org_admin
					from	rhnUserGroupMembers	new_ugm,
							rhnUserGroupType	ugt,
							rhnUserGroup		ug,
							rhnUserGroupMembers	ugm
					where	ugm.user_id = user_id_in
						and ugm.user_group_id = ug.id
						and ug.group_type = ugt.id
						and ugt.label = 'org_admin'
						and ug.id = new_ugm.user_group_id
						and new_ugm.user_id != user_id_in
						and rownum = 1;
				exception
					when no_data_found then
                        if deleting_org = 0 then
    						rhn_exception.raise_exception('cannot_delete_user');
                        end if;
				end;
				for sg in servergroups_needing_admins loop
					rhn_user.add_servergroup_perm(other_org_admin,
						sg.server_group_id);
				end loop;
			end loop;
		end if;
		for message in messages loop
			delete
				from	rhnUserMessage
				where	user_id = user_id_in
					and message_id = message.id;
			begin
				select	1
				into	users
				from	rhnUserMessage
				where	message_id = message.id
					and rownum = 1;
				delete
					from	rhnMessage
					where	id = message.id;
			exception
				when no_data_found then
					null;
			end;
		end loop;
		delete from rhn_command_queue_sessions where contact_id = user_id_in;
		delete from rhn_contact_groups
		where recid in (
			select contact_group_id
			from rhn_contact_group_members
			where member_contact_method_id in (
				select recid from rhn_contact_methods
				where contact_id = user_id_in
				)
			)
			and not exists (
				select 1
				from rhn_contact_group_members, rhn_contact_methods
				where rhn_contact_groups.recid = rhn_contact_group_members.contact_group_id
					and rhn_contact_group_members.member_contact_method_id = rhn_contact_methods.recid
					and rhn_contact_methods.contact_id <> user_id_in
			);
		delete from rhn_contact_methods where contact_id = user_id_in;
		delete from rhn_redirects where contact_id = user_id_in;
		delete from rhnUserServerPerms where user_id = user_id_in;
                delete from rhnAppInstallSession where user_id = user_id_in;
		if other_users != 0 then
			update		rhnRegToken
				set		user_id = nvl(other_org_admin, other_user_id)
				where	org_id = our_org_id
					and user_id = user_id_in;
			begin
				delete from web_contact where id = user_id_in;
			exception
				when others then
					rhn_exception.raise_exception('cannot_delete_user');
			end;
		else
            begin
                delete from web_contact where id = user_id_in;
		    exception
				when others then
					rhn_exception.raise_exception('cannot_delete_user');
			end;
		end if;
		return;
	end delete_user;
END rhn_org;
/
SHOW ERRORS

select 'rhnsat/packages/rhn_quota.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_quota.pkb
create or replace package body
rhn_quota
is
	function recompute_org_quota_used (
		org_id_in in number
	) return number is
		retval number := 0;
	begin
		begin
			select	NVL(sum(a.file_size),0)
			into	retval
			from	(
				select	distinct content.id, content.file_size
				from	rhnConfigContent	content,
						rhnConfigRevision	cr,
						rhnConfigFile		cf,
						rhnConfigChannel	cc
				where	cc.org_id = org_id_in
					and cc.id = cf.config_channel_id
					and cf.id = cr.config_file_id
					and cr.config_content_id = content.id
				) a;
		exception
			when others then
				null;
		end;
		return retval;
	end recompute_org_quota_used;
	function get_org_for_config_content (
		config_content_id_in in number
	) return number is
		org_id number;
	begin
		select	cc.org_id
		into	org_id
		from	rhnConfigChannel	cc,
				rhnConfigFile		cf,
				rhnConfigRevision	cr
		where	cr.config_content_id = config_content_id_in
			and cr.config_file_id = cf.id
			and cf.config_channel_id = cc.id;
		return org_id;
	end get_org_for_config_content;
	procedure set_org_quota_total (
		org_id_in in number,
		total_in in number
	) is
		available number;
	begin
		select	total_in + oq.bonus
		into	available
		from	rhnOrgQuota oq
		where	oq.org_id = org_id_in;
		rhn_config.prune_org_configs(org_id_in, available);
		update		rhnOrgQuota
			set		total = total_in
			where	org_id = org_id_in;
	exception
		when no_data_found then
			insert into rhnOrgQuota ( org_id, total )
				values (org_id_in, total_in);
		when others then
			null;
	end set_org_quota_total;
	procedure update_org_quota (
		org_id_in in number
	) is
	begin
		update rhnOrgQuota
			set used = rhn_quota.recompute_org_quota_used(org_id_in)
			where org_id = org_id_in;
	end update_org_quota;
end rhn_quota;
/
show errors

select 'rhnsat/packages/rhn_server.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_server.pkb
create or replace
package body rhn_server
is
    function system_service_level(
    	server_id_in in number,
	service_level_in in varchar2
    ) return number is
    cursor ents is 
      select label from rhnServerEntitlementView
      where server_id = server_id_in;
    retval number := 0;
    begin
         for ent in ents loop
            retval := rhn_entitlements.entitlement_grants_service (ent.label, service_level_in);
            if retval = 1 then
               return retval;
            end if;
         end loop;
         return retval;
    end system_service_level;
    function can_change_base_channel(server_id_in IN NUMBER)
    return number
    is
    	throwaway number;
    begin
	select 1 into throwaway
	  from rhnServer S
	 where S.id = server_id_in
	   and not exists (select 1 from rhnSatelliteInfo SI where SI.server_id = S.id)
	   and not exists (select 1 from rhnProxyInfo PI where PI.server_id = S.id);
	return 1;
    exception
    	when no_data_found
	    then
	    return 0;
    end can_change_base_channel;
    procedure set_custom_value(
    	server_id_in in number,
	user_id_in in number,
	key_label_in in varchar2,
	value_in in varchar2
    ) is
    	key_id_val number;
    begin
    	select CDK.id into key_id_val
	  from rhnCustomDataKey CDK,
	       rhnServer S
	 where S.id = server_id_in
	   and S.org_id = CDK.org_id
	   and CDK.label = key_label_in;
	begin
	    insert into rhnServerCustomDataValue (server_id, key_id, value, created_by, last_modified_by)
	    values (server_id_in, key_id_val, value_in, user_id_in, user_id_in);
	exception
	    when DUP_VAL_ON_INDEX
	    	then
		update rhnServerCustomDataValue
		   set value = value_in,
		       last_modified_by = user_id_in
		 where server_id = server_id_in
		   and key_id = key_id_val;		   
	end;
    end set_custom_value;
    function bulk_set_custom_value(
    	key_label_in in varchar2,
	value_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    )
    return integer
    is
    i integer := 0;
    begin
        i := 0;
    	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    if rhn_server.system_service_level(server.element, 'provisioning') = 1 then
	    	rhn_server.set_custom_value(server.element, set_uid_in, key_label_in, value_in);
            i := i + 1;
	    end if;
	end loop server;
    return i;
    end bulk_set_custom_value;
    procedure bulk_snapshot_tag(
    	org_id_in in number,
        tagname_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    ) is
    	snapshot_id number;
    begin
    	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
	    if rhn_server.system_service_level(server.element, 'provisioning') = 1 then
	    	begin
	    	    select max(id) into snapshot_id
	    	    from rhnSnapshot
	    	    where server_id = server.element;
	    	exception
	    	    when NO_DATA_FOUND then
		    	rhn_server.snapshot_server(server.element, 'tagging system:  ' || tagname_in);
			select max(id) into snapshot_id
			from rhnSnapshot
			where server_id = server.element;
		end;
		begin
		    rhn_server.tag_snapshot(snapshot_id, org_id_in, tagname_in);
		exception
		    when DUP_VAL_ON_INDEX
		    	then
			null;
		end;
	    end if;
	end loop server;    
    end bulk_snapshot_tag;
    procedure tag_delete(
    	server_id_in in number,
	tag_id_in in number
    ) is
    	cursor snapshots is
		select	snapshot_id
		from	rhnSnapshotTag
		where	tag_id = tag_id_in;
	tag_id_tmp number;
    begin
    	select	id into tag_id_tmp
	from	rhnTag
	where	id = tag_id_in
	for update;
	delete
		from	rhnSnapshotTag
		where	server_id = server_id_in
			and tag_id = tag_id_in;
	for snapshot in snapshots loop
		return;
	end loop;
	delete
		from rhnTag
		where id = tag_id_in;
    end tag_delete;
    procedure tag_snapshot(
        snapshot_id_in in number,
	org_id_in in number,
	tagname_in in varchar2
    ) is
    begin
    	insert into rhnSnapshotTag (snapshot_id, server_id, tag_id)
	select snapshot_id_in, server_id, lookup_tag(org_id_in, tagname_in)
	from rhnSnapshot
	where id = snapshot_id_in;
    end tag_snapshot;
    procedure bulk_snapshot(
    	reason_in in varchar2,
	set_label_in in varchar2,
	set_uid_in in number
    ) is
    begin
    	for server in rhn_set.set_iterator(set_label_in, set_uid_in)
	loop
    	    if rhn_server.system_service_level(server.element, 'provisioning') = 1 then
	    	rhn_server.snapshot_server(server.element, reason_in);
	    end if;
	end loop server;
    end bulk_snapshot;
    procedure snapshot_server(
    	server_id_in in number,
	reason_in in varchar2
    ) is
    	snapshot_id number;
	cursor revisions is
		select distinct
			cr.id
		from	rhnConfigRevision	cr,
			rhnConfigFileName	cfn,
			rhnConfigFile		cf,
			rhnConfigChannel	cc,
			rhnServerConfigChannel	scc
		where	1=1
			and scc.server_id = server_id_in
			and scc.config_channel_id = cc.id
			and cc.id = cf.config_channel_id
			and cf.id = cr.config_file_id
			and cr.id = cf.latest_config_revision_id
			and cf.config_file_name_id = cfn.id
			and cf.id = lookup_first_matching_cf(scc.server_id, cfn.path);
	locked integer;
    begin
    	select rhn_snapshot_id_seq.nextval into snapshot_id from dual;
	insert into rhnSnapshot (id, org_id, server_id, reason) (
		select	snapshot_id,
			s.org_id,
			server_id_in,
			reason_in
		from	rhnServer s
		where	s.id = server_id_in
	);
	insert into rhnSnapshotChannel (snapshot_id, channel_id) (
		select	snapshot_id, sc.channel_id
		from	rhnServerChannel sc
		where	sc.server_id = server_id_in
	);
	insert into rhnSnapshotServerGroup (snapshot_id, server_group_id) (
		select	snapshot_id, sgm.server_group_id
		from	rhnServerGroupMembers sgm
		where	sgm.server_id = server_id_in
	);
        locked := 0;
        while true loop
            begin
                insert into rhnPackageNEVRA (id, name_id, evr_id, package_arch_id)
                select rhn_pkgnevra_id_seq.nextval, sp.name_id, sp.evr_id, sp.package_arch_id
                from rhnServerPackage sp
                where sp.server_id = server_id_in
                        and not exists
                        (select 1
                                from rhnPackageNEVRA nevra
                                where nevra.name_id = sp.name_id
                                        and nevra.evr_id = sp.evr_id
                                        and (nevra.package_arch_id = sp.package_arch_id
                                            or (nevra.package_arch_id is null
                                                and sp.package_arch_id is null)));
                exit;
            exception when dup_val_on_index then
                if locked = 1 then
                    raise;
                else
                    lock table rhnPackageNEVRA in exclusive mode;
                    locked := 1;
                end if;
            end;
        end loop;
	insert into rhnSnapshotPackage (snapshot_id, nevra_id) (
                select distinct snapshot_id, nevra.id
                from    rhnServerPackage sp, rhnPackageNEVRA nevra
                where   sp.server_id = server_id_in
                        and nevra.name_id = sp.name_id
                        and nevra.evr_id = sp.evr_id
                        and (nevra.package_arch_id = sp.package_arch_id
                            or (nevra.package_arch_id is null
                                and sp.package_arch_id is null))
	);
	insert into rhnSnapshotConfigChannel ( snapshot_id, config_channel_id ) (
		select	snapshot_id, scc.config_channel_id
		from	rhnServerConfigChannel scc
		where	server_id = server_id_in
	);
	for revision in revisions loop
		insert into rhnSnapshotConfigRevision (
				snapshot_id, config_revision_id
			) values (
				snapshot_id, revision.id
			);
	end loop;
    end snapshot_server;
    procedure remove_action(
    	server_id_in in number,
	action_id_in in number
    ) is
    	cursor chained_actions is
		select	id, prerequisite
		from	rhnAction
		start with id = action_id_in
		connect by prior id = prerequisite
		order by prerequisite desc;
	cursor sessions is
		select	s.id
		from	rhnKickstartSession s
		where	server_id_in in (s.old_server_id, s.new_server_id)
			and s.action_id = action_id_in
			and not exists (
				select	1
				from	rhnKickstartSessionState ss
				where	ss.id = s.state_id
					and ss.label in ('failed','complete')
			);
	type chain_end_type is table of number index by binary_integer;
	chain_ends chain_end_type;
	i number;
	prereq number := 1;
    begin
	select	prerequisite
	into	prereq
	from	rhnAction
	where	id = action_id_in;
	if prereq is not null then
		rhn_exception.raise_exception('action_is_child');
	end if;
	i := 0;
	for action in chained_actions loop
		if action.prerequisite is null then
			chain_ends(i) := action.id;
			i := i + 1;
		else
			delete from rhnServerAction
				where server_id = server_id_in
				and action_id = action.id;
		end if;
	end loop;
	i := chain_ends.first;
	while i is not null loop
		delete from rhnServerAction
			where server_id = server_id_in
			and action_id = chain_ends(i);
		i := chain_ends.next(i);
	end loop;
	for s in sessions loop
		update rhnKickstartSession
			set 	state_id = (
					select	id
					from	rhnKickstartSessionState
					where	label = 'failed'
				),
				action_id = null
			where	id = s.id;
		set_ks_session_history_message(s.id, 'failed', 'Kickstart cancelled due to action removal');
	end loop;
    end remove_action;
    function check_user_access(server_id_in in number, user_id_in in number)
    return number
    is
    	has_access number;
    begin
        select 1 into has_access
	  from rhnServer S,
	       web_contact wc
	 where wc.org_id = s.org_id
	   and s.id = server_id_in
	   and wc.id = user_id_in;
    	if rhn_user.check_role(user_id_in, 'org_admin') = 1
	then
	    return 1;
	end if;
    	select 1 into has_access
	  from rhnServerGroupMembers SGM,
	       rhnUserServerGroupPerms USG
	 where SGM.server_group_id = USG.server_group_id
	   and SGM.server_id = server_id_in
	   and USG.user_id = user_id_in
	   and rownum = 1;
	return 1;
    exception
    	when no_data_found
	    then
	    return 0;
    end check_user_access;
    function can_server_consume_virt_slot(server_id_in in number,
                                           group_type_in in
                                           rhnServerGroupType.label%TYPE)
    return number                                           
    is
        cursor server_virt_slots is
            select vi.VIRTUAL_SYSTEM_ID
            from
                rhnVirtualInstance vi
            where
                vi.VIRTUAL_SYSTEM_ID = server_id_in
                and exists ( select 1
                     from rhnServerEntitlementView sev
                 where vi.HOST_SYSTEM_ID = sev.server_id
                 and sev.label in ('virtualization_host',
                                   'virtualization_host_platform') )
                and exists ( select 1
                     from rhnServerEntitlementView sev2
                 where vi.HOST_SYSTEM_ID = sev2.server_id
                 and sev2.label = group_type_in );
    begin
        for server_virt_slot in server_virt_slots loop
            return 1;
        end loop;
        return 0;
    end can_server_consume_virt_slot;
    procedure insert_into_servergroup (
		server_id_in in number,
		server_group_id_in in number
    ) is
		cursor sg_users is
			select	user_id id
			from	rhnUserServerGroupPerms
			where	server_group_id = server_group_id_in;
		used_slots number;
		max_slots number;
		org_id number;
		mgmt_available number;
		mgmt_upgrade number;
		mgmt_sgid number;
		prov_available number;
		prov_upgrade number;
		prov_sgid number;
		group_label rhnServerGroupType.label%TYPE;
		group_type number;
	begin
		select	sg.group_type, sg.org_id, sg.current_members, sg.max_members
		into	group_type, org_id, used_slots, max_slots
		from	rhnServerGroup sg
		where	sg.id = server_group_id_in
		for update of sg.current_members;
		if group_type is null then
			if used_slots >= max_slots then
				rhn_exception.raise_exception('servergroup_max_members');
			end if;
			insert into rhnServerGroupMembers(
					server_id, server_group_id
				) values (
					server_id_in, server_group_id_in
				);
			update rhnServerGroup
				set current_members = current_members + 1
				where id = server_group_id_in;
			for u in sg_users loop
				rhn_cache.update_perms_for_user(u.id);
			end loop;
			return;
		end if;
		select	label
		into	group_label
		from	rhnServerGroupType	sgt
		where	sgt.id = group_type;
		if group_label in ('sw_mgr_entitled',
                           'enterprise_entitled',
                           'monitoring_entitled',
                           'provisioning_entitled',
                           'virtualization_host',
                           'virtualization_host_platform') then
			if used_slots >= max_slots and 
               (can_server_consume_virt_slot(server_id_in, group_label) != 1) 
               then
				rhn_exception.raise_exception('servergroup_max_members');
			end if;
			insert into rhnServerGroupMembers(
					server_id, server_group_id
				) values (
					server_id_in, server_group_id_in
				);
            if can_server_consume_virt_slot(server_id_in, group_label) = 0 then
                update rhnServerGroup
                set current_members = current_members + 1
                where id = server_group_id_in;
            end if;                
			return;
		end if;
	end;
	function insert_into_servergroup_maybe (
		server_id_in in number,
		server_group_id_in in number
	) return number is 
		retval number := 0;
		cursor servergroups is
			select	s.id	server_id,
					sg.id	server_group_id
			from	rhnServerGroup	sg,
					rhnServer		s
			where	s.id = server_id_in
				and sg.id = server_group_id_in
				and s.org_id = sg.org_id
				and not exists (
					select	1
					from	rhnServerGroupMembers sgm
					where	sgm.server_id = s.id
						and sgm.server_group_id = sg.id
				);
	begin
		for sgm in servergroups loop
			rhn_server.insert_into_servergroup(sgm.server_id, sgm.server_group_id);
			retval := retval + 1;
		end loop;
		return retval;
	end insert_into_servergroup_maybe;
	procedure insert_set_into_servergroup (
		server_group_id_in in number,
		user_id_in in number,
		set_label_in in varchar2
	) is
		cursor servers is
			select	st.element	id
			from	rhnSet		st
			where	st.user_id = user_id_in
				and st.label = set_label_in
				and exists (
					select	1
					from	rhnUserManagedServerGroups umsg
					where	umsg.server_group_id = server_group_id_in
						and umsg.user_id = user_id_in
					)
				and not exists (
					select	1
					from	rhnServerGroupMembers sgm
					where	sgm.server_id = st.element
						and sgm.server_group_id = server_group_id_in
				);
	begin
		for s in servers loop
			rhn_server.insert_into_servergroup(s.id, server_group_id_in);
		end loop;
	end insert_set_into_servergroup;
    procedure delete_from_servergroup (
    	server_id_in in number,
		server_group_id_in in number
    ) is
		cursor sg_users is
			select	user_id id
			from	rhnUserServerGroupPerms
			where	server_group_id = server_group_id_in;
        cursor server_virt_groups is
            select 1
            from rhnServerEntitlementVirtual sev
            where sev.server_id = server_id_in
            and sev.server_group_id = server_group_id_in;
		oid number;
		mgmt_sgid number;
		label rhnServerGroupType.label%TYPE;
		group_type number;
	begin
		begin
			select	sg.group_type, sg.org_id
			into	group_type,	oid
			from	rhnServerGroupMembers	sgm,
					rhnServerGroup			sg
			where	sg.id = server_group_id_in
				and sg.id = sgm.server_group_id
				and sgm.server_id = server_id_in
			for update of sg.current_members;
		exception
			when no_data_found then
				rhn_exception.raise_exception('server_not_in_group');
		end;
		if group_type is null then
			delete from rhnServerGroupMembers
				where server_group_id = server_group_id_in
				and	server_id = server_id_in;
			update rhnServerGroup
				set current_members = current_members - 1
				where id = server_group_id_in;
			for u in sg_users loop
				rhn_cache.update_perms_for_user(u.id);
			end loop;
			return;
		end if;
		select	sgt.label
		into	label
		from	rhnServerGroupType sgt
		where	sgt.id = group_type;
		if label in ('sw_mgr_entitled',
                     'enterprise_entitled', 
                     'provisioning_entitled', 
                     'monitoring_entitled',
                     'virtualization_host',
                     'virtualization_host_platform') then
            for server_virt_group in server_virt_groups loop                
                delete from rhnServerGroupMembers
                where server_group_id = server_group_id_in
                and	server_id = server_id_in;
                return;
            end loop;                
            delete from rhnServerGroupMembers
            where server_group_id = server_group_id_in
            and	server_id = server_id_in;
            update rhnServerGroup
            set current_members = current_members - 1
            where id = server_group_id_in;
		end if;
	end;
	procedure delete_set_from_servergroup (
		server_group_id_in in number,
		user_id_in in number,
		set_label_in in varchar2
	) is
		cursor servergroups is
			select	sgm.server_id, sgm.server_group_id
			from	rhnSet st,
					rhnServerGroupMembers sgm
			where	sgm.server_group_id = server_group_id_in
				and st.user_id = user_id_in
				and st.label = set_label_in
				and sgm.server_id = st.element
				and exists (
					select	1
					from	rhnUserManagedServerGroups usgp
					where	usgp.server_group_id = server_group_id_in
						and usgp.user_id = user_id_in
				);
	begin
		for sgm in servergroups loop
			rhn_server.delete_from_servergroup(sgm.server_id, server_group_id_in);
		end loop;
	end delete_set_from_servergroup;
	procedure clear_servergroup (
		server_group_id_in in number
	) is
		cursor servers is
			select	sgm.server_id	id
			from	rhnServerGroupMembers sgm
			where	sgm.server_group_id = server_group_id_in;
	begin
		for s in servers loop
			rhn_server.delete_from_servergroup(s.id, server_group_id_in);
		end loop;
	end clear_servergroup;
	procedure delete_from_org_servergroups (
		server_id_in in number
	) is
		cursor servergroups is
			select	sgm.server_group_id id
			from	rhnServerGroup sg,
					rhnServerGroupMembers sgm
			where	sgm.server_id = server_id_in
				and sgm.server_group_id = sg.id
				and sg.group_type is null;
	begin
		for sg in servergroups loop
			rhn_server.delete_from_servergroup(server_id_in, sg.id);
		end loop;
	end delete_from_org_servergroups;
	function get_ip_address (
		server_id_in in number
	) return varchar2 is
		cursor interfaces is
			select	name, ip_addr
			from	rhnServerNetInterface
			where	server_id = server_id_in
				and ip_addr != '127.0.0.1';
		cursor addresses is
			select	ipaddr ip_addr
			from	rhnServerNetwork
			where	server_id = server_id_in
				and ipaddr != '127.0.0.1';
	begin
		for addr in addresses loop
			return addr.ip_addr;
		end loop;
		for iface in interfaces loop
			return iface.ip_addr;
		end loop;
		return NULL;
	end get_ip_address;
end rhn_server;
/
SHOW ERRORS

select 'rhnsat/packages/rhn_user.pkb' sql_file from dual;
-- SQL relevant contents from file rhnsat/packages/rhn_user.pkb
create or replace
package body rhn_user
is
	body_version varchar2(100) := '';
    function check_role(user_id_in in number, role_in in varchar2)
    return number
    is
    	throwaway number;
    begin
	select 1 into throwaway
	  from rhnUserGroupType UGT,
	       rhnUserGroup UG,
	       rhnUserGroupMembers UGM
	 where UGM.user_id = user_id_in
	   and UGM.user_group_id = UG.id
	   and UG.group_type = UGT.id
	   and UGT.label = role_in;
	return 1;
    exception
    	when no_data_found
	    then
	    return 0;
    end check_role;
    function check_role_implied(user_id_in in number, role_in in varchar2)
    return number
    is
    	throwaway number;
    begin
    	if rhn_user.check_role(user_id_in, role_in) = 1
	then
	    return 1;
    	end if;
	if role_in = 'config_admin' and rhn_user.check_role(user_id_in, 'org_admin') = 1
	then
	    return 1;
	end if;
	if role_in = 'channel_admin' and rhn_user.check_role(user_id_in, 'org_admin') = 1
	then
	    return 1;
	end if;
	return 0;	
    end check_role_implied;
    function get_org_id(user_id_in in number)
    return number
    is
    	org_id_out number;
    begin
    	select org_id into org_id_out
	  from web_contact
	 where id = user_id_in;
	return org_id_out;
    end get_org_id;
	function find_mailable_address(user_id_in in number)
	return varchar2 is
		PRAGMA AUTONOMOUS_TRANSACTION;
		cursor addrs is
			select	ea.state_id, ea.address
			from	rhnEmailAddressState eas,
					rhnEmailAddress ea
			where	ea.user_id = user_id_in
				and eas.label = 'verified'
				and ea.state_id = eas.id
			union all
			select	ea.state_id, ea.address
			from	rhnEmailAddressState eas,
					rhnEmailAddress ea
			where	ea.user_id = user_id_in
				and eas.label = 'unverified'
				and ea.state_id = eas.id
			union all
			select	ea.state_id, ea.address
			from	rhnEmailAddressState eas,
					rhnEmailAddress ea
			where	ea.user_id = user_id_in
				and eas.label = 'pending'
				and ea.state_id = eas.id
			union all
			select	ea.state_id, ea.address
			from	rhnEmailAddressState eas,
					rhnEmailAddress ea
			where	ea.user_id = user_id_in
				and eas.label = 'pending_warned'
				and ea.state_id = eas.id
			union all
			select	ea.state_id, ea.address
			from	rhnEmailAddressState eas,
					rhnEmailAddress ea
			where	ea.user_id = user_id_in
				and eas.label = 'needs_verifying'
				and ea.state_id = eas.id
			union all
			select	-1 state_id,
					email address
			from	web_user_personal_info
			where	web_user_id = user_id_in;
		retval rhnEmailAddress.address%TYPE;
	begin
		for addr in addrs loop
			retval := addr.address;
			if addr.address is null then
				update web_user_contact_permission
					set email = 'N'
					where web_user_id = user_id_in;
				commit;
				return null;
			end if;
			if addr.state_id = -1 then
				insert into rhnEmailAddress (
						id, address,
						user_id, state_id
					) (
						select	rhn_eaddress_id_seq.nextval, addr.address,
								user_id_in, eas.id
						from	rhnEmailAddressState eas
						where	eas.label = 'unverified'
					);
			end if;
			commit;
			return retval;
		end loop;
		return null;
	end;
	procedure add_servergroup_perm(
		user_id_in in number,
		server_group_id_in in number
	) is
		cursor	orgs_match is
			select	1
			from	rhnServerGroup sg,
					web_contact u
			where	u.id = user_id_in
				and sg.id = server_group_id_in
				and sg.org_id = u.org_id;
	begin
		for okay in orgs_match loop
			insert into rhnUserServerGroupPerms(user_id, server_group_id)
				values (user_id_in, server_group_id_in);
			rhn_cache.update_perms_for_user(user_id_in);
			return;
		end loop;
		rhn_exception.raise_exception('usgp_different_orgs');
	exception when dup_val_on_index then
		rhn_exception.raise_exception('usgp_already_allowed');
	end add_servergroup_perm;
	procedure remove_servergroup_perm(
		user_id_in in number,
		server_group_id_in in number
	) is
		cursor perms is
			select	1
			from	rhnUserServerGroupPerms
			where	user_id = user_id_in
				and server_group_id = server_group_id_in;
	begin
		for perm in perms loop
			delete from rhnUserServerGroupPerms
				where	user_id = user_id_in
					and server_group_id = server_group_id_in;
			rhn_cache.update_perms_for_user(user_id_in);
			return;
		end loop;
		rhn_exception.raise_exception('usgp_not_allowed');
	end remove_servergroup_perm;
	procedure add_to_usergroup(
		user_id_in in number,
		user_group_id_in in number
	) is
		cursor perm_granting_usergroups is
			select	user_group_id_in
			from	rhnUserGroup		ug,
					rhnUserGroupType	ugt
			where	ugt.label in ('org_admin') -- and server_group_admin ?
				and ug.id = user_group_id_in
				and ug.group_type = ugt.id;
	begin
		insert into rhnUserGroupMembers(user_id, user_group_id)
			values (user_id_in, user_group_id_in);
		for ug in perm_granting_usergroups loop
			rhn_cache.update_perms_for_user(user_id_in);
			return;
		end loop;
	end add_to_usergroup;
	procedure add_users_to_usergroups(
		user_id_in in number
	) is
		cursor ugms is
			select	element user_id,
					element_two user_group_id
			from	rhnSet
			where	user_id = user_id_in
				and label = 'user_group_list';
	begin
		for ugm in ugms loop
			rhn_user.add_to_usergroup(ugm.user_id, ugm.user_group_id);
		end loop;
	end add_users_to_usergroups;
	procedure remove_from_usergroup(
		user_id_in in number,
		user_group_id_in in number
	) is
		cursor perm_granting_usergroups is
			select	label
			from	rhnUserGroupType	ugt,
					rhnUserGroupMembers	ugm,
					rhnUserGroup		ug
			where	1=1
				and ug.id = user_group_id_in
				and ugm.user_group_id = user_group_id_in
				and ug.group_type = ugt.id
				and ugm.user_id = user_id_in;
	begin
		for ug in perm_granting_usergroups loop
			delete from rhnUserGroupMembers
				where	user_id = user_id_in
					and user_group_id = user_group_id_in;
			if ug.label in ('org_admin') then
				rhn_cache.update_perms_for_user(user_id_in);
			end if;
		end loop;
	end remove_from_usergroup;
	procedure remove_users_from_servergroups(
		user_id_in in number
	) is
		cursor ugms is
			select	element user_id,
					element_two user_group_id
			from	rhnSet
			where	user_id = user_id_in
				and label = 'user_group_list';
	begin
		for ugm in ugms loop
			rhn_user.remove_from_usergroup(ugm.user_id, ugm.user_group_id);
		end loop;
	end remove_users_from_servergroups;
end rhn_user;
/
SHOW ERRORS

select 'rhnsat/tables/rhnVersionInfo_data.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/tables/rhnVersionInfo_data.sql
select '' sql_file from dual;
delete
from rhnVersionInfo
where label = 'schema'
 and name_id = lookup_package_name('spacewalk-schema');
insert into rhnVersionInfo(
 label,
 name_id,
 evr_id
) (
 select 'schema',
  lookup_package_name('spacewalk-schema'),
  lookup_evr(null, '0.4.17' , '1.el5' )
 from dual
);
commit;

select 'rhnsat/quit.sql' sql_file from dual;
-- SQL relevant contents from file rhnsat/quit.sql
quit;

